// Compiled by ClojureScript 1.10.520 {:static-fns true, :optimize-constants true}
goog.provide('clojure.data');
goog.require('cljs.core');
goog.require('cljs.core.constants');
goog.require('clojure.set');
/**
 * Internal helper for diff.
 */
clojure.data.atom_diff = (function clojure$data$atom_diff(a,b){
if(cljs.core._EQ_.cljs$core$IFn$_invoke$arity$2(a,b)){
return new cljs.core.PersistentVector(null, 3, 5, cljs.core.PersistentVector.EMPTY_NODE, [null,null,a], null);
} else {
return new cljs.core.PersistentVector(null, 3, 5, cljs.core.PersistentVector.EMPTY_NODE, [a,b,null], null);
}
});
/**
 * Convert an associative-by-numeric-index collection into
 * an equivalent vector, with nil for any missing keys
 */
clojure.data.vectorize = (function clojure$data$vectorize(m){
if(cljs.core.seq(m)){
return cljs.core.reduce.cljs$core$IFn$_invoke$arity$3((function (result,p__8566){
var vec__8567 = p__8566;
var k = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(vec__8567,(0),null);
var v = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(vec__8567,(1),null);
return cljs.core.assoc.cljs$core$IFn$_invoke$arity$3(result,k,v);
}),cljs.core.vec(cljs.core.repeat.cljs$core$IFn$_invoke$arity$2(cljs.core.apply.cljs$core$IFn$_invoke$arity$2(cljs.core.max,cljs.core.keys(m)),null)),m);
} else {
return null;
}
});
/**
 * Diff associative things a and b, comparing only the key k.
 */
clojure.data.diff_associative_key = (function clojure$data$diff_associative_key(a,b,k){
var va = cljs.core.get.cljs$core$IFn$_invoke$arity$2(a,k);
var vb = cljs.core.get.cljs$core$IFn$_invoke$arity$2(b,k);
var vec__8570 = clojure.data.diff(va,vb);
var a_STAR_ = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(vec__8570,(0),null);
var b_STAR_ = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(vec__8570,(1),null);
var ab = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(vec__8570,(2),null);
var in_a = cljs.core.contains_QMARK_(a,k);
var in_b = cljs.core.contains_QMARK_(b,k);
var same = ((in_a) && (in_b) && ((((!((ab == null)))) || ((((va == null)) && ((vb == null)))))));
return new cljs.core.PersistentVector(null, 3, 5, cljs.core.PersistentVector.EMPTY_NODE, [((((in_a) && ((((!((a_STAR_ == null)))) || ((!(same)))))))?cljs.core.PersistentArrayMap.createAsIfByAssoc([k,a_STAR_]):null),((((in_b) && ((((!((b_STAR_ == null)))) || ((!(same)))))))?cljs.core.PersistentArrayMap.createAsIfByAssoc([k,b_STAR_]):null),((same)?cljs.core.PersistentArrayMap.createAsIfByAssoc([k,ab]):null)], null);
});
/**
 * Diff associative things a and b, comparing only keys in ks (if supplied).
 */
clojure.data.diff_associative = (function clojure$data$diff_associative(var_args){
var G__8574 = arguments.length;
switch (G__8574) {
case 2:
return clojure.data.diff_associative.cljs$core$IFn$_invoke$arity$2((arguments[(0)]),(arguments[(1)]));

break;
case 3:
return clojure.data.diff_associative.cljs$core$IFn$_invoke$arity$3((arguments[(0)]),(arguments[(1)]),(arguments[(2)]));

break;
default:
throw (new Error(["Invalid arity: ",cljs.core.str.cljs$core$IFn$_invoke$arity$1(arguments.length)].join('')));

}
});

clojure.data.diff_associative.cljs$core$IFn$_invoke$arity$2 = (function (a,b){
return clojure.data.diff_associative.cljs$core$IFn$_invoke$arity$3(a,b,clojure.set.union.cljs$core$IFn$_invoke$arity$2(cljs.core.keys(a),cljs.core.keys(b)));
});

clojure.data.diff_associative.cljs$core$IFn$_invoke$arity$3 = (function (a,b,ks){
return cljs.core.reduce.cljs$core$IFn$_invoke$arity$3((function (diff1,diff2){
return cljs.core.doall.cljs$core$IFn$_invoke$arity$1(cljs.core.map.cljs$core$IFn$_invoke$arity$3(cljs.core.merge,diff1,diff2));
}),new cljs.core.PersistentVector(null, 3, 5, cljs.core.PersistentVector.EMPTY_NODE, [null,null,null], null),cljs.core.map.cljs$core$IFn$_invoke$arity$2(cljs.core.partial.cljs$core$IFn$_invoke$arity$3(clojure.data.diff_associative_key,a,b),ks));
});

clojure.data.diff_associative.cljs$lang$maxFixedArity = 3;

clojure.data.diff_sequential = (function clojure$data$diff_sequential(a,b){
return cljs.core.vec(cljs.core.map.cljs$core$IFn$_invoke$arity$2(clojure.data.vectorize,clojure.data.diff_associative.cljs$core$IFn$_invoke$arity$3(((cljs.core.vector_QMARK_(a))?a:cljs.core.vec(a)),((cljs.core.vector_QMARK_(b))?b:cljs.core.vec(b)),cljs.core.range.cljs$core$IFn$_invoke$arity$1((function (){var x__4219__auto__ = cljs.core.count(a);
var y__4220__auto__ = cljs.core.count(b);
return ((x__4219__auto__ > y__4220__auto__) ? x__4219__auto__ : y__4220__auto__);
})()))));
});
clojure.data.diff_set = (function clojure$data$diff_set(a,b){
return new cljs.core.PersistentVector(null, 3, 5, cljs.core.PersistentVector.EMPTY_NODE, [cljs.core.not_empty(clojure.set.difference.cljs$core$IFn$_invoke$arity$2(a,b)),cljs.core.not_empty(clojure.set.difference.cljs$core$IFn$_invoke$arity$2(b,a)),cljs.core.not_empty(clojure.set.intersection.cljs$core$IFn$_invoke$arity$2(a,b))], null);
});

/**
 * Implementation detail. Subject to change.
 * @interface
 */
clojure.data.EqualityPartition = function(){};

/**
 * Implementation detail. Subject to change.
 */
clojure.data.equality_partition = (function clojure$data$equality_partition(x){
if((((!((x == null)))) && ((!((x.clojure$data$EqualityPartition$equality_partition$arity$1 == null)))))){
return x.clojure$data$EqualityPartition$equality_partition$arity$1(x);
} else {
var x__4433__auto__ = (((x == null))?null:x);
var m__4434__auto__ = (clojure.data.equality_partition[goog.typeOf(x__4433__auto__)]);
if((!((m__4434__auto__ == null)))){
return (m__4434__auto__.cljs$core$IFn$_invoke$arity$1 ? m__4434__auto__.cljs$core$IFn$_invoke$arity$1(x) : m__4434__auto__.call(null,x));
} else {
var m__4431__auto__ = (clojure.data.equality_partition["_"]);
if((!((m__4431__auto__ == null)))){
return (m__4431__auto__.cljs$core$IFn$_invoke$arity$1 ? m__4431__auto__.cljs$core$IFn$_invoke$arity$1(x) : m__4431__auto__.call(null,x));
} else {
throw cljs.core.missing_protocol("EqualityPartition.equality-partition",x);
}
}
}
});


/**
 * Implementation detail. Subject to change.
 * @interface
 */
clojure.data.Diff = function(){};

/**
 * Implementation detail. Subject to change.
 */
clojure.data.diff_similar = (function clojure$data$diff_similar(a,b){
if((((!((a == null)))) && ((!((a.clojure$data$Diff$diff_similar$arity$2 == null)))))){
return a.clojure$data$Diff$diff_similar$arity$2(a,b);
} else {
var x__4433__auto__ = (((a == null))?null:a);
var m__4434__auto__ = (clojure.data.diff_similar[goog.typeOf(x__4433__auto__)]);
if((!((m__4434__auto__ == null)))){
return (m__4434__auto__.cljs$core$IFn$_invoke$arity$2 ? m__4434__auto__.cljs$core$IFn$_invoke$arity$2(a,b) : m__4434__auto__.call(null,a,b));
} else {
var m__4431__auto__ = (clojure.data.diff_similar["_"]);
if((!((m__4431__auto__ == null)))){
return (m__4431__auto__.cljs$core$IFn$_invoke$arity$2 ? m__4431__auto__.cljs$core$IFn$_invoke$arity$2(a,b) : m__4431__auto__.call(null,a,b));
} else {
throw cljs.core.missing_protocol("Diff.diff-similar",a);
}
}
}
});

goog.object.set(clojure.data.EqualityPartition,"null",true);

var G__8576_8600 = clojure.data.equality_partition;
var G__8577_8601 = "null";
var G__8578_8602 = ((function (G__8576_8600,G__8577_8601){
return (function (x){
return cljs.core.cst$kw$atom;
});})(G__8576_8600,G__8577_8601))
;
goog.object.set(G__8576_8600,G__8577_8601,G__8578_8602);

goog.object.set(clojure.data.EqualityPartition,"string",true);

var G__8579_8603 = clojure.data.equality_partition;
var G__8580_8604 = "string";
var G__8581_8605 = ((function (G__8579_8603,G__8580_8604){
return (function (x){
return cljs.core.cst$kw$atom;
});})(G__8579_8603,G__8580_8604))
;
goog.object.set(G__8579_8603,G__8580_8604,G__8581_8605);

goog.object.set(clojure.data.EqualityPartition,"number",true);

var G__8582_8606 = clojure.data.equality_partition;
var G__8583_8607 = "number";
var G__8584_8608 = ((function (G__8582_8606,G__8583_8607){
return (function (x){
return cljs.core.cst$kw$atom;
});})(G__8582_8606,G__8583_8607))
;
goog.object.set(G__8582_8606,G__8583_8607,G__8584_8608);

goog.object.set(clojure.data.EqualityPartition,"array",true);

var G__8585_8609 = clojure.data.equality_partition;
var G__8586_8610 = "array";
var G__8587_8611 = ((function (G__8585_8609,G__8586_8610){
return (function (x){
return cljs.core.cst$kw$sequential;
});})(G__8585_8609,G__8586_8610))
;
goog.object.set(G__8585_8609,G__8586_8610,G__8587_8611);

goog.object.set(clojure.data.EqualityPartition,"function",true);

var G__8588_8612 = clojure.data.equality_partition;
var G__8589_8613 = "function";
var G__8590_8614 = ((function (G__8588_8612,G__8589_8613){
return (function (x){
return cljs.core.cst$kw$atom;
});})(G__8588_8612,G__8589_8613))
;
goog.object.set(G__8588_8612,G__8589_8613,G__8590_8614);

goog.object.set(clojure.data.EqualityPartition,"boolean",true);

var G__8591_8615 = clojure.data.equality_partition;
var G__8592_8616 = "boolean";
var G__8593_8617 = ((function (G__8591_8615,G__8592_8616){
return (function (x){
return cljs.core.cst$kw$atom;
});})(G__8591_8615,G__8592_8616))
;
goog.object.set(G__8591_8615,G__8592_8616,G__8593_8617);

goog.object.set(clojure.data.EqualityPartition,"_",true);

var G__8594_8618 = clojure.data.equality_partition;
var G__8595_8619 = "_";
var G__8596_8620 = ((function (G__8594_8618,G__8595_8619){
return (function (x){
if((((!((x == null))))?(((((x.cljs$lang$protocol_mask$partition0$ & (1024))) || ((cljs.core.PROTOCOL_SENTINEL === x.cljs$core$IMap$))))?true:(((!x.cljs$lang$protocol_mask$partition0$))?cljs.core.native_satisfies_QMARK_(cljs.core.IMap,x):false)):cljs.core.native_satisfies_QMARK_(cljs.core.IMap,x))){
return cljs.core.cst$kw$map;
} else {
if((((!((x == null))))?(((((x.cljs$lang$protocol_mask$partition0$ & (4096))) || ((cljs.core.PROTOCOL_SENTINEL === x.cljs$core$ISet$))))?true:(((!x.cljs$lang$protocol_mask$partition0$))?cljs.core.native_satisfies_QMARK_(cljs.core.ISet,x):false)):cljs.core.native_satisfies_QMARK_(cljs.core.ISet,x))){
return cljs.core.cst$kw$set;
} else {
if((((!((x == null))))?(((((x.cljs$lang$protocol_mask$partition0$ & (16777216))) || ((cljs.core.PROTOCOL_SENTINEL === x.cljs$core$ISequential$))))?true:(((!x.cljs$lang$protocol_mask$partition0$))?cljs.core.native_satisfies_QMARK_(cljs.core.ISequential,x):false)):cljs.core.native_satisfies_QMARK_(cljs.core.ISequential,x))){
return cljs.core.cst$kw$sequential;
} else {
return cljs.core.cst$kw$atom;

}
}
}
});})(G__8594_8618,G__8595_8619))
;
goog.object.set(G__8594_8618,G__8595_8619,G__8596_8620);
goog.object.set(clojure.data.Diff,"null",true);

var G__8621_8645 = clojure.data.diff_similar;
var G__8622_8646 = "null";
var G__8623_8647 = ((function (G__8621_8645,G__8622_8646){
return (function (a,b){
return clojure.data.atom_diff(a,b);
});})(G__8621_8645,G__8622_8646))
;
goog.object.set(G__8621_8645,G__8622_8646,G__8623_8647);

goog.object.set(clojure.data.Diff,"string",true);

var G__8624_8648 = clojure.data.diff_similar;
var G__8625_8649 = "string";
var G__8626_8650 = ((function (G__8624_8648,G__8625_8649){
return (function (a,b){
return clojure.data.atom_diff(a,b);
});})(G__8624_8648,G__8625_8649))
;
goog.object.set(G__8624_8648,G__8625_8649,G__8626_8650);

goog.object.set(clojure.data.Diff,"number",true);

var G__8627_8651 = clojure.data.diff_similar;
var G__8628_8652 = "number";
var G__8629_8653 = ((function (G__8627_8651,G__8628_8652){
return (function (a,b){
return clojure.data.atom_diff(a,b);
});})(G__8627_8651,G__8628_8652))
;
goog.object.set(G__8627_8651,G__8628_8652,G__8629_8653);

goog.object.set(clojure.data.Diff,"array",true);

var G__8630_8654 = clojure.data.diff_similar;
var G__8631_8655 = "array";
var G__8632_8656 = ((function (G__8630_8654,G__8631_8655){
return (function (a,b){
return clojure.data.diff_sequential(a,b);
});})(G__8630_8654,G__8631_8655))
;
goog.object.set(G__8630_8654,G__8631_8655,G__8632_8656);

goog.object.set(clojure.data.Diff,"function",true);

var G__8633_8657 = clojure.data.diff_similar;
var G__8634_8658 = "function";
var G__8635_8659 = ((function (G__8633_8657,G__8634_8658){
return (function (a,b){
return clojure.data.atom_diff(a,b);
});})(G__8633_8657,G__8634_8658))
;
goog.object.set(G__8633_8657,G__8634_8658,G__8635_8659);

goog.object.set(clojure.data.Diff,"boolean",true);

var G__8636_8660 = clojure.data.diff_similar;
var G__8637_8661 = "boolean";
var G__8638_8662 = ((function (G__8636_8660,G__8637_8661){
return (function (a,b){
return clojure.data.atom_diff(a,b);
});})(G__8636_8660,G__8637_8661))
;
goog.object.set(G__8636_8660,G__8637_8661,G__8638_8662);

goog.object.set(clojure.data.Diff,"_",true);

var G__8639_8663 = clojure.data.diff_similar;
var G__8640_8664 = "_";
var G__8641_8665 = ((function (G__8639_8663,G__8640_8664){
return (function (a,b){
var fexpr__8643 = (function (){var G__8644 = clojure.data.equality_partition(a);
var G__8644__$1 = (((G__8644 instanceof cljs.core.Keyword))?G__8644.fqn:null);
switch (G__8644__$1) {
case "atom":
return clojure.data.atom_diff;

break;
case "set":
return clojure.data.diff_set;

break;
case "sequential":
return clojure.data.diff_sequential;

break;
case "map":
return clojure.data.diff_associative;

break;
default:
throw (new Error(["No matching clause: ",cljs.core.str.cljs$core$IFn$_invoke$arity$1(G__8644__$1)].join('')));

}
})();
return (fexpr__8643.cljs$core$IFn$_invoke$arity$2 ? fexpr__8643.cljs$core$IFn$_invoke$arity$2(a,b) : fexpr__8643.call(null,a,b));
});})(G__8639_8663,G__8640_8664))
;
goog.object.set(G__8639_8663,G__8640_8664,G__8641_8665);
/**
 * Recursively compares a and b, returning a tuple of
 *   [things-only-in-a things-only-in-b things-in-both].
 *   Comparison rules:
 * 
 *   * For equal a and b, return [nil nil a].
 *   * Maps are subdiffed where keys match and values differ.
 *   * Sets are never subdiffed.
 *   * All sequential things are treated as associative collections
 *  by their indexes, with results returned as vectors.
 *   * Everything else (including strings!) is treated as
 *  an atom and compared for equality.
 */
clojure.data.diff = (function clojure$data$diff(a,b){
if(cljs.core._EQ_.cljs$core$IFn$_invoke$arity$2(a,b)){
return new cljs.core.PersistentVector(null, 3, 5, cljs.core.PersistentVector.EMPTY_NODE, [null,null,a], null);
} else {
if(cljs.core._EQ_.cljs$core$IFn$_invoke$arity$2(clojure.data.equality_partition(a),clojure.data.equality_partition(b))){
return clojure.data.diff_similar(a,b);
} else {
return clojure.data.atom_diff(a,b);
}
}
});
