// Compiled by ClojureScript 1.10.520 {:static-fns true, :optimize-constants true}
goog.provide('cljs.cache');
goog.require('cljs.core');
goog.require('cljs.core.constants');
goog.require('tailrecursion.priority_map');

/**
 * This is the protocol describing the basic cache capability.
 * @interface
 */
cljs.cache.CacheProtocol = function(){};

/**
 * Retrieve the value associated with `e` if it exists, else `nil` in
 *   the 2-arg case. Retrieve the value associated with `e` if it exists,
 *   else `not-found` in the 3-arg case.
 */
cljs.cache.lookup = (function cljs$cache$lookup(var_args){
var G__116342 = arguments.length;
switch (G__116342) {
case 2:
return cljs.cache.lookup.cljs$core$IFn$_invoke$arity$2((arguments[(0)]),(arguments[(1)]));

break;
case 3:
return cljs.cache.lookup.cljs$core$IFn$_invoke$arity$3((arguments[(0)]),(arguments[(1)]),(arguments[(2)]));

break;
default:
throw (new Error(["Invalid arity: ",cljs.core.str.cljs$core$IFn$_invoke$arity$1(arguments.length)].join('')));

}
});

cljs.cache.lookup.cljs$core$IFn$_invoke$arity$2 = (function (cache,e){
if((((!((cache == null)))) && ((!((cache.cljs$cache$CacheProtocol$lookup$arity$2 == null)))))){
return cache.cljs$cache$CacheProtocol$lookup$arity$2(cache,e);
} else {
var x__4433__auto__ = (((cache == null))?null:cache);
var m__4434__auto__ = (cljs.cache.lookup[goog.typeOf(x__4433__auto__)]);
if((!((m__4434__auto__ == null)))){
return (m__4434__auto__.cljs$core$IFn$_invoke$arity$2 ? m__4434__auto__.cljs$core$IFn$_invoke$arity$2(cache,e) : m__4434__auto__.call(null,cache,e));
} else {
var m__4431__auto__ = (cljs.cache.lookup["_"]);
if((!((m__4431__auto__ == null)))){
return (m__4431__auto__.cljs$core$IFn$_invoke$arity$2 ? m__4431__auto__.cljs$core$IFn$_invoke$arity$2(cache,e) : m__4431__auto__.call(null,cache,e));
} else {
throw cljs.core.missing_protocol("CacheProtocol.lookup",cache);
}
}
}
});

cljs.cache.lookup.cljs$core$IFn$_invoke$arity$3 = (function (cache,e,not_found){
if((((!((cache == null)))) && ((!((cache.cljs$cache$CacheProtocol$lookup$arity$3 == null)))))){
return cache.cljs$cache$CacheProtocol$lookup$arity$3(cache,e,not_found);
} else {
var x__4433__auto__ = (((cache == null))?null:cache);
var m__4434__auto__ = (cljs.cache.lookup[goog.typeOf(x__4433__auto__)]);
if((!((m__4434__auto__ == null)))){
return (m__4434__auto__.cljs$core$IFn$_invoke$arity$3 ? m__4434__auto__.cljs$core$IFn$_invoke$arity$3(cache,e,not_found) : m__4434__auto__.call(null,cache,e,not_found));
} else {
var m__4431__auto__ = (cljs.cache.lookup["_"]);
if((!((m__4431__auto__ == null)))){
return (m__4431__auto__.cljs$core$IFn$_invoke$arity$3 ? m__4431__auto__.cljs$core$IFn$_invoke$arity$3(cache,e,not_found) : m__4431__auto__.call(null,cache,e,not_found));
} else {
throw cljs.core.missing_protocol("CacheProtocol.lookup",cache);
}
}
}
});

cljs.cache.lookup.cljs$lang$maxFixedArity = 3;


/**
 * Checks if the cache contains a value associated with `e`
 */
cljs.cache.has_QMARK_ = (function cljs$cache$has_QMARK_(cache,e){
if((((!((cache == null)))) && ((!((cache.cljs$cache$CacheProtocol$has_QMARK_$arity$2 == null)))))){
return cache.cljs$cache$CacheProtocol$has_QMARK_$arity$2(cache,e);
} else {
var x__4433__auto__ = (((cache == null))?null:cache);
var m__4434__auto__ = (cljs.cache.has_QMARK_[goog.typeOf(x__4433__auto__)]);
if((!((m__4434__auto__ == null)))){
return (m__4434__auto__.cljs$core$IFn$_invoke$arity$2 ? m__4434__auto__.cljs$core$IFn$_invoke$arity$2(cache,e) : m__4434__auto__.call(null,cache,e));
} else {
var m__4431__auto__ = (cljs.cache.has_QMARK_["_"]);
if((!((m__4431__auto__ == null)))){
return (m__4431__auto__.cljs$core$IFn$_invoke$arity$2 ? m__4431__auto__.cljs$core$IFn$_invoke$arity$2(cache,e) : m__4431__auto__.call(null,cache,e));
} else {
throw cljs.core.missing_protocol("CacheProtocol.has?",cache);
}
}
}
});

/**
 * Is meant to be called if the cache is determined to contain a value
 *   associated with `e`
 */
cljs.cache.hit = (function cljs$cache$hit(cache,e){
if((((!((cache == null)))) && ((!((cache.cljs$cache$CacheProtocol$hit$arity$2 == null)))))){
return cache.cljs$cache$CacheProtocol$hit$arity$2(cache,e);
} else {
var x__4433__auto__ = (((cache == null))?null:cache);
var m__4434__auto__ = (cljs.cache.hit[goog.typeOf(x__4433__auto__)]);
if((!((m__4434__auto__ == null)))){
return (m__4434__auto__.cljs$core$IFn$_invoke$arity$2 ? m__4434__auto__.cljs$core$IFn$_invoke$arity$2(cache,e) : m__4434__auto__.call(null,cache,e));
} else {
var m__4431__auto__ = (cljs.cache.hit["_"]);
if((!((m__4431__auto__ == null)))){
return (m__4431__auto__.cljs$core$IFn$_invoke$arity$2 ? m__4431__auto__.cljs$core$IFn$_invoke$arity$2(cache,e) : m__4431__auto__.call(null,cache,e));
} else {
throw cljs.core.missing_protocol("CacheProtocol.hit",cache);
}
}
}
});

/**
 * Is meant to be called if the cache is determined to **not** contain a
 *   value associated with `e`
 */
cljs.cache.miss = (function cljs$cache$miss(cache,e,ret){
if((((!((cache == null)))) && ((!((cache.cljs$cache$CacheProtocol$miss$arity$3 == null)))))){
return cache.cljs$cache$CacheProtocol$miss$arity$3(cache,e,ret);
} else {
var x__4433__auto__ = (((cache == null))?null:cache);
var m__4434__auto__ = (cljs.cache.miss[goog.typeOf(x__4433__auto__)]);
if((!((m__4434__auto__ == null)))){
return (m__4434__auto__.cljs$core$IFn$_invoke$arity$3 ? m__4434__auto__.cljs$core$IFn$_invoke$arity$3(cache,e,ret) : m__4434__auto__.call(null,cache,e,ret));
} else {
var m__4431__auto__ = (cljs.cache.miss["_"]);
if((!((m__4431__auto__ == null)))){
return (m__4431__auto__.cljs$core$IFn$_invoke$arity$3 ? m__4431__auto__.cljs$core$IFn$_invoke$arity$3(cache,e,ret) : m__4431__auto__.call(null,cache,e,ret));
} else {
throw cljs.core.missing_protocol("CacheProtocol.miss",cache);
}
}
}
});

/**
 * Removes an entry from the cache
 */
cljs.cache.evict = (function cljs$cache$evict(cache,e){
if((((!((cache == null)))) && ((!((cache.cljs$cache$CacheProtocol$evict$arity$2 == null)))))){
return cache.cljs$cache$CacheProtocol$evict$arity$2(cache,e);
} else {
var x__4433__auto__ = (((cache == null))?null:cache);
var m__4434__auto__ = (cljs.cache.evict[goog.typeOf(x__4433__auto__)]);
if((!((m__4434__auto__ == null)))){
return (m__4434__auto__.cljs$core$IFn$_invoke$arity$2 ? m__4434__auto__.cljs$core$IFn$_invoke$arity$2(cache,e) : m__4434__auto__.call(null,cache,e));
} else {
var m__4431__auto__ = (cljs.cache.evict["_"]);
if((!((m__4431__auto__ == null)))){
return (m__4431__auto__.cljs$core$IFn$_invoke$arity$2 ? m__4431__auto__.cljs$core$IFn$_invoke$arity$2(cache,e) : m__4431__auto__.call(null,cache,e));
} else {
throw cljs.core.missing_protocol("CacheProtocol.evict",cache);
}
}
}
});

/**
 * Is used to signal that the cache should be created with a seed.
 *   The contract is that said cache should return an instance of its
 *   own type.
 */
cljs.cache.seed = (function cljs$cache$seed(cache,base){
if((((!((cache == null)))) && ((!((cache.cljs$cache$CacheProtocol$seed$arity$2 == null)))))){
return cache.cljs$cache$CacheProtocol$seed$arity$2(cache,base);
} else {
var x__4433__auto__ = (((cache == null))?null:cache);
var m__4434__auto__ = (cljs.cache.seed[goog.typeOf(x__4433__auto__)]);
if((!((m__4434__auto__ == null)))){
return (m__4434__auto__.cljs$core$IFn$_invoke$arity$2 ? m__4434__auto__.cljs$core$IFn$_invoke$arity$2(cache,base) : m__4434__auto__.call(null,cache,base));
} else {
var m__4431__auto__ = (cljs.cache.seed["_"]);
if((!((m__4431__auto__ == null)))){
return (m__4431__auto__.cljs$core$IFn$_invoke$arity$2 ? m__4431__auto__.cljs$core$IFn$_invoke$arity$2(cache,base) : m__4431__auto__.call(null,cache,base));
} else {
throw cljs.core.missing_protocol("CacheProtocol.seed",cache);
}
}
}
});

cljs.cache.default_wrapper_fn = (function cljs$cache$default_wrapper_fn(p1__116344_SHARP_,p2__116345_SHARP_){
return (p1__116344_SHARP_.cljs$core$IFn$_invoke$arity$1 ? p1__116344_SHARP_.cljs$core$IFn$_invoke$arity$1(p2__116345_SHARP_) : p1__116344_SHARP_.call(null,p2__116345_SHARP_));
});
/**
 * The basic hit/miss logic for the cache system. Expects a wrap function and
 *   value function.  The wrap function takes the value function and the item in
 *   question and is expected to run the value function with the item whenever a
 *   cache miss occurs.  The intent is to hide any cache-specific cells from
 *   leaking into the cache logic itelf.
 */
cljs.cache.through = (function cljs$cache$through(var_args){
var G__116348 = arguments.length;
switch (G__116348) {
case 2:
return cljs.cache.through.cljs$core$IFn$_invoke$arity$2((arguments[(0)]),(arguments[(1)]));

break;
case 3:
return cljs.cache.through.cljs$core$IFn$_invoke$arity$3((arguments[(0)]),(arguments[(1)]),(arguments[(2)]));

break;
case 4:
return cljs.cache.through.cljs$core$IFn$_invoke$arity$4((arguments[(0)]),(arguments[(1)]),(arguments[(2)]),(arguments[(3)]));

break;
default:
throw (new Error(["Invalid arity: ",cljs.core.str.cljs$core$IFn$_invoke$arity$1(arguments.length)].join('')));

}
});

cljs.cache.through.cljs$core$IFn$_invoke$arity$2 = (function (cache,item){
return cljs.cache.through.cljs$core$IFn$_invoke$arity$4(cljs.cache.default_wrapper_fn,cljs.core.identity,cache,item);
});

cljs.cache.through.cljs$core$IFn$_invoke$arity$3 = (function (value_fn,cache,item){
return cljs.cache.through.cljs$core$IFn$_invoke$arity$4(cljs.cache.default_wrapper_fn,value_fn,cache,item);
});

cljs.cache.through.cljs$core$IFn$_invoke$arity$4 = (function (wrap_fn,value_fn,cache,item){
if(cljs.core.truth_(cljs.cache.has_QMARK_(cache,item))){
return cljs.cache.hit(cache,item);
} else {
return cljs.cache.miss(cache,item,(function (){var G__116349 = (function (p1__116346_SHARP_){
return (value_fn.cljs$core$IFn$_invoke$arity$1 ? value_fn.cljs$core$IFn$_invoke$arity$1(p1__116346_SHARP_) : value_fn.call(null,p1__116346_SHARP_));
});
var G__116350 = item;
return (wrap_fn.cljs$core$IFn$_invoke$arity$2 ? wrap_fn.cljs$core$IFn$_invoke$arity$2(G__116349,G__116350) : wrap_fn.call(null,G__116349,G__116350));
})());
}
});

cljs.cache.through.cljs$lang$maxFixedArity = 4;


/**
* @constructor
 * @implements {cljs.core.IEquiv}
 * @implements {cljs.core.ICollection}
 * @implements {cljs.core.IEmptyableCollection}
 * @implements {cljs.core.ICounted}
 * @implements {cljs.cache.CacheProtocol}
 * @implements {cljs.core.ISeqable}
 * @implements {cljs.core.IIterable}
 * @implements {cljs.cache.Object}
 * @implements {cljs.core.IAssociative}
 * @implements {cljs.core.IMap}
 * @implements {cljs.core.ILookup}
*/
cljs.cache.BasicCache = (function (cache){
this.cache = cache;
this.cljs$lang$protocol_mask$partition0$ = 10487566;
this.cljs$lang$protocol_mask$partition1$ = 131072;
});
cljs.cache.BasicCache.prototype.toString = (function (){
var self__ = this;
var _ = this;
return cljs.core.str.cljs$core$IFn$_invoke$arity$1(self__.cache);
});

cljs.cache.BasicCache.prototype.cljs$core$IEquiv$_equiv$arity$2 = (function (this__116323__auto__,other__116330__auto__){
var self__ = this;
var this__116323__auto____$1 = this;
return cljs.core._EQ_.cljs$core$IFn$_invoke$arity$2(other__116330__auto__,self__.cache);
});

cljs.cache.BasicCache.prototype.cljs$core$ICollection$_conj$arity$2 = (function (this__116323__auto__,elem__116329__auto__){
var self__ = this;
var this__116323__auto____$1 = this;
return this__116323__auto____$1.cljs$cache$CacheProtocol$seed$arity$2(null,(function (){var fexpr__116352 = cljs.core.cst$sym$cljs$cache_SLASH__DASH_conj;
return (fexpr__116352.cljs$core$IFn$_invoke$arity$2 ? fexpr__116352.cljs$core$IFn$_invoke$arity$2(self__.cache,elem__116329__auto__) : fexpr__116352.call(null,self__.cache,elem__116329__auto__));
})());
});

cljs.cache.BasicCache.prototype.cljs$core$IEmptyableCollection$_empty$arity$1 = (function (this__116323__auto__){
var self__ = this;
var this__116323__auto____$1 = this;
return this__116323__auto____$1.cljs$cache$CacheProtocol$seed$arity$2(null,(function (){var fexpr__116353 = cljs.core.cst$sym$cljs$cache_SLASH__DASH_empty;
return (fexpr__116353.cljs$core$IFn$_invoke$arity$1 ? fexpr__116353.cljs$core$IFn$_invoke$arity$1(self__.cache) : fexpr__116353.call(null,self__.cache));
})());
});

cljs.cache.BasicCache.prototype.cljs$core$ICounted$_count$arity$1 = (function (this__116323__auto__){
var self__ = this;
var this__116323__auto____$1 = this;
return cljs.core._count(self__.cache);
});

cljs.cache.BasicCache.prototype.cljs$core$ISeqable$_seq$arity$1 = (function (___116326__auto__){
var self__ = this;
var ___116326__auto____$1 = this;
return cljs.core._seq(self__.cache);
});

cljs.cache.BasicCache.prototype.cljs$cache$CacheProtocol$ = cljs.core.PROTOCOL_SENTINEL;

cljs.cache.BasicCache.prototype.cljs$cache$CacheProtocol$lookup$arity$2 = (function (_,item){
var self__ = this;
var ___$1 = this;
return cljs.core.get.cljs$core$IFn$_invoke$arity$2(self__.cache,item);
});

cljs.cache.BasicCache.prototype.cljs$cache$CacheProtocol$lookup$arity$3 = (function (_,item,not_found){
var self__ = this;
var ___$1 = this;
return cljs.core.get.cljs$core$IFn$_invoke$arity$3(self__.cache,item,not_found);
});

cljs.cache.BasicCache.prototype.cljs$cache$CacheProtocol$has_QMARK_$arity$2 = (function (_,item){
var self__ = this;
var ___$1 = this;
return cljs.core.contains_QMARK_(self__.cache,item);
});

cljs.cache.BasicCache.prototype.cljs$cache$CacheProtocol$hit$arity$2 = (function (this$,item){
var self__ = this;
var this$__$1 = this;
return this$__$1;
});

cljs.cache.BasicCache.prototype.cljs$cache$CacheProtocol$miss$arity$3 = (function (_,item,result){
var self__ = this;
var ___$1 = this;
return (new cljs.cache.BasicCache(cljs.core.assoc.cljs$core$IFn$_invoke$arity$3(self__.cache,item,result)));
});

cljs.cache.BasicCache.prototype.cljs$cache$CacheProtocol$evict$arity$2 = (function (_,key){
var self__ = this;
var ___$1 = this;
return (new cljs.cache.BasicCache(cljs.core.dissoc.cljs$core$IFn$_invoke$arity$2(self__.cache,key)));
});

cljs.cache.BasicCache.prototype.cljs$cache$CacheProtocol$seed$arity$2 = (function (_,base){
var self__ = this;
var ___$1 = this;
return (new cljs.cache.BasicCache(base));
});

cljs.cache.BasicCache.prototype.cljs$core$IIterable$_iterator$arity$1 = (function (___116326__auto__){
var self__ = this;
var ___116326__auto____$1 = this;
return self__.cache.iterator();
});

cljs.cache.BasicCache.prototype.cljs$core$IAssociative$_assoc$arity$3 = (function (this__116323__auto__,k__116327__auto__,v__116328__auto__){
var self__ = this;
var this__116323__auto____$1 = this;
return this__116323__auto____$1.cljs$cache$CacheProtocol$miss$arity$3(null,k__116327__auto__,v__116328__auto__);
});

cljs.cache.BasicCache.prototype.cljs$core$IAssociative$_contains_key_QMARK_$arity$2 = (function (this__116323__auto__,k__116327__auto__){
var self__ = this;
var this__116323__auto____$1 = this;
return this__116323__auto____$1.cljs$cache$CacheProtocol$has_QMARK_$arity$2(null,k__116327__auto__);
});

cljs.cache.BasicCache.prototype.cljs$core$IMap$_dissoc$arity$2 = (function (this__116323__auto__,k__116327__auto__){
var self__ = this;
var this__116323__auto____$1 = this;
return this__116323__auto____$1.cljs$cache$CacheProtocol$evict$arity$2(null,k__116327__auto__);
});

cljs.cache.BasicCache.prototype.cljs$core$ILookup$_lookup$arity$2 = (function (this__116323__auto__,key__116324__auto__){
var self__ = this;
var this__116323__auto____$1 = this;
return this__116323__auto____$1.cljs$core$ILookup$_lookup$arity$3(null,key__116324__auto__,null);
});

cljs.cache.BasicCache.prototype.cljs$core$ILookup$_lookup$arity$3 = (function (this__116323__auto__,key__116324__auto__,not_found__116325__auto__){
var self__ = this;
var this__116323__auto____$1 = this;
if(cljs.core.truth_(this__116323__auto____$1.cljs$cache$CacheProtocol$has_QMARK_$arity$2(null,key__116324__auto__))){
return this__116323__auto____$1.cljs$cache$CacheProtocol$lookup$arity$2(null,key__116324__auto__);
} else {
return not_found__116325__auto__;
}
});

cljs.cache.BasicCache.getBasis = (function (){
return new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [cljs.core.cst$sym$cache], null);
});

cljs.cache.BasicCache.cljs$lang$type = true;

cljs.cache.BasicCache.cljs$lang$ctorStr = "cljs.cache/BasicCache";

cljs.cache.BasicCache.cljs$lang$ctorPrWriter = (function (this__4374__auto__,writer__4375__auto__,opt__4376__auto__){
return cljs.core._write(writer__4375__auto__,"cljs.cache/BasicCache");
});

/**
 * Positional factory function for cljs.cache/BasicCache.
 */
cljs.cache.__GT_BasicCache = (function cljs$cache$__GT_BasicCache(cache){
return (new cljs.cache.BasicCache(cache));
});

cljs.cache.get_time = (function cljs$cache$get_time(){
return (new Date()).getTime();
});
/**
 * returns a fn that dissocs expired keys from a map
 */
cljs.cache.key_killer_fn = (function cljs$cache$key_killer_fn(ttl,expiry,now){
var ks = cljs.core.map.cljs$core$IFn$_invoke$arity$2(cljs.core.key,cljs.core.filter.cljs$core$IFn$_invoke$arity$2((function (p1__116354_SHARP_){
return ((now - cljs.core.val(p1__116354_SHARP_)) > expiry);
}),ttl));
return ((function (ks){
return (function (p1__116355_SHARP_){
return cljs.core.apply.cljs$core$IFn$_invoke$arity$3(cljs.core.dissoc,p1__116355_SHARP_,ks);
});
;})(ks))
});

/**
* @constructor
 * @implements {cljs.core.IEquiv}
 * @implements {cljs.core.ICollection}
 * @implements {cljs.core.IEmptyableCollection}
 * @implements {cljs.core.ICounted}
 * @implements {cljs.cache.CacheProtocol}
 * @implements {cljs.core.ISeqable}
 * @implements {cljs.core.IIterable}
 * @implements {cljs.cache.Object}
 * @implements {cljs.core.IAssociative}
 * @implements {cljs.core.IMap}
 * @implements {cljs.core.ILookup}
*/
cljs.cache.TTLCache = (function (cache,ttl,ttl_ms){
this.cache = cache;
this.ttl = ttl;
this.ttl_ms = ttl_ms;
this.cljs$lang$protocol_mask$partition0$ = 10487566;
this.cljs$lang$protocol_mask$partition1$ = 131072;
});
cljs.cache.TTLCache.prototype.toString = (function (){
var self__ = this;
var _ = this;
return [cljs.core.str.cljs$core$IFn$_invoke$arity$1(self__.cache),","," ",cljs.core.str.cljs$core$IFn$_invoke$arity$1(self__.ttl),","," ",cljs.core.str.cljs$core$IFn$_invoke$arity$1(self__.ttl_ms)].join('');
});

cljs.cache.TTLCache.prototype.cljs$core$IEquiv$_equiv$arity$2 = (function (this__116323__auto__,other__116330__auto__){
var self__ = this;
var this__116323__auto____$1 = this;
return cljs.core._EQ_.cljs$core$IFn$_invoke$arity$2(other__116330__auto__,self__.cache);
});

cljs.cache.TTLCache.prototype.cljs$core$ICollection$_conj$arity$2 = (function (this__116323__auto__,elem__116329__auto__){
var self__ = this;
var this__116323__auto____$1 = this;
return this__116323__auto____$1.cljs$cache$CacheProtocol$seed$arity$2(null,(function (){var fexpr__116356 = cljs.core.cst$sym$cljs$cache_SLASH__DASH_conj;
return (fexpr__116356.cljs$core$IFn$_invoke$arity$2 ? fexpr__116356.cljs$core$IFn$_invoke$arity$2(self__.cache,elem__116329__auto__) : fexpr__116356.call(null,self__.cache,elem__116329__auto__));
})());
});

cljs.cache.TTLCache.prototype.cljs$core$IEmptyableCollection$_empty$arity$1 = (function (this__116323__auto__){
var self__ = this;
var this__116323__auto____$1 = this;
return this__116323__auto____$1.cljs$cache$CacheProtocol$seed$arity$2(null,(function (){var fexpr__116357 = cljs.core.cst$sym$cljs$cache_SLASH__DASH_empty;
return (fexpr__116357.cljs$core$IFn$_invoke$arity$1 ? fexpr__116357.cljs$core$IFn$_invoke$arity$1(self__.cache) : fexpr__116357.call(null,self__.cache));
})());
});

cljs.cache.TTLCache.prototype.cljs$core$ICounted$_count$arity$1 = (function (this__116323__auto__){
var self__ = this;
var this__116323__auto____$1 = this;
return cljs.core._count(self__.cache);
});

cljs.cache.TTLCache.prototype.cljs$core$ISeqable$_seq$arity$1 = (function (___116326__auto__){
var self__ = this;
var ___116326__auto____$1 = this;
return cljs.core._seq(self__.cache);
});

cljs.cache.TTLCache.prototype.cljs$cache$CacheProtocol$ = cljs.core.PROTOCOL_SENTINEL;

cljs.cache.TTLCache.prototype.cljs$cache$CacheProtocol$lookup$arity$2 = (function (this$,item){
var self__ = this;
var this$__$1 = this;
var ret = this$__$1.cljs$cache$CacheProtocol$lookup$arity$3(null,item,cljs.core.cst$kw$cljs$cache_SLASH_nope);
if(cljs.core._EQ_.cljs$core$IFn$_invoke$arity$2(ret,cljs.core.cst$kw$cljs$cache_SLASH_nope)){
return null;
} else {
return ret;
}
});

cljs.cache.TTLCache.prototype.cljs$cache$CacheProtocol$lookup$arity$3 = (function (this$,item,not_found){
var self__ = this;
var this$__$1 = this;
if(cljs.core.truth_(this$__$1.cljs$cache$CacheProtocol$has_QMARK_$arity$2(null,item))){
return cljs.core.get.cljs$core$IFn$_invoke$arity$2(self__.cache,item);
} else {
return not_found;
}
});

cljs.cache.TTLCache.prototype.cljs$cache$CacheProtocol$has_QMARK_$arity$2 = (function (_,item){
var self__ = this;
var ___$1 = this;
var t = cljs.core.get.cljs$core$IFn$_invoke$arity$3(self__.ttl,item,(- self__.ttl_ms));
return ((cljs.cache.get_time() - t) < self__.ttl_ms);
});

cljs.cache.TTLCache.prototype.cljs$cache$CacheProtocol$hit$arity$2 = (function (this$,item){
var self__ = this;
var this$__$1 = this;
return this$__$1;
});

cljs.cache.TTLCache.prototype.cljs$cache$CacheProtocol$miss$arity$3 = (function (this$,item,result){
var self__ = this;
var this$__$1 = this;
var now = cljs.cache.get_time();
var kill_old = cljs.cache.key_killer_fn(self__.ttl,self__.ttl_ms,now);
return (new cljs.cache.TTLCache(cljs.core.assoc.cljs$core$IFn$_invoke$arity$3((kill_old.cljs$core$IFn$_invoke$arity$1 ? kill_old.cljs$core$IFn$_invoke$arity$1(self__.cache) : kill_old.call(null,self__.cache)),item,result),cljs.core.assoc.cljs$core$IFn$_invoke$arity$3((kill_old.cljs$core$IFn$_invoke$arity$1 ? kill_old.cljs$core$IFn$_invoke$arity$1(self__.ttl) : kill_old.call(null,self__.ttl)),item,now),self__.ttl_ms));
});

cljs.cache.TTLCache.prototype.cljs$cache$CacheProtocol$seed$arity$2 = (function (_,base){
var self__ = this;
var ___$1 = this;
var now = cljs.cache.get_time();
return (new cljs.cache.TTLCache(base,cljs.core.into.cljs$core$IFn$_invoke$arity$2(cljs.core.PersistentArrayMap.EMPTY,(function (){var iter__4523__auto__ = ((function (now,___$1){
return (function cljs$cache$iter__116358(s__116359){
return (new cljs.core.LazySeq(null,((function (now,___$1){
return (function (){
var s__116359__$1 = s__116359;
while(true){
var temp__5735__auto__ = cljs.core.seq(s__116359__$1);
if(temp__5735__auto__){
var s__116359__$2 = temp__5735__auto__;
if(cljs.core.chunked_seq_QMARK_(s__116359__$2)){
var c__4521__auto__ = cljs.core.chunk_first(s__116359__$2);
var size__4522__auto__ = cljs.core.count(c__4521__auto__);
var b__116361 = cljs.core.chunk_buffer(size__4522__auto__);
if((function (){var i__116360 = (0);
while(true){
if((i__116360 < size__4522__auto__)){
var x = cljs.core._nth.cljs$core$IFn$_invoke$arity$2(c__4521__auto__,i__116360);
cljs.core.chunk_append(b__116361,new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [cljs.core.key(x),now], null));

var G__116362 = (i__116360 + (1));
i__116360 = G__116362;
continue;
} else {
return true;
}
break;
}
})()){
return cljs.core.chunk_cons(cljs.core.chunk(b__116361),cljs$cache$iter__116358(cljs.core.chunk_rest(s__116359__$2)));
} else {
return cljs.core.chunk_cons(cljs.core.chunk(b__116361),null);
}
} else {
var x = cljs.core.first(s__116359__$2);
return cljs.core.cons(new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [cljs.core.key(x),now], null),cljs$cache$iter__116358(cljs.core.rest(s__116359__$2)));
}
} else {
return null;
}
break;
}
});})(now,___$1))
,null,null));
});})(now,___$1))
;
return iter__4523__auto__(base);
})()),self__.ttl_ms));
});

cljs.cache.TTLCache.prototype.cljs$cache$CacheProtocol$evict$arity$2 = (function (_,key){
var self__ = this;
var ___$1 = this;
return (new cljs.cache.TTLCache(cljs.core.dissoc.cljs$core$IFn$_invoke$arity$2(self__.cache,key),cljs.core.dissoc.cljs$core$IFn$_invoke$arity$2(self__.ttl,key),self__.ttl_ms));
});

cljs.cache.TTLCache.prototype.cljs$core$IIterable$_iterator$arity$1 = (function (___116326__auto__){
var self__ = this;
var ___116326__auto____$1 = this;
return self__.cache.iterator();
});

cljs.cache.TTLCache.prototype.cljs$core$IAssociative$_assoc$arity$3 = (function (this__116323__auto__,k__116327__auto__,v__116328__auto__){
var self__ = this;
var this__116323__auto____$1 = this;
return this__116323__auto____$1.cljs$cache$CacheProtocol$miss$arity$3(null,k__116327__auto__,v__116328__auto__);
});

cljs.cache.TTLCache.prototype.cljs$core$IAssociative$_contains_key_QMARK_$arity$2 = (function (this__116323__auto__,k__116327__auto__){
var self__ = this;
var this__116323__auto____$1 = this;
return this__116323__auto____$1.cljs$cache$CacheProtocol$has_QMARK_$arity$2(null,k__116327__auto__);
});

cljs.cache.TTLCache.prototype.cljs$core$IMap$_dissoc$arity$2 = (function (this__116323__auto__,k__116327__auto__){
var self__ = this;
var this__116323__auto____$1 = this;
return this__116323__auto____$1.cljs$cache$CacheProtocol$evict$arity$2(null,k__116327__auto__);
});

cljs.cache.TTLCache.prototype.cljs$core$ILookup$_lookup$arity$2 = (function (this__116323__auto__,key__116324__auto__){
var self__ = this;
var this__116323__auto____$1 = this;
return this__116323__auto____$1.cljs$core$ILookup$_lookup$arity$3(null,key__116324__auto__,null);
});

cljs.cache.TTLCache.prototype.cljs$core$ILookup$_lookup$arity$3 = (function (this__116323__auto__,key__116324__auto__,not_found__116325__auto__){
var self__ = this;
var this__116323__auto____$1 = this;
if(cljs.core.truth_(this__116323__auto____$1.cljs$cache$CacheProtocol$has_QMARK_$arity$2(null,key__116324__auto__))){
return this__116323__auto____$1.cljs$cache$CacheProtocol$lookup$arity$2(null,key__116324__auto__);
} else {
return not_found__116325__auto__;
}
});

cljs.cache.TTLCache.getBasis = (function (){
return new cljs.core.PersistentVector(null, 3, 5, cljs.core.PersistentVector.EMPTY_NODE, [cljs.core.cst$sym$cache,cljs.core.cst$sym$ttl,cljs.core.cst$sym$ttl_DASH_ms], null);
});

cljs.cache.TTLCache.cljs$lang$type = true;

cljs.cache.TTLCache.cljs$lang$ctorStr = "cljs.cache/TTLCache";

cljs.cache.TTLCache.cljs$lang$ctorPrWriter = (function (this__4374__auto__,writer__4375__auto__,opt__4376__auto__){
return cljs.core._write(writer__4375__auto__,"cljs.cache/TTLCache");
});

/**
 * Positional factory function for cljs.cache/TTLCache.
 */
cljs.cache.__GT_TTLCache = (function cljs$cache$__GT_TTLCache(cache,ttl,ttl_ms){
return (new cljs.cache.TTLCache(cache,ttl,ttl_ms));
});

cljs.cache.build_leastness_queue = (function cljs$cache$build_leastness_queue(base,limit,start_at){
return cljs.core.into.cljs$core$IFn$_invoke$arity$2(tailrecursion.priority_map.priority_map(),cljs.core.concat.cljs$core$IFn$_invoke$arity$2(cljs.core.take.cljs$core$IFn$_invoke$arity$2((limit - cljs.core.count(base)),(function (){var iter__4523__auto__ = (function cljs$cache$build_leastness_queue_$_iter__116363(s__116364){
return (new cljs.core.LazySeq(null,(function (){
var s__116364__$1 = s__116364;
while(true){
var temp__5735__auto__ = cljs.core.seq(s__116364__$1);
if(temp__5735__auto__){
var s__116364__$2 = temp__5735__auto__;
if(cljs.core.chunked_seq_QMARK_(s__116364__$2)){
var c__4521__auto__ = cljs.core.chunk_first(s__116364__$2);
var size__4522__auto__ = cljs.core.count(c__4521__auto__);
var b__116366 = cljs.core.chunk_buffer(size__4522__auto__);
if((function (){var i__116365 = (0);
while(true){
if((i__116365 < size__4522__auto__)){
var k = cljs.core._nth.cljs$core$IFn$_invoke$arity$2(c__4521__auto__,i__116365);
cljs.core.chunk_append(b__116366,new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [k,k], null));

var G__116377 = (i__116365 + (1));
i__116365 = G__116377;
continue;
} else {
return true;
}
break;
}
})()){
return cljs.core.chunk_cons(cljs.core.chunk(b__116366),cljs$cache$build_leastness_queue_$_iter__116363(cljs.core.chunk_rest(s__116364__$2)));
} else {
return cljs.core.chunk_cons(cljs.core.chunk(b__116366),null);
}
} else {
var k = cljs.core.first(s__116364__$2);
return cljs.core.cons(new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [k,k], null),cljs$cache$build_leastness_queue_$_iter__116363(cljs.core.rest(s__116364__$2)));
}
} else {
return null;
}
break;
}
}),null,null));
});
return iter__4523__auto__(cljs.core.range.cljs$core$IFn$_invoke$arity$2((- limit),(0)));
})()),(function (){var iter__4523__auto__ = (function cljs$cache$build_leastness_queue_$_iter__116367(s__116368){
return (new cljs.core.LazySeq(null,(function (){
var s__116368__$1 = s__116368;
while(true){
var temp__5735__auto__ = cljs.core.seq(s__116368__$1);
if(temp__5735__auto__){
var s__116368__$2 = temp__5735__auto__;
if(cljs.core.chunked_seq_QMARK_(s__116368__$2)){
var c__4521__auto__ = cljs.core.chunk_first(s__116368__$2);
var size__4522__auto__ = cljs.core.count(c__4521__auto__);
var b__116370 = cljs.core.chunk_buffer(size__4522__auto__);
if((function (){var i__116369 = (0);
while(true){
if((i__116369 < size__4522__auto__)){
var vec__116371 = cljs.core._nth.cljs$core$IFn$_invoke$arity$2(c__4521__auto__,i__116369);
var k = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(vec__116371,(0),null);
var _ = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(vec__116371,(1),null);
cljs.core.chunk_append(b__116370,new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [k,start_at], null));

var G__116378 = (i__116369 + (1));
i__116369 = G__116378;
continue;
} else {
return true;
}
break;
}
})()){
return cljs.core.chunk_cons(cljs.core.chunk(b__116370),cljs$cache$build_leastness_queue_$_iter__116367(cljs.core.chunk_rest(s__116368__$2)));
} else {
return cljs.core.chunk_cons(cljs.core.chunk(b__116370),null);
}
} else {
var vec__116374 = cljs.core.first(s__116368__$2);
var k = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(vec__116374,(0),null);
var _ = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(vec__116374,(1),null);
return cljs.core.cons(new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [k,start_at], null),cljs$cache$build_leastness_queue_$_iter__116367(cljs.core.rest(s__116368__$2)));
}
} else {
return null;
}
break;
}
}),null,null));
});
return iter__4523__auto__(base);
})()));
});

/**
* @constructor
 * @implements {cljs.core.IEquiv}
 * @implements {cljs.core.ICollection}
 * @implements {cljs.core.IEmptyableCollection}
 * @implements {cljs.core.ICounted}
 * @implements {cljs.cache.CacheProtocol}
 * @implements {cljs.core.ISeqable}
 * @implements {cljs.core.IIterable}
 * @implements {cljs.cache.Object}
 * @implements {cljs.core.IAssociative}
 * @implements {cljs.core.IMap}
 * @implements {cljs.core.ILookup}
*/
cljs.cache.LRUCache = (function (cache,lru,tick,limit){
this.cache = cache;
this.lru = lru;
this.tick = tick;
this.limit = limit;
this.cljs$lang$protocol_mask$partition0$ = 10487566;
this.cljs$lang$protocol_mask$partition1$ = 131072;
});
cljs.cache.LRUCache.prototype.toString = (function (){
var self__ = this;
var _ = this;
return [cljs.core.str.cljs$core$IFn$_invoke$arity$1(self__.cache),","," ",cljs.core.str.cljs$core$IFn$_invoke$arity$1(self__.lru),","," ",cljs.core.str.cljs$core$IFn$_invoke$arity$1(self__.tick),","," ",cljs.core.str.cljs$core$IFn$_invoke$arity$1(self__.limit)].join('');
});

cljs.cache.LRUCache.prototype.cljs$core$IEquiv$_equiv$arity$2 = (function (this__116323__auto__,other__116330__auto__){
var self__ = this;
var this__116323__auto____$1 = this;
return cljs.core._EQ_.cljs$core$IFn$_invoke$arity$2(other__116330__auto__,self__.cache);
});

cljs.cache.LRUCache.prototype.cljs$core$ICollection$_conj$arity$2 = (function (this__116323__auto__,elem__116329__auto__){
var self__ = this;
var this__116323__auto____$1 = this;
return this__116323__auto____$1.cljs$cache$CacheProtocol$seed$arity$2(null,(function (){var fexpr__116379 = cljs.core.cst$sym$cljs$cache_SLASH__DASH_conj;
return (fexpr__116379.cljs$core$IFn$_invoke$arity$2 ? fexpr__116379.cljs$core$IFn$_invoke$arity$2(self__.cache,elem__116329__auto__) : fexpr__116379.call(null,self__.cache,elem__116329__auto__));
})());
});

cljs.cache.LRUCache.prototype.cljs$core$IEmptyableCollection$_empty$arity$1 = (function (this__116323__auto__){
var self__ = this;
var this__116323__auto____$1 = this;
return this__116323__auto____$1.cljs$cache$CacheProtocol$seed$arity$2(null,(function (){var fexpr__116380 = cljs.core.cst$sym$cljs$cache_SLASH__DASH_empty;
return (fexpr__116380.cljs$core$IFn$_invoke$arity$1 ? fexpr__116380.cljs$core$IFn$_invoke$arity$1(self__.cache) : fexpr__116380.call(null,self__.cache));
})());
});

cljs.cache.LRUCache.prototype.cljs$core$ICounted$_count$arity$1 = (function (this__116323__auto__){
var self__ = this;
var this__116323__auto____$1 = this;
return cljs.core._count(self__.cache);
});

cljs.cache.LRUCache.prototype.cljs$core$ISeqable$_seq$arity$1 = (function (___116326__auto__){
var self__ = this;
var ___116326__auto____$1 = this;
return cljs.core._seq(self__.cache);
});

cljs.cache.LRUCache.prototype.cljs$cache$CacheProtocol$ = cljs.core.PROTOCOL_SENTINEL;

cljs.cache.LRUCache.prototype.cljs$cache$CacheProtocol$lookup$arity$2 = (function (_,item){
var self__ = this;
var ___$1 = this;
return cljs.core.get.cljs$core$IFn$_invoke$arity$2(self__.cache,item);
});

cljs.cache.LRUCache.prototype.cljs$cache$CacheProtocol$lookup$arity$3 = (function (_,item,not_found){
var self__ = this;
var ___$1 = this;
return cljs.core.get.cljs$core$IFn$_invoke$arity$3(self__.cache,item,not_found);
});

cljs.cache.LRUCache.prototype.cljs$cache$CacheProtocol$has_QMARK_$arity$2 = (function (_,item){
var self__ = this;
var ___$1 = this;
return cljs.core.contains_QMARK_(self__.cache,item);
});

cljs.cache.LRUCache.prototype.cljs$cache$CacheProtocol$hit$arity$2 = (function (_,item){
var self__ = this;
var ___$1 = this;
var tick_PLUS_ = (self__.tick + (1));
return (new cljs.cache.LRUCache(self__.cache,((cljs.core.contains_QMARK_(self__.cache,item))?cljs.core.assoc.cljs$core$IFn$_invoke$arity$3(self__.lru,item,tick_PLUS_):self__.lru),tick_PLUS_,self__.limit));
});

cljs.cache.LRUCache.prototype.cljs$cache$CacheProtocol$miss$arity$3 = (function (_,item,result){
var self__ = this;
var ___$1 = this;
var tick_PLUS_ = (self__.tick + (1));
if((cljs.core.count(self__.lru) >= self__.limit)){
var k = ((cljs.core.contains_QMARK_(self__.lru,item))?item:cljs.core.first(cljs.core.peek(self__.lru)));
var c = cljs.core.assoc.cljs$core$IFn$_invoke$arity$3(cljs.core.dissoc.cljs$core$IFn$_invoke$arity$2(self__.cache,k),item,result);
var l = cljs.core.assoc.cljs$core$IFn$_invoke$arity$3(cljs.core.dissoc.cljs$core$IFn$_invoke$arity$2(self__.lru,k),item,tick_PLUS_);
return (new cljs.cache.LRUCache(c,l,tick_PLUS_,self__.limit));
} else {
return (new cljs.cache.LRUCache(cljs.core.assoc.cljs$core$IFn$_invoke$arity$3(self__.cache,item,result),cljs.core.assoc.cljs$core$IFn$_invoke$arity$3(self__.lru,item,tick_PLUS_),tick_PLUS_,self__.limit));
}
});

cljs.cache.LRUCache.prototype.cljs$cache$CacheProtocol$evict$arity$2 = (function (this$,key){
var self__ = this;
var this$__$1 = this;
if(cljs.core.contains_QMARK_(self__.cache,key)){
return (new cljs.cache.LRUCache(cljs.core.dissoc.cljs$core$IFn$_invoke$arity$2(self__.cache,key),cljs.core.dissoc.cljs$core$IFn$_invoke$arity$2(self__.lru,key),(self__.tick + (1)),self__.limit));
} else {
return this$__$1;
}
});

cljs.cache.LRUCache.prototype.cljs$cache$CacheProtocol$seed$arity$2 = (function (_,base){
var self__ = this;
var ___$1 = this;
return (new cljs.cache.LRUCache(base,cljs.cache.build_leastness_queue(base,self__.limit,(0)),(0),self__.limit));
});

cljs.cache.LRUCache.prototype.cljs$core$IIterable$_iterator$arity$1 = (function (___116326__auto__){
var self__ = this;
var ___116326__auto____$1 = this;
return self__.cache.iterator();
});

cljs.cache.LRUCache.prototype.cljs$core$IAssociative$_assoc$arity$3 = (function (this__116323__auto__,k__116327__auto__,v__116328__auto__){
var self__ = this;
var this__116323__auto____$1 = this;
return this__116323__auto____$1.cljs$cache$CacheProtocol$miss$arity$3(null,k__116327__auto__,v__116328__auto__);
});

cljs.cache.LRUCache.prototype.cljs$core$IAssociative$_contains_key_QMARK_$arity$2 = (function (this__116323__auto__,k__116327__auto__){
var self__ = this;
var this__116323__auto____$1 = this;
return this__116323__auto____$1.cljs$cache$CacheProtocol$has_QMARK_$arity$2(null,k__116327__auto__);
});

cljs.cache.LRUCache.prototype.cljs$core$IMap$_dissoc$arity$2 = (function (this__116323__auto__,k__116327__auto__){
var self__ = this;
var this__116323__auto____$1 = this;
return this__116323__auto____$1.cljs$cache$CacheProtocol$evict$arity$2(null,k__116327__auto__);
});

cljs.cache.LRUCache.prototype.cljs$core$ILookup$_lookup$arity$2 = (function (this__116323__auto__,key__116324__auto__){
var self__ = this;
var this__116323__auto____$1 = this;
return this__116323__auto____$1.cljs$core$ILookup$_lookup$arity$3(null,key__116324__auto__,null);
});

cljs.cache.LRUCache.prototype.cljs$core$ILookup$_lookup$arity$3 = (function (this__116323__auto__,key__116324__auto__,not_found__116325__auto__){
var self__ = this;
var this__116323__auto____$1 = this;
if(cljs.core.truth_(this__116323__auto____$1.cljs$cache$CacheProtocol$has_QMARK_$arity$2(null,key__116324__auto__))){
return this__116323__auto____$1.cljs$cache$CacheProtocol$lookup$arity$2(null,key__116324__auto__);
} else {
return not_found__116325__auto__;
}
});

cljs.cache.LRUCache.getBasis = (function (){
return new cljs.core.PersistentVector(null, 4, 5, cljs.core.PersistentVector.EMPTY_NODE, [cljs.core.cst$sym$cache,cljs.core.cst$sym$lru,cljs.core.cst$sym$tick,cljs.core.cst$sym$limit], null);
});

cljs.cache.LRUCache.cljs$lang$type = true;

cljs.cache.LRUCache.cljs$lang$ctorStr = "cljs.cache/LRUCache";

cljs.cache.LRUCache.cljs$lang$ctorPrWriter = (function (this__4374__auto__,writer__4375__auto__,opt__4376__auto__){
return cljs.core._write(writer__4375__auto__,"cljs.cache/LRUCache");
});

/**
 * Positional factory function for cljs.cache/LRUCache.
 */
cljs.cache.__GT_LRUCache = (function cljs$cache$__GT_LRUCache(cache,lru,tick,limit){
return (new cljs.cache.LRUCache(cache,lru,tick,limit));
});

/**
 * Returns a pluggable basic cache initialied to `base`
 */
cljs.cache.basic_cache_factory = (function cljs$cache$basic_cache_factory(base){
if(cljs.core.map_QMARK_(base)){
} else {
throw (new Error("Assert failed: (map? base)"));
}

return (new cljs.cache.BasicCache(base));
});
/**
 * Returns a TTL cache with the cache and expiration-table initialied to `base` --
 * each with the same time-to-live.
 * 
 * This function also allows an optional `:ttl` argument that defines the default
 * time in milliseconds that entries are allowed to reside in the cache.
 */
cljs.cache.ttl_cache_factory = (function cljs$cache$ttl_cache_factory(var_args){
var args__4736__auto__ = [];
var len__4730__auto___116386 = arguments.length;
var i__4731__auto___116387 = (0);
while(true){
if((i__4731__auto___116387 < len__4730__auto___116386)){
args__4736__auto__.push((arguments[i__4731__auto___116387]));

var G__116388 = (i__4731__auto___116387 + (1));
i__4731__auto___116387 = G__116388;
continue;
} else {
}
break;
}

var argseq__4737__auto__ = ((((1) < args__4736__auto__.length))?(new cljs.core.IndexedSeq(args__4736__auto__.slice((1)),(0),null)):null);
return cljs.cache.ttl_cache_factory.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__4737__auto__);
});

cljs.cache.ttl_cache_factory.cljs$core$IFn$_invoke$arity$variadic = (function (base,p__116383){
var map__116384 = p__116383;
var map__116384__$1 = (((((!((map__116384 == null))))?(((((map__116384.cljs$lang$protocol_mask$partition0$ & (64))) || ((cljs.core.PROTOCOL_SENTINEL === map__116384.cljs$core$ISeq$))))?true:false):false))?cljs.core.apply.cljs$core$IFn$_invoke$arity$2(cljs.core.hash_map,map__116384):map__116384);
var ttl = cljs.core.get.cljs$core$IFn$_invoke$arity$3(map__116384__$1,cljs.core.cst$kw$ttl,(2000));
if(typeof ttl === 'number'){
} else {
throw (new Error("Assert failed: (number? ttl)"));
}

if(((0) <= ttl)){
} else {
throw (new Error("Assert failed: (<= 0 ttl)"));
}

if(cljs.core.map_QMARK_(base)){
} else {
throw (new Error("Assert failed: (map? base)"));
}

return (new cljs.cache.TTLCache(cljs.core.PersistentArrayMap.EMPTY,cljs.core.PersistentArrayMap.EMPTY,ttl)).cljs$cache$CacheProtocol$seed$arity$2(null,base);
});

cljs.cache.ttl_cache_factory.cljs$lang$maxFixedArity = (1);

/** @this {Function} */
cljs.cache.ttl_cache_factory.cljs$lang$applyTo = (function (seq116381){
var G__116382 = cljs.core.first(seq116381);
var seq116381__$1 = cljs.core.next(seq116381);
var self__4717__auto__ = this;
return self__4717__auto__.cljs$core$IFn$_invoke$arity$variadic(G__116382,seq116381__$1);
});

/**
 * Returns an LRU cache with the cache and usage-table initialied to `base` --
 * each entry is initialized with the same usage value.
 * This function takes an optional `:threshold` argument that defines the maximum number
 * of elements in the cache before the LRU semantics apply (default is 32).
 */
cljs.cache.lru_cache_factory = (function cljs$cache$lru_cache_factory(var_args){
var args__4736__auto__ = [];
var len__4730__auto___116394 = arguments.length;
var i__4731__auto___116395 = (0);
while(true){
if((i__4731__auto___116395 < len__4730__auto___116394)){
args__4736__auto__.push((arguments[i__4731__auto___116395]));

var G__116396 = (i__4731__auto___116395 + (1));
i__4731__auto___116395 = G__116396;
continue;
} else {
}
break;
}

var argseq__4737__auto__ = ((((1) < args__4736__auto__.length))?(new cljs.core.IndexedSeq(args__4736__auto__.slice((1)),(0),null)):null);
return cljs.cache.lru_cache_factory.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__4737__auto__);
});

cljs.cache.lru_cache_factory.cljs$core$IFn$_invoke$arity$variadic = (function (base,p__116391){
var map__116392 = p__116391;
var map__116392__$1 = (((((!((map__116392 == null))))?(((((map__116392.cljs$lang$protocol_mask$partition0$ & (64))) || ((cljs.core.PROTOCOL_SENTINEL === map__116392.cljs$core$ISeq$))))?true:false):false))?cljs.core.apply.cljs$core$IFn$_invoke$arity$2(cljs.core.hash_map,map__116392):map__116392);
var threshold = cljs.core.get.cljs$core$IFn$_invoke$arity$3(map__116392__$1,cljs.core.cst$kw$threshold,(32));
if(typeof threshold === 'number'){
} else {
throw (new Error("Assert failed: (number? threshold)"));
}

if(((0) < threshold)){
} else {
throw (new Error("Assert failed: (< 0 threshold)"));
}

if(cljs.core.map_QMARK_(base)){
} else {
throw (new Error("Assert failed: (map? base)"));
}

return (new cljs.cache.LRUCache(cljs.core.PersistentArrayMap.EMPTY,tailrecursion.priority_map.priority_map(),(0),threshold)).cljs$cache$CacheProtocol$seed$arity$2(null,base);
});

cljs.cache.lru_cache_factory.cljs$lang$maxFixedArity = (1);

/** @this {Function} */
cljs.cache.lru_cache_factory.cljs$lang$applyTo = (function (seq116389){
var G__116390 = cljs.core.first(seq116389);
var seq116389__$1 = cljs.core.next(seq116389);
var self__4717__auto__ = this;
return self__4717__auto__.cljs$core$IFn$_invoke$arity$variadic(G__116390,seq116389__$1);
});

