// Compiled by ClojureScript 1.10.520 {:target :nodejs}
goog.provide('cljs.source_map');
goog.require('cljs.core');
goog.require('goog.object');
goog.require('clojure.string');
goog.require('clojure.set');
goog.require('cljs.source_map.base64_vlq');
/**
 * Take a seq of source file names and return a map from
 * file number to integer index. For reverse source maps.
 */
cljs.source_map.indexed_sources = (function cljs$source_map$indexed_sources(sources){
return cljs.core.reduce.call(null,(function (m,p__114770){
var vec__114771 = p__114770;
var i = cljs.core.nth.call(null,vec__114771,(0),null);
var v = cljs.core.nth.call(null,vec__114771,(1),null);
return cljs.core.assoc.call(null,m,v,i);
}),cljs.core.PersistentArrayMap.EMPTY,cljs.core.map_indexed.call(null,(function (a,b){
return new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [a,b], null);
}),sources));
});
/**
 * Take a seq of source file names and return a comparator
 * that can be used to construct a sorted map. For reverse
 * source maps.
 */
cljs.source_map.source_compare = (function cljs$source_map$source_compare(sources){
var sources__$1 = cljs.source_map.indexed_sources.call(null,sources);
return ((function (sources__$1){
return (function (a,b){
return cljs.core.compare.call(null,sources__$1.call(null,a),sources__$1.call(null,b));
});
;})(sources__$1))
});
/**
 * Take a source map segment represented as a vector
 * and return a map.
 */
cljs.source_map.seg__GT_map = (function cljs$source_map$seg__GT_map(seg,source_map){
var vec__114774 = seg;
var gcol = cljs.core.nth.call(null,vec__114774,(0),null);
var source = cljs.core.nth.call(null,vec__114774,(1),null);
var line = cljs.core.nth.call(null,vec__114774,(2),null);
var col = cljs.core.nth.call(null,vec__114774,(3),null);
var name = cljs.core.nth.call(null,vec__114774,(4),null);
return new cljs.core.PersistentArrayMap(null, 5, [new cljs.core.Keyword(null,"gcol","gcol",309250807),gcol,new cljs.core.Keyword(null,"source","source",-433931539),(goog.object.get(source_map,"sources")[source]),new cljs.core.Keyword(null,"line","line",212345235),line,new cljs.core.Keyword(null,"col","col",-1959363084),col,new cljs.core.Keyword(null,"name","name",1843675177),(function (){var temp__5735__auto__ = new cljs.core.Keyword(null,"name","name",1843675177).cljs$core$IFn$_invoke$arity$1(cljs.core.meta.call(null,seg));
if(cljs.core.truth_(temp__5735__auto__)){
var name__$1 = temp__5735__auto__;
return (goog.object.get(source_map,"names")[name__$1]);
} else {
return null;
}
})()], null);
});
/**
 * Combine a source map segment vector and a relative
 * source map segment vector and combine them to get
 * an absolute segment posititon information as a vector.
 */
cljs.source_map.seg_combine = (function cljs$source_map$seg_combine(seg,relseg){
var vec__114777 = seg;
var gcol = cljs.core.nth.call(null,vec__114777,(0),null);
var source = cljs.core.nth.call(null,vec__114777,(1),null);
var line = cljs.core.nth.call(null,vec__114777,(2),null);
var col = cljs.core.nth.call(null,vec__114777,(3),null);
var name = cljs.core.nth.call(null,vec__114777,(4),null);
var vec__114780 = relseg;
var rgcol = cljs.core.nth.call(null,vec__114780,(0),null);
var rsource = cljs.core.nth.call(null,vec__114780,(1),null);
var rline = cljs.core.nth.call(null,vec__114780,(2),null);
var rcol = cljs.core.nth.call(null,vec__114780,(3),null);
var rname = cljs.core.nth.call(null,vec__114780,(4),null);
var nseg = new cljs.core.PersistentVector(null, 5, 5, cljs.core.PersistentVector.EMPTY_NODE, [(gcol + rgcol),((function (){var or__4131__auto__ = source;
if(cljs.core.truth_(or__4131__auto__)){
return or__4131__auto__;
} else {
return (0);
}
})() + rsource),((function (){var or__4131__auto__ = line;
if(cljs.core.truth_(or__4131__auto__)){
return or__4131__auto__;
} else {
return (0);
}
})() + rline),((function (){var or__4131__auto__ = col;
if(cljs.core.truth_(or__4131__auto__)){
return or__4131__auto__;
} else {
return (0);
}
})() + rcol),((function (){var or__4131__auto__ = name;
if(cljs.core.truth_(or__4131__auto__)){
return or__4131__auto__;
} else {
return (0);
}
})() + rname)], null);
if(cljs.core.truth_(name)){
return cljs.core.with_meta.call(null,nseg,new cljs.core.PersistentArrayMap(null, 1, [new cljs.core.Keyword(null,"name","name",1843675177),(name + rname)], null));
} else {
return nseg;
}
});
/**
 * Helper for decode-reverse. Take a reverse source map and
 *   update it with a segment map.
 */
cljs.source_map.update_reverse_result = (function cljs$source_map$update_reverse_result(result,segmap,gline){
var map__114783 = segmap;
var map__114783__$1 = (((((!((map__114783 == null))))?(((((map__114783.cljs$lang$protocol_mask$partition0$ & (64))) || ((cljs.core.PROTOCOL_SENTINEL === map__114783.cljs$core$ISeq$))))?true:false):false))?cljs.core.apply.call(null,cljs.core.hash_map,map__114783):map__114783);
var gcol = cljs.core.get.call(null,map__114783__$1,new cljs.core.Keyword(null,"gcol","gcol",309250807));
var source = cljs.core.get.call(null,map__114783__$1,new cljs.core.Keyword(null,"source","source",-433931539));
var line = cljs.core.get.call(null,map__114783__$1,new cljs.core.Keyword(null,"line","line",212345235));
var col = cljs.core.get.call(null,map__114783__$1,new cljs.core.Keyword(null,"col","col",-1959363084));
var name = cljs.core.get.call(null,map__114783__$1,new cljs.core.Keyword(null,"name","name",1843675177));
var d = new cljs.core.PersistentArrayMap(null, 2, [new cljs.core.Keyword(null,"gline","gline",-1086242431),gline,new cljs.core.Keyword(null,"gcol","gcol",309250807),gcol], null);
var d__$1 = (cljs.core.truth_(name)?cljs.core.assoc.call(null,d,new cljs.core.Keyword(null,"name","name",1843675177),name):d);
return cljs.core.update_in.call(null,result,new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [source], null),cljs.core.fnil.call(null,((function (map__114783,map__114783__$1,gcol,source,line,col,name,d,d__$1){
return (function (m){
return cljs.core.update_in.call(null,m,new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [line], null),cljs.core.fnil.call(null,((function (map__114783,map__114783__$1,gcol,source,line,col,name,d,d__$1){
return (function (m__$1){
return cljs.core.update_in.call(null,m__$1,new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [col], null),cljs.core.fnil.call(null,((function (map__114783,map__114783__$1,gcol,source,line,col,name,d,d__$1){
return (function (v){
return cljs.core.conj.call(null,v,d__$1);
});})(map__114783,map__114783__$1,gcol,source,line,col,name,d,d__$1))
,cljs.core.PersistentVector.EMPTY));
});})(map__114783,map__114783__$1,gcol,source,line,col,name,d,d__$1))
,cljs.core.sorted_map.call(null)));
});})(map__114783,map__114783__$1,gcol,source,line,col,name,d,d__$1))
,cljs.core.sorted_map.call(null)));
});
/**
 * Convert a v3 source map JSON object into a reverse source map
 *   mapping original ClojureScript source locations to the generated
 *   JavaScript.
 */
cljs.source_map.decode_reverse = (function cljs$source_map$decode_reverse(var_args){
var G__114786 = arguments.length;
switch (G__114786) {
case 1:
return cljs.source_map.decode_reverse.cljs$core$IFn$_invoke$arity$1((arguments[(0)]));

break;
case 2:
return cljs.source_map.decode_reverse.cljs$core$IFn$_invoke$arity$2((arguments[(0)]),(arguments[(1)]));

break;
default:
throw (new Error(["Invalid arity: ",cljs.core.str.cljs$core$IFn$_invoke$arity$1(arguments.length)].join('')));

}
});

cljs.source_map.decode_reverse.cljs$core$IFn$_invoke$arity$1 = (function (source_map){
return cljs.source_map.decode_reverse.call(null,goog.object.get(source_map,"mappings"),source_map);
});

cljs.source_map.decode_reverse.cljs$core$IFn$_invoke$arity$2 = (function (mappings,source_map){
var sources = goog.object.get(source_map,"sources");
var relseg_init = new cljs.core.PersistentVector(null, 5, 5, cljs.core.PersistentVector.EMPTY_NODE, [(0),(0),(0),(0),(0)], null);
var lines = cljs.core.seq.call(null,clojure.string.split.call(null,mappings,/;/));
var gline = (0);
var lines__$1 = lines;
var relseg = relseg_init;
var result = cljs.core.sorted_map_by.call(null,cljs.source_map.source_compare.call(null,sources));
while(true){
if(lines__$1){
var line = cljs.core.first.call(null,lines__$1);
var vec__114790 = ((clojure.string.blank_QMARK_.call(null,line))?new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [result,relseg], null):(function (){var segs = cljs.core.seq.call(null,clojure.string.split.call(null,line,/,/));
var segs__$1 = segs;
var relseg__$1 = relseg;
var result__$1 = result;
while(true){
if(segs__$1){
var seg = cljs.core.first.call(null,segs__$1);
var nrelseg = cljs.source_map.seg_combine.call(null,cljs.source_map.base64_vlq.decode.call(null,seg),relseg__$1);
var G__114794 = cljs.core.next.call(null,segs__$1);
var G__114795 = nrelseg;
var G__114796 = cljs.source_map.update_reverse_result.call(null,result__$1,cljs.source_map.seg__GT_map.call(null,nrelseg,source_map),gline);
segs__$1 = G__114794;
relseg__$1 = G__114795;
result__$1 = G__114796;
continue;
} else {
return new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [result__$1,relseg__$1], null);
}
break;
}
})());
var result__$1 = cljs.core.nth.call(null,vec__114790,(0),null);
var relseg__$1 = cljs.core.nth.call(null,vec__114790,(1),null);
var G__114797 = (gline + (1));
var G__114798 = cljs.core.next.call(null,lines__$1);
var G__114799 = cljs.core.assoc.call(null,relseg__$1,(0),(0));
var G__114800 = result__$1;
gline = G__114797;
lines__$1 = G__114798;
relseg = G__114799;
result = G__114800;
continue;
} else {
return result;
}
break;
}
});

cljs.source_map.decode_reverse.cljs$lang$maxFixedArity = 2;

/**
 * Helper for decode. Take a source map and update it based on a
 *   segment map.
 */
cljs.source_map.update_result = (function cljs$source_map$update_result(result,segmap,gline){
var map__114802 = segmap;
var map__114802__$1 = (((((!((map__114802 == null))))?(((((map__114802.cljs$lang$protocol_mask$partition0$ & (64))) || ((cljs.core.PROTOCOL_SENTINEL === map__114802.cljs$core$ISeq$))))?true:false):false))?cljs.core.apply.call(null,cljs.core.hash_map,map__114802):map__114802);
var gcol = cljs.core.get.call(null,map__114802__$1,new cljs.core.Keyword(null,"gcol","gcol",309250807));
var source = cljs.core.get.call(null,map__114802__$1,new cljs.core.Keyword(null,"source","source",-433931539));
var line = cljs.core.get.call(null,map__114802__$1,new cljs.core.Keyword(null,"line","line",212345235));
var col = cljs.core.get.call(null,map__114802__$1,new cljs.core.Keyword(null,"col","col",-1959363084));
var name = cljs.core.get.call(null,map__114802__$1,new cljs.core.Keyword(null,"name","name",1843675177));
var d = new cljs.core.PersistentArrayMap(null, 3, [new cljs.core.Keyword(null,"line","line",212345235),line,new cljs.core.Keyword(null,"col","col",-1959363084),col,new cljs.core.Keyword(null,"source","source",-433931539),source], null);
var d__$1 = (cljs.core.truth_(name)?cljs.core.assoc.call(null,d,new cljs.core.Keyword(null,"name","name",1843675177),name):d);
return cljs.core.update_in.call(null,result,new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [gline], null),cljs.core.fnil.call(null,((function (map__114802,map__114802__$1,gcol,source,line,col,name,d,d__$1){
return (function (m){
return cljs.core.update_in.call(null,m,new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [gcol], null),cljs.core.fnil.call(null,((function (map__114802,map__114802__$1,gcol,source,line,col,name,d,d__$1){
return (function (p1__114801_SHARP_){
return cljs.core.conj.call(null,p1__114801_SHARP_,d__$1);
});})(map__114802,map__114802__$1,gcol,source,line,col,name,d,d__$1))
,cljs.core.PersistentVector.EMPTY));
});})(map__114802,map__114802__$1,gcol,source,line,col,name,d,d__$1))
,cljs.core.sorted_map.call(null)));
});
/**
 * Convert a v3 source map JSON object into a source map mapping
 *   generated JavaScript source locations to the original
 *   ClojureScript.
 */
cljs.source_map.decode = (function cljs$source_map$decode(var_args){
var G__114805 = arguments.length;
switch (G__114805) {
case 1:
return cljs.source_map.decode.cljs$core$IFn$_invoke$arity$1((arguments[(0)]));

break;
case 2:
return cljs.source_map.decode.cljs$core$IFn$_invoke$arity$2((arguments[(0)]),(arguments[(1)]));

break;
default:
throw (new Error(["Invalid arity: ",cljs.core.str.cljs$core$IFn$_invoke$arity$1(arguments.length)].join('')));

}
});

cljs.source_map.decode.cljs$core$IFn$_invoke$arity$1 = (function (source_map){
return cljs.source_map.decode.call(null,goog.object.get(source_map,"mappings"),source_map);
});

cljs.source_map.decode.cljs$core$IFn$_invoke$arity$2 = (function (mappings,source_map){
var sources = goog.object.get(source_map,"sources");
var relseg_init = new cljs.core.PersistentVector(null, 5, 5, cljs.core.PersistentVector.EMPTY_NODE, [(0),(0),(0),(0),(0)], null);
var lines = cljs.core.seq.call(null,clojure.string.split.call(null,mappings,/;/));
var gline = (0);
var lines__$1 = lines;
var relseg = relseg_init;
var result = cljs.core.PersistentArrayMap.EMPTY;
while(true){
if(lines__$1){
var line = cljs.core.first.call(null,lines__$1);
var vec__114809 = ((clojure.string.blank_QMARK_.call(null,line))?new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [result,relseg], null):(function (){var segs = cljs.core.seq.call(null,clojure.string.split.call(null,line,/,/));
var segs__$1 = segs;
var relseg__$1 = relseg;
var result__$1 = result;
while(true){
if(segs__$1){
var seg = cljs.core.first.call(null,segs__$1);
var nrelseg = cljs.source_map.seg_combine.call(null,cljs.source_map.base64_vlq.decode.call(null,seg),relseg__$1);
var G__114813 = cljs.core.next.call(null,segs__$1);
var G__114814 = nrelseg;
var G__114815 = cljs.source_map.update_result.call(null,result__$1,cljs.source_map.seg__GT_map.call(null,nrelseg,source_map),gline);
segs__$1 = G__114813;
relseg__$1 = G__114814;
result__$1 = G__114815;
continue;
} else {
return new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [result__$1,relseg__$1], null);
}
break;
}
})());
var result__$1 = cljs.core.nth.call(null,vec__114809,(0),null);
var relseg__$1 = cljs.core.nth.call(null,vec__114809,(1),null);
var G__114816 = (gline + (1));
var G__114817 = cljs.core.next.call(null,lines__$1);
var G__114818 = cljs.core.assoc.call(null,relseg__$1,(0),(0));
var G__114819 = result__$1;
gline = G__114816;
lines__$1 = G__114817;
relseg = G__114818;
result = G__114819;
continue;
} else {
return result;
}
break;
}
});

cljs.source_map.decode.cljs$lang$maxFixedArity = 2;

/**
 * Take a nested sorted map encoding line and column information
 * for a file and return a vector of vectors of encoded segments.
 * Each vector represents a line, and the internal vectors are segments
 * representing the contents of the line.
 */
cljs.source_map.lines__GT_segs = (function cljs$source_map$lines__GT_segs(lines){
var relseg = cljs.core.atom.call(null,new cljs.core.PersistentVector(null, 5, 5, cljs.core.PersistentVector.EMPTY_NODE, [(0),(0),(0),(0),(0)], null));
return cljs.core.reduce.call(null,((function (relseg){
return (function (segs,cols){
cljs.core.swap_BANG_.call(null,relseg,((function (relseg){
return (function (p__114820){
var vec__114821 = p__114820;
var _ = cljs.core.nth.call(null,vec__114821,(0),null);
var source = cljs.core.nth.call(null,vec__114821,(1),null);
var line = cljs.core.nth.call(null,vec__114821,(2),null);
var col = cljs.core.nth.call(null,vec__114821,(3),null);
var name = cljs.core.nth.call(null,vec__114821,(4),null);
return new cljs.core.PersistentVector(null, 5, 5, cljs.core.PersistentVector.EMPTY_NODE, [(0),source,line,col,name], null);
});})(relseg))
);

return cljs.core.conj.call(null,segs,cljs.core.reduce.call(null,((function (relseg){
return (function (cols__$1,p__114824){
var vec__114825 = p__114824;
var gcol = cljs.core.nth.call(null,vec__114825,(0),null);
var sidx = cljs.core.nth.call(null,vec__114825,(1),null);
var line = cljs.core.nth.call(null,vec__114825,(2),null);
var col = cljs.core.nth.call(null,vec__114825,(3),null);
var name = cljs.core.nth.call(null,vec__114825,(4),null);
var seg = vec__114825;
var offset = cljs.core.map.call(null,cljs.core._,seg,cljs.core.deref.call(null,relseg));
cljs.core.swap_BANG_.call(null,relseg,((function (offset,vec__114825,gcol,sidx,line,col,name,seg,relseg){
return (function (p__114828){
var vec__114829 = p__114828;
var _ = cljs.core.nth.call(null,vec__114829,(0),null);
var ___$1 = cljs.core.nth.call(null,vec__114829,(1),null);
var ___$2 = cljs.core.nth.call(null,vec__114829,(2),null);
var ___$3 = cljs.core.nth.call(null,vec__114829,(3),null);
var lname = cljs.core.nth.call(null,vec__114829,(4),null);
return new cljs.core.PersistentVector(null, 5, 5, cljs.core.PersistentVector.EMPTY_NODE, [gcol,sidx,line,col,(function (){var or__4131__auto__ = name;
if(cljs.core.truth_(or__4131__auto__)){
return or__4131__auto__;
} else {
return lname;
}
})()], null);
});})(offset,vec__114825,gcol,sidx,line,col,name,seg,relseg))
);

return cljs.core.conj.call(null,cols__$1,cljs.source_map.base64_vlq.encode.call(null,offset));
});})(relseg))
,cljs.core.PersistentVector.EMPTY,cols));
});})(relseg))
,cljs.core.PersistentVector.EMPTY,lines);
});
/**
 * Take an internal source map representation represented as nested
 * sorted maps of file, line, column and return a source map v3 JSON
 * string.
 */
cljs.source_map.encode = (function cljs$source_map$encode(m,opts){
var lines = cljs.core.atom.call(null,new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [cljs.core.PersistentVector.EMPTY], null));
var names__GT_idx = cljs.core.atom.call(null,cljs.core.PersistentArrayMap.EMPTY);
var name_idx = cljs.core.atom.call(null,(0));
var preamble_lines = cljs.core.take.call(null,(function (){var or__4131__auto__ = new cljs.core.Keyword(null,"preamble-line-count","preamble-line-count",-659949744).cljs$core$IFn$_invoke$arity$1(opts);
if(cljs.core.truth_(or__4131__auto__)){
return or__4131__auto__;
} else {
return (0);
}
})(),cljs.core.repeat.call(null,cljs.core.PersistentVector.EMPTY));
var info__GT_segv = ((function (lines,names__GT_idx,name_idx,preamble_lines){
return (function (info,source_idx,line,col){
var segv = new cljs.core.PersistentVector(null, 4, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"gcol","gcol",309250807).cljs$core$IFn$_invoke$arity$1(info),source_idx,line,col], null);
var temp__5733__auto__ = new cljs.core.Keyword(null,"name","name",1843675177).cljs$core$IFn$_invoke$arity$1(info);
if(cljs.core.truth_(temp__5733__auto__)){
var name = temp__5733__auto__;
var idx = (function (){var temp__5733__auto____$1 = cljs.core.get.call(null,cljs.core.deref.call(null,names__GT_idx),name);
if(cljs.core.truth_(temp__5733__auto____$1)){
var idx = temp__5733__auto____$1;
return idx;
} else {
var cidx = cljs.core.deref.call(null,name_idx);
cljs.core.swap_BANG_.call(null,names__GT_idx,cljs.core.assoc,name,cidx);

cljs.core.swap_BANG_.call(null,name_idx,cljs.core.inc);

return cidx;
}
})();
return cljs.core.conj.call(null,segv,idx);
} else {
return segv;
}
});})(lines,names__GT_idx,name_idx,preamble_lines))
;
var encode_cols = ((function (lines,names__GT_idx,name_idx,preamble_lines,info__GT_segv){
return (function (infos,source_idx,line,col){
var seq__114835 = cljs.core.seq.call(null,infos);
var chunk__114836 = null;
var count__114837 = (0);
var i__114838 = (0);
while(true){
if((i__114838 < count__114837)){
var info = cljs.core._nth.call(null,chunk__114836,i__114838);
var segv_115189 = info__GT_segv.call(null,info,source_idx,line,col);
var gline_115190 = new cljs.core.Keyword(null,"gline","gline",-1086242431).cljs$core$IFn$_invoke$arity$1(info);
var lc_115191 = cljs.core.count.call(null,cljs.core.deref.call(null,lines));
if((gline_115190 > (lc_115191 - (1)))){
cljs.core.swap_BANG_.call(null,lines,((function (seq__114835,chunk__114836,count__114837,i__114838,segv_115189,gline_115190,lc_115191,info,lines,names__GT_idx,name_idx,preamble_lines,info__GT_segv){
return (function (lines__$1){
return cljs.core.conj.call(null,cljs.core.into.call(null,lines__$1,cljs.core.repeat.call(null,((gline_115190 - (lc_115191 - (1))) - (1)),cljs.core.PersistentVector.EMPTY)),new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [segv_115189], null));
});})(seq__114835,chunk__114836,count__114837,i__114838,segv_115189,gline_115190,lc_115191,info,lines,names__GT_idx,name_idx,preamble_lines,info__GT_segv))
);
} else {
cljs.core.swap_BANG_.call(null,lines,((function (seq__114835,chunk__114836,count__114837,i__114838,segv_115189,gline_115190,lc_115191,info,lines,names__GT_idx,name_idx,preamble_lines,info__GT_segv){
return (function (lines__$1){
return cljs.core.update_in.call(null,lines__$1,new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [gline_115190], null),cljs.core.conj,segv_115189);
});})(seq__114835,chunk__114836,count__114837,i__114838,segv_115189,gline_115190,lc_115191,info,lines,names__GT_idx,name_idx,preamble_lines,info__GT_segv))
);
}


var G__115192 = seq__114835;
var G__115193 = chunk__114836;
var G__115194 = count__114837;
var G__115195 = (i__114838 + (1));
seq__114835 = G__115192;
chunk__114836 = G__115193;
count__114837 = G__115194;
i__114838 = G__115195;
continue;
} else {
var temp__5735__auto__ = cljs.core.seq.call(null,seq__114835);
if(temp__5735__auto__){
var seq__114835__$1 = temp__5735__auto__;
if(cljs.core.chunked_seq_QMARK_.call(null,seq__114835__$1)){
var c__4550__auto__ = cljs.core.chunk_first.call(null,seq__114835__$1);
var G__115196 = cljs.core.chunk_rest.call(null,seq__114835__$1);
var G__115197 = c__4550__auto__;
var G__115198 = cljs.core.count.call(null,c__4550__auto__);
var G__115199 = (0);
seq__114835 = G__115196;
chunk__114836 = G__115197;
count__114837 = G__115198;
i__114838 = G__115199;
continue;
} else {
var info = cljs.core.first.call(null,seq__114835__$1);
var segv_115200 = info__GT_segv.call(null,info,source_idx,line,col);
var gline_115201 = new cljs.core.Keyword(null,"gline","gline",-1086242431).cljs$core$IFn$_invoke$arity$1(info);
var lc_115202 = cljs.core.count.call(null,cljs.core.deref.call(null,lines));
if((gline_115201 > (lc_115202 - (1)))){
cljs.core.swap_BANG_.call(null,lines,((function (seq__114835,chunk__114836,count__114837,i__114838,segv_115200,gline_115201,lc_115202,info,seq__114835__$1,temp__5735__auto__,lines,names__GT_idx,name_idx,preamble_lines,info__GT_segv){
return (function (lines__$1){
return cljs.core.conj.call(null,cljs.core.into.call(null,lines__$1,cljs.core.repeat.call(null,((gline_115201 - (lc_115202 - (1))) - (1)),cljs.core.PersistentVector.EMPTY)),new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [segv_115200], null));
});})(seq__114835,chunk__114836,count__114837,i__114838,segv_115200,gline_115201,lc_115202,info,seq__114835__$1,temp__5735__auto__,lines,names__GT_idx,name_idx,preamble_lines,info__GT_segv))
);
} else {
cljs.core.swap_BANG_.call(null,lines,((function (seq__114835,chunk__114836,count__114837,i__114838,segv_115200,gline_115201,lc_115202,info,seq__114835__$1,temp__5735__auto__,lines,names__GT_idx,name_idx,preamble_lines,info__GT_segv){
return (function (lines__$1){
return cljs.core.update_in.call(null,lines__$1,new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [gline_115201], null),cljs.core.conj,segv_115200);
});})(seq__114835,chunk__114836,count__114837,i__114838,segv_115200,gline_115201,lc_115202,info,seq__114835__$1,temp__5735__auto__,lines,names__GT_idx,name_idx,preamble_lines,info__GT_segv))
);
}


var G__115203 = cljs.core.next.call(null,seq__114835__$1);
var G__115204 = null;
var G__115205 = (0);
var G__115206 = (0);
seq__114835 = G__115203;
chunk__114836 = G__115204;
count__114837 = G__115205;
i__114838 = G__115206;
continue;
}
} else {
return null;
}
}
break;
}
});})(lines,names__GT_idx,name_idx,preamble_lines,info__GT_segv))
;
var seq__114839_115207 = cljs.core.seq.call(null,cljs.core.map_indexed.call(null,((function (lines,names__GT_idx,name_idx,preamble_lines,info__GT_segv,encode_cols){
return (function (i,v){
return new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [i,v], null);
});})(lines,names__GT_idx,name_idx,preamble_lines,info__GT_segv,encode_cols))
,m));
var chunk__114840_115208 = null;
var count__114841_115209 = (0);
var i__114842_115210 = (0);
while(true){
if((i__114842_115210 < count__114841_115209)){
var vec__115015_115211 = cljs.core._nth.call(null,chunk__114840_115208,i__114842_115210);
var source_idx_115212 = cljs.core.nth.call(null,vec__115015_115211,(0),null);
var vec__115018_115213 = cljs.core.nth.call(null,vec__115015_115211,(1),null);
var __115214 = cljs.core.nth.call(null,vec__115018_115213,(0),null);
var lines_115215__$1 = cljs.core.nth.call(null,vec__115018_115213,(1),null);
var seq__115021_115216 = cljs.core.seq.call(null,lines_115215__$1);
var chunk__115022_115217 = null;
var count__115023_115218 = (0);
var i__115024_115219 = (0);
while(true){
if((i__115024_115219 < count__115023_115218)){
var vec__115063_115220 = cljs.core._nth.call(null,chunk__115022_115217,i__115024_115219);
var line_115221 = cljs.core.nth.call(null,vec__115063_115220,(0),null);
var cols_115222 = cljs.core.nth.call(null,vec__115063_115220,(1),null);
var seq__115066_115223 = cljs.core.seq.call(null,cols_115222);
var chunk__115067_115224 = null;
var count__115068_115225 = (0);
var i__115069_115226 = (0);
while(true){
if((i__115069_115226 < count__115068_115225)){
var vec__115076_115227 = cljs.core._nth.call(null,chunk__115067_115224,i__115069_115226);
var col_115228 = cljs.core.nth.call(null,vec__115076_115227,(0),null);
var infos_115229 = cljs.core.nth.call(null,vec__115076_115227,(1),null);
encode_cols.call(null,infos_115229,source_idx_115212,line_115221,col_115228);


var G__115230 = seq__115066_115223;
var G__115231 = chunk__115067_115224;
var G__115232 = count__115068_115225;
var G__115233 = (i__115069_115226 + (1));
seq__115066_115223 = G__115230;
chunk__115067_115224 = G__115231;
count__115068_115225 = G__115232;
i__115069_115226 = G__115233;
continue;
} else {
var temp__5735__auto___115234 = cljs.core.seq.call(null,seq__115066_115223);
if(temp__5735__auto___115234){
var seq__115066_115235__$1 = temp__5735__auto___115234;
if(cljs.core.chunked_seq_QMARK_.call(null,seq__115066_115235__$1)){
var c__4550__auto___115236 = cljs.core.chunk_first.call(null,seq__115066_115235__$1);
var G__115237 = cljs.core.chunk_rest.call(null,seq__115066_115235__$1);
var G__115238 = c__4550__auto___115236;
var G__115239 = cljs.core.count.call(null,c__4550__auto___115236);
var G__115240 = (0);
seq__115066_115223 = G__115237;
chunk__115067_115224 = G__115238;
count__115068_115225 = G__115239;
i__115069_115226 = G__115240;
continue;
} else {
var vec__115079_115241 = cljs.core.first.call(null,seq__115066_115235__$1);
var col_115242 = cljs.core.nth.call(null,vec__115079_115241,(0),null);
var infos_115243 = cljs.core.nth.call(null,vec__115079_115241,(1),null);
encode_cols.call(null,infos_115243,source_idx_115212,line_115221,col_115242);


var G__115244 = cljs.core.next.call(null,seq__115066_115235__$1);
var G__115245 = null;
var G__115246 = (0);
var G__115247 = (0);
seq__115066_115223 = G__115244;
chunk__115067_115224 = G__115245;
count__115068_115225 = G__115246;
i__115069_115226 = G__115247;
continue;
}
} else {
}
}
break;
}


var G__115248 = seq__115021_115216;
var G__115249 = chunk__115022_115217;
var G__115250 = count__115023_115218;
var G__115251 = (i__115024_115219 + (1));
seq__115021_115216 = G__115248;
chunk__115022_115217 = G__115249;
count__115023_115218 = G__115250;
i__115024_115219 = G__115251;
continue;
} else {
var temp__5735__auto___115252 = cljs.core.seq.call(null,seq__115021_115216);
if(temp__5735__auto___115252){
var seq__115021_115253__$1 = temp__5735__auto___115252;
if(cljs.core.chunked_seq_QMARK_.call(null,seq__115021_115253__$1)){
var c__4550__auto___115254 = cljs.core.chunk_first.call(null,seq__115021_115253__$1);
var G__115255 = cljs.core.chunk_rest.call(null,seq__115021_115253__$1);
var G__115256 = c__4550__auto___115254;
var G__115257 = cljs.core.count.call(null,c__4550__auto___115254);
var G__115258 = (0);
seq__115021_115216 = G__115255;
chunk__115022_115217 = G__115256;
count__115023_115218 = G__115257;
i__115024_115219 = G__115258;
continue;
} else {
var vec__115082_115259 = cljs.core.first.call(null,seq__115021_115253__$1);
var line_115260 = cljs.core.nth.call(null,vec__115082_115259,(0),null);
var cols_115261 = cljs.core.nth.call(null,vec__115082_115259,(1),null);
var seq__115085_115262 = cljs.core.seq.call(null,cols_115261);
var chunk__115086_115263 = null;
var count__115087_115264 = (0);
var i__115088_115265 = (0);
while(true){
if((i__115088_115265 < count__115087_115264)){
var vec__115095_115266 = cljs.core._nth.call(null,chunk__115086_115263,i__115088_115265);
var col_115267 = cljs.core.nth.call(null,vec__115095_115266,(0),null);
var infos_115268 = cljs.core.nth.call(null,vec__115095_115266,(1),null);
encode_cols.call(null,infos_115268,source_idx_115212,line_115260,col_115267);


var G__115269 = seq__115085_115262;
var G__115270 = chunk__115086_115263;
var G__115271 = count__115087_115264;
var G__115272 = (i__115088_115265 + (1));
seq__115085_115262 = G__115269;
chunk__115086_115263 = G__115270;
count__115087_115264 = G__115271;
i__115088_115265 = G__115272;
continue;
} else {
var temp__5735__auto___115273__$1 = cljs.core.seq.call(null,seq__115085_115262);
if(temp__5735__auto___115273__$1){
var seq__115085_115274__$1 = temp__5735__auto___115273__$1;
if(cljs.core.chunked_seq_QMARK_.call(null,seq__115085_115274__$1)){
var c__4550__auto___115275 = cljs.core.chunk_first.call(null,seq__115085_115274__$1);
var G__115276 = cljs.core.chunk_rest.call(null,seq__115085_115274__$1);
var G__115277 = c__4550__auto___115275;
var G__115278 = cljs.core.count.call(null,c__4550__auto___115275);
var G__115279 = (0);
seq__115085_115262 = G__115276;
chunk__115086_115263 = G__115277;
count__115087_115264 = G__115278;
i__115088_115265 = G__115279;
continue;
} else {
var vec__115098_115280 = cljs.core.first.call(null,seq__115085_115274__$1);
var col_115281 = cljs.core.nth.call(null,vec__115098_115280,(0),null);
var infos_115282 = cljs.core.nth.call(null,vec__115098_115280,(1),null);
encode_cols.call(null,infos_115282,source_idx_115212,line_115260,col_115281);


var G__115283 = cljs.core.next.call(null,seq__115085_115274__$1);
var G__115284 = null;
var G__115285 = (0);
var G__115286 = (0);
seq__115085_115262 = G__115283;
chunk__115086_115263 = G__115284;
count__115087_115264 = G__115285;
i__115088_115265 = G__115286;
continue;
}
} else {
}
}
break;
}


var G__115287 = cljs.core.next.call(null,seq__115021_115253__$1);
var G__115288 = null;
var G__115289 = (0);
var G__115290 = (0);
seq__115021_115216 = G__115287;
chunk__115022_115217 = G__115288;
count__115023_115218 = G__115289;
i__115024_115219 = G__115290;
continue;
}
} else {
}
}
break;
}


var G__115291 = seq__114839_115207;
var G__115292 = chunk__114840_115208;
var G__115293 = count__114841_115209;
var G__115294 = (i__114842_115210 + (1));
seq__114839_115207 = G__115291;
chunk__114840_115208 = G__115292;
count__114841_115209 = G__115293;
i__114842_115210 = G__115294;
continue;
} else {
var temp__5735__auto___115295 = cljs.core.seq.call(null,seq__114839_115207);
if(temp__5735__auto___115295){
var seq__114839_115296__$1 = temp__5735__auto___115295;
if(cljs.core.chunked_seq_QMARK_.call(null,seq__114839_115296__$1)){
var c__4550__auto___115297 = cljs.core.chunk_first.call(null,seq__114839_115296__$1);
var G__115298 = cljs.core.chunk_rest.call(null,seq__114839_115296__$1);
var G__115299 = c__4550__auto___115297;
var G__115300 = cljs.core.count.call(null,c__4550__auto___115297);
var G__115301 = (0);
seq__114839_115207 = G__115298;
chunk__114840_115208 = G__115299;
count__114841_115209 = G__115300;
i__114842_115210 = G__115301;
continue;
} else {
var vec__115101_115302 = cljs.core.first.call(null,seq__114839_115296__$1);
var source_idx_115303 = cljs.core.nth.call(null,vec__115101_115302,(0),null);
var vec__115104_115304 = cljs.core.nth.call(null,vec__115101_115302,(1),null);
var __115305 = cljs.core.nth.call(null,vec__115104_115304,(0),null);
var lines_115306__$1 = cljs.core.nth.call(null,vec__115104_115304,(1),null);
var seq__115107_115307 = cljs.core.seq.call(null,lines_115306__$1);
var chunk__115108_115308 = null;
var count__115109_115309 = (0);
var i__115110_115310 = (0);
while(true){
if((i__115110_115310 < count__115109_115309)){
var vec__115149_115311 = cljs.core._nth.call(null,chunk__115108_115308,i__115110_115310);
var line_115312 = cljs.core.nth.call(null,vec__115149_115311,(0),null);
var cols_115313 = cljs.core.nth.call(null,vec__115149_115311,(1),null);
var seq__115152_115314 = cljs.core.seq.call(null,cols_115313);
var chunk__115153_115315 = null;
var count__115154_115316 = (0);
var i__115155_115317 = (0);
while(true){
if((i__115155_115317 < count__115154_115316)){
var vec__115162_115318 = cljs.core._nth.call(null,chunk__115153_115315,i__115155_115317);
var col_115319 = cljs.core.nth.call(null,vec__115162_115318,(0),null);
var infos_115320 = cljs.core.nth.call(null,vec__115162_115318,(1),null);
encode_cols.call(null,infos_115320,source_idx_115303,line_115312,col_115319);


var G__115321 = seq__115152_115314;
var G__115322 = chunk__115153_115315;
var G__115323 = count__115154_115316;
var G__115324 = (i__115155_115317 + (1));
seq__115152_115314 = G__115321;
chunk__115153_115315 = G__115322;
count__115154_115316 = G__115323;
i__115155_115317 = G__115324;
continue;
} else {
var temp__5735__auto___115325__$1 = cljs.core.seq.call(null,seq__115152_115314);
if(temp__5735__auto___115325__$1){
var seq__115152_115326__$1 = temp__5735__auto___115325__$1;
if(cljs.core.chunked_seq_QMARK_.call(null,seq__115152_115326__$1)){
var c__4550__auto___115327 = cljs.core.chunk_first.call(null,seq__115152_115326__$1);
var G__115328 = cljs.core.chunk_rest.call(null,seq__115152_115326__$1);
var G__115329 = c__4550__auto___115327;
var G__115330 = cljs.core.count.call(null,c__4550__auto___115327);
var G__115331 = (0);
seq__115152_115314 = G__115328;
chunk__115153_115315 = G__115329;
count__115154_115316 = G__115330;
i__115155_115317 = G__115331;
continue;
} else {
var vec__115165_115332 = cljs.core.first.call(null,seq__115152_115326__$1);
var col_115333 = cljs.core.nth.call(null,vec__115165_115332,(0),null);
var infos_115334 = cljs.core.nth.call(null,vec__115165_115332,(1),null);
encode_cols.call(null,infos_115334,source_idx_115303,line_115312,col_115333);


var G__115335 = cljs.core.next.call(null,seq__115152_115326__$1);
var G__115336 = null;
var G__115337 = (0);
var G__115338 = (0);
seq__115152_115314 = G__115335;
chunk__115153_115315 = G__115336;
count__115154_115316 = G__115337;
i__115155_115317 = G__115338;
continue;
}
} else {
}
}
break;
}


var G__115339 = seq__115107_115307;
var G__115340 = chunk__115108_115308;
var G__115341 = count__115109_115309;
var G__115342 = (i__115110_115310 + (1));
seq__115107_115307 = G__115339;
chunk__115108_115308 = G__115340;
count__115109_115309 = G__115341;
i__115110_115310 = G__115342;
continue;
} else {
var temp__5735__auto___115343__$1 = cljs.core.seq.call(null,seq__115107_115307);
if(temp__5735__auto___115343__$1){
var seq__115107_115344__$1 = temp__5735__auto___115343__$1;
if(cljs.core.chunked_seq_QMARK_.call(null,seq__115107_115344__$1)){
var c__4550__auto___115345 = cljs.core.chunk_first.call(null,seq__115107_115344__$1);
var G__115346 = cljs.core.chunk_rest.call(null,seq__115107_115344__$1);
var G__115347 = c__4550__auto___115345;
var G__115348 = cljs.core.count.call(null,c__4550__auto___115345);
var G__115349 = (0);
seq__115107_115307 = G__115346;
chunk__115108_115308 = G__115347;
count__115109_115309 = G__115348;
i__115110_115310 = G__115349;
continue;
} else {
var vec__115168_115350 = cljs.core.first.call(null,seq__115107_115344__$1);
var line_115351 = cljs.core.nth.call(null,vec__115168_115350,(0),null);
var cols_115352 = cljs.core.nth.call(null,vec__115168_115350,(1),null);
var seq__115171_115353 = cljs.core.seq.call(null,cols_115352);
var chunk__115172_115354 = null;
var count__115173_115355 = (0);
var i__115174_115356 = (0);
while(true){
if((i__115174_115356 < count__115173_115355)){
var vec__115181_115357 = cljs.core._nth.call(null,chunk__115172_115354,i__115174_115356);
var col_115358 = cljs.core.nth.call(null,vec__115181_115357,(0),null);
var infos_115359 = cljs.core.nth.call(null,vec__115181_115357,(1),null);
encode_cols.call(null,infos_115359,source_idx_115303,line_115351,col_115358);


var G__115360 = seq__115171_115353;
var G__115361 = chunk__115172_115354;
var G__115362 = count__115173_115355;
var G__115363 = (i__115174_115356 + (1));
seq__115171_115353 = G__115360;
chunk__115172_115354 = G__115361;
count__115173_115355 = G__115362;
i__115174_115356 = G__115363;
continue;
} else {
var temp__5735__auto___115364__$2 = cljs.core.seq.call(null,seq__115171_115353);
if(temp__5735__auto___115364__$2){
var seq__115171_115365__$1 = temp__5735__auto___115364__$2;
if(cljs.core.chunked_seq_QMARK_.call(null,seq__115171_115365__$1)){
var c__4550__auto___115366 = cljs.core.chunk_first.call(null,seq__115171_115365__$1);
var G__115367 = cljs.core.chunk_rest.call(null,seq__115171_115365__$1);
var G__115368 = c__4550__auto___115366;
var G__115369 = cljs.core.count.call(null,c__4550__auto___115366);
var G__115370 = (0);
seq__115171_115353 = G__115367;
chunk__115172_115354 = G__115368;
count__115173_115355 = G__115369;
i__115174_115356 = G__115370;
continue;
} else {
var vec__115184_115371 = cljs.core.first.call(null,seq__115171_115365__$1);
var col_115372 = cljs.core.nth.call(null,vec__115184_115371,(0),null);
var infos_115373 = cljs.core.nth.call(null,vec__115184_115371,(1),null);
encode_cols.call(null,infos_115373,source_idx_115303,line_115351,col_115372);


var G__115374 = cljs.core.next.call(null,seq__115171_115365__$1);
var G__115375 = null;
var G__115376 = (0);
var G__115377 = (0);
seq__115171_115353 = G__115374;
chunk__115172_115354 = G__115375;
count__115173_115355 = G__115376;
i__115174_115356 = G__115377;
continue;
}
} else {
}
}
break;
}


var G__115378 = cljs.core.next.call(null,seq__115107_115344__$1);
var G__115379 = null;
var G__115380 = (0);
var G__115381 = (0);
seq__115107_115307 = G__115378;
chunk__115108_115308 = G__115379;
count__115109_115309 = G__115380;
i__115110_115310 = G__115381;
continue;
}
} else {
}
}
break;
}


var G__115382 = cljs.core.next.call(null,seq__114839_115296__$1);
var G__115383 = null;
var G__115384 = (0);
var G__115385 = (0);
seq__114839_115207 = G__115382;
chunk__114840_115208 = G__115383;
count__114841_115209 = G__115384;
i__114842_115210 = G__115385;
continue;
}
} else {
}
}
break;
}

var source_map_file_contents = (function (){var G__115187 = ({"version": (3), "file": new cljs.core.Keyword(null,"file","file",-1269645878).cljs$core$IFn$_invoke$arity$1(opts), "sources": (function (){var paths = cljs.core.keys.call(null,m);
var f = cljs.core.comp.call(null,((new cljs.core.Keyword(null,"source-map-timestamp","source-map-timestamp",1973015633).cljs$core$IFn$_invoke$arity$1(opts) === true)?((function (paths,lines,names__GT_idx,name_idx,preamble_lines,info__GT_segv,encode_cols){
return (function (p1__114832_SHARP_){
return [cljs.core.str.cljs$core$IFn$_invoke$arity$1(p1__114832_SHARP_),"?rel=",cljs.core.str.cljs$core$IFn$_invoke$arity$1((new Date()).valueOf())].join('');
});})(paths,lines,names__GT_idx,name_idx,preamble_lines,info__GT_segv,encode_cols))
:cljs.core.identity),((function (paths,lines,names__GT_idx,name_idx,preamble_lines,info__GT_segv,encode_cols){
return (function (p1__114833_SHARP_){
return cljs.core.last.call(null,clojure.string.split.call(null,p1__114833_SHARP_,/\//));
});})(paths,lines,names__GT_idx,name_idx,preamble_lines,info__GT_segv,encode_cols))
);
return cljs.core.into_array.call(null,cljs.core.map.call(null,f,paths));
})(), "lineCount": new cljs.core.Keyword(null,"lines","lines",-700165781).cljs$core$IFn$_invoke$arity$1(opts), "mappings": clojure.string.join.call(null,";",cljs.core.map.call(null,((function (lines,names__GT_idx,name_idx,preamble_lines,info__GT_segv,encode_cols){
return (function (p1__114834_SHARP_){
return clojure.string.join.call(null,",",p1__114834_SHARP_);
});})(lines,names__GT_idx,name_idx,preamble_lines,info__GT_segv,encode_cols))
,cljs.source_map.lines__GT_segs.call(null,cljs.core.concat.call(null,preamble_lines,cljs.core.deref.call(null,lines))))), "names": cljs.core.into_array.call(null,cljs.core.map.call(null,clojure.set.map_invert.call(null,cljs.core.deref.call(null,names__GT_idx)),cljs.core.range.call(null,cljs.core.count.call(null,cljs.core.deref.call(null,names__GT_idx)))))});
if(cljs.core.truth_(new cljs.core.Keyword(null,"sources-content","sources-content",1729970239).cljs$core$IFn$_invoke$arity$1(opts))){
var G__115188 = G__115187;
goog.object.set(G__115188,"sourcesContent",cljs.core.into_array.call(null,new cljs.core.Keyword(null,"sources-content","sources-content",1729970239).cljs$core$IFn$_invoke$arity$1(opts)));

return G__115188;
} else {
return G__115187;
}
})();
return JSON.stringify(source_map_file_contents);
});
/**
 * Merge an internal source map representation of a single
 * ClojureScript file mapping original to generated with a
 * second source map mapping original JS to generated JS.
 * The is to support source maps that work through multiple
 * compilation steps like Google Closure optimization passes.
 */
cljs.source_map.merge_source_maps = (function cljs$source_map$merge_source_maps(cljs_map,js_map){
var line_map_seq = cljs.core.seq.call(null,cljs_map);
var new_lines = cljs.core.sorted_map.call(null);
while(true){
if(line_map_seq){
var vec__115386 = cljs.core.first.call(null,line_map_seq);
var line = cljs.core.nth.call(null,vec__115386,(0),null);
var col_map = cljs.core.nth.call(null,vec__115386,(1),null);
var new_cols = (function (){var col_map_seq = cljs.core.seq.call(null,col_map);
var new_cols = cljs.core.sorted_map.call(null);
while(true){
if(col_map_seq){
var vec__115389 = cljs.core.first.call(null,col_map_seq);
var col = cljs.core.nth.call(null,vec__115389,(0),null);
var infos = cljs.core.nth.call(null,vec__115389,(1),null);
var G__115395 = cljs.core.next.call(null,col_map_seq);
var G__115396 = cljs.core.assoc.call(null,new_cols,col,cljs.core.reduce.call(null,((function (col_map_seq,new_cols,line_map_seq,new_lines,vec__115389,col,infos,vec__115386,line,col_map){
return (function (v,p__115392){
var map__115393 = p__115392;
var map__115393__$1 = (((((!((map__115393 == null))))?(((((map__115393.cljs$lang$protocol_mask$partition0$ & (64))) || ((cljs.core.PROTOCOL_SENTINEL === map__115393.cljs$core$ISeq$))))?true:false):false))?cljs.core.apply.call(null,cljs.core.hash_map,map__115393):map__115393);
var gline = cljs.core.get.call(null,map__115393__$1,new cljs.core.Keyword(null,"gline","gline",-1086242431));
var gcol = cljs.core.get.call(null,map__115393__$1,new cljs.core.Keyword(null,"gcol","gcol",309250807));
return cljs.core.into.call(null,v,cljs.core.get_in.call(null,js_map,new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [gline,gcol], null)));
});})(col_map_seq,new_cols,line_map_seq,new_lines,vec__115389,col,infos,vec__115386,line,col_map))
,cljs.core.PersistentVector.EMPTY,infos));
col_map_seq = G__115395;
new_cols = G__115396;
continue;
} else {
return new_cols;
}
break;
}
})();
var G__115397 = cljs.core.next.call(null,line_map_seq);
var G__115398 = cljs.core.assoc.call(null,new_lines,line,new_cols);
line_map_seq = G__115397;
new_lines = G__115398;
continue;
} else {
return new_lines;
}
break;
}
});
/**
 * Given a ClojureScript to JavaScript source map, invert it. Useful when
 * mapping JavaScript stack traces when environment support is unavailable.
 */
cljs.source_map.invert_reverse_map = (function cljs$source_map$invert_reverse_map(reverse_map){
var inverted = cljs.core.atom.call(null,cljs.core.sorted_map.call(null));
var seq__115399_115671 = cljs.core.seq.call(null,reverse_map);
var chunk__115400_115672 = null;
var count__115401_115673 = (0);
var i__115402_115674 = (0);
while(true){
if((i__115402_115674 < count__115401_115673)){
var vec__115537_115675 = cljs.core._nth.call(null,chunk__115400_115672,i__115402_115674);
var line_115676 = cljs.core.nth.call(null,vec__115537_115675,(0),null);
var columns_115677 = cljs.core.nth.call(null,vec__115537_115675,(1),null);
var seq__115540_115678 = cljs.core.seq.call(null,columns_115677);
var chunk__115541_115679 = null;
var count__115542_115680 = (0);
var i__115543_115681 = (0);
while(true){
if((i__115543_115681 < count__115542_115680)){
var vec__115574_115682 = cljs.core._nth.call(null,chunk__115541_115679,i__115543_115681);
var column_115683 = cljs.core.nth.call(null,vec__115574_115682,(0),null);
var column_info_115684 = cljs.core.nth.call(null,vec__115574_115682,(1),null);
var seq__115577_115685 = cljs.core.seq.call(null,column_info_115684);
var chunk__115578_115686 = null;
var count__115579_115687 = (0);
var i__115580_115688 = (0);
while(true){
if((i__115580_115688 < count__115579_115687)){
var map__115585_115689 = cljs.core._nth.call(null,chunk__115578_115686,i__115580_115688);
var map__115585_115690__$1 = (((((!((map__115585_115689 == null))))?(((((map__115585_115689.cljs$lang$protocol_mask$partition0$ & (64))) || ((cljs.core.PROTOCOL_SENTINEL === map__115585_115689.cljs$core$ISeq$))))?true:false):false))?cljs.core.apply.call(null,cljs.core.hash_map,map__115585_115689):map__115585_115689);
var gline_115691 = cljs.core.get.call(null,map__115585_115690__$1,new cljs.core.Keyword(null,"gline","gline",-1086242431));
var gcol_115692 = cljs.core.get.call(null,map__115585_115690__$1,new cljs.core.Keyword(null,"gcol","gcol",309250807));
var name_115693 = cljs.core.get.call(null,map__115585_115690__$1,new cljs.core.Keyword(null,"name","name",1843675177));
cljs.core.swap_BANG_.call(null,inverted,cljs.core.update_in,new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [gline_115691], null),cljs.core.fnil.call(null,((function (seq__115577_115685,chunk__115578_115686,count__115579_115687,i__115580_115688,seq__115540_115678,chunk__115541_115679,count__115542_115680,i__115543_115681,seq__115399_115671,chunk__115400_115672,count__115401_115673,i__115402_115674,map__115585_115689,map__115585_115690__$1,gline_115691,gcol_115692,name_115693,vec__115574_115682,column_115683,column_info_115684,vec__115537_115675,line_115676,columns_115677,inverted){
return (function (columns__$1){
return cljs.core.update_in.call(null,columns__$1,new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [gcol_115692], null),cljs.core.fnil.call(null,cljs.core.conj,cljs.core.PersistentVector.EMPTY),new cljs.core.PersistentArrayMap(null, 3, [new cljs.core.Keyword(null,"line","line",212345235),line_115676,new cljs.core.Keyword(null,"col","col",-1959363084),column_115683,new cljs.core.Keyword(null,"name","name",1843675177),name_115693], null));
});})(seq__115577_115685,chunk__115578_115686,count__115579_115687,i__115580_115688,seq__115540_115678,chunk__115541_115679,count__115542_115680,i__115543_115681,seq__115399_115671,chunk__115400_115672,count__115401_115673,i__115402_115674,map__115585_115689,map__115585_115690__$1,gline_115691,gcol_115692,name_115693,vec__115574_115682,column_115683,column_info_115684,vec__115537_115675,line_115676,columns_115677,inverted))
,cljs.core.sorted_map.call(null)));


var G__115694 = seq__115577_115685;
var G__115695 = chunk__115578_115686;
var G__115696 = count__115579_115687;
var G__115697 = (i__115580_115688 + (1));
seq__115577_115685 = G__115694;
chunk__115578_115686 = G__115695;
count__115579_115687 = G__115696;
i__115580_115688 = G__115697;
continue;
} else {
var temp__5735__auto___115698 = cljs.core.seq.call(null,seq__115577_115685);
if(temp__5735__auto___115698){
var seq__115577_115699__$1 = temp__5735__auto___115698;
if(cljs.core.chunked_seq_QMARK_.call(null,seq__115577_115699__$1)){
var c__4550__auto___115700 = cljs.core.chunk_first.call(null,seq__115577_115699__$1);
var G__115701 = cljs.core.chunk_rest.call(null,seq__115577_115699__$1);
var G__115702 = c__4550__auto___115700;
var G__115703 = cljs.core.count.call(null,c__4550__auto___115700);
var G__115704 = (0);
seq__115577_115685 = G__115701;
chunk__115578_115686 = G__115702;
count__115579_115687 = G__115703;
i__115580_115688 = G__115704;
continue;
} else {
var map__115587_115705 = cljs.core.first.call(null,seq__115577_115699__$1);
var map__115587_115706__$1 = (((((!((map__115587_115705 == null))))?(((((map__115587_115705.cljs$lang$protocol_mask$partition0$ & (64))) || ((cljs.core.PROTOCOL_SENTINEL === map__115587_115705.cljs$core$ISeq$))))?true:false):false))?cljs.core.apply.call(null,cljs.core.hash_map,map__115587_115705):map__115587_115705);
var gline_115707 = cljs.core.get.call(null,map__115587_115706__$1,new cljs.core.Keyword(null,"gline","gline",-1086242431));
var gcol_115708 = cljs.core.get.call(null,map__115587_115706__$1,new cljs.core.Keyword(null,"gcol","gcol",309250807));
var name_115709 = cljs.core.get.call(null,map__115587_115706__$1,new cljs.core.Keyword(null,"name","name",1843675177));
cljs.core.swap_BANG_.call(null,inverted,cljs.core.update_in,new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [gline_115707], null),cljs.core.fnil.call(null,((function (seq__115577_115685,chunk__115578_115686,count__115579_115687,i__115580_115688,seq__115540_115678,chunk__115541_115679,count__115542_115680,i__115543_115681,seq__115399_115671,chunk__115400_115672,count__115401_115673,i__115402_115674,map__115587_115705,map__115587_115706__$1,gline_115707,gcol_115708,name_115709,seq__115577_115699__$1,temp__5735__auto___115698,vec__115574_115682,column_115683,column_info_115684,vec__115537_115675,line_115676,columns_115677,inverted){
return (function (columns__$1){
return cljs.core.update_in.call(null,columns__$1,new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [gcol_115708], null),cljs.core.fnil.call(null,cljs.core.conj,cljs.core.PersistentVector.EMPTY),new cljs.core.PersistentArrayMap(null, 3, [new cljs.core.Keyword(null,"line","line",212345235),line_115676,new cljs.core.Keyword(null,"col","col",-1959363084),column_115683,new cljs.core.Keyword(null,"name","name",1843675177),name_115709], null));
});})(seq__115577_115685,chunk__115578_115686,count__115579_115687,i__115580_115688,seq__115540_115678,chunk__115541_115679,count__115542_115680,i__115543_115681,seq__115399_115671,chunk__115400_115672,count__115401_115673,i__115402_115674,map__115587_115705,map__115587_115706__$1,gline_115707,gcol_115708,name_115709,seq__115577_115699__$1,temp__5735__auto___115698,vec__115574_115682,column_115683,column_info_115684,vec__115537_115675,line_115676,columns_115677,inverted))
,cljs.core.sorted_map.call(null)));


var G__115710 = cljs.core.next.call(null,seq__115577_115699__$1);
var G__115711 = null;
var G__115712 = (0);
var G__115713 = (0);
seq__115577_115685 = G__115710;
chunk__115578_115686 = G__115711;
count__115579_115687 = G__115712;
i__115580_115688 = G__115713;
continue;
}
} else {
}
}
break;
}


var G__115714 = seq__115540_115678;
var G__115715 = chunk__115541_115679;
var G__115716 = count__115542_115680;
var G__115717 = (i__115543_115681 + (1));
seq__115540_115678 = G__115714;
chunk__115541_115679 = G__115715;
count__115542_115680 = G__115716;
i__115543_115681 = G__115717;
continue;
} else {
var temp__5735__auto___115718 = cljs.core.seq.call(null,seq__115540_115678);
if(temp__5735__auto___115718){
var seq__115540_115719__$1 = temp__5735__auto___115718;
if(cljs.core.chunked_seq_QMARK_.call(null,seq__115540_115719__$1)){
var c__4550__auto___115720 = cljs.core.chunk_first.call(null,seq__115540_115719__$1);
var G__115721 = cljs.core.chunk_rest.call(null,seq__115540_115719__$1);
var G__115722 = c__4550__auto___115720;
var G__115723 = cljs.core.count.call(null,c__4550__auto___115720);
var G__115724 = (0);
seq__115540_115678 = G__115721;
chunk__115541_115679 = G__115722;
count__115542_115680 = G__115723;
i__115543_115681 = G__115724;
continue;
} else {
var vec__115589_115725 = cljs.core.first.call(null,seq__115540_115719__$1);
var column_115726 = cljs.core.nth.call(null,vec__115589_115725,(0),null);
var column_info_115727 = cljs.core.nth.call(null,vec__115589_115725,(1),null);
var seq__115592_115728 = cljs.core.seq.call(null,column_info_115727);
var chunk__115593_115729 = null;
var count__115594_115730 = (0);
var i__115595_115731 = (0);
while(true){
if((i__115595_115731 < count__115594_115730)){
var map__115600_115732 = cljs.core._nth.call(null,chunk__115593_115729,i__115595_115731);
var map__115600_115733__$1 = (((((!((map__115600_115732 == null))))?(((((map__115600_115732.cljs$lang$protocol_mask$partition0$ & (64))) || ((cljs.core.PROTOCOL_SENTINEL === map__115600_115732.cljs$core$ISeq$))))?true:false):false))?cljs.core.apply.call(null,cljs.core.hash_map,map__115600_115732):map__115600_115732);
var gline_115734 = cljs.core.get.call(null,map__115600_115733__$1,new cljs.core.Keyword(null,"gline","gline",-1086242431));
var gcol_115735 = cljs.core.get.call(null,map__115600_115733__$1,new cljs.core.Keyword(null,"gcol","gcol",309250807));
var name_115736 = cljs.core.get.call(null,map__115600_115733__$1,new cljs.core.Keyword(null,"name","name",1843675177));
cljs.core.swap_BANG_.call(null,inverted,cljs.core.update_in,new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [gline_115734], null),cljs.core.fnil.call(null,((function (seq__115592_115728,chunk__115593_115729,count__115594_115730,i__115595_115731,seq__115540_115678,chunk__115541_115679,count__115542_115680,i__115543_115681,seq__115399_115671,chunk__115400_115672,count__115401_115673,i__115402_115674,map__115600_115732,map__115600_115733__$1,gline_115734,gcol_115735,name_115736,vec__115589_115725,column_115726,column_info_115727,seq__115540_115719__$1,temp__5735__auto___115718,vec__115537_115675,line_115676,columns_115677,inverted){
return (function (columns__$1){
return cljs.core.update_in.call(null,columns__$1,new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [gcol_115735], null),cljs.core.fnil.call(null,cljs.core.conj,cljs.core.PersistentVector.EMPTY),new cljs.core.PersistentArrayMap(null, 3, [new cljs.core.Keyword(null,"line","line",212345235),line_115676,new cljs.core.Keyword(null,"col","col",-1959363084),column_115726,new cljs.core.Keyword(null,"name","name",1843675177),name_115736], null));
});})(seq__115592_115728,chunk__115593_115729,count__115594_115730,i__115595_115731,seq__115540_115678,chunk__115541_115679,count__115542_115680,i__115543_115681,seq__115399_115671,chunk__115400_115672,count__115401_115673,i__115402_115674,map__115600_115732,map__115600_115733__$1,gline_115734,gcol_115735,name_115736,vec__115589_115725,column_115726,column_info_115727,seq__115540_115719__$1,temp__5735__auto___115718,vec__115537_115675,line_115676,columns_115677,inverted))
,cljs.core.sorted_map.call(null)));


var G__115737 = seq__115592_115728;
var G__115738 = chunk__115593_115729;
var G__115739 = count__115594_115730;
var G__115740 = (i__115595_115731 + (1));
seq__115592_115728 = G__115737;
chunk__115593_115729 = G__115738;
count__115594_115730 = G__115739;
i__115595_115731 = G__115740;
continue;
} else {
var temp__5735__auto___115741__$1 = cljs.core.seq.call(null,seq__115592_115728);
if(temp__5735__auto___115741__$1){
var seq__115592_115742__$1 = temp__5735__auto___115741__$1;
if(cljs.core.chunked_seq_QMARK_.call(null,seq__115592_115742__$1)){
var c__4550__auto___115743 = cljs.core.chunk_first.call(null,seq__115592_115742__$1);
var G__115744 = cljs.core.chunk_rest.call(null,seq__115592_115742__$1);
var G__115745 = c__4550__auto___115743;
var G__115746 = cljs.core.count.call(null,c__4550__auto___115743);
var G__115747 = (0);
seq__115592_115728 = G__115744;
chunk__115593_115729 = G__115745;
count__115594_115730 = G__115746;
i__115595_115731 = G__115747;
continue;
} else {
var map__115602_115748 = cljs.core.first.call(null,seq__115592_115742__$1);
var map__115602_115749__$1 = (((((!((map__115602_115748 == null))))?(((((map__115602_115748.cljs$lang$protocol_mask$partition0$ & (64))) || ((cljs.core.PROTOCOL_SENTINEL === map__115602_115748.cljs$core$ISeq$))))?true:false):false))?cljs.core.apply.call(null,cljs.core.hash_map,map__115602_115748):map__115602_115748);
var gline_115750 = cljs.core.get.call(null,map__115602_115749__$1,new cljs.core.Keyword(null,"gline","gline",-1086242431));
var gcol_115751 = cljs.core.get.call(null,map__115602_115749__$1,new cljs.core.Keyword(null,"gcol","gcol",309250807));
var name_115752 = cljs.core.get.call(null,map__115602_115749__$1,new cljs.core.Keyword(null,"name","name",1843675177));
cljs.core.swap_BANG_.call(null,inverted,cljs.core.update_in,new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [gline_115750], null),cljs.core.fnil.call(null,((function (seq__115592_115728,chunk__115593_115729,count__115594_115730,i__115595_115731,seq__115540_115678,chunk__115541_115679,count__115542_115680,i__115543_115681,seq__115399_115671,chunk__115400_115672,count__115401_115673,i__115402_115674,map__115602_115748,map__115602_115749__$1,gline_115750,gcol_115751,name_115752,seq__115592_115742__$1,temp__5735__auto___115741__$1,vec__115589_115725,column_115726,column_info_115727,seq__115540_115719__$1,temp__5735__auto___115718,vec__115537_115675,line_115676,columns_115677,inverted){
return (function (columns__$1){
return cljs.core.update_in.call(null,columns__$1,new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [gcol_115751], null),cljs.core.fnil.call(null,cljs.core.conj,cljs.core.PersistentVector.EMPTY),new cljs.core.PersistentArrayMap(null, 3, [new cljs.core.Keyword(null,"line","line",212345235),line_115676,new cljs.core.Keyword(null,"col","col",-1959363084),column_115726,new cljs.core.Keyword(null,"name","name",1843675177),name_115752], null));
});})(seq__115592_115728,chunk__115593_115729,count__115594_115730,i__115595_115731,seq__115540_115678,chunk__115541_115679,count__115542_115680,i__115543_115681,seq__115399_115671,chunk__115400_115672,count__115401_115673,i__115402_115674,map__115602_115748,map__115602_115749__$1,gline_115750,gcol_115751,name_115752,seq__115592_115742__$1,temp__5735__auto___115741__$1,vec__115589_115725,column_115726,column_info_115727,seq__115540_115719__$1,temp__5735__auto___115718,vec__115537_115675,line_115676,columns_115677,inverted))
,cljs.core.sorted_map.call(null)));


var G__115753 = cljs.core.next.call(null,seq__115592_115742__$1);
var G__115754 = null;
var G__115755 = (0);
var G__115756 = (0);
seq__115592_115728 = G__115753;
chunk__115593_115729 = G__115754;
count__115594_115730 = G__115755;
i__115595_115731 = G__115756;
continue;
}
} else {
}
}
break;
}


var G__115757 = cljs.core.next.call(null,seq__115540_115719__$1);
var G__115758 = null;
var G__115759 = (0);
var G__115760 = (0);
seq__115540_115678 = G__115757;
chunk__115541_115679 = G__115758;
count__115542_115680 = G__115759;
i__115543_115681 = G__115760;
continue;
}
} else {
}
}
break;
}


var G__115761 = seq__115399_115671;
var G__115762 = chunk__115400_115672;
var G__115763 = count__115401_115673;
var G__115764 = (i__115402_115674 + (1));
seq__115399_115671 = G__115761;
chunk__115400_115672 = G__115762;
count__115401_115673 = G__115763;
i__115402_115674 = G__115764;
continue;
} else {
var temp__5735__auto___115765 = cljs.core.seq.call(null,seq__115399_115671);
if(temp__5735__auto___115765){
var seq__115399_115766__$1 = temp__5735__auto___115765;
if(cljs.core.chunked_seq_QMARK_.call(null,seq__115399_115766__$1)){
var c__4550__auto___115767 = cljs.core.chunk_first.call(null,seq__115399_115766__$1);
var G__115768 = cljs.core.chunk_rest.call(null,seq__115399_115766__$1);
var G__115769 = c__4550__auto___115767;
var G__115770 = cljs.core.count.call(null,c__4550__auto___115767);
var G__115771 = (0);
seq__115399_115671 = G__115768;
chunk__115400_115672 = G__115769;
count__115401_115673 = G__115770;
i__115402_115674 = G__115771;
continue;
} else {
var vec__115604_115772 = cljs.core.first.call(null,seq__115399_115766__$1);
var line_115773 = cljs.core.nth.call(null,vec__115604_115772,(0),null);
var columns_115774 = cljs.core.nth.call(null,vec__115604_115772,(1),null);
var seq__115607_115775 = cljs.core.seq.call(null,columns_115774);
var chunk__115608_115776 = null;
var count__115609_115777 = (0);
var i__115610_115778 = (0);
while(true){
if((i__115610_115778 < count__115609_115777)){
var vec__115641_115779 = cljs.core._nth.call(null,chunk__115608_115776,i__115610_115778);
var column_115780 = cljs.core.nth.call(null,vec__115641_115779,(0),null);
var column_info_115781 = cljs.core.nth.call(null,vec__115641_115779,(1),null);
var seq__115644_115782 = cljs.core.seq.call(null,column_info_115781);
var chunk__115645_115783 = null;
var count__115646_115784 = (0);
var i__115647_115785 = (0);
while(true){
if((i__115647_115785 < count__115646_115784)){
var map__115652_115786 = cljs.core._nth.call(null,chunk__115645_115783,i__115647_115785);
var map__115652_115787__$1 = (((((!((map__115652_115786 == null))))?(((((map__115652_115786.cljs$lang$protocol_mask$partition0$ & (64))) || ((cljs.core.PROTOCOL_SENTINEL === map__115652_115786.cljs$core$ISeq$))))?true:false):false))?cljs.core.apply.call(null,cljs.core.hash_map,map__115652_115786):map__115652_115786);
var gline_115788 = cljs.core.get.call(null,map__115652_115787__$1,new cljs.core.Keyword(null,"gline","gline",-1086242431));
var gcol_115789 = cljs.core.get.call(null,map__115652_115787__$1,new cljs.core.Keyword(null,"gcol","gcol",309250807));
var name_115790 = cljs.core.get.call(null,map__115652_115787__$1,new cljs.core.Keyword(null,"name","name",1843675177));
cljs.core.swap_BANG_.call(null,inverted,cljs.core.update_in,new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [gline_115788], null),cljs.core.fnil.call(null,((function (seq__115644_115782,chunk__115645_115783,count__115646_115784,i__115647_115785,seq__115607_115775,chunk__115608_115776,count__115609_115777,i__115610_115778,seq__115399_115671,chunk__115400_115672,count__115401_115673,i__115402_115674,map__115652_115786,map__115652_115787__$1,gline_115788,gcol_115789,name_115790,vec__115641_115779,column_115780,column_info_115781,vec__115604_115772,line_115773,columns_115774,seq__115399_115766__$1,temp__5735__auto___115765,inverted){
return (function (columns__$1){
return cljs.core.update_in.call(null,columns__$1,new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [gcol_115789], null),cljs.core.fnil.call(null,cljs.core.conj,cljs.core.PersistentVector.EMPTY),new cljs.core.PersistentArrayMap(null, 3, [new cljs.core.Keyword(null,"line","line",212345235),line_115773,new cljs.core.Keyword(null,"col","col",-1959363084),column_115780,new cljs.core.Keyword(null,"name","name",1843675177),name_115790], null));
});})(seq__115644_115782,chunk__115645_115783,count__115646_115784,i__115647_115785,seq__115607_115775,chunk__115608_115776,count__115609_115777,i__115610_115778,seq__115399_115671,chunk__115400_115672,count__115401_115673,i__115402_115674,map__115652_115786,map__115652_115787__$1,gline_115788,gcol_115789,name_115790,vec__115641_115779,column_115780,column_info_115781,vec__115604_115772,line_115773,columns_115774,seq__115399_115766__$1,temp__5735__auto___115765,inverted))
,cljs.core.sorted_map.call(null)));


var G__115791 = seq__115644_115782;
var G__115792 = chunk__115645_115783;
var G__115793 = count__115646_115784;
var G__115794 = (i__115647_115785 + (1));
seq__115644_115782 = G__115791;
chunk__115645_115783 = G__115792;
count__115646_115784 = G__115793;
i__115647_115785 = G__115794;
continue;
} else {
var temp__5735__auto___115795__$1 = cljs.core.seq.call(null,seq__115644_115782);
if(temp__5735__auto___115795__$1){
var seq__115644_115796__$1 = temp__5735__auto___115795__$1;
if(cljs.core.chunked_seq_QMARK_.call(null,seq__115644_115796__$1)){
var c__4550__auto___115797 = cljs.core.chunk_first.call(null,seq__115644_115796__$1);
var G__115798 = cljs.core.chunk_rest.call(null,seq__115644_115796__$1);
var G__115799 = c__4550__auto___115797;
var G__115800 = cljs.core.count.call(null,c__4550__auto___115797);
var G__115801 = (0);
seq__115644_115782 = G__115798;
chunk__115645_115783 = G__115799;
count__115646_115784 = G__115800;
i__115647_115785 = G__115801;
continue;
} else {
var map__115654_115802 = cljs.core.first.call(null,seq__115644_115796__$1);
var map__115654_115803__$1 = (((((!((map__115654_115802 == null))))?(((((map__115654_115802.cljs$lang$protocol_mask$partition0$ & (64))) || ((cljs.core.PROTOCOL_SENTINEL === map__115654_115802.cljs$core$ISeq$))))?true:false):false))?cljs.core.apply.call(null,cljs.core.hash_map,map__115654_115802):map__115654_115802);
var gline_115804 = cljs.core.get.call(null,map__115654_115803__$1,new cljs.core.Keyword(null,"gline","gline",-1086242431));
var gcol_115805 = cljs.core.get.call(null,map__115654_115803__$1,new cljs.core.Keyword(null,"gcol","gcol",309250807));
var name_115806 = cljs.core.get.call(null,map__115654_115803__$1,new cljs.core.Keyword(null,"name","name",1843675177));
cljs.core.swap_BANG_.call(null,inverted,cljs.core.update_in,new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [gline_115804], null),cljs.core.fnil.call(null,((function (seq__115644_115782,chunk__115645_115783,count__115646_115784,i__115647_115785,seq__115607_115775,chunk__115608_115776,count__115609_115777,i__115610_115778,seq__115399_115671,chunk__115400_115672,count__115401_115673,i__115402_115674,map__115654_115802,map__115654_115803__$1,gline_115804,gcol_115805,name_115806,seq__115644_115796__$1,temp__5735__auto___115795__$1,vec__115641_115779,column_115780,column_info_115781,vec__115604_115772,line_115773,columns_115774,seq__115399_115766__$1,temp__5735__auto___115765,inverted){
return (function (columns__$1){
return cljs.core.update_in.call(null,columns__$1,new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [gcol_115805], null),cljs.core.fnil.call(null,cljs.core.conj,cljs.core.PersistentVector.EMPTY),new cljs.core.PersistentArrayMap(null, 3, [new cljs.core.Keyword(null,"line","line",212345235),line_115773,new cljs.core.Keyword(null,"col","col",-1959363084),column_115780,new cljs.core.Keyword(null,"name","name",1843675177),name_115806], null));
});})(seq__115644_115782,chunk__115645_115783,count__115646_115784,i__115647_115785,seq__115607_115775,chunk__115608_115776,count__115609_115777,i__115610_115778,seq__115399_115671,chunk__115400_115672,count__115401_115673,i__115402_115674,map__115654_115802,map__115654_115803__$1,gline_115804,gcol_115805,name_115806,seq__115644_115796__$1,temp__5735__auto___115795__$1,vec__115641_115779,column_115780,column_info_115781,vec__115604_115772,line_115773,columns_115774,seq__115399_115766__$1,temp__5735__auto___115765,inverted))
,cljs.core.sorted_map.call(null)));


var G__115807 = cljs.core.next.call(null,seq__115644_115796__$1);
var G__115808 = null;
var G__115809 = (0);
var G__115810 = (0);
seq__115644_115782 = G__115807;
chunk__115645_115783 = G__115808;
count__115646_115784 = G__115809;
i__115647_115785 = G__115810;
continue;
}
} else {
}
}
break;
}


var G__115811 = seq__115607_115775;
var G__115812 = chunk__115608_115776;
var G__115813 = count__115609_115777;
var G__115814 = (i__115610_115778 + (1));
seq__115607_115775 = G__115811;
chunk__115608_115776 = G__115812;
count__115609_115777 = G__115813;
i__115610_115778 = G__115814;
continue;
} else {
var temp__5735__auto___115815__$1 = cljs.core.seq.call(null,seq__115607_115775);
if(temp__5735__auto___115815__$1){
var seq__115607_115816__$1 = temp__5735__auto___115815__$1;
if(cljs.core.chunked_seq_QMARK_.call(null,seq__115607_115816__$1)){
var c__4550__auto___115817 = cljs.core.chunk_first.call(null,seq__115607_115816__$1);
var G__115818 = cljs.core.chunk_rest.call(null,seq__115607_115816__$1);
var G__115819 = c__4550__auto___115817;
var G__115820 = cljs.core.count.call(null,c__4550__auto___115817);
var G__115821 = (0);
seq__115607_115775 = G__115818;
chunk__115608_115776 = G__115819;
count__115609_115777 = G__115820;
i__115610_115778 = G__115821;
continue;
} else {
var vec__115656_115822 = cljs.core.first.call(null,seq__115607_115816__$1);
var column_115823 = cljs.core.nth.call(null,vec__115656_115822,(0),null);
var column_info_115824 = cljs.core.nth.call(null,vec__115656_115822,(1),null);
var seq__115659_115825 = cljs.core.seq.call(null,column_info_115824);
var chunk__115660_115826 = null;
var count__115661_115827 = (0);
var i__115662_115828 = (0);
while(true){
if((i__115662_115828 < count__115661_115827)){
var map__115667_115829 = cljs.core._nth.call(null,chunk__115660_115826,i__115662_115828);
var map__115667_115830__$1 = (((((!((map__115667_115829 == null))))?(((((map__115667_115829.cljs$lang$protocol_mask$partition0$ & (64))) || ((cljs.core.PROTOCOL_SENTINEL === map__115667_115829.cljs$core$ISeq$))))?true:false):false))?cljs.core.apply.call(null,cljs.core.hash_map,map__115667_115829):map__115667_115829);
var gline_115831 = cljs.core.get.call(null,map__115667_115830__$1,new cljs.core.Keyword(null,"gline","gline",-1086242431));
var gcol_115832 = cljs.core.get.call(null,map__115667_115830__$1,new cljs.core.Keyword(null,"gcol","gcol",309250807));
var name_115833 = cljs.core.get.call(null,map__115667_115830__$1,new cljs.core.Keyword(null,"name","name",1843675177));
cljs.core.swap_BANG_.call(null,inverted,cljs.core.update_in,new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [gline_115831], null),cljs.core.fnil.call(null,((function (seq__115659_115825,chunk__115660_115826,count__115661_115827,i__115662_115828,seq__115607_115775,chunk__115608_115776,count__115609_115777,i__115610_115778,seq__115399_115671,chunk__115400_115672,count__115401_115673,i__115402_115674,map__115667_115829,map__115667_115830__$1,gline_115831,gcol_115832,name_115833,vec__115656_115822,column_115823,column_info_115824,seq__115607_115816__$1,temp__5735__auto___115815__$1,vec__115604_115772,line_115773,columns_115774,seq__115399_115766__$1,temp__5735__auto___115765,inverted){
return (function (columns__$1){
return cljs.core.update_in.call(null,columns__$1,new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [gcol_115832], null),cljs.core.fnil.call(null,cljs.core.conj,cljs.core.PersistentVector.EMPTY),new cljs.core.PersistentArrayMap(null, 3, [new cljs.core.Keyword(null,"line","line",212345235),line_115773,new cljs.core.Keyword(null,"col","col",-1959363084),column_115823,new cljs.core.Keyword(null,"name","name",1843675177),name_115833], null));
});})(seq__115659_115825,chunk__115660_115826,count__115661_115827,i__115662_115828,seq__115607_115775,chunk__115608_115776,count__115609_115777,i__115610_115778,seq__115399_115671,chunk__115400_115672,count__115401_115673,i__115402_115674,map__115667_115829,map__115667_115830__$1,gline_115831,gcol_115832,name_115833,vec__115656_115822,column_115823,column_info_115824,seq__115607_115816__$1,temp__5735__auto___115815__$1,vec__115604_115772,line_115773,columns_115774,seq__115399_115766__$1,temp__5735__auto___115765,inverted))
,cljs.core.sorted_map.call(null)));


var G__115834 = seq__115659_115825;
var G__115835 = chunk__115660_115826;
var G__115836 = count__115661_115827;
var G__115837 = (i__115662_115828 + (1));
seq__115659_115825 = G__115834;
chunk__115660_115826 = G__115835;
count__115661_115827 = G__115836;
i__115662_115828 = G__115837;
continue;
} else {
var temp__5735__auto___115838__$2 = cljs.core.seq.call(null,seq__115659_115825);
if(temp__5735__auto___115838__$2){
var seq__115659_115839__$1 = temp__5735__auto___115838__$2;
if(cljs.core.chunked_seq_QMARK_.call(null,seq__115659_115839__$1)){
var c__4550__auto___115840 = cljs.core.chunk_first.call(null,seq__115659_115839__$1);
var G__115841 = cljs.core.chunk_rest.call(null,seq__115659_115839__$1);
var G__115842 = c__4550__auto___115840;
var G__115843 = cljs.core.count.call(null,c__4550__auto___115840);
var G__115844 = (0);
seq__115659_115825 = G__115841;
chunk__115660_115826 = G__115842;
count__115661_115827 = G__115843;
i__115662_115828 = G__115844;
continue;
} else {
var map__115669_115845 = cljs.core.first.call(null,seq__115659_115839__$1);
var map__115669_115846__$1 = (((((!((map__115669_115845 == null))))?(((((map__115669_115845.cljs$lang$protocol_mask$partition0$ & (64))) || ((cljs.core.PROTOCOL_SENTINEL === map__115669_115845.cljs$core$ISeq$))))?true:false):false))?cljs.core.apply.call(null,cljs.core.hash_map,map__115669_115845):map__115669_115845);
var gline_115847 = cljs.core.get.call(null,map__115669_115846__$1,new cljs.core.Keyword(null,"gline","gline",-1086242431));
var gcol_115848 = cljs.core.get.call(null,map__115669_115846__$1,new cljs.core.Keyword(null,"gcol","gcol",309250807));
var name_115849 = cljs.core.get.call(null,map__115669_115846__$1,new cljs.core.Keyword(null,"name","name",1843675177));
cljs.core.swap_BANG_.call(null,inverted,cljs.core.update_in,new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [gline_115847], null),cljs.core.fnil.call(null,((function (seq__115659_115825,chunk__115660_115826,count__115661_115827,i__115662_115828,seq__115607_115775,chunk__115608_115776,count__115609_115777,i__115610_115778,seq__115399_115671,chunk__115400_115672,count__115401_115673,i__115402_115674,map__115669_115845,map__115669_115846__$1,gline_115847,gcol_115848,name_115849,seq__115659_115839__$1,temp__5735__auto___115838__$2,vec__115656_115822,column_115823,column_info_115824,seq__115607_115816__$1,temp__5735__auto___115815__$1,vec__115604_115772,line_115773,columns_115774,seq__115399_115766__$1,temp__5735__auto___115765,inverted){
return (function (columns__$1){
return cljs.core.update_in.call(null,columns__$1,new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [gcol_115848], null),cljs.core.fnil.call(null,cljs.core.conj,cljs.core.PersistentVector.EMPTY),new cljs.core.PersistentArrayMap(null, 3, [new cljs.core.Keyword(null,"line","line",212345235),line_115773,new cljs.core.Keyword(null,"col","col",-1959363084),column_115823,new cljs.core.Keyword(null,"name","name",1843675177),name_115849], null));
});})(seq__115659_115825,chunk__115660_115826,count__115661_115827,i__115662_115828,seq__115607_115775,chunk__115608_115776,count__115609_115777,i__115610_115778,seq__115399_115671,chunk__115400_115672,count__115401_115673,i__115402_115674,map__115669_115845,map__115669_115846__$1,gline_115847,gcol_115848,name_115849,seq__115659_115839__$1,temp__5735__auto___115838__$2,vec__115656_115822,column_115823,column_info_115824,seq__115607_115816__$1,temp__5735__auto___115815__$1,vec__115604_115772,line_115773,columns_115774,seq__115399_115766__$1,temp__5735__auto___115765,inverted))
,cljs.core.sorted_map.call(null)));


var G__115850 = cljs.core.next.call(null,seq__115659_115839__$1);
var G__115851 = null;
var G__115852 = (0);
var G__115853 = (0);
seq__115659_115825 = G__115850;
chunk__115660_115826 = G__115851;
count__115661_115827 = G__115852;
i__115662_115828 = G__115853;
continue;
}
} else {
}
}
break;
}


var G__115854 = cljs.core.next.call(null,seq__115607_115816__$1);
var G__115855 = null;
var G__115856 = (0);
var G__115857 = (0);
seq__115607_115775 = G__115854;
chunk__115608_115776 = G__115855;
count__115609_115777 = G__115856;
i__115610_115778 = G__115857;
continue;
}
} else {
}
}
break;
}


var G__115858 = cljs.core.next.call(null,seq__115399_115766__$1);
var G__115859 = null;
var G__115860 = (0);
var G__115861 = (0);
seq__115399_115671 = G__115858;
chunk__115400_115672 = G__115859;
count__115401_115673 = G__115860;
i__115402_115674 = G__115861;
continue;
}
} else {
}
}
break;
}

return cljs.core.deref.call(null,inverted);
});
