// Compiled by ClojureScript 1.10.520 {:static-fns true, :optimize-constants true}
goog.provide('fluree.db.query.fql_parser');
goog.require('cljs.core');
goog.require('cljs.core.constants');
goog.require('fluree.db.util.core');
goog.require('fluree.db.dbproto');
goog.require('clojure.string');
goog.require('fluree.db.spec');
goog.require('fluree.db.util.async');
goog.require('fluree.db.util.log');
goog.require('fluree.db.query.schema');
/**
 * Checks to see if the where clause has ' = ', ' > ', ' < ', ' <= ', or ' >= ', and returns true if yes
 */
fluree.db.query.fql_parser.where_clause_valid_QMARK_ = (function fluree$db$query$fql_parser$where_clause_valid_QMARK_(where_clause){
var and__4120__auto__ = typeof where_clause === 'string';
if(and__4120__auto__){
return cljs.core.re_find(/^.* (=|>|<|>=|<=|not=) .*$/,where_clause);
} else {
return and__4120__auto__;
}
});
/**
 * Returns a where clause spec based on a string where caluse.
 *   The spec can be applied to a specific db to coerce predicate names
 *   to predicate ids, validate types, and ultimately generate a filtering function.
 */
fluree.db.query.fql_parser.parse_where_spec = (function fluree$db$query$fql_parser$parse_where_spec(var_args){
var G__110436 = arguments.length;
switch (G__110436) {
case 1:
return fluree.db.query.fql_parser.parse_where_spec.cljs$core$IFn$_invoke$arity$1((arguments[(0)]));

break;
case 2:
return fluree.db.query.fql_parser.parse_where_spec.cljs$core$IFn$_invoke$arity$2((arguments[(0)]),(arguments[(1)]));

break;
default:
throw (new Error(["Invalid arity: ",cljs.core.str.cljs$core$IFn$_invoke$arity$1(arguments.length)].join('')));

}
});

fluree.db.query.fql_parser.parse_where_spec.cljs$core$IFn$_invoke$arity$1 = (function (where){
return fluree.db.query.fql_parser.parse_where_spec.cljs$core$IFn$_invoke$arity$2(where,null);
});

fluree.db.query.fql_parser.parse_where_spec.cljs$core$IFn$_invoke$arity$2 = (function (where,default_collection){
if(cljs.core.truth_(fluree.db.query.fql_parser.where_clause_valid_QMARK_(where))){
} else {
throw cljs.core.ex_info.cljs$core$IFn$_invoke$arity$2(["Invalid where clause: ",cljs.core.str.cljs$core$IFn$_invoke$arity$1(where)].join(''),new cljs.core.PersistentArrayMap(null, 2, [cljs.core.cst$kw$status,(400),cljs.core.cst$kw$error,cljs.core.cst$kw$db_SLASH_invalid_DASH_query], null));
}

var where_type = (cljs.core.truth_((function (){var and__4120__auto__ = cljs.core.re_matches(/.+ AND .+/,where);
if(cljs.core.truth_(and__4120__auto__)){
return cljs.core.not(cljs.core.re_matches(/.+ OR .+/,where));
} else {
return and__4120__auto__;
}
})())?cljs.core.cst$kw$and:(cljs.core.truth_((function (){var and__4120__auto__ = cljs.core.re_matches(/.+ OR .+/,where);
if(cljs.core.truth_(and__4120__auto__)){
return cljs.core.not(cljs.core.re_matches(/.+ AND .+/,where));
} else {
return and__4120__auto__;
}
})())?cljs.core.cst$kw$or:((((cljs.core.not(cljs.core.re_matches(/.+ OR .+/,where))) && (cljs.core.not(cljs.core.re_matches(/.+ AND .+/,where)))))?cljs.core.cst$kw$or:(function(){throw cljs.core.ex_info.cljs$core$IFn$_invoke$arity$2(["Where clause can have either AND or OR operations, but not both currently: ",cljs.core.str.cljs$core$IFn$_invoke$arity$1(where)].join(''),new cljs.core.PersistentArrayMap(null, 2, [cljs.core.cst$kw$status,(400),cljs.core.cst$kw$error,cljs.core.cst$kw$db_SLASH_invalid_DASH_query], null))})()
)));
var args = (function (){var G__110437 = where_type;
var G__110437__$1 = (((G__110437 instanceof cljs.core.Keyword))?G__110437.fqn:null);
switch (G__110437__$1) {
case "and":
return clojure.string.split.cljs$core$IFn$_invoke$arity$2(where,/ AND /);

break;
case "or":
return clojure.string.split.cljs$core$IFn$_invoke$arity$2(where,/ OR /);

break;
default:
throw (new Error(["No matching clause: ",cljs.core.str.cljs$core$IFn$_invoke$arity$1(G__110437__$1)].join('')));

}
})();
var statements = cljs.core.reduce.cljs$core$IFn$_invoke$arity$3(((function (where_type,args){
return (function (acc,arg){
var arg__$1 = clojure.string.trim(arg);
var vec__110438 = cljs.core.re_find(/^([^\s=><].+)[\s]+:?(=|>|<|>=|<=|not=)[\s]+:?(.+)$/,arg__$1);
var _ = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(vec__110438,(0),null);
var pred_name = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(vec__110438,(1),null);
var op = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(vec__110438,(2),null);
var match = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(vec__110438,(3),null);
var pred_name__$1 = ((fluree.db.query.schema.reverse_ref_QMARK_.cljs$core$IFn$_invoke$arity$2(pred_name,false))?(function(){throw cljs.core.ex_info.cljs$core$IFn$_invoke$arity$2(["Reverse references cannot be used in a where clause. Provided: ",cljs.core.str.cljs$core$IFn$_invoke$arity$1(pred_name)].join(''),new cljs.core.PersistentArrayMap(null, 2, [cljs.core.cst$kw$status,(400),cljs.core.cst$kw$error,cljs.core.cst$kw$db_SLASH_invalid_DASH_query], null))})():((clojure.string.includes_QMARK_(pred_name,"/"))?pred_name:(cljs.core.truth_(default_collection)?[cljs.core.str.cljs$core$IFn$_invoke$arity$1(default_collection),"/",cljs.core.str.cljs$core$IFn$_invoke$arity$1(pred_name)].join(''):(function(){throw cljs.core.ex_info.cljs$core$IFn$_invoke$arity$2(["Only full namespaced predicate\n                                         names can be used in a where clause. This can be\n                                         provided in a from clause. Provided: ",cljs.core.str.cljs$core$IFn$_invoke$arity$1(pred_name)].join(''),new cljs.core.PersistentArrayMap(null, 2, [cljs.core.cst$kw$status,(400),cljs.core.cst$kw$error,cljs.core.cst$kw$db_SLASH_invalid_DASH_query], null))})()
)));
var op_STAR_ = (function (){var G__110441 = op;
switch (G__110441) {
case "=":
return cljs.core._EQ_;

break;
case ">":
return cljs.core._GT_;

break;
case ">=":
return cljs.core._GT__EQ_;

break;
case "<":
return cljs.core._LT_;

break;
case "<=":
return cljs.core._LT__EQ_;

break;
case "not=":
return cljs.core.not_EQ_;

break;
default:
throw (new Error(["No matching clause: ",cljs.core.str.cljs$core$IFn$_invoke$arity$1(G__110441)].join('')));

}
})();
var match_STAR_ = (function (){var temp__5733__auto__ = (function (){var or__4131__auto__ = cljs.core.re_find(/'(.*)'$/,match);
if(cljs.core.truth_(or__4131__auto__)){
return or__4131__auto__;
} else {
return cljs.core.re_find(/\"(.*)\"$/,match);
}
})();
if(cljs.core.truth_(temp__5733__auto__)){
var match_str = temp__5733__auto__;
return cljs.core.second(match_str);
} else {
try{if(cljs.core._EQ_.cljs$core$IFn$_invoke$arity$2("true",match)){
return true;
} else {
if(cljs.core._EQ_.cljs$core$IFn$_invoke$arity$2("false",match)){
return false;
} else {
if(clojure.string.includes_QMARK_(match,".")){
return parseFloat(match);
} else {
return parseInt(match);

}
}
}
}catch (e110442){var ___$1 = e110442;
throw cljs.core.ex_info.cljs$core$IFn$_invoke$arity$2(["Invalid where clause in argument: ",cljs.core.str.cljs$core$IFn$_invoke$arity$1(arg__$1)].join(''),new cljs.core.PersistentArrayMap(null, 2, [cljs.core.cst$kw$status,(400),cljs.core.cst$kw$error,cljs.core.cst$kw$db_SLASH_invalid_DASH_query], null));
}}
})();
return cljs.core.conj.cljs$core$IFn$_invoke$arity$2(acc,new cljs.core.PersistentVector(null, 3, 5, cljs.core.PersistentVector.EMPTY_NODE, [pred_name__$1,op_STAR_,match_STAR_], null));
});})(where_type,args))
,cljs.core.PersistentVector.EMPTY,args);
return new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [where_type,statements], null);
});

fluree.db.query.fql_parser.parse_where_spec.cljs$lang$maxFixedArity = 2;

/**
 * Conforms a where spec, using provided db, to use predicate ids and coerces where match values.
 *   If an predicate does not exist, it drops it.
 */
fluree.db.query.fql_parser.conform_where = (function fluree$db$query$fql_parser$conform_where(db,p__110446){
var vec__110447 = p__110446;
var where_type = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(vec__110447,(0),null);
var statements = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(vec__110447,(1),null);
var statements_STAR_ = cljs.core.not_empty(cljs.core.remove.cljs$core$IFn$_invoke$arity$2(cljs.core.nil_QMARK_,cljs.core.map.cljs$core$IFn$_invoke$arity$2(((function (vec__110447,where_type,statements){
return (function (p__110450){
var vec__110451 = p__110450;
var pred_name = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(vec__110451,(0),null);
var op = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(vec__110451,(1),null);
var o = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(vec__110451,(2),null);
var pid = fluree.db.dbproto._p_prop(db,cljs.core.cst$kw$id,pred_name);
if(cljs.core.truth_(pid)){
var pred_type = fluree.db.dbproto._p_prop(db,cljs.core.cst$kw$type,pid);
var o_STAR_ = fluree.db.spec.type_check.cljs$core$IFn$_invoke$arity$2(o,pred_type);
return new cljs.core.PersistentVector(null, 3, 5, cljs.core.PersistentVector.EMPTY_NODE, [pid,op,o_STAR_], null);
} else {
return null;
}
});})(vec__110447,where_type,statements))
,statements)));
if(cljs.core.truth_(statements_STAR_)){
return new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [where_type,statements_STAR_], null);
} else {
return null;
}
});
/**
 * Parses a where clause and coerces the predicates 
 */
fluree.db.query.fql_parser.parse_where = (function fluree$db$query$fql_parser$parse_where(var_args){
var G__110455 = arguments.length;
switch (G__110455) {
case 2:
return fluree.db.query.fql_parser.parse_where.cljs$core$IFn$_invoke$arity$2((arguments[(0)]),(arguments[(1)]));

break;
case 3:
return fluree.db.query.fql_parser.parse_where.cljs$core$IFn$_invoke$arity$3((arguments[(0)]),(arguments[(1)]),(arguments[(2)]));

break;
default:
throw (new Error(["Invalid arity: ",cljs.core.str.cljs$core$IFn$_invoke$arity$1(arguments.length)].join('')));

}
});

fluree.db.query.fql_parser.parse_where.cljs$core$IFn$_invoke$arity$2 = (function (db,where){
return fluree.db.query.fql_parser.parse_where.cljs$core$IFn$_invoke$arity$3(db,where,null);
});

fluree.db.query.fql_parser.parse_where.cljs$core$IFn$_invoke$arity$3 = (function (db,where,default_collection){
var where_spec = fluree.db.query.fql_parser.parse_where_spec.cljs$core$IFn$_invoke$arity$2(where,default_collection);
return fluree.db.query.fql_parser.conform_where(db,where_spec);
});

fluree.db.query.fql_parser.parse_where.cljs$lang$maxFixedArity = 3;

/**
 * Takes a sequential select statement and turns it into a map.
 */
fluree.db.query.fql_parser.to_select_map = (function fluree$db$query$fql_parser$to_select_map(select){
return cljs.core.reduce.cljs$core$IFn$_invoke$arity$3((function (acc,x){
var kv = ((cljs.core.sequential_QMARK_(x))?new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [fluree.db.util.core.keyword__GT_str(cljs.core.first(x)),(function (){var v_STAR_ = cljs.core.second(x);
if(cljs.core.coll_QMARK_(v_STAR_)){
return (fluree.db.query.fql_parser.to_select_map.cljs$core$IFn$_invoke$arity$1 ? fluree.db.query.fql_parser.to_select_map.cljs$core$IFn$_invoke$arity$1(v_STAR_) : fluree.db.query.fql_parser.to_select_map.call(null,v_STAR_));
} else {
return v_STAR_;
}
})()], null):((cljs.core.map_QMARK_(x))?(function (){var values = cljs.core.mapv.cljs$core$IFn$_invoke$arity$2((function (x_item){
var key_x = fluree.db.util.core.keyword__GT_str(cljs.core.key(x_item));
var val_x = cljs.core.val(x_item);
var val_x_SINGLEQUOTE_ = ((cljs.core._EQ_.cljs$core$IFn$_invoke$arity$2("_orderBy",key_x))?((cljs.core.coll_QMARK_(val_x))?new cljs.core.PersistentArrayMap(null, 2, [cljs.core.cst$kw$order,cljs.core.first(val_x),cljs.core.cst$kw$predicate,cljs.core.second(val_x)], null):new cljs.core.PersistentArrayMap(null, 2, [cljs.core.cst$kw$order,"ASC",cljs.core.cst$kw$predicate,val_x], null)):((cljs.core.coll_QMARK_(val_x))?(fluree.db.query.fql_parser.to_select_map.cljs$core$IFn$_invoke$arity$1 ? fluree.db.query.fql_parser.to_select_map.cljs$core$IFn$_invoke$arity$1(val_x) : fluree.db.query.fql_parser.to_select_map.call(null,val_x)):val_x
));
return new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [key_x,val_x_SINGLEQUOTE_], null);
}),x);
return cljs.core.into.cljs$core$IFn$_invoke$arity$2(cljs.core.PersistentVector.EMPTY,cljs.core.flatten(values));
})():new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [x,null], null)
));
return cljs.core.apply.cljs$core$IFn$_invoke$arity$3(cljs.core.assoc,acc,kv);
}),cljs.core.PersistentArrayMap.EMPTY,select);
});
/**
 * Parses select statement into our own select format.
 *   Has no dependency on a database, or a given schema
 *   at this point.
 * 
 *   Select spec has the following keys:
 *   :name  - name of the predicate
 *   :namespace? - if the predicate 'name' has a namespace included
 *   :wildcard? - true if wildcard query
 *   :id? - true if  _id was explicitly requested
 *   :reverse? - if this predicate is a reverse lookup. 'name' will be the non-reverse named predicate
 *   :as - The result key name to use in the results map for this predicate
 *   :recur - number of recur iterations, if specified
 *   :limit - limit the number of results, if specified (100 default)
 *   :offset - offset the number of results, if specified (0 default)
 *   :select - sub-selection for this predicate - only applicable to 'ref' predicates
 *   :compact - If we are to remove namespaces (or names from reverse refs)
 *   
 */
fluree.db.query.fql_parser.parse = (function fluree$db$query$fql_parser$parse(select,opts){
var select__$1 = ((cljs.core.coll_QMARK_(select))?fluree.db.query.fql_parser.to_select_map(select):select);
var default_compact_QMARK_ = cljs.core.cst$kw$compact.cljs$core$IFn$_invoke$arity$1(opts);
return cljs.core.reduce_kv(((function (select__$1,default_compact_QMARK_){
return (function (acc,k,v){
var pred = (((k instanceof cljs.core.Keyword))?fluree.db.util.core.keyword__GT_str(k):(((k instanceof cljs.core.Symbol))?cljs.core.str.cljs$core$IFn$_invoke$arity$1(k):k
));
var v_SINGLEQUOTE_ = ((cljs.core.sequential_QMARK_(v))?fluree.db.query.fql_parser.to_select_map(v):v);
var compact_QMARK_ = ((cljs.core.contains_QMARK_(v_SINGLEQUOTE_,"_compact"))?cljs.core.get.cljs$core$IFn$_invoke$arity$2(v_SINGLEQUOTE_,"_compact"):default_compact_QMARK_);
if(cljs.core._EQ_.cljs$core$IFn$_invoke$arity$2("*",pred)){
return cljs.core.assoc.cljs$core$IFn$_invoke$arity$variadic(acc,cljs.core.cst$kw$wildcard_QMARK_,true,cljs.core.prim_seq.cljs$core$IFn$_invoke$arity$2([cljs.core.cst$kw$compact_QMARK_,compact_QMARK_], 0));
} else {
if(cljs.core._EQ_.cljs$core$IFn$_invoke$arity$2("_id",pred)){
return cljs.core.assoc.cljs$core$IFn$_invoke$arity$3(acc,cljs.core.cst$kw$id_QMARK_,true);
} else {
var _ = (cljs.core.truth_((function (){var and__4120__auto__ = v_SINGLEQUOTE_;
if(cljs.core.truth_(and__4120__auto__)){
return (!(cljs.core.map_QMARK_(v)));
} else {
return and__4120__auto__;
}
})())?(function(){throw cljs.core.ex_info.cljs$core$IFn$_invoke$arity$2(["Invalid select spec: ",cljs.core.str.cljs$core$IFn$_invoke$arity$1(select__$1)].join(''),new cljs.core.PersistentArrayMap(null, 2, [cljs.core.cst$kw$status,(400),cljs.core.cst$kw$db,cljs.core.cst$kw$db_SLASH_invalid_DASH_query], null))})():null);
var sub_select = (function (){var G__110457 = cljs.core.not_empty(cljs.core.dissoc.cljs$core$IFn$_invoke$arity$variadic(v_SINGLEQUOTE_,"_limit",cljs.core.prim_seq.cljs$core$IFn$_invoke$arity$2(["_offset","_as","_recur","_component","_orderBy","_compact"], 0)));
if((G__110457 == null)){
return null;
} else {
return (fluree.db.query.fql_parser.parse.cljs$core$IFn$_invoke$arity$2 ? fluree.db.query.fql_parser.parse.cljs$core$IFn$_invoke$arity$2(G__110457,opts) : fluree.db.query.fql_parser.parse.call(null,G__110457,opts));
}
})();
var namespace_QMARK_ = clojure.string.includes_QMARK_(pred,"/");
var reverse_QMARK_ = clojure.string.includes_QMARK_(pred,"/_");
var pred_SINGLEQUOTE_ = ((reverse_QMARK_)?clojure.string.replace(pred,"/_","/"):pred);
var as = ((cljs.core.contains_QMARK_(v_SINGLEQUOTE_,"_as"))?cljs.core.get.cljs$core$IFn$_invoke$arity$2(v_SINGLEQUOTE_,"_as"):(cljs.core.truth_((function (){var and__4120__auto__ = default_compact_QMARK_;
if(cljs.core.truth_(and__4120__auto__)){
return reverse_QMARK_;
} else {
return and__4120__auto__;
}
})())?cljs.core.re_find(/^[^\/]+/,pred):(cljs.core.truth_((function (){var and__4120__auto__ = default_compact_QMARK_;
if(cljs.core.truth_(and__4120__auto__)){
return namespace_QMARK_;
} else {
return and__4120__auto__;
}
})())?cljs.core.second(cljs.core.re_find(/\/(.+)/,pred)):k
)));
var spec = cljs.core.PersistentHashMap.fromArrays([cljs.core.cst$kw$id_QMARK_,cljs.core.cst$kw$componentFollow_QMARK_,cljs.core.cst$kw$limit,cljs.core.cst$kw$reverse_QMARK_,cljs.core.cst$kw$offset,cljs.core.cst$kw$name,cljs.core.cst$kw$as,cljs.core.cst$kw$namespace_QMARK_,cljs.core.cst$kw$recur,cljs.core.cst$kw$compact_QMARK_,cljs.core.cst$kw$wildcard_QMARK_,cljs.core.cst$kw$select,cljs.core.cst$kw$orderBy],[cljs.core.cst$kw$id_QMARK_.cljs$core$IFn$_invoke$arity$1(sub_select),cljs.core.get.cljs$core$IFn$_invoke$arity$2(v_SINGLEQUOTE_,"_component"),cljs.core.get.cljs$core$IFn$_invoke$arity$3(v_SINGLEQUOTE_,"_limit",(100)),reverse_QMARK_,cljs.core.get.cljs$core$IFn$_invoke$arity$3(v_SINGLEQUOTE_,"_offset",(0)),pred_SINGLEQUOTE_,as,namespace_QMARK_,cljs.core.get.cljs$core$IFn$_invoke$arity$2(v_SINGLEQUOTE_,"_recur"),compact_QMARK_,cljs.core.cst$kw$wildcard_QMARK_.cljs$core$IFn$_invoke$arity$1(sub_select),cljs.core.cst$kw$select.cljs$core$IFn$_invoke$arity$1(sub_select),cljs.core.get.cljs$core$IFn$_invoke$arity$2(v_SINGLEQUOTE_,"_orderBy")]);
if(reverse_QMARK_){
return cljs.core.assoc_in(acc,new cljs.core.PersistentVector(null, 3, 5, cljs.core.PersistentVector.EMPTY_NODE, [cljs.core.cst$kw$select,cljs.core.cst$kw$reverse,pred_SINGLEQUOTE_], null),spec);
} else {
if(namespace_QMARK_){
return cljs.core.assoc_in(acc,new cljs.core.PersistentVector(null, 3, 5, cljs.core.PersistentVector.EMPTY_NODE, [cljs.core.cst$kw$select,cljs.core.cst$kw$pred_DASH_id,pred_SINGLEQUOTE_], null),spec);
} else {
return cljs.core.assoc_in(acc,new cljs.core.PersistentVector(null, 3, 5, cljs.core.PersistentVector.EMPTY_NODE, [cljs.core.cst$kw$select,cljs.core.cst$kw$ns_DASH_lookup,pred_SINGLEQUOTE_], null),spec);

}
}

}
}
});})(select__$1,default_compact_QMARK_))
,cljs.core.PersistentArrayMap.EMPTY,select__$1);
});
fluree.db.query.fql_parser.p__GT_pred_config = (function fluree$db$query$fql_parser$p__GT_pred_config(db,p,compact_QMARK_){
var name = fluree.db.dbproto._p_prop(db,cljs.core.cst$kw$name,p);
return new cljs.core.PersistentArrayMap(null, 8, [cljs.core.cst$kw$p,p,cljs.core.cst$kw$limit,(100),cljs.core.cst$kw$name,name,cljs.core.cst$kw$as,(cljs.core.truth_((function (){var and__4120__auto__ = compact_QMARK_;
if(cljs.core.truth_(and__4120__auto__)){
return name;
} else {
return and__4120__auto__;
}
})())?cljs.core.second(cljs.core.re_find(/\/(.+)/,name)):(function (){var or__4131__auto__ = name;
if(cljs.core.truth_(or__4131__auto__)){
return or__4131__auto__;
} else {
return cljs.core.str.cljs$core$IFn$_invoke$arity$1(p);
}
})()),cljs.core.cst$kw$multi_QMARK_,fluree.db.dbproto._p_prop(db,cljs.core.cst$kw$multi,p),cljs.core.cst$kw$component_QMARK_,fluree.db.dbproto._p_prop(db,cljs.core.cst$kw$component,p),cljs.core.cst$kw$tag_QMARK_,cljs.core._EQ_.cljs$core$IFn$_invoke$arity$2(cljs.core.cst$kw$tag,fluree.db.dbproto._p_prop(db,cljs.core.cst$kw$type,p)),cljs.core.cst$kw$ref_QMARK_,fluree.db.dbproto._p_prop(db,cljs.core.cst$kw$ref_QMARK_,p)], null);
});
/**
 * For a flake selection, build out parts of the
 *   base set of predicates so we don't need to look them up
 *   each time... like multi, component, etc.
 */
fluree.db.query.fql_parser.build_predicate_map = (function fluree$db$query$fql_parser$build_predicate_map(db,pred_name){
var temp__5735__auto__ = fluree.db.dbproto._p_prop(db,cljs.core.cst$kw$id,pred_name);
if(cljs.core.truth_(temp__5735__auto__)){
var p = temp__5735__auto__;
return fluree.db.query.fql_parser.p__GT_pred_config(db,p,false);
} else {
return null;
}
});
/**
 * Given an predicate spec produced by the parsed select statement,
 *   when an predicate does not have a namespace we will default it to
 *   utilize the namespace of the subject.
 * 
 *   This fills out the predicate spec that couldn't be done earlier because
 *   we did not know the collection.
 */
fluree.db.query.fql_parser.ns_lookup_pred_spec = (function fluree$db$query$fql_parser$ns_lookup_pred_spec(db,collection_id,ns_lookup_spec_map){
var collection_name = fluree.db.dbproto._c_prop(db,cljs.core.cst$kw$name,collection_id);
return cljs.core.reduce_kv(((function (collection_name){
return (function (acc,k,v){
var pred = [cljs.core.str.cljs$core$IFn$_invoke$arity$1(collection_name),"/",cljs.core.str.cljs$core$IFn$_invoke$arity$1(k)].join('');
var temp__5733__auto__ = fluree.db.query.fql_parser.build_predicate_map(db,pred);
if(cljs.core.truth_(temp__5733__auto__)){
var p_map = temp__5733__auto__;
return cljs.core.assoc.cljs$core$IFn$_invoke$arity$3(acc,cljs.core.cst$kw$p.cljs$core$IFn$_invoke$arity$1(p_map),cljs.core.merge.cljs$core$IFn$_invoke$arity$variadic(cljs.core.prim_seq.cljs$core$IFn$_invoke$arity$2([p_map,v], 0)));
} else {
return acc;
}
});})(collection_name))
,null,ns_lookup_spec_map);
});
fluree.db.query.fql_parser.parse_db_STAR_ = (function fluree$db$query$fql_parser$parse_db_STAR_(db,sub_select){
var G__110464 = sub_select;
var vec__110465 = G__110464;
var seq__110466 = cljs.core.seq(vec__110465);
var first__110467 = cljs.core.first(seq__110466);
var seq__110466__$1 = cljs.core.next(seq__110466);
var vec__110468 = first__110467;
var k = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(vec__110468,(0),null);
var v = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(vec__110468,(1),null);
var r = seq__110466__$1;
var acc = cljs.core.PersistentArrayMap.EMPTY;
var G__110464__$1 = G__110464;
var acc__$1 = acc;
while(true){
var vec__110532 = G__110464__$1;
var seq__110533 = cljs.core.seq(vec__110532);
var first__110534 = cljs.core.first(seq__110533);
var seq__110533__$1 = cljs.core.next(seq__110533);
var vec__110535 = first__110534;
var k__$1 = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(vec__110535,(0),null);
var v__$1 = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(vec__110535,(1),null);
var r__$1 = seq__110533__$1;
var acc__$2 = acc__$1;
if(cljs.core.not(k__$1)){
return acc__$2;
} else {
var v_SINGLEQUOTE_ = ((cljs.core.not((function (){var fexpr__110538 = new cljs.core.PersistentHashSet(null, new cljs.core.PersistentArrayMap(null, 2, [cljs.core.cst$kw$pred_DASH_id,null,cljs.core.cst$kw$reverse,null], null), null);
return (fexpr__110538.cljs$core$IFn$_invoke$arity$1 ? fexpr__110538.cljs$core$IFn$_invoke$arity$1(k__$1) : fexpr__110538.call(null,k__$1));
})()))?v__$1:(function (){var G__110545 = v__$1;
var vec__110546 = G__110545;
var seq__110547 = cljs.core.seq(vec__110546);
var first__110548 = cljs.core.first(seq__110547);
var seq__110547__$1 = cljs.core.next(seq__110547);
var vec__110549 = first__110548;
var k_STAR_ = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(vec__110549,(0),null);
var v_STAR_ = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(vec__110549,(1),null);
var r_STAR_ = seq__110547__$1;
var acc_STAR_ = cljs.core.PersistentArrayMap.EMPTY;
var G__110545__$1 = G__110545;
var acc_STAR___$1 = acc_STAR_;
while(true){
var vec__110558 = G__110545__$1;
var seq__110559 = cljs.core.seq(vec__110558);
var first__110560 = cljs.core.first(seq__110559);
var seq__110559__$1 = cljs.core.next(seq__110559);
var vec__110561 = first__110560;
var k_STAR___$1 = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(vec__110561,(0),null);
var v_STAR___$1 = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(vec__110561,(1),null);
var r_STAR___$1 = seq__110559__$1;
var acc_STAR___$2 = acc_STAR___$1;
if(cljs.core.not(k_STAR___$1)){
return acc_STAR___$2;
} else {
var p_map = fluree.db.query.fql_parser.build_predicate_map(db,k_STAR___$1);
var acc_STAR__STAR_ = (cljs.core.truth_(p_map)?cljs.core.assoc.cljs$core$IFn$_invoke$arity$3(acc_STAR___$2,cljs.core.cst$kw$p.cljs$core$IFn$_invoke$arity$1(p_map),cljs.core.merge.cljs$core$IFn$_invoke$arity$variadic(cljs.core.prim_seq.cljs$core$IFn$_invoke$arity$2([p_map,v_STAR___$1], 0))):acc_STAR___$2);
var G__110593 = r_STAR___$1;
var G__110594 = acc_STAR__STAR_;
G__110545__$1 = G__110593;
acc_STAR___$1 = G__110594;
continue;
}
break;
}
})());
var v_SINGLEQUOTE__SINGLEQUOTE_ = (function (){var G__110570 = v_SINGLEQUOTE_;
var vec__110571 = G__110570;
var seq__110572 = cljs.core.seq(vec__110571);
var first__110573 = cljs.core.first(seq__110572);
var seq__110572__$1 = cljs.core.next(seq__110572);
var vec__110574 = first__110573;
var k_STAR_ = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(vec__110574,(0),null);
var v_STAR_ = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(vec__110574,(1),null);
var r_STAR_ = seq__110572__$1;
var acc_STAR_ = cljs.core.PersistentArrayMap.EMPTY;
var G__110570__$1 = G__110570;
var acc_STAR___$1 = acc_STAR_;
while(true){
var vec__110585 = G__110570__$1;
var seq__110586 = cljs.core.seq(vec__110585);
var first__110587 = cljs.core.first(seq__110586);
var seq__110586__$1 = cljs.core.next(seq__110586);
var vec__110588 = first__110587;
var k_STAR___$1 = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(vec__110588,(0),null);
var v_STAR___$1 = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(vec__110588,(1),null);
var r_STAR___$1 = seq__110586__$1;
var acc_STAR___$2 = acc_STAR___$1;
if(cljs.core.not(k_STAR___$1)){
return acc_STAR___$2;
} else {
var acc_STAR__STAR_ = (cljs.core.truth_(cljs.core.cst$kw$select.cljs$core$IFn$_invoke$arity$1(v_STAR___$1))?cljs.core.assoc.cljs$core$IFn$_invoke$arity$3(acc_STAR___$2,k_STAR___$1,cljs.core.assoc.cljs$core$IFn$_invoke$arity$3(v_STAR___$1,cljs.core.cst$kw$select,(function (){var G__110591 = db;
var G__110592 = cljs.core.cst$kw$select.cljs$core$IFn$_invoke$arity$1(v_STAR___$1);
return (fluree.db.query.fql_parser.parse_db_STAR_.cljs$core$IFn$_invoke$arity$2 ? fluree.db.query.fql_parser.parse_db_STAR_.cljs$core$IFn$_invoke$arity$2(G__110591,G__110592) : fluree.db.query.fql_parser.parse_db_STAR_.call(null,G__110591,G__110592));
})())):cljs.core.assoc.cljs$core$IFn$_invoke$arity$3(acc_STAR___$2,k_STAR___$1,v_STAR___$1));
var G__110595 = r_STAR___$1;
var G__110596 = acc_STAR__STAR_;
G__110570__$1 = G__110595;
acc_STAR___$1 = G__110596;
continue;
}
break;
}
})();
var acc_SINGLEQUOTE_ = cljs.core.assoc.cljs$core$IFn$_invoke$arity$3(acc__$2,k__$1,v_SINGLEQUOTE__SINGLEQUOTE_);
var G__110597 = r__$1;
var G__110598 = acc_SINGLEQUOTE_;
G__110464__$1 = G__110597;
acc__$1 = G__110598;
continue;
}
break;
}
});
fluree.db.query.fql_parser.select_cache = cljs.core.atom.cljs$core$IFn$_invoke$arity$1(new cljs.core.PersistentArrayMap(null, 1, [cljs.core.cst$kw$version,(0)], null));
fluree.db.query.fql_parser.reset_select_cache_BANG_ = (function fluree$db$query$fql_parser$reset_select_cache_BANG_(){
return cljs.core.reset_BANG_(fluree.db.query.fql_parser.select_cache,new cljs.core.PersistentArrayMap(null, 1, [cljs.core.cst$kw$version,(0)], null));
});
/**
 * Parses, but leverages a specific db to convert predicate
 * names that it can into more complete select statement maps.
 * 
 * Caches results based on database version.
 */
fluree.db.query.fql_parser.parse_db = (function fluree$db$query$fql_parser$parse_db(db,select,opts){
var schema_version = fluree.db.query.schema.version(db);
if((schema_version < cljs.core.cst$kw$version.cljs$core$IFn$_invoke$arity$1(cljs.core.deref(fluree.db.query.fql_parser.select_cache)))){
cljs.core.reset_BANG_(fluree.db.query.fql_parser.select_cache,new cljs.core.PersistentArrayMap(null, 1, [cljs.core.cst$kw$version,schema_version], null));
} else {
}

var or__4131__auto__ = cljs.core.get.cljs$core$IFn$_invoke$arity$2(cljs.core.deref(fluree.db.query.fql_parser.select_cache),new cljs.core.PersistentVector(null, 3, 5, cljs.core.PersistentVector.EMPTY_NODE, [schema_version,select,opts], null));
if(cljs.core.truth_(or__4131__auto__)){
return or__4131__auto__;
} else {
var select_smt = fluree.db.query.fql_parser.parse(select,opts);
var select_smt_STAR_ = cljs.core.assoc.cljs$core$IFn$_invoke$arity$3(select_smt,cljs.core.cst$kw$select,fluree.db.query.fql_parser.parse_db_STAR_(db,cljs.core.cst$kw$select.cljs$core$IFn$_invoke$arity$1(select_smt)));
cljs.core.swap_BANG_.cljs$core$IFn$_invoke$arity$4(fluree.db.query.fql_parser.select_cache,cljs.core.assoc,new cljs.core.PersistentVector(null, 3, 5, cljs.core.PersistentVector.EMPTY_NODE, [schema_version,select,opts], null),select_smt_STAR_);

return select_smt_STAR_;
}
});
