// Compiled by ClojureScript 1.10.520 {:static-fns true, :optimize-constants true}
goog.provide('fluree.db.query.fql');
goog.require('cljs.core');
goog.require('cljs.core.constants');
goog.require('fluree.db.query.fql_parser');
goog.require('fluree.db.dbproto');
goog.require('fluree.db.util.log');
goog.require('clojure.string');
goog.require('fluree.db.query.range');
goog.require('fluree.db.flake');
goog.require('fluree.db.util.core');
goog.require('clojure.set');
goog.require('fluree.db.query.analytical');
goog.require('fluree.db.query.schema');
goog.require('cljs.core.async');
goog.require('fluree.db.util.async');

/**
 * Can sit in a flake pipeline and accumulate a count of 1 for every flake pulled.
 * 
 *   Inputs are:
 *   - fuel - volatile! that holds fuel counter
 *   - max-fuel - throw exception if @fuel ever exceeds this number
 * 
 *   To get final count, just deref fuel volatile when when where is complete.
 */
fluree.db.query.fql.fuel_flake_transducer = (function fluree$db$query$fql$fuel_flake_transducer(fuel,max_fuel){
return (function (xf){
return (function() {
var G__110601 = null;
var G__110601__0 = (function (){
return (xf.cljs$core$IFn$_invoke$arity$0 ? xf.cljs$core$IFn$_invoke$arity$0() : xf.call(null));
});
var G__110601__1 = (function (result){
return (xf.cljs$core$IFn$_invoke$arity$1 ? xf.cljs$core$IFn$_invoke$arity$1(result) : xf.call(null,result));
});
var G__110601__2 = (function (result,flake){
cljs.core._vreset_BANG_(fuel,(cljs.core._deref(fuel) + (1)));

if(cljs.core.truth_((function (){var and__4120__auto__ = max_fuel;
if(cljs.core.truth_(and__4120__auto__)){
return (cljs.core.deref(fuel) > max_fuel);
} else {
return and__4120__auto__;
}
})())){
throw cljs.core.ex_info.cljs$core$IFn$_invoke$arity$2(["Maximum query cost of ",cljs.core.str.cljs$core$IFn$_invoke$arity$1(max_fuel)," exceeded."].join(''),new cljs.core.PersistentArrayMap(null, 2, [cljs.core.cst$kw$status,(400),cljs.core.cst$kw$error,cljs.core.cst$kw$db_SLASH_exceeded_DASH_cost], null));
} else {
}

return (xf.cljs$core$IFn$_invoke$arity$2 ? xf.cljs$core$IFn$_invoke$arity$2(result,flake) : xf.call(null,result,flake));
});
G__110601 = function(result,flake){
switch(arguments.length){
case 0:
return G__110601__0.call(this);
case 1:
return G__110601__1.call(this,result);
case 2:
return G__110601__2.call(this,result,flake);
}
throw(new Error('Invalid arity: ' + arguments.length));
};
G__110601.cljs$core$IFn$_invoke$arity$0 = G__110601__0;
G__110601.cljs$core$IFn$_invoke$arity$1 = G__110601__1;
G__110601.cljs$core$IFn$_invoke$arity$2 = G__110601__2;
return G__110601;
})()
});
});
/**
 * Can sit in a flake group pipeline and accumulate a count of 1 for every flake pulled.
 * 
 *   Supply with a volatile!
 * 
 *   To get final count, just deref volatile when when where is complete.
 */
fluree.db.query.fql.fuel_flakes_transducer = (function fluree$db$query$fql$fuel_flakes_transducer(fuel,max_fuel){
return (function (xf){
return (function() {
var G__110602 = null;
var G__110602__0 = (function (){
return (xf.cljs$core$IFn$_invoke$arity$0 ? xf.cljs$core$IFn$_invoke$arity$0() : xf.call(null));
});
var G__110602__1 = (function (result){
return (xf.cljs$core$IFn$_invoke$arity$1 ? xf.cljs$core$IFn$_invoke$arity$1(result) : xf.call(null,result));
});
var G__110602__2 = (function (result,flakes){
cljs.core._vreset_BANG_(fuel,(cljs.core._deref(fuel) + cljs.core.count(flakes)));

return (xf.cljs$core$IFn$_invoke$arity$2 ? xf.cljs$core$IFn$_invoke$arity$2(result,flakes) : xf.call(null,result,flakes));
});
G__110602 = function(result,flakes){
switch(arguments.length){
case 0:
return G__110602__0.call(this);
case 1:
return G__110602__1.call(this,result);
case 2:
return G__110602__2.call(this,result,flakes);
}
throw(new Error('Invalid arity: ' + arguments.length));
};
G__110602.cljs$core$IFn$_invoke$arity$0 = G__110602__0;
G__110602.cljs$core$IFn$_invoke$arity$1 = G__110602__1;
G__110602.cljs$core$IFn$_invoke$arity$2 = G__110602__2;
return G__110602;
})()
});
});
/**
 * Adds a n amount of fuel and will throw if max fuel exceeded.
 */
fluree.db.query.fql.add_fuel = (function fluree$db$query$fql$add_fuel(fuel,n,max_fuel){
cljs.core._vreset_BANG_(fuel,(cljs.core._deref(fuel) + n));

if(cljs.core.truth_((function (){var and__4120__auto__ = max_fuel;
if(cljs.core.truth_(and__4120__auto__)){
return (cljs.core.deref(fuel) > max_fuel);
} else {
return and__4120__auto__;
}
})())){
throw cljs.core.ex_info.cljs$core$IFn$_invoke$arity$2(["Maximum query cost of ",cljs.core.str.cljs$core$IFn$_invoke$arity$1(max_fuel)," exceeded."].join(''),new cljs.core.PersistentArrayMap(null, 2, [cljs.core.cst$kw$status,(400),cljs.core.cst$kw$error,cljs.core.cst$kw$db_SLASH_exceeded_DASH_cost], null));
} else {
return null;
}
});
/**
 * Just uses query cache to avoid constant lookups.
 */
fluree.db.query.fql.wildcard_pred_spec = (function fluree$db$query$fql$wildcard_pred_spec(db,cache,p,compact_QMARK_){
var or__4131__auto__ = cljs.core.get_in.cljs$core$IFn$_invoke$arity$2(cljs.core.deref(cache),new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [p,compact_QMARK_], null));
if(cljs.core.truth_(or__4131__auto__)){
return or__4131__auto__;
} else {
var p_map = fluree.db.query.fql_parser.p__GT_pred_config(db,p,compact_QMARK_);
cljs.core._vreset_BANG_(cache,cljs.core.assoc_in(cljs.core._deref(cache),new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [p,compact_QMARK_], null),p_map));

return p_map;
}
});
fluree.db.query.fql.compare_fn = (function fluree$db$query$fql$compare_fn(a,b){
if(typeof a === 'string'){
var res = cljs.core.compare(clojure.string.upper_case(a),clojure.string.upper_case(b));
if(cljs.core._EQ_.cljs$core$IFn$_invoke$arity$2(res,(0))){
return ((-1) * cljs.core.compare(a,b));
} else {
return res;
}
} else {
return cljs.core.compare(a,b);
}
});
/**
 * We only need to do this if there is an orderBy, otherwise limit and offset
 *   were performed in index-range.
 */
fluree.db.query.fql.sort_offset_and_limit_res = (function fluree$db$query$fql$sort_offset_and_limit_res(sortPred,sortOrder,offset,limit,res){
if(cljs.core.vector_QMARK_(res)){
var G__110604 = res;
var G__110604__$1 = (cljs.core.truth_(sortPred)?cljs.core.sort_by.cljs$core$IFn$_invoke$arity$3(((function (G__110604){
return (function (p1__110603_SHARP_){
return cljs.core.get.cljs$core$IFn$_invoke$arity$2(p1__110603_SHARP_,sortPred);
});})(G__110604))
,fluree.db.query.fql.compare_fn,G__110604):G__110604);
var G__110604__$2 = ((cljs.core._EQ_.cljs$core$IFn$_invoke$arity$2("DESC",sortOrder))?cljs.core.reverse(G__110604__$1):G__110604__$1);
var G__110604__$3 = (cljs.core.truth_(offset)?cljs.core.drop.cljs$core$IFn$_invoke$arity$2(offset,G__110604__$2):G__110604__$2);
if(cljs.core.truth_(limit)){
return cljs.core.take.cljs$core$IFn$_invoke$arity$2(limit,G__110604__$3);
} else {
return G__110604__$3;
}
} else {
return res;
}
});
fluree.db.query.fql.add_pred = (function fluree$db$query$fql$add_pred(var_args){
var G__110606 = arguments.length;
switch (G__110606) {
case 9:
return fluree.db.query.fql.add_pred.cljs$core$IFn$_invoke$arity$9((arguments[(0)]),(arguments[(1)]),(arguments[(2)]),(arguments[(3)]),(arguments[(4)]),(arguments[(5)]),(arguments[(6)]),(arguments[(7)]),(arguments[(8)]));

break;
case 10:
return fluree.db.query.fql.add_pred.cljs$core$IFn$_invoke$arity$10((arguments[(0)]),(arguments[(1)]),(arguments[(2)]),(arguments[(3)]),(arguments[(4)]),(arguments[(5)]),(arguments[(6)]),(arguments[(7)]),(arguments[(8)]),(arguments[(9)]));

break;
default:
throw (new Error(["Invalid arity: ",cljs.core.str.cljs$core$IFn$_invoke$arity$1(arguments.length)].join('')));

}
});

fluree.db.query.fql.add_pred.cljs$core$IFn$_invoke$arity$9 = (function (db,cache,fuel,max_fuel,acc,pred_spec,flake,componentFollow_QMARK_,recur_QMARK_){
return fluree.db.query.fql.add_pred.cljs$core$IFn$_invoke$arity$10(db,cache,fuel,max_fuel,acc,pred_spec,flake,componentFollow_QMARK_,recur_QMARK_,cljs.core.PersistentArrayMap.EMPTY);
});

fluree.db.query.fql.add_pred.cljs$core$IFn$_invoke$arity$10 = (function (db,cache,fuel,max_fuel,acc,pred_spec,flake,componentFollow_QMARK_,recur_QMARK_,offset_map){
var c__99809__auto__ = cljs.core.async.chan.cljs$core$IFn$_invoke$arity$1((1));
cljs.core.async.impl.dispatch.run(((function (c__99809__auto__){
return (function (){
var f__99810__auto__ = (function (){var switch__99702__auto__ = ((function (c__99809__auto__){
return (function (state_110905){
var state_val_110906 = (state_110905[(1)]);
if((state_val_110906 === (65))){
var state_110905__$1 = state_110905;
if(cljs.core.truth_(componentFollow_QMARK_)){
var statearr_110907_111067 = state_110905__$1;
(statearr_110907_111067[(1)] = (71));

} else {
var statearr_110908_111068 = state_110905__$1;
(statearr_110908_111068[(1)] = (72));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_110906 === (70))){
var inst_110634 = (state_110905[(7)]);
var inst_110772 = (state_110905[(2)]);
var inst_110773 = fluree.db.util.async.throw_err(inst_110772);
var inst_110774 = cljs.core._deref(cache);
var inst_110775 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_110776 = flake.o;
var inst_110777 = cljs.core.cst$kw$name.cljs$core$IFn$_invoke$arity$1(inst_110634);
var inst_110778 = [inst_110776,inst_110777];
var inst_110779 = (new cljs.core.PersistentVector(null,2,(5),inst_110775,inst_110778,null));
var inst_110780 = cljs.core.assoc.cljs$core$IFn$_invoke$arity$3(inst_110774,inst_110779,inst_110773);
var inst_110781 = cljs.core._vreset_BANG_(cache,inst_110780);
var state_110905__$1 = (function (){var statearr_110909 = state_110905;
(statearr_110909[(8)] = inst_110781);

return statearr_110909;
})();
var statearr_110910_111069 = state_110905__$1;
(statearr_110910_111069[(2)] = inst_110773);

(statearr_110910_111069[(1)] = (69));


return cljs.core.cst$kw$recur;
} else {
if((state_val_110906 === (62))){
var inst_110743 = (state_110905[(9)]);
var state_110905__$1 = state_110905;
var statearr_110911_111070 = state_110905__$1;
(statearr_110911_111070[(2)] = inst_110743);

(statearr_110911_111070[(1)] = (63));


return cljs.core.cst$kw$recur;
} else {
if((state_val_110906 === (74))){
var inst_110634 = (state_110905[(7)]);
var inst_110793 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_110794 = flake.o;
var inst_110795 = [inst_110794];
var inst_110796 = (new cljs.core.PersistentVector(null,1,(5),inst_110793,inst_110795,null));
var inst_110797 = [cljs.core.cst$kw$limit];
var inst_110798 = cljs.core.cst$kw$limit.cljs$core$IFn$_invoke$arity$1(inst_110634);
var inst_110799 = [inst_110798];
var inst_110800 = cljs.core.PersistentHashMap.fromArrays(inst_110797,inst_110799);
var inst_110801 = fluree.db.query.range.index_range.cljs$core$IFn$_invoke$arity$5(db,cljs.core.cst$kw$spot,cljs.core._EQ_,inst_110796,inst_110800);
var state_110905__$1 = state_110905;
return cljs.core.async.impl.ioc_helpers.take_BANG_(state_110905__$1,(77),inst_110801);
} else {
if((state_val_110906 === (7))){
var inst_110621 = (state_110905[(2)]);
var state_110905__$1 = state_110905;
if(cljs.core.truth_(inst_110621)){
var statearr_110912_111071 = state_110905__$1;
(statearr_110912_111071[(1)] = (8));

} else {
var statearr_110913_111072 = state_110905__$1;
(statearr_110913_111072[(1)] = (9));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_110906 === (59))){
var inst_110737 = (state_110905[(10)]);
var state_110905__$1 = state_110905;
var statearr_110914_111073 = state_110905__$1;
(statearr_110914_111073[(2)] = inst_110737);

(statearr_110914_111073[(1)] = (60));


return cljs.core.cst$kw$recur;
} else {
if((state_val_110906 === (86))){
var inst_110822 = (state_110905[(11)]);
var state_110905__$1 = state_110905;
var statearr_110915_111074 = state_110905__$1;
(statearr_110915_111074[(2)] = inst_110822);

(statearr_110915_111074[(1)] = (87));


return cljs.core.cst$kw$recur;
} else {
if((state_val_110906 === (20))){
var inst_110634 = (state_110905[(7)]);
var inst_110650 = inst_110634.cljs$lang$protocol_mask$partition0$;
var inst_110651 = (inst_110650 & (64));
var inst_110652 = inst_110634.cljs$core$ISeq$;
var inst_110653 = (cljs.core.PROTOCOL_SENTINEL === inst_110652);
var inst_110654 = ((inst_110651) || (inst_110653));
var state_110905__$1 = state_110905;
if(cljs.core.truth_(inst_110654)){
var statearr_110916_111075 = state_110905__$1;
(statearr_110916_111075[(1)] = (23));

} else {
var statearr_110917_111076 = state_110905__$1;
(statearr_110917_111076[(1)] = (24));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_110906 === (72))){
var state_110905__$1 = state_110905;
var statearr_110918_111077 = state_110905__$1;
(statearr_110918_111077[(2)] = componentFollow_QMARK_);

(statearr_110918_111077[(1)] = (73));


return cljs.core.cst$kw$recur;
} else {
if((state_val_110906 === (58))){
var inst_110737 = (state_110905[(10)]);
var inst_110739 = fluree.db.query.fql.fuel_flake_transducer(fuel,max_fuel);
var inst_110740 = cljs.core.sequence.cljs$core$IFn$_invoke$arity$2(inst_110739,inst_110737);
var state_110905__$1 = state_110905;
var statearr_110919_111078 = state_110905__$1;
(statearr_110919_111078[(2)] = inst_110740);

(statearr_110919_111078[(1)] = (60));


return cljs.core.cst$kw$recur;
} else {
if((state_val_110906 === (60))){
var inst_110743 = (state_110905[(2)]);
var state_110905__$1 = (function (){var statearr_110920 = state_110905;
(statearr_110920[(9)] = inst_110743);

return statearr_110920;
})();
var statearr_110921_111079 = state_110905__$1;
(statearr_110921_111079[(1)] = (61));



return cljs.core.cst$kw$recur;
} else {
if((state_val_110906 === (27))){
var inst_110634 = (state_110905[(7)]);
var state_110905__$1 = state_110905;
var statearr_110923_111080 = state_110905__$1;
(statearr_110923_111080[(2)] = inst_110634);

(statearr_110923_111080[(1)] = (28));


return cljs.core.cst$kw$recur;
} else {
if((state_val_110906 === (1))){
var state_110905__$1 = state_110905;
var statearr_110924_111081 = state_110905__$1;
(statearr_110924_111081[(2)] = null);

(statearr_110924_111081[(1)] = (4));


return cljs.core.cst$kw$recur;
} else {
if((state_val_110906 === (69))){
var inst_110758 = (state_110905[(12)]);
var inst_110783 = (state_110905[(2)]);
var inst_110784 = [inst_110783,offset_map];
var inst_110785 = (new cljs.core.PersistentVector(null,2,(5),inst_110758,inst_110784,null));
var state_110905__$1 = state_110905;
var statearr_110925_111082 = state_110905__$1;
(statearr_110925_111082[(2)] = inst_110785);

(statearr_110925_111082[(1)] = (66));


return cljs.core.cst$kw$recur;
} else {
if((state_val_110906 === (101))){
var state_110905__$1 = state_110905;
var statearr_110926_111083 = state_110905__$1;
(statearr_110926_111083[(1)] = (103));



return cljs.core.cst$kw$recur;
} else {
if((state_val_110906 === (24))){
var state_110905__$1 = state_110905;
var statearr_110928_111084 = state_110905__$1;
(statearr_110928_111084[(2)] = false);

(statearr_110928_111084[(1)] = (25));


return cljs.core.cst$kw$recur;
} else {
if((state_val_110906 === (102))){
var inst_110899 = (state_110905[(2)]);
var state_110905__$1 = state_110905;
var statearr_110929_111085 = state_110905__$1;
(statearr_110929_111085[(2)] = inst_110899);

(statearr_110929_111085[(1)] = (99));


return cljs.core.cst$kw$recur;
} else {
if((state_val_110906 === (55))){
var inst_110861 = (state_110905[(2)]);
var state_110905__$1 = state_110905;
var statearr_110930_111086 = state_110905__$1;
(statearr_110930_111086[(2)] = inst_110861);

(statearr_110930_111086[(1)] = (46));


return cljs.core.cst$kw$recur;
} else {
if((state_val_110906 === (85))){
var inst_110634 = (state_110905[(7)]);
var inst_110645 = (state_110905[(13)]);
var inst_110628 = (state_110905[(14)]);
var inst_110669 = (state_110905[(15)]);
var inst_110667 = (state_110905[(16)]);
var inst_110822 = (state_110905[(11)]);
var inst_110672 = (state_110905[(17)]);
var inst_110671 = (state_110905[(18)]);
var inst_110804 = (state_110905[(19)]);
var inst_110670 = (state_110905[(20)]);
var inst_110668 = (state_110905[(21)]);
var inst_110666 = (state_110905[(22)]);
var inst_110824 = (function (){var map__110611 = inst_110666;
var p = inst_110672;
var pred_spec__$1 = inst_110628;
var orderBy = inst_110670;
var G__110816 = inst_110822;
var children = inst_110804;
var multi_QMARK_ = inst_110667;
var limit = inst_110669;
var offset = inst_110671;
var k = inst_110645;
var pred_spec_SINGLEQUOTE_ = inst_110634;
var ref_QMARK_ = inst_110668;
return ((function (map__110611,p,pred_spec__$1,orderBy,G__110816,children,multi_QMARK_,limit,offset,k,pred_spec_SINGLEQUOTE_,ref_QMARK_,inst_110634,inst_110645,inst_110628,inst_110669,inst_110667,inst_110822,inst_110672,inst_110671,inst_110804,inst_110670,inst_110668,inst_110666,state_val_110906,c__99809__auto__){
return (function (n){
var G__110931 = db;
var G__110932 = cache;
var G__110933 = fuel;
var G__110934 = max_fuel;
var G__110935 = new cljs.core.PersistentArrayMap(null, 1, [cljs.core.cst$kw$wildcard_QMARK_,true], null);
var G__110936 = n;
return (fluree.db.query.fql.flakes__GT_res.cljs$core$IFn$_invoke$arity$6 ? fluree.db.query.fql.flakes__GT_res.cljs$core$IFn$_invoke$arity$6(G__110931,G__110932,G__110933,G__110934,G__110935,G__110936) : fluree.db.query.fql.flakes__GT_res.call(null,G__110931,G__110932,G__110933,G__110934,G__110935,G__110936));
});
;})(map__110611,p,pred_spec__$1,orderBy,G__110816,children,multi_QMARK_,limit,offset,k,pred_spec_SINGLEQUOTE_,ref_QMARK_,inst_110634,inst_110645,inst_110628,inst_110669,inst_110667,inst_110822,inst_110672,inst_110671,inst_110804,inst_110670,inst_110668,inst_110666,state_val_110906,c__99809__auto__))
})();
var inst_110825 = (inst_110824.cljs$core$IFn$_invoke$arity$1 ? inst_110824.cljs$core$IFn$_invoke$arity$1(inst_110822) : inst_110824.call(null,inst_110822));
var state_110905__$1 = state_110905;
var statearr_110937_111087 = state_110905__$1;
(statearr_110937_111087[(2)] = inst_110825);

(statearr_110937_111087[(1)] = (87));


return cljs.core.cst$kw$recur;
} else {
if((state_val_110906 === (39))){
var inst_110672 = (state_110905[(17)]);
var inst_110671 = (state_110905[(18)]);
var inst_110691 = (inst_110671 - (1));
var inst_110692 = cljs.core.assoc.cljs$core$IFn$_invoke$arity$3(offset_map,inst_110672,inst_110691);
var state_110905__$1 = state_110905;
var statearr_110938_111088 = state_110905__$1;
(statearr_110938_111088[(2)] = inst_110692);

(statearr_110938_111088[(1)] = (40));


return cljs.core.cst$kw$recur;
} else {
if((state_val_110906 === (88))){
var inst_110838 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_110839 = ["_id"];
var inst_110840 = flake.o;
var inst_110841 = [inst_110840];
var inst_110842 = cljs.core.PersistentHashMap.fromArrays(inst_110839,inst_110841);
var inst_110843 = [inst_110842,offset_map];
var inst_110844 = (new cljs.core.PersistentVector(null,2,(5),inst_110838,inst_110843,null));
var state_110905__$1 = state_110905;
var statearr_110939_111089 = state_110905__$1;
(statearr_110939_111089[(2)] = inst_110844);

(statearr_110939_111089[(1)] = (90));


return cljs.core.cst$kw$recur;
} else {
if((state_val_110906 === (46))){
var inst_110863 = (state_110905[(2)]);
var state_110905__$1 = state_110905;
var statearr_110940_111090 = state_110905__$1;
(statearr_110940_111090[(2)] = inst_110863);

(statearr_110940_111090[(1)] = (37));


return cljs.core.cst$kw$recur;
} else {
if((state_val_110906 === (4))){
var inst_110615 = (state_110905[(23)]);
var _ = cljs.core.async.impl.ioc_helpers.add_exception_frame(state_110905,(3),Error,null,(2));
var inst_110615__$1 = cljs.core.cst$kw$wildcard_QMARK_.cljs$core$IFn$_invoke$arity$1(pred_spec);
var state_110905__$1 = (function (){var statearr_110941 = state_110905;
(statearr_110941[(23)] = inst_110615__$1);

return statearr_110941;
})();
if(cljs.core.truth_(inst_110615__$1)){
var statearr_110942_111091 = state_110905__$1;
(statearr_110942_111091[(1)] = (5));

} else {
var statearr_110943_111092 = state_110905__$1;
(statearr_110943_111092[(1)] = (6));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_110906 === (77))){
var inst_110804 = (state_110905[(19)]);
var inst_110803 = (state_110905[(2)]);
var inst_110804__$1 = fluree.db.util.async.throw_err(inst_110803);
var inst_110805 = cljs.core.empty_QMARK_(inst_110804__$1);
var state_110905__$1 = (function (){var statearr_110944 = state_110905;
(statearr_110944[(19)] = inst_110804__$1);

return statearr_110944;
})();
if(inst_110805){
var statearr_110945_111093 = state_110905__$1;
(statearr_110945_111093[(1)] = (78));

} else {
var statearr_110946_111094 = state_110905__$1;
(statearr_110946_111094[(1)] = (79));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_110906 === (95))){
var inst_110869 = (state_110905[(24)]);
var state_110905__$1 = state_110905;
var statearr_110947_111095 = state_110905__$1;
(statearr_110947_111095[(2)] = inst_110869);

(statearr_110947_111095[(1)] = (96));


return cljs.core.cst$kw$recur;
} else {
if((state_val_110906 === (54))){
var inst_110634 = (state_110905[(7)]);
var inst_110756 = cljs.core.cst$kw$tag_QMARK_.cljs$core$IFn$_invoke$arity$1(inst_110634);
var state_110905__$1 = state_110905;
if(cljs.core.truth_(inst_110756)){
var statearr_110948_111096 = state_110905__$1;
(statearr_110948_111096[(1)] = (64));

} else {
var statearr_110949_111097 = state_110905__$1;
(statearr_110949_111097[(1)] = (65));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_110906 === (92))){
var state_110905__$1 = state_110905;
var statearr_110950_111098 = state_110905__$1;
(statearr_110950_111098[(2)] = null);

(statearr_110950_111098[(1)] = (93));


return cljs.core.cst$kw$recur;
} else {
if((state_val_110906 === (104))){
var state_110905__$1 = state_110905;
var statearr_110951_111099 = state_110905__$1;
(statearr_110951_111099[(2)] = null);

(statearr_110951_111099[(1)] = (105));


return cljs.core.cst$kw$recur;
} else {
if((state_val_110906 === (15))){
var inst_110634 = (state_110905[(7)]);
var inst_110638 = (state_110905[(25)]);
var inst_110638__$1 = cljs.core.cst$kw$name.cljs$core$IFn$_invoke$arity$1(inst_110634);
var state_110905__$1 = (function (){var statearr_110952 = state_110905;
(statearr_110952[(25)] = inst_110638__$1);

return statearr_110952;
})();
if(cljs.core.truth_(inst_110638__$1)){
var statearr_110953_111100 = state_110905__$1;
(statearr_110953_111100[(1)] = (17));

} else {
var statearr_110954_111101 = state_110905__$1;
(statearr_110954_111101[(1)] = (18));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_110906 === (48))){
var inst_110712 = (state_110905[(26)]);
var state_110905__$1 = state_110905;
var statearr_110955_111102 = state_110905__$1;
(statearr_110955_111102[(2)] = inst_110712);

(statearr_110955_111102[(1)] = (49));


return cljs.core.cst$kw$recur;
} else {
if((state_val_110906 === (50))){
var inst_110714 = (state_110905[(27)]);
var state_110905__$1 = state_110905;
var statearr_110956_111103 = state_110905__$1;
(statearr_110956_111103[(2)] = inst_110714);

(statearr_110956_111103[(1)] = (52));


return cljs.core.cst$kw$recur;
} else {
if((state_val_110906 === (75))){
var inst_110668 = (state_110905[(21)]);
var state_110905__$1 = state_110905;
if(cljs.core.truth_(inst_110668)){
var statearr_110957_111104 = state_110905__$1;
(statearr_110957_111104[(1)] = (88));

} else {
var statearr_110958_111105 = state_110905__$1;
(statearr_110958_111105[(1)] = (89));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_110906 === (99))){
var inst_110901 = (state_110905[(2)]);
var state_110905__$1 = state_110905;
var statearr_110959_111106 = state_110905__$1;
(statearr_110959_111106[(2)] = inst_110901);


cljs.core.async.impl.ioc_helpers.process_exception(state_110905__$1);

return cljs.core.cst$kw$recur;
} else {
if((state_val_110906 === (21))){
var state_110905__$1 = state_110905;
var statearr_110960_111107 = state_110905__$1;
(statearr_110960_111107[(2)] = false);

(statearr_110960_111107[(1)] = (22));


return cljs.core.cst$kw$recur;
} else {
if((state_val_110906 === (31))){
var inst_110684 = (state_110905[(2)]);
var state_110905__$1 = state_110905;
if(cljs.core.truth_(inst_110684)){
var statearr_110961_111108 = state_110905__$1;
(statearr_110961_111108[(1)] = (35));

} else {
var statearr_110962_111109 = state_110905__$1;
(statearr_110962_111109[(1)] = (36));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_110906 === (32))){
var inst_110672 = (state_110905[(17)]);
var inst_110671 = (state_110905[(18)]);
var inst_110675 = cljs.core.not_EQ_.cljs$core$IFn$_invoke$arity$2((0),inst_110671);
var inst_110676 = cljs.core.get.cljs$core$IFn$_invoke$arity$2(offset_map,inst_110672);
var inst_110677 = cljs.core.not_EQ_.cljs$core$IFn$_invoke$arity$2((0),inst_110676);
var inst_110678 = ((inst_110675) && (inst_110677));
var state_110905__$1 = state_110905;
var statearr_110963_111110 = state_110905__$1;
(statearr_110963_111110[(2)] = inst_110678);

(statearr_110963_111110[(1)] = (34));


return cljs.core.cst$kw$recur;
} else {
if((state_val_110906 === (40))){
var inst_110686 = (state_110905[(28)]);
var inst_110694 = (state_110905[(2)]);
var inst_110695 = [null,inst_110694];
var inst_110696 = (new cljs.core.PersistentVector(null,2,(5),inst_110686,inst_110695,null));
var state_110905__$1 = state_110905;
var statearr_110964_111111 = state_110905__$1;
(statearr_110964_111111[(2)] = inst_110696);

(statearr_110964_111111[(1)] = (37));


return cljs.core.cst$kw$recur;
} else {
if((state_val_110906 === (91))){
var inst_110847 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_110848 = flake.o;
var inst_110849 = [inst_110848,offset_map];
var inst_110850 = (new cljs.core.PersistentVector(null,2,(5),inst_110847,inst_110849,null));
var state_110905__$1 = state_110905;
var statearr_110965_111112 = state_110905__$1;
(statearr_110965_111112[(2)] = inst_110850);

(statearr_110965_111112[(1)] = (93));


return cljs.core.cst$kw$recur;
} else {
if((state_val_110906 === (56))){
var inst_110728 = (state_110905[(29)]);
var inst_110751 = (state_110905[(2)]);
var inst_110752 = fluree.db.util.async.throw_err(inst_110751);
var inst_110753 = [inst_110752,offset_map];
var inst_110754 = (new cljs.core.PersistentVector(null,2,(5),inst_110728,inst_110753,null));
var state_110905__$1 = state_110905;
var statearr_110966_111113 = state_110905__$1;
(statearr_110966_111113[(2)] = inst_110754);

(statearr_110966_111113[(1)] = (55));


return cljs.core.cst$kw$recur;
} else {
if((state_val_110906 === (33))){
var inst_110671 = (state_110905[(18)]);
var state_110905__$1 = state_110905;
var statearr_110967_111114 = state_110905__$1;
(statearr_110967_111114[(2)] = inst_110671);

(statearr_110967_111114[(1)] = (34));


return cljs.core.cst$kw$recur;
} else {
if((state_val_110906 === (13))){
var inst_110634 = (state_110905[(7)]);
var inst_110635 = (state_110905[(30)]);
var inst_110634__$1 = (state_110905[(2)]);
var inst_110635__$1 = cljs.core.cst$kw$as.cljs$core$IFn$_invoke$arity$1(inst_110634__$1);
var state_110905__$1 = (function (){var statearr_110968 = state_110905;
(statearr_110968[(7)] = inst_110634__$1);

(statearr_110968[(30)] = inst_110635__$1);

return statearr_110968;
})();
if(cljs.core.truth_(inst_110635__$1)){
var statearr_110969_111115 = state_110905__$1;
(statearr_110969_111115[(1)] = (14));

} else {
var statearr_110970_111116 = state_110905__$1;
(statearr_110970_111116[(1)] = (15));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_110906 === (22))){
var inst_110661 = (state_110905[(2)]);
var state_110905__$1 = state_110905;
if(cljs.core.truth_(inst_110661)){
var statearr_110971_111117 = state_110905__$1;
(statearr_110971_111117[(1)] = (26));

} else {
var statearr_110972_111118 = state_110905__$1;
(statearr_110972_111118[(1)] = (27));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_110906 === (90))){
var inst_110855 = (state_110905[(2)]);
var state_110905__$1 = state_110905;
var statearr_110973_111119 = state_110905__$1;
(statearr_110973_111119[(2)] = inst_110855);

(statearr_110973_111119[(1)] = (76));


return cljs.core.cst$kw$recur;
} else {
if((state_val_110906 === (36))){
var inst_110667 = (state_110905[(16)]);
var state_110905__$1 = state_110905;
if(cljs.core.truth_(inst_110667)){
var statearr_110974_111120 = state_110905__$1;
(statearr_110974_111120[(1)] = (41));

} else {
var statearr_110975_111121 = state_110905__$1;
(statearr_110975_111121[(1)] = (42));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_110906 === (41))){
var inst_110645 = (state_110905[(13)]);
var inst_110669 = (state_110905[(15)]);
var inst_110670 = (state_110905[(20)]);
var inst_110699 = cljs.core.not(inst_110670);
var inst_110700 = cljs.core.get.cljs$core$IFn$_invoke$arity$2(acc,inst_110645);
var inst_110701 = cljs.core.count(inst_110700);
var inst_110702 = (inst_110701 >= inst_110669);
var inst_110703 = ((inst_110699) && (inst_110702));
var state_110905__$1 = state_110905;
var statearr_110976_111122 = state_110905__$1;
(statearr_110976_111122[(2)] = inst_110703);

(statearr_110976_111122[(1)] = (43));


return cljs.core.cst$kw$recur;
} else {
if((state_val_110906 === (89))){
var state_110905__$1 = state_110905;
var statearr_110977_111123 = state_110905__$1;
(statearr_110977_111123[(1)] = (91));



return cljs.core.cst$kw$recur;
} else {
if((state_val_110906 === (100))){
var inst_110645 = (state_110905[(13)]);
var inst_110866 = (state_110905[(31)]);
var inst_110867 = (state_110905[(32)]);
var inst_110886 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_110887 = cljs.core.assoc.cljs$core$IFn$_invoke$arity$3(acc,inst_110645,inst_110866);
var inst_110888 = [inst_110887,inst_110867];
var inst_110889 = (new cljs.core.PersistentVector(null,2,(5),inst_110886,inst_110888,null));
var state_110905__$1 = state_110905;
var statearr_110979_111124 = state_110905__$1;
(statearr_110979_111124[(2)] = inst_110889);

(statearr_110979_111124[(1)] = (102));


return cljs.core.cst$kw$recur;
} else {
if((state_val_110906 === (43))){
var inst_110706 = (state_110905[(2)]);
var state_110905__$1 = state_110905;
if(cljs.core.truth_(inst_110706)){
var statearr_110980_111125 = state_110905__$1;
(statearr_110980_111125[(1)] = (44));

} else {
var statearr_110981_111126 = state_110905__$1;
(statearr_110981_111126[(1)] = (45));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_110906 === (61))){
var inst_110634 = (state_110905[(7)]);
var inst_110645 = (state_110905[(13)]);
var inst_110628 = (state_110905[(14)]);
var inst_110669 = (state_110905[(15)]);
var inst_110667 = (state_110905[(16)]);
var inst_110743 = (state_110905[(9)]);
var inst_110672 = (state_110905[(17)]);
var inst_110671 = (state_110905[(18)]);
var inst_110670 = (state_110905[(20)]);
var inst_110668 = (state_110905[(21)]);
var inst_110727 = (state_110905[(33)]);
var inst_110666 = (state_110905[(22)]);
var inst_110745 = (function (){var map__110611 = inst_110666;
var p = inst_110672;
var pred_spec__$1 = inst_110628;
var orderBy = inst_110670;
var nested_select_spec = inst_110727;
var multi_QMARK_ = inst_110667;
var limit = inst_110669;
var offset = inst_110671;
var G__110729 = inst_110743;
var k = inst_110645;
var pred_spec_SINGLEQUOTE_ = inst_110634;
var ref_QMARK_ = inst_110668;
return ((function (map__110611,p,pred_spec__$1,orderBy,nested_select_spec,multi_QMARK_,limit,offset,G__110729,k,pred_spec_SINGLEQUOTE_,ref_QMARK_,inst_110634,inst_110645,inst_110628,inst_110669,inst_110667,inst_110743,inst_110672,inst_110671,inst_110670,inst_110668,inst_110727,inst_110666,state_val_110906,c__99809__auto__){
return (function (n){
return (fluree.db.query.fql.flakes__GT_res.cljs$core$IFn$_invoke$arity$6 ? fluree.db.query.fql.flakes__GT_res.cljs$core$IFn$_invoke$arity$6(db,cache,fuel,max_fuel,nested_select_spec,n) : fluree.db.query.fql.flakes__GT_res.call(null,db,cache,fuel,max_fuel,nested_select_spec,n));
});
;})(map__110611,p,pred_spec__$1,orderBy,nested_select_spec,multi_QMARK_,limit,offset,G__110729,k,pred_spec_SINGLEQUOTE_,ref_QMARK_,inst_110634,inst_110645,inst_110628,inst_110669,inst_110667,inst_110743,inst_110672,inst_110671,inst_110670,inst_110668,inst_110727,inst_110666,state_val_110906,c__99809__auto__))
})();
var inst_110746 = (inst_110745.cljs$core$IFn$_invoke$arity$1 ? inst_110745.cljs$core$IFn$_invoke$arity$1(inst_110743) : inst_110745.call(null,inst_110743));
var state_110905__$1 = state_110905;
var statearr_110982_111127 = state_110905__$1;
(statearr_110982_111127[(2)] = inst_110746);

(statearr_110982_111127[(1)] = (63));


return cljs.core.cst$kw$recur;
} else {
if((state_val_110906 === (29))){
var inst_110671 = (state_110905[(18)]);
var state_110905__$1 = state_110905;
if(cljs.core.truth_(inst_110671)){
var statearr_110983_111128 = state_110905__$1;
(statearr_110983_111128[(1)] = (32));

} else {
var statearr_110984_111129 = state_110905__$1;
(statearr_110984_111129[(1)] = (33));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_110906 === (44))){
var inst_110708 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_110709 = [null,offset_map];
var inst_110710 = (new cljs.core.PersistentVector(null,2,(5),inst_110708,inst_110709,null));
var state_110905__$1 = state_110905;
var statearr_110985_111130 = state_110905__$1;
(statearr_110985_111130[(2)] = inst_110710);

(statearr_110985_111130[(1)] = (46));


return cljs.core.cst$kw$recur;
} else {
if((state_val_110906 === (93))){
var inst_110853 = (state_110905[(2)]);
var state_110905__$1 = state_110905;
var statearr_110986_111131 = state_110905__$1;
(statearr_110986_111131[(2)] = inst_110853);

(statearr_110986_111131[(1)] = (90));


return cljs.core.cst$kw$recur;
} else {
if((state_val_110906 === (6))){
var inst_110615 = (state_110905[(23)]);
var state_110905__$1 = state_110905;
var statearr_110987_111132 = state_110905__$1;
(statearr_110987_111132[(2)] = inst_110615);

(statearr_110987_111132[(1)] = (7));


return cljs.core.cst$kw$recur;
} else {
if((state_val_110906 === (28))){
var inst_110667 = (state_110905[(16)]);
var inst_110666 = (state_110905[(22)]);
var inst_110666__$1 = (state_110905[(2)]);
var inst_110667__$1 = cljs.core.get.cljs$core$IFn$_invoke$arity$2(inst_110666__$1,cljs.core.cst$kw$multi_QMARK_);
var inst_110668 = cljs.core.get.cljs$core$IFn$_invoke$arity$2(inst_110666__$1,cljs.core.cst$kw$ref_QMARK_);
var inst_110669 = cljs.core.get.cljs$core$IFn$_invoke$arity$2(inst_110666__$1,cljs.core.cst$kw$limit);
var inst_110670 = cljs.core.get.cljs$core$IFn$_invoke$arity$2(inst_110666__$1,cljs.core.cst$kw$orderBy);
var inst_110671 = cljs.core.get.cljs$core$IFn$_invoke$arity$2(inst_110666__$1,cljs.core.cst$kw$offset);
var inst_110672 = cljs.core.get.cljs$core$IFn$_invoke$arity$2(inst_110666__$1,cljs.core.cst$kw$p);
var state_110905__$1 = (function (){var statearr_110988 = state_110905;
(statearr_110988[(15)] = inst_110669);

(statearr_110988[(16)] = inst_110667__$1);

(statearr_110988[(17)] = inst_110672);

(statearr_110988[(18)] = inst_110671);

(statearr_110988[(20)] = inst_110670);

(statearr_110988[(21)] = inst_110668);

(statearr_110988[(22)] = inst_110666__$1);

return statearr_110988;
})();
if(cljs.core.truth_(inst_110667__$1)){
var statearr_110989_111133 = state_110905__$1;
(statearr_110989_111133[(1)] = (29));

} else {
var statearr_110990_111134 = state_110905__$1;
(statearr_110990_111134[(1)] = (30));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_110906 === (64))){
var inst_110634 = (state_110905[(7)]);
var inst_110765 = (state_110905[(34)]);
var inst_110758 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_110759 = cljs.core.deref(cache);
var inst_110760 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_110761 = flake.o;
var inst_110762 = cljs.core.cst$kw$name.cljs$core$IFn$_invoke$arity$1(inst_110634);
var inst_110763 = [inst_110761,inst_110762];
var inst_110764 = (new cljs.core.PersistentVector(null,2,(5),inst_110760,inst_110763,null));
var inst_110765__$1 = cljs.core.get.cljs$core$IFn$_invoke$arity$2(inst_110759,inst_110764);
var state_110905__$1 = (function (){var statearr_110991 = state_110905;
(statearr_110991[(12)] = inst_110758);

(statearr_110991[(34)] = inst_110765__$1);

return statearr_110991;
})();
if(cljs.core.truth_(inst_110765__$1)){
var statearr_110992_111135 = state_110905__$1;
(statearr_110992_111135[(1)] = (67));

} else {
var statearr_110993_111136 = state_110905__$1;
(statearr_110993_111136[(1)] = (68));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_110906 === (103))){
var inst_110867 = (state_110905[(32)]);
var inst_110892 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_110893 = [acc,inst_110867];
var inst_110894 = (new cljs.core.PersistentVector(null,2,(5),inst_110892,inst_110893,null));
var state_110905__$1 = state_110905;
var statearr_110994_111137 = state_110905__$1;
(statearr_110994_111137[(2)] = inst_110894);

(statearr_110994_111137[(1)] = (105));


return cljs.core.cst$kw$recur;
} else {
if((state_val_110906 === (51))){
var inst_110634 = (state_110905[(7)]);
var inst_110717 = cljs.core.cst$kw$wildcard_QMARK_.cljs$core$IFn$_invoke$arity$1(inst_110634);
var state_110905__$1 = state_110905;
var statearr_110995_111138 = state_110905__$1;
(statearr_110995_111138[(2)] = inst_110717);

(statearr_110995_111138[(1)] = (52));


return cljs.core.cst$kw$recur;
} else {
if((state_val_110906 === (25))){
var inst_110658 = (state_110905[(2)]);
var state_110905__$1 = state_110905;
var statearr_110996_111139 = state_110905__$1;
(statearr_110996_111139[(2)] = inst_110658);

(statearr_110996_111139[(1)] = (22));


return cljs.core.cst$kw$recur;
} else {
if((state_val_110906 === (34))){
var inst_110681 = (state_110905[(2)]);
var state_110905__$1 = state_110905;
var statearr_110997_111140 = state_110905__$1;
(statearr_110997_111140[(2)] = inst_110681);

(statearr_110997_111140[(1)] = (31));


return cljs.core.cst$kw$recur;
} else {
if((state_val_110906 === (17))){
var inst_110638 = (state_110905[(25)]);
var state_110905__$1 = state_110905;
var statearr_110998_111141 = state_110905__$1;
(statearr_110998_111141[(2)] = inst_110638);

(statearr_110998_111141[(1)] = (19));


return cljs.core.cst$kw$recur;
} else {
if((state_val_110906 === (3))){
var inst_110607 = (state_110905[(2)]);
var state_110905__$1 = state_110905;
var statearr_110999_111142 = state_110905__$1;
(statearr_110999_111142[(2)] = inst_110607);


cljs.core.async.impl.ioc_helpers.process_exception(state_110905__$1);

return cljs.core.cst$kw$recur;
} else {
if((state_val_110906 === (12))){
var inst_110628 = (state_110905[(14)]);
var inst_110632 = cljs.core.assoc.cljs$core$IFn$_invoke$arity$3(inst_110628,cljs.core.cst$kw$componentFollow_QMARK_,componentFollow_QMARK_);
var state_110905__$1 = state_110905;
var statearr_111000_111143 = state_110905__$1;
(statearr_111000_111143[(2)] = inst_110632);

(statearr_111000_111143[(1)] = (13));


return cljs.core.cst$kw$recur;
} else {
if((state_val_110906 === (2))){
var inst_110903 = (state_110905[(2)]);
var state_110905__$1 = state_110905;
return cljs.core.async.impl.ioc_helpers.return_chan(state_110905__$1,inst_110903);
} else {
if((state_val_110906 === (66))){
var inst_110859 = (state_110905[(2)]);
var state_110905__$1 = state_110905;
var statearr_111001_111144 = state_110905__$1;
(statearr_111001_111144[(2)] = inst_110859);

(statearr_111001_111144[(1)] = (55));


return cljs.core.cst$kw$recur;
} else {
if((state_val_110906 === (23))){
var state_110905__$1 = state_110905;
var statearr_111002_111145 = state_110905__$1;
(statearr_111002_111145[(2)] = true);

(statearr_111002_111145[(1)] = (25));


return cljs.core.cst$kw$recur;
} else {
if((state_val_110906 === (47))){
var inst_110634 = (state_110905[(7)]);
var inst_110714 = (state_110905[(27)]);
var inst_110714__$1 = cljs.core.cst$kw$select.cljs$core$IFn$_invoke$arity$1(inst_110634);
var state_110905__$1 = (function (){var statearr_111003 = state_110905;
(statearr_111003[(27)] = inst_110714__$1);

return statearr_111003;
})();
if(cljs.core.truth_(inst_110714__$1)){
var statearr_111004_111146 = state_110905__$1;
(statearr_111004_111146[(1)] = (50));

} else {
var statearr_111005_111147 = state_110905__$1;
(statearr_111005_111147[(1)] = (51));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_110906 === (35))){
var inst_110672 = (state_110905[(17)]);
var inst_110686 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_110687 = cljs.core.get.cljs$core$IFn$_invoke$arity$2(offset_map,inst_110672);
var state_110905__$1 = (function (){var statearr_111006 = state_110905;
(statearr_111006[(28)] = inst_110686);

return statearr_111006;
})();
if(cljs.core.truth_(inst_110687)){
var statearr_111007_111148 = state_110905__$1;
(statearr_111007_111148[(1)] = (38));

} else {
var statearr_111008_111149 = state_110905__$1;
(statearr_111008_111149[(1)] = (39));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_110906 === (82))){
var inst_110804 = (state_110905[(19)]);
var inst_110818 = fluree.db.query.fql.fuel_flake_transducer(fuel,max_fuel);
var inst_110819 = cljs.core.sequence.cljs$core$IFn$_invoke$arity$2(inst_110818,inst_110804);
var state_110905__$1 = state_110905;
var statearr_111009_111150 = state_110905__$1;
(statearr_111009_111150[(2)] = inst_110819);

(statearr_111009_111150[(1)] = (84));


return cljs.core.cst$kw$recur;
} else {
if((state_val_110906 === (76))){
var inst_110857 = (state_110905[(2)]);
var state_110905__$1 = state_110905;
var statearr_111010_111151 = state_110905__$1;
(statearr_111010_111151[(2)] = inst_110857);

(statearr_111010_111151[(1)] = (66));


return cljs.core.cst$kw$recur;
} else {
if((state_val_110906 === (97))){
var inst_110645 = (state_110905[(13)]);
var inst_110866 = (state_110905[(31)]);
var inst_110867 = (state_110905[(32)]);
var inst_110875 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_110876 = cljs.core.PersistentVector.EMPTY;
var inst_110877 = cljs.core.get.cljs$core$IFn$_invoke$arity$3(acc,inst_110645,inst_110876);
var inst_110878 = cljs.core.conj.cljs$core$IFn$_invoke$arity$2(inst_110877,inst_110866);
var inst_110879 = cljs.core.assoc.cljs$core$IFn$_invoke$arity$3(acc,inst_110645,inst_110878);
var inst_110880 = [inst_110879,inst_110867];
var inst_110881 = (new cljs.core.PersistentVector(null,2,(5),inst_110875,inst_110880,null));
var state_110905__$1 = state_110905;
var statearr_111011_111152 = state_110905__$1;
(statearr_111011_111152[(2)] = inst_110881);

(statearr_111011_111152[(1)] = (99));


return cljs.core.cst$kw$recur;
} else {
if((state_val_110906 === (19))){
var inst_110643 = (state_110905[(2)]);
var state_110905__$1 = state_110905;
var statearr_111012_111153 = state_110905__$1;
(statearr_111012_111153[(2)] = inst_110643);

(statearr_111012_111153[(1)] = (16));


return cljs.core.cst$kw$recur;
} else {
if((state_val_110906 === (57))){
var inst_110736 = (state_110905[(2)]);
var inst_110737 = fluree.db.util.async.throw_err(inst_110736);
var state_110905__$1 = (function (){var statearr_111013 = state_110905;
(statearr_111013[(10)] = inst_110737);

return statearr_111013;
})();
if(cljs.core.truth_(fuel)){
var statearr_111014_111154 = state_110905__$1;
(statearr_111014_111154[(1)] = (58));

} else {
var statearr_111015_111155 = state_110905__$1;
(statearr_111015_111155[(1)] = (59));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_110906 === (68))){
var inst_110634 = (state_110905[(7)]);
var inst_110768 = flake.o;
var inst_110769 = cljs.core.cst$kw$name.cljs$core$IFn$_invoke$arity$1(inst_110634);
var inst_110770 = fluree.db.dbproto._tag.cljs$core$IFn$_invoke$arity$3(db,inst_110768,inst_110769);
var state_110905__$1 = state_110905;
return cljs.core.async.impl.ioc_helpers.take_BANG_(state_110905__$1,(70),inst_110770);
} else {
if((state_val_110906 === (11))){
var inst_110628 = (state_110905[(14)]);
var state_110905__$1 = state_110905;
var statearr_111016_111156 = state_110905__$1;
(statearr_111016_111156[(2)] = inst_110628);

(statearr_111016_111156[(1)] = (13));


return cljs.core.cst$kw$recur;
} else {
if((state_val_110906 === (9))){
var state_110905__$1 = state_110905;
var statearr_111017_111157 = state_110905__$1;
(statearr_111017_111157[(2)] = pred_spec);

(statearr_111017_111157[(1)] = (10));


return cljs.core.cst$kw$recur;
} else {
if((state_val_110906 === (5))){
var inst_110617 = cljs.core.cst$kw$as.cljs$core$IFn$_invoke$arity$1(pred_spec);
var inst_110618 = (inst_110617 == null);
var state_110905__$1 = state_110905;
var statearr_111018_111158 = state_110905__$1;
(statearr_111018_111158[(2)] = inst_110618);

(statearr_111018_111158[(1)] = (7));


return cljs.core.cst$kw$recur;
} else {
if((state_val_110906 === (83))){
var inst_110804 = (state_110905[(19)]);
var state_110905__$1 = state_110905;
var statearr_111019_111159 = state_110905__$1;
(statearr_111019_111159[(2)] = inst_110804);

(statearr_111019_111159[(1)] = (84));


return cljs.core.cst$kw$recur;
} else {
if((state_val_110906 === (14))){
var inst_110635 = (state_110905[(30)]);
var state_110905__$1 = state_110905;
var statearr_111020_111160 = state_110905__$1;
(statearr_111020_111160[(2)] = inst_110635);

(statearr_111020_111160[(1)] = (16));


return cljs.core.cst$kw$recur;
} else {
if((state_val_110906 === (45))){
var inst_110712 = (state_110905[(26)]);
var inst_110712__$1 = cljs.core.not(recur_QMARK_);
var state_110905__$1 = (function (){var statearr_111021 = state_110905;
(statearr_111021[(26)] = inst_110712__$1);

return statearr_111021;
})();
if(inst_110712__$1){
var statearr_111022_111161 = state_110905__$1;
(statearr_111022_111161[(1)] = (47));

} else {
var statearr_111023_111162 = state_110905__$1;
(statearr_111023_111162[(1)] = (48));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_110906 === (53))){
var inst_110634 = (state_110905[(7)]);
var inst_110724 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_110725 = [cljs.core.cst$kw$wildcard_QMARK_,cljs.core.cst$kw$compact_QMARK_,cljs.core.cst$kw$select];
var inst_110726 = (new cljs.core.PersistentVector(null,3,(5),inst_110724,inst_110725,null));
var inst_110727 = cljs.core.select_keys(inst_110634,inst_110726);
var inst_110728 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_110730 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_110731 = flake.o;
var inst_110732 = [inst_110731];
var inst_110733 = (new cljs.core.PersistentVector(null,1,(5),inst_110730,inst_110732,null));
var inst_110734 = fluree.db.query.range.index_range.cljs$core$IFn$_invoke$arity$4(db,cljs.core.cst$kw$spot,cljs.core._EQ_,inst_110733);
var state_110905__$1 = (function (){var statearr_111024 = state_110905;
(statearr_111024[(29)] = inst_110728);

(statearr_111024[(33)] = inst_110727);

return statearr_111024;
})();
return cljs.core.async.impl.ioc_helpers.take_BANG_(state_110905__$1,(57),inst_110734);
} else {
if((state_val_110906 === (78))){
var inst_110807 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_110808 = ["_id"];
var inst_110809 = flake.o;
var inst_110810 = [inst_110809];
var inst_110811 = cljs.core.PersistentHashMap.fromArrays(inst_110808,inst_110810);
var inst_110812 = [inst_110811,offset_map];
var inst_110813 = (new cljs.core.PersistentVector(null,2,(5),inst_110807,inst_110812,null));
var state_110905__$1 = state_110905;
var statearr_111025_111163 = state_110905__$1;
(statearr_111025_111163[(2)] = inst_110813);

(statearr_111025_111163[(1)] = (80));


return cljs.core.cst$kw$recur;
} else {
if((state_val_110906 === (26))){
var inst_110634 = (state_110905[(7)]);
var inst_110663 = cljs.core.apply.cljs$core$IFn$_invoke$arity$2(cljs.core.hash_map,inst_110634);
var state_110905__$1 = state_110905;
var statearr_111026_111164 = state_110905__$1;
(statearr_111026_111164[(2)] = inst_110663);

(statearr_111026_111164[(1)] = (28));


return cljs.core.cst$kw$recur;
} else {
if((state_val_110906 === (16))){
var inst_110634 = (state_110905[(7)]);
var inst_110645 = (state_110905[(2)]);
var inst_110647 = (inst_110634 == null);
var inst_110648 = cljs.core.not(inst_110647);
var state_110905__$1 = (function (){var statearr_111027 = state_110905;
(statearr_111027[(13)] = inst_110645);

return statearr_111027;
})();
if(inst_110648){
var statearr_111028_111165 = state_110905__$1;
(statearr_111028_111165[(1)] = (20));

} else {
var statearr_111029_111166 = state_110905__$1;
(statearr_111029_111166[(1)] = (21));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_110906 === (81))){
var inst_110815 = (state_110905[(35)]);
var inst_110830 = (state_110905[(2)]);
var inst_110831 = fluree.db.util.async.throw_err(inst_110830);
var inst_110832 = [inst_110831,offset_map];
var inst_110833 = (new cljs.core.PersistentVector(null,2,(5),inst_110815,inst_110832,null));
var state_110905__$1 = state_110905;
var statearr_111030_111167 = state_110905__$1;
(statearr_111030_111167[(2)] = inst_110833);

(statearr_111030_111167[(1)] = (80));


return cljs.core.cst$kw$recur;
} else {
if((state_val_110906 === (79))){
var inst_110815 = cljs.core.PersistentVector.EMPTY_NODE;
var state_110905__$1 = (function (){var statearr_111031 = state_110905;
(statearr_111031[(35)] = inst_110815);

return statearr_111031;
})();
if(cljs.core.truth_(fuel)){
var statearr_111032_111168 = state_110905__$1;
(statearr_111032_111168[(1)] = (82));

} else {
var statearr_111033_111169 = state_110905__$1;
(statearr_111033_111169[(1)] = (83));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_110906 === (38))){
var inst_110672 = (state_110905[(17)]);
var inst_110689 = cljs.core.update.cljs$core$IFn$_invoke$arity$3(offset_map,inst_110672,cljs.core.dec);
var state_110905__$1 = state_110905;
var statearr_111034_111170 = state_110905__$1;
(statearr_111034_111170[(2)] = inst_110689);

(statearr_111034_111170[(1)] = (40));


return cljs.core.cst$kw$recur;
} else {
if((state_val_110906 === (98))){
var inst_110866 = (state_110905[(31)]);
var inst_110883 = (inst_110866 == null);
var inst_110884 = cljs.core.not(inst_110883);
var state_110905__$1 = state_110905;
if(inst_110884){
var statearr_111035_111171 = state_110905__$1;
(statearr_111035_111171[(1)] = (100));

} else {
var statearr_111036_111172 = state_110905__$1;
(statearr_111036_111172[(1)] = (101));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_110906 === (87))){
var inst_110828 = (state_110905[(2)]);
var state_110905__$1 = state_110905;
return cljs.core.async.impl.ioc_helpers.take_BANG_(state_110905__$1,(81),inst_110828);
} else {
if((state_val_110906 === (30))){
var inst_110667 = (state_110905[(16)]);
var state_110905__$1 = state_110905;
var statearr_111037_111173 = state_110905__$1;
(statearr_111037_111173[(2)] = inst_110667);

(statearr_111037_111173[(1)] = (31));


return cljs.core.cst$kw$recur;
} else {
if((state_val_110906 === (73))){
var inst_110791 = (state_110905[(2)]);
var state_110905__$1 = state_110905;
if(cljs.core.truth_(inst_110791)){
var statearr_111038_111174 = state_110905__$1;
(statearr_111038_111174[(1)] = (74));

} else {
var statearr_111039_111175 = state_110905__$1;
(statearr_111039_111175[(1)] = (75));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_110906 === (96))){
var inst_110873 = (state_110905[(2)]);
var state_110905__$1 = state_110905;
if(cljs.core.truth_(inst_110873)){
var statearr_111040_111176 = state_110905__$1;
(statearr_111040_111176[(1)] = (97));

} else {
var statearr_111041_111177 = state_110905__$1;
(statearr_111041_111177[(1)] = (98));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_110906 === (10))){
var inst_110628 = (state_110905[(14)]);
var inst_110628__$1 = (state_110905[(2)]);
var inst_110629 = cljs.core.contains_QMARK_(inst_110628__$1,cljs.core.cst$kw$componentFollow_QMARK_);
var state_110905__$1 = (function (){var statearr_111042 = state_110905;
(statearr_111042[(14)] = inst_110628__$1);

return statearr_111042;
})();
if(inst_110629){
var statearr_111043_111178 = state_110905__$1;
(statearr_111043_111178[(1)] = (11));

} else {
var statearr_111044_111179 = state_110905__$1;
(statearr_111044_111179[(1)] = (12));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_110906 === (18))){
var inst_110634 = (state_110905[(7)]);
var inst_110641 = cljs.core.cst$kw$p.cljs$core$IFn$_invoke$arity$1(inst_110634);
var state_110905__$1 = state_110905;
var statearr_111045_111180 = state_110905__$1;
(statearr_111045_111180[(2)] = inst_110641);

(statearr_111045_111180[(1)] = (19));


return cljs.core.cst$kw$recur;
} else {
if((state_val_110906 === (105))){
var inst_110897 = (state_110905[(2)]);
var state_110905__$1 = state_110905;
var statearr_111046_111181 = state_110905__$1;
(statearr_111046_111181[(2)] = inst_110897);

(statearr_111046_111181[(1)] = (102));


return cljs.core.cst$kw$recur;
} else {
if((state_val_110906 === (52))){
var inst_110719 = (state_110905[(2)]);
var state_110905__$1 = state_110905;
var statearr_111047_111182 = state_110905__$1;
(statearr_111047_111182[(2)] = inst_110719);

(statearr_111047_111182[(1)] = (49));


return cljs.core.cst$kw$recur;
} else {
if((state_val_110906 === (67))){
var inst_110765 = (state_110905[(34)]);
var state_110905__$1 = state_110905;
var statearr_111048_111183 = state_110905__$1;
(statearr_111048_111183[(2)] = inst_110765);

(statearr_111048_111183[(1)] = (69));


return cljs.core.cst$kw$recur;
} else {
if((state_val_110906 === (71))){
var inst_110634 = (state_110905[(7)]);
var inst_110788 = cljs.core.cst$kw$component_QMARK_.cljs$core$IFn$_invoke$arity$1(inst_110634);
var state_110905__$1 = state_110905;
var statearr_111049_111184 = state_110905__$1;
(statearr_111049_111184[(2)] = inst_110788);

(statearr_111049_111184[(1)] = (73));


return cljs.core.cst$kw$recur;
} else {
if((state_val_110906 === (42))){
var inst_110667 = (state_110905[(16)]);
var state_110905__$1 = state_110905;
var statearr_111050_111185 = state_110905__$1;
(statearr_111050_111185[(2)] = inst_110667);

(statearr_111050_111185[(1)] = (43));


return cljs.core.cst$kw$recur;
} else {
if((state_val_110906 === (80))){
var inst_110835 = (state_110905[(2)]);
var state_110905__$1 = state_110905;
var statearr_111051_111186 = state_110905__$1;
(statearr_111051_111186[(2)] = inst_110835);

(statearr_111051_111186[(1)] = (76));


return cljs.core.cst$kw$recur;
} else {
if((state_val_110906 === (37))){
var inst_110866 = (state_110905[(31)]);
var inst_110869 = (state_110905[(24)]);
var inst_110865 = (state_110905[(2)]);
var inst_110866__$1 = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(inst_110865,(0),null);
var inst_110867 = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(inst_110865,(1),null);
var inst_110868 = (inst_110866__$1 == null);
var inst_110869__$1 = cljs.core.not(inst_110868);
var state_110905__$1 = (function (){var statearr_111052 = state_110905;
(statearr_111052[(31)] = inst_110866__$1);

(statearr_111052[(24)] = inst_110869__$1);

(statearr_111052[(32)] = inst_110867);

return statearr_111052;
})();
if(inst_110869__$1){
var statearr_111053_111187 = state_110905__$1;
(statearr_111053_111187[(1)] = (94));

} else {
var statearr_111054_111188 = state_110905__$1;
(statearr_111054_111188[(1)] = (95));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_110906 === (63))){
var inst_110749 = (state_110905[(2)]);
var state_110905__$1 = state_110905;
return cljs.core.async.impl.ioc_helpers.take_BANG_(state_110905__$1,(56),inst_110749);
} else {
if((state_val_110906 === (94))){
var inst_110667 = (state_110905[(16)]);
var state_110905__$1 = state_110905;
var statearr_111055_111189 = state_110905__$1;
(statearr_111055_111189[(2)] = inst_110667);

(statearr_111055_111189[(1)] = (96));


return cljs.core.cst$kw$recur;
} else {
if((state_val_110906 === (8))){
var inst_110623 = flake.p;
var inst_110624 = cljs.core.cst$kw$compact_QMARK_.cljs$core$IFn$_invoke$arity$1(pred_spec);
var inst_110625 = fluree.db.query.fql.wildcard_pred_spec(db,cache,inst_110623,inst_110624);
var state_110905__$1 = state_110905;
var statearr_111056_111190 = state_110905__$1;
(statearr_111056_111190[(2)] = inst_110625);

(statearr_111056_111190[(1)] = (10));


return cljs.core.cst$kw$recur;
} else {
if((state_val_110906 === (49))){
var inst_110722 = (state_110905[(2)]);
var state_110905__$1 = state_110905;
if(cljs.core.truth_(inst_110722)){
var statearr_111057_111191 = state_110905__$1;
(statearr_111057_111191[(1)] = (53));

} else {
var statearr_111058_111192 = state_110905__$1;
(statearr_111058_111192[(1)] = (54));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_110906 === (84))){
var inst_110822 = (state_110905[(2)]);
var state_110905__$1 = (function (){var statearr_111059 = state_110905;
(statearr_111059[(11)] = inst_110822);

return statearr_111059;
})();
var statearr_111060_111193 = state_110905__$1;
(statearr_111060_111193[(1)] = (85));



return cljs.core.cst$kw$recur;
} else {
return null;
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
});})(c__99809__auto__))
;
return ((function (switch__99702__auto__,c__99809__auto__){
return (function() {
var fluree$db$query$fql$state_machine__99703__auto__ = null;
var fluree$db$query$fql$state_machine__99703__auto____0 = (function (){
var statearr_111062 = [null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null];
(statearr_111062[(0)] = fluree$db$query$fql$state_machine__99703__auto__);

(statearr_111062[(1)] = (1));

return statearr_111062;
});
var fluree$db$query$fql$state_machine__99703__auto____1 = (function (state_110905){
while(true){
var ret_value__99704__auto__ = (function (){try{while(true){
var result__99705__auto__ = switch__99702__auto__(state_110905);
if(cljs.core.keyword_identical_QMARK_(result__99705__auto__,cljs.core.cst$kw$recur)){
continue;
} else {
return result__99705__auto__;
}
break;
}
}catch (e111063){if((e111063 instanceof Object)){
var ex__99706__auto__ = e111063;
var statearr_111064_111194 = state_110905;
(statearr_111064_111194[(5)] = ex__99706__auto__);


cljs.core.async.impl.ioc_helpers.process_exception(state_110905);

return cljs.core.cst$kw$recur;
} else {
throw e111063;

}
}})();
if(cljs.core.keyword_identical_QMARK_(ret_value__99704__auto__,cljs.core.cst$kw$recur)){
var G__111195 = state_110905;
state_110905 = G__111195;
continue;
} else {
return ret_value__99704__auto__;
}
break;
}
});
fluree$db$query$fql$state_machine__99703__auto__ = function(state_110905){
switch(arguments.length){
case 0:
return fluree$db$query$fql$state_machine__99703__auto____0.call(this);
case 1:
return fluree$db$query$fql$state_machine__99703__auto____1.call(this,state_110905);
}
throw(new Error('Invalid arity: ' + arguments.length));
};
fluree$db$query$fql$state_machine__99703__auto__.cljs$core$IFn$_invoke$arity$0 = fluree$db$query$fql$state_machine__99703__auto____0;
fluree$db$query$fql$state_machine__99703__auto__.cljs$core$IFn$_invoke$arity$1 = fluree$db$query$fql$state_machine__99703__auto____1;
return fluree$db$query$fql$state_machine__99703__auto__;
})()
;})(switch__99702__auto__,c__99809__auto__))
})();
var state__99811__auto__ = (function (){var statearr_111065 = (f__99810__auto__.cljs$core$IFn$_invoke$arity$0 ? f__99810__auto__.cljs$core$IFn$_invoke$arity$0() : f__99810__auto__.call(null));
(statearr_111065[(6)] = c__99809__auto__);

return statearr_111065;
})();
return cljs.core.async.impl.ioc_helpers.run_state_machine_wrapped(state__99811__auto__);
});})(c__99809__auto__))
);

return c__99809__auto__;
});

fluree.db.query.fql.add_pred.cljs$lang$maxFixedArity = 10;

/**
 * Resolves a full predicate select spec in case there are
 *   any namespace lookups (:ns-lookup) in the map that
 *   need to be resolved for this given subject.
 */
fluree.db.query.fql.full_select_spec = (function fluree$db$query$fql$full_select_spec(db,cache,base_pred_spec,subject_id){
var coll_id = fluree.db.flake.sid__GT_cid(subject_id);
var or__4131__auto__ = cljs.core.get.cljs$core$IFn$_invoke$arity$2(cljs.core.deref(cache),new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [coll_id,base_pred_spec], null));
if(cljs.core.truth_(or__4131__auto__)){
return or__4131__auto__;
} else {
var lookup_specs = fluree.db.query.fql_parser.ns_lookup_pred_spec(db,coll_id,cljs.core.get_in.cljs$core$IFn$_invoke$arity$2(base_pred_spec,new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [cljs.core.cst$kw$select,cljs.core.cst$kw$ns_DASH_lookup], null)));
var updated_spec = cljs.core.update.cljs$core$IFn$_invoke$arity$3(base_pred_spec,cljs.core.cst$kw$select,((function (lookup_specs,or__4131__auto__,coll_id){
return (function (sel){
return cljs.core.dissoc.cljs$core$IFn$_invoke$arity$2(cljs.core.assoc.cljs$core$IFn$_invoke$arity$3(sel,cljs.core.cst$kw$pred_DASH_id,cljs.core.merge.cljs$core$IFn$_invoke$arity$variadic(cljs.core.prim_seq.cljs$core$IFn$_invoke$arity$2([lookup_specs,cljs.core.cst$kw$pred_DASH_id.cljs$core$IFn$_invoke$arity$1(sel)], 0))),cljs.core.cst$kw$ns_DASH_lookup);
});})(lookup_specs,or__4131__auto__,coll_id))
);
cljs.core._vreset_BANG_(cache,cljs.core.assoc.cljs$core$IFn$_invoke$arity$3(cljs.core._deref(cache),new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [coll_id,base_pred_spec], null),updated_spec));

return updated_spec;
}
});
/**
 * Returns true if the predicate spec has a sub-selection that requires a namespace lookup.
 */
fluree.db.query.fql.has_ns_lookups_QMARK_ = (function fluree$db$query$fql$has_ns_lookups_QMARK_(select_spec){
return cljs.core.get_in.cljs$core$IFn$_invoke$arity$2(select_spec,new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [cljs.core.cst$kw$select,cljs.core.cst$kw$ns_DASH_lookup], null));
});
fluree.db.query.fql.s = (function fluree$db$query$fql$s(f){
return f.s;
});
fluree.db.query.fql.o = (function fluree$db$query$fql$o(f){
return f.o;
});
/**
 * Resolves all reverse references into a result map.
 */
fluree.db.query.fql.resolve_reverse_refs = (function fluree$db$query$fql$resolve_reverse_refs(db,cache,fuel,max_fuel,subject_id,reverse_refs_specs){
var c__99809__auto__ = cljs.core.async.chan.cljs$core$IFn$_invoke$arity$1((1));
cljs.core.async.impl.dispatch.run(((function (c__99809__auto__){
return (function (){
var f__99810__auto__ = (function (){var switch__99702__auto__ = ((function (c__99809__auto__){
return (function (state_111371){
var state_val_111372 = (state_111371[(1)]);
if((state_val_111372 === (7))){
var inst_111211 = (state_111371[(7)]);
var state_111371__$1 = state_111371;
var statearr_111373_111462 = state_111371__$1;
(statearr_111373_111462[(2)] = inst_111211);

(statearr_111373_111462[(1)] = (9));


return cljs.core.cst$kw$recur;
} else {
if((state_val_111372 === (59))){
var inst_111359 = (state_111371[(2)]);
var state_111371__$1 = state_111371;
var statearr_111374_111463 = state_111371__$1;
(statearr_111374_111463[(2)] = inst_111359);

(statearr_111374_111463[(1)] = (56));


return cljs.core.cst$kw$recur;
} else {
if((state_val_111372 === (20))){
var state_111371__$1 = state_111371;
var statearr_111375_111464 = state_111371__$1;
(statearr_111375_111464[(2)] = fuel);

(statearr_111375_111464[(1)] = (22));


return cljs.core.cst$kw$recur;
} else {
if((state_val_111372 === (58))){
var inst_111253 = (state_111371[(8)]);
var state_111371__$1 = state_111371;
var statearr_111376_111465 = state_111371__$1;
(statearr_111376_111465[(2)] = inst_111253);

(statearr_111376_111465[(1)] = (59));


return cljs.core.cst$kw$recur;
} else {
if((state_val_111372 === (27))){
var inst_111251 = (state_111371[(9)]);
var inst_111353 = (state_111371[(2)]);
var state_111371__$1 = (function (){var statearr_111377 = state_111371;
(statearr_111377[(10)] = inst_111353);

return statearr_111377;
})();
if(cljs.core.truth_(inst_111251)){
var statearr_111378_111466 = state_111371__$1;
(statearr_111378_111466[(1)] = (54));

} else {
var statearr_111379_111467 = state_111371__$1;
(statearr_111379_111467[(1)] = (55));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_111372 === (1))){
var state_111371__$1 = state_111371;
var statearr_111380_111468 = state_111371__$1;
(statearr_111380_111468[(2)] = null);

(statearr_111380_111468[(1)] = (4));


return cljs.core.cst$kw$recur;
} else {
if((state_val_111372 === (24))){
var state_111371__$1 = state_111371;
var statearr_111381_111469 = state_111371__$1;
(statearr_111381_111469[(2)] = null);

(statearr_111381_111469[(1)] = (25));


return cljs.core.cst$kw$recur;
} else {
if((state_val_111372 === (55))){
var inst_111252 = (state_111371[(11)]);
var state_111371__$1 = state_111371;
if(cljs.core.truth_(inst_111252)){
var statearr_111382_111470 = state_111371__$1;
(statearr_111382_111470[(1)] = (57));

} else {
var statearr_111383_111471 = state_111371__$1;
(statearr_111383_111471[(1)] = (58));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_111372 === (39))){
var inst_111310 = (state_111371[(2)]);
var state_111371__$1 = state_111371;
if(cljs.core.truth_(inst_111310)){
var statearr_111384_111472 = state_111371__$1;
(statearr_111384_111472[(1)] = (40));

} else {
var statearr_111385_111473 = state_111371__$1;
(statearr_111385_111473[(1)] = (41));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_111372 === (46))){
var inst_111227 = (state_111371[(12)]);
var inst_111322 = (state_111371[(13)]);
var inst_111321 = (state_111371[(2)]);
var inst_111322__$1 = fluree.db.util.async.throw_err(inst_111321);
var inst_111323 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_111324 = [cljs.core.cst$kw$wildcard_QMARK_,cljs.core.cst$kw$compact_QMARK_,cljs.core.cst$kw$select,cljs.core.cst$kw$limit];
var inst_111325 = (new cljs.core.PersistentVector(null,4,(5),inst_111323,inst_111324,null));
var inst_111326 = cljs.core.select_keys(inst_111227,inst_111325);
var inst_111327 = cljs.core.empty_QMARK_(inst_111322__$1);
var state_111371__$1 = (function (){var statearr_111386 = state_111371;
(statearr_111386[(13)] = inst_111322__$1);

(statearr_111386[(14)] = inst_111326);

return statearr_111386;
})();
if(inst_111327){
var statearr_111387_111474 = state_111371__$1;
(statearr_111387_111474[(1)] = (47));

} else {
var statearr_111388_111475 = state_111371__$1;
(statearr_111388_111475[(1)] = (48));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_111372 === (4))){
var _ = cljs.core.async.impl.ioc_helpers.add_exception_frame(state_111371,(3),Error,null,(2));
var inst_111207 = cljs.core.seq(reverse_refs_specs);
var inst_111208 = cljs.core.first(inst_111207);
var inst_111209 = cljs.core.next(inst_111207);
var inst_111210 = reverse_refs_specs;
var inst_111211 = null;
var state_111371__$1 = (function (){var statearr_111389 = state_111371;
(statearr_111389[(15)] = inst_111208);

(statearr_111389[(16)] = inst_111209);

(statearr_111389[(7)] = inst_111211);

(statearr_111389[(17)] = inst_111210);

return statearr_111389;
})();
var statearr_111390_111476 = state_111371__$1;
(statearr_111390_111476[(2)] = null);

(statearr_111390_111476[(1)] = (5));


return cljs.core.cst$kw$recur;
} else {
if((state_val_111372 === (54))){
var inst_111251 = (state_111371[(9)]);
var state_111371__$1 = state_111371;
var statearr_111391_111477 = state_111371__$1;
(statearr_111391_111477[(2)] = inst_111251);

(statearr_111391_111477[(1)] = (56));


return cljs.core.cst$kw$recur;
} else {
if((state_val_111372 === (15))){
var inst_111240 = (state_111371[(2)]);
var state_111371__$1 = state_111371;
var statearr_111392_111478 = state_111371__$1;
(statearr_111392_111478[(2)] = inst_111240);

(statearr_111392_111478[(1)] = (12));


return cljs.core.cst$kw$recur;
} else {
if((state_val_111372 === (48))){
var state_111371__$1 = state_111371;
if(cljs.core.truth_(fuel)){
var statearr_111393_111479 = state_111371__$1;
(statearr_111393_111479[(1)] = (50));

} else {
var statearr_111394_111480 = state_111371__$1;
(statearr_111394_111480[(1)] = (51));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_111372 === (50))){
var inst_111322 = (state_111371[(13)]);
var inst_111331 = cljs.core.count(inst_111322);
var inst_111332 = fluree.db.query.fql.add_fuel(fuel,inst_111331,max_fuel);
var state_111371__$1 = state_111371;
var statearr_111395_111481 = state_111371__$1;
(statearr_111395_111481[(2)] = inst_111332);

(statearr_111395_111481[(1)] = (52));


return cljs.core.cst$kw$recur;
} else {
if((state_val_111372 === (21))){
var inst_111262 = (state_111371[(18)]);
var state_111371__$1 = state_111371;
var statearr_111396_111482 = state_111371__$1;
(statearr_111396_111482[(2)] = inst_111262);

(statearr_111396_111482[(1)] = (22));


return cljs.core.cst$kw$recur;
} else {
if((state_val_111372 === (31))){
var inst_111250 = (state_111371[(19)]);
var inst_111285 = (state_111371[(20)]);
var inst_111298 = (inst_111285 >= inst_111250);
var state_111371__$1 = state_111371;
var statearr_111398_111483 = state_111371__$1;
(statearr_111398_111483[(2)] = inst_111298);

(statearr_111398_111483[(1)] = (33));


return cljs.core.cst$kw$recur;
} else {
if((state_val_111372 === (32))){
var inst_111250 = (state_111371[(19)]);
var state_111371__$1 = state_111371;
var statearr_111399_111484 = state_111371__$1;
(statearr_111399_111484[(2)] = inst_111250);

(statearr_111399_111484[(1)] = (33));


return cljs.core.cst$kw$recur;
} else {
if((state_val_111372 === (40))){
var inst_111285 = (state_111371[(20)]);
var inst_111286 = (state_111371[(21)]);
var inst_111293 = (state_111371[(22)]);
var inst_111312 = (inst_111285 + (1));
var tmp111397 = inst_111286;
var inst_111284 = inst_111293;
var inst_111285__$1 = inst_111312;
var inst_111286__$1 = tmp111397;
var state_111371__$1 = (function (){var statearr_111400 = state_111371;
(statearr_111400[(20)] = inst_111285__$1);

(statearr_111400[(21)] = inst_111286__$1);

(statearr_111400[(23)] = inst_111284);

return statearr_111400;
})();
var statearr_111401_111485 = state_111371__$1;
(statearr_111401_111485[(2)] = null);

(statearr_111401_111485[(1)] = (26));


return cljs.core.cst$kw$recur;
} else {
if((state_val_111372 === (56))){
var inst_111353 = (state_111371[(10)]);
var inst_111218 = (state_111371[(24)]);
var inst_111211 = (state_111371[(7)]);
var inst_111361 = (state_111371[(2)]);
var inst_111362 = cljs.core.assoc.cljs$core$IFn$_invoke$arity$3(inst_111211,inst_111361,inst_111353);
var inst_111210 = inst_111218;
var inst_111211__$1 = inst_111362;
var state_111371__$1 = (function (){var statearr_111402 = state_111371;
(statearr_111402[(7)] = inst_111211__$1);

(statearr_111402[(17)] = inst_111210);

return statearr_111402;
})();
var statearr_111403_111486 = state_111371__$1;
(statearr_111403_111486[(2)] = null);

(statearr_111403_111486[(1)] = (5));


return cljs.core.cst$kw$recur;
} else {
if((state_val_111372 === (33))){
var inst_111301 = (state_111371[(2)]);
var state_111371__$1 = state_111371;
var statearr_111404_111487 = state_111371__$1;
(statearr_111404_111487[(2)] = inst_111301);

(statearr_111404_111487[(1)] = (30));


return cljs.core.cst$kw$recur;
} else {
if((state_val_111372 === (13))){
var state_111371__$1 = state_111371;
var statearr_111405_111488 = state_111371__$1;
(statearr_111405_111488[(2)] = true);

(statearr_111405_111488[(1)] = (15));


return cljs.core.cst$kw$recur;
} else {
if((state_val_111372 === (22))){
var inst_111266 = (state_111371[(2)]);
var state_111371__$1 = state_111371;
if(cljs.core.truth_(inst_111266)){
var statearr_111406_111489 = state_111371__$1;
(statearr_111406_111489[(1)] = (23));

} else {
var statearr_111407_111490 = state_111371__$1;
(statearr_111407_111490[(1)] = (24));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_111372 === (36))){
var inst_111351 = (state_111371[(2)]);
var state_111371__$1 = state_111371;
var statearr_111408_111491 = state_111371__$1;
(statearr_111408_111491[(2)] = inst_111351);

(statearr_111408_111491[(1)] = (27));


return cljs.core.cst$kw$recur;
} else {
if((state_val_111372 === (41))){
var state_111371__$1 = state_111371;
var statearr_111409_111492 = state_111371__$1;
(statearr_111409_111492[(1)] = (43));



return cljs.core.cst$kw$recur;
} else {
if((state_val_111372 === (43))){
var inst_111292 = (state_111371[(25)]);
var inst_111316 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_111317 = [inst_111292];
var inst_111318 = (new cljs.core.PersistentVector(null,1,(5),inst_111316,inst_111317,null));
var inst_111319 = fluree.db.query.range.index_range.cljs$core$IFn$_invoke$arity$4(db,cljs.core.cst$kw$spot,cljs.core._EQ_,inst_111318);
var state_111371__$1 = state_111371;
return cljs.core.async.impl.ioc_helpers.take_BANG_(state_111371__$1,(46),inst_111319);
} else {
if((state_val_111372 === (29))){
var inst_111250 = (state_111371[(19)]);
var state_111371__$1 = state_111371;
if(cljs.core.truth_(inst_111250)){
var statearr_111411_111493 = state_111371__$1;
(statearr_111411_111493[(1)] = (31));

} else {
var statearr_111412_111494 = state_111371__$1;
(statearr_111412_111494[(1)] = (32));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_111372 === (44))){
var state_111371__$1 = state_111371;
var statearr_111413_111495 = state_111371__$1;
(statearr_111413_111495[(2)] = null);

(statearr_111413_111495[(1)] = (45));


return cljs.core.cst$kw$recur;
} else {
if((state_val_111372 === (6))){
var inst_111367 = (state_111371[(2)]);
var state_111371__$1 = state_111371;
var statearr_111414_111496 = state_111371__$1;
(statearr_111414_111496[(2)] = inst_111367);


cljs.core.async.impl.ioc_helpers.process_exception(state_111371__$1);

return cljs.core.cst$kw$recur;
} else {
if((state_val_111372 === (28))){
var inst_111294 = (state_111371[(26)]);
var state_111371__$1 = state_111371;
var statearr_111415_111497 = state_111371__$1;
(statearr_111415_111497[(2)] = inst_111294);

(statearr_111415_111497[(1)] = (30));


return cljs.core.cst$kw$recur;
} else {
if((state_val_111372 === (51))){
var state_111371__$1 = state_111371;
var statearr_111416_111498 = state_111371__$1;
(statearr_111416_111498[(2)] = null);

(statearr_111416_111498[(1)] = (52));


return cljs.core.cst$kw$recur;
} else {
if((state_val_111372 === (25))){
var inst_111262 = (state_111371[(18)]);
var inst_111272 = (state_111371[(2)]);
var inst_111280 = cljs.core.seq(inst_111262);
var inst_111281 = cljs.core.first(inst_111280);
var inst_111282 = cljs.core.next(inst_111280);
var inst_111283 = cljs.core.PersistentVector.EMPTY;
var inst_111284 = inst_111262;
var inst_111285 = (0);
var inst_111286 = inst_111283;
var state_111371__$1 = (function (){var statearr_111417 = state_111371;
(statearr_111417[(20)] = inst_111285);

(statearr_111417[(27)] = inst_111281);

(statearr_111417[(28)] = inst_111272);

(statearr_111417[(29)] = inst_111282);

(statearr_111417[(21)] = inst_111286);

(statearr_111417[(23)] = inst_111284);

return statearr_111417;
})();
var statearr_111418_111499 = state_111371__$1;
(statearr_111418_111499[(2)] = null);

(statearr_111418_111499[(1)] = (26));


return cljs.core.cst$kw$recur;
} else {
if((state_val_111372 === (34))){
var inst_111286 = (state_111371[(21)]);
var state_111371__$1 = state_111371;
var statearr_111419_111500 = state_111371__$1;
(statearr_111419_111500[(2)] = inst_111286);

(statearr_111419_111500[(1)] = (36));


return cljs.core.cst$kw$recur;
} else {
if((state_val_111372 === (17))){
var inst_111227 = (state_111371[(12)]);
var state_111371__$1 = state_111371;
var statearr_111420_111501 = state_111371__$1;
(statearr_111420_111501[(2)] = inst_111227);

(statearr_111420_111501[(1)] = (18));


return cljs.core.cst$kw$recur;
} else {
if((state_val_111372 === (3))){
var inst_111196 = (state_111371[(2)]);
var state_111371__$1 = state_111371;
var statearr_111421_111502 = state_111371__$1;
(statearr_111421_111502[(2)] = inst_111196);


cljs.core.async.impl.ioc_helpers.process_exception(state_111371__$1);

return cljs.core.cst$kw$recur;
} else {
if((state_val_111372 === (12))){
var inst_111243 = (state_111371[(2)]);
var state_111371__$1 = state_111371;
if(cljs.core.truth_(inst_111243)){
var statearr_111422_111503 = state_111371__$1;
(statearr_111422_111503[(1)] = (16));

} else {
var statearr_111423_111504 = state_111371__$1;
(statearr_111423_111504[(1)] = (17));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_111372 === (2))){
var inst_111369 = (state_111371[(2)]);
var state_111371__$1 = state_111371;
return cljs.core.async.impl.ioc_helpers.return_chan(state_111371__$1,inst_111369);
} else {
if((state_val_111372 === (23))){
var inst_111262 = (state_111371[(18)]);
var inst_111268 = cljs.core.count(inst_111262);
var inst_111269 = fluree.db.query.fql.add_fuel(fuel,inst_111268,max_fuel);
var state_111371__$1 = state_111371;
var statearr_111424_111505 = state_111371__$1;
(statearr_111424_111505[(2)] = inst_111269);

(statearr_111424_111505[(1)] = (25));


return cljs.core.cst$kw$recur;
} else {
if((state_val_111372 === (47))){
var inst_111286 = (state_111371[(21)]);
var state_111371__$1 = state_111371;
var statearr_111425_111506 = state_111371__$1;
(statearr_111425_111506[(2)] = inst_111286);

(statearr_111425_111506[(1)] = (49));


return cljs.core.cst$kw$recur;
} else {
if((state_val_111372 === (35))){
var inst_111249 = (state_111371[(30)]);
var state_111371__$1 = state_111371;
if(cljs.core.truth_(inst_111249)){
var statearr_111426_111507 = state_111371__$1;
(statearr_111426_111507[(1)] = (37));

} else {
var statearr_111427_111508 = state_111371__$1;
(statearr_111427_111508[(1)] = (38));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_111372 === (19))){
var inst_111262 = (state_111371[(18)]);
var inst_111259 = (state_111371[(2)]);
var inst_111260 = fluree.db.util.async.throw_err(inst_111259);
var inst_111261 = cljs.core.map.cljs$core$IFn$_invoke$arity$2(fluree.db.query.fql.s,inst_111260);
var inst_111262__$1 = cljs.core.not_empty(inst_111261);
var state_111371__$1 = (function (){var statearr_111428 = state_111371;
(statearr_111428[(18)] = inst_111262__$1);

return statearr_111428;
})();
if(cljs.core.truth_(inst_111262__$1)){
var statearr_111429_111509 = state_111371__$1;
(statearr_111429_111509[(1)] = (20));

} else {
var statearr_111430_111510 = state_111371__$1;
(statearr_111430_111510[(1)] = (21));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_111372 === (57))){
var inst_111252 = (state_111371[(11)]);
var state_111371__$1 = state_111371;
var statearr_111431_111511 = state_111371__$1;
(statearr_111431_111511[(2)] = inst_111252);

(statearr_111431_111511[(1)] = (59));


return cljs.core.cst$kw$recur;
} else {
if((state_val_111372 === (11))){
var state_111371__$1 = state_111371;
var statearr_111432_111512 = state_111371__$1;
(statearr_111432_111512[(2)] = false);

(statearr_111432_111512[(1)] = (12));


return cljs.core.cst$kw$recur;
} else {
if((state_val_111372 === (9))){
var inst_111365 = (state_111371[(2)]);
var state_111371__$1 = state_111371;
var statearr_111433_111513 = state_111371__$1;
(statearr_111433_111513[(2)] = inst_111365);

(statearr_111433_111513[(1)] = (6));


return cljs.core.cst$kw$recur;
} else {
if((state_val_111372 === (5))){
var inst_111217 = (state_111371[(31)]);
var inst_111210 = (state_111371[(17)]);
var inst_111216 = cljs.core.seq(inst_111210);
var inst_111217__$1 = cljs.core.first(inst_111216);
var inst_111218 = cljs.core.next(inst_111216);
var inst_111219 = cljs.core.not(inst_111217__$1);
var state_111371__$1 = (function (){var statearr_111434 = state_111371;
(statearr_111434[(31)] = inst_111217__$1);

(statearr_111434[(24)] = inst_111218);

return statearr_111434;
})();
if(inst_111219){
var statearr_111435_111514 = state_111371__$1;
(statearr_111435_111514[(1)] = (7));

} else {
var statearr_111436_111515 = state_111371__$1;
(statearr_111436_111515[(1)] = (8));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_111372 === (14))){
var state_111371__$1 = state_111371;
var statearr_111437_111516 = state_111371__$1;
(statearr_111437_111516[(2)] = false);

(statearr_111437_111516[(1)] = (15));


return cljs.core.cst$kw$recur;
} else {
if((state_val_111372 === (45))){
var inst_111347 = (state_111371[(2)]);
var state_111371__$1 = state_111371;
var statearr_111438_111517 = state_111371__$1;
(statearr_111438_111517[(2)] = inst_111347);

(statearr_111438_111517[(1)] = (42));


return cljs.core.cst$kw$recur;
} else {
if((state_val_111372 === (53))){
var inst_111286 = (state_111371[(21)]);
var inst_111338 = (state_111371[(2)]);
var inst_111339 = fluree.db.util.async.throw_err(inst_111338);
var inst_111340 = cljs.core.conj.cljs$core$IFn$_invoke$arity$2(inst_111286,inst_111339);
var state_111371__$1 = state_111371;
var statearr_111439_111518 = state_111371__$1;
(statearr_111439_111518[(2)] = inst_111340);

(statearr_111439_111518[(1)] = (49));


return cljs.core.cst$kw$recur;
} else {
if((state_val_111372 === (26))){
var inst_111292 = (state_111371[(25)]);
var inst_111294 = (state_111371[(26)]);
var inst_111284 = (state_111371[(23)]);
var inst_111291 = cljs.core.seq(inst_111284);
var inst_111292__$1 = cljs.core.first(inst_111291);
var inst_111293 = cljs.core.next(inst_111291);
var inst_111294__$1 = cljs.core.not(inst_111292__$1);
var state_111371__$1 = (function (){var statearr_111440 = state_111371;
(statearr_111440[(25)] = inst_111292__$1);

(statearr_111440[(22)] = inst_111293);

(statearr_111440[(26)] = inst_111294__$1);

return statearr_111440;
})();
if(inst_111294__$1){
var statearr_111441_111519 = state_111371__$1;
(statearr_111441_111519[(1)] = (28));

} else {
var statearr_111442_111520 = state_111371__$1;
(statearr_111442_111520[(1)] = (29));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_111372 === (16))){
var inst_111227 = (state_111371[(12)]);
var inst_111245 = cljs.core.apply.cljs$core$IFn$_invoke$arity$2(cljs.core.hash_map,inst_111227);
var state_111371__$1 = state_111371;
var statearr_111443_111521 = state_111371__$1;
(statearr_111443_111521[(2)] = inst_111245);

(statearr_111443_111521[(1)] = (18));


return cljs.core.cst$kw$recur;
} else {
if((state_val_111372 === (38))){
var inst_111249 = (state_111371[(30)]);
var state_111371__$1 = state_111371;
var statearr_111444_111522 = state_111371__$1;
(statearr_111444_111522[(2)] = inst_111249);

(statearr_111444_111522[(1)] = (39));


return cljs.core.cst$kw$recur;
} else {
if((state_val_111372 === (30))){
var inst_111303 = (state_111371[(2)]);
var state_111371__$1 = state_111371;
if(cljs.core.truth_(inst_111303)){
var statearr_111445_111523 = state_111371__$1;
(statearr_111445_111523[(1)] = (34));

} else {
var statearr_111446_111524 = state_111371__$1;
(statearr_111446_111524[(1)] = (35));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_111372 === (10))){
var inst_111227 = (state_111371[(12)]);
var inst_111232 = inst_111227.cljs$lang$protocol_mask$partition0$;
var inst_111233 = (inst_111232 & (64));
var inst_111234 = inst_111227.cljs$core$ISeq$;
var inst_111235 = (cljs.core.PROTOCOL_SENTINEL === inst_111234);
var inst_111236 = ((inst_111233) || (inst_111235));
var state_111371__$1 = state_111371;
if(cljs.core.truth_(inst_111236)){
var statearr_111447_111525 = state_111371__$1;
(statearr_111447_111525[(1)] = (13));

} else {
var statearr_111448_111526 = state_111371__$1;
(statearr_111448_111526[(1)] = (14));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_111372 === (18))){
var inst_111226 = (state_111371[(32)]);
var inst_111248 = (state_111371[(2)]);
var inst_111249 = cljs.core.get.cljs$core$IFn$_invoke$arity$2(inst_111248,cljs.core.cst$kw$offset);
var inst_111250 = cljs.core.get.cljs$core$IFn$_invoke$arity$2(inst_111248,cljs.core.cst$kw$limit);
var inst_111251 = cljs.core.get.cljs$core$IFn$_invoke$arity$2(inst_111248,cljs.core.cst$kw$as);
var inst_111252 = cljs.core.get.cljs$core$IFn$_invoke$arity$2(inst_111248,cljs.core.cst$kw$name);
var inst_111253 = cljs.core.get.cljs$core$IFn$_invoke$arity$2(inst_111248,cljs.core.cst$kw$p);
var inst_111254 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_111255 = [subject_id,inst_111226];
var inst_111256 = (new cljs.core.PersistentVector(null,2,(5),inst_111254,inst_111255,null));
var inst_111257 = fluree.db.query.range.index_range.cljs$core$IFn$_invoke$arity$4(db,cljs.core.cst$kw$opst,cljs.core._EQ_,inst_111256);
var state_111371__$1 = (function (){var statearr_111449 = state_111371;
(statearr_111449[(9)] = inst_111251);

(statearr_111449[(30)] = inst_111249);

(statearr_111449[(8)] = inst_111253);

(statearr_111449[(19)] = inst_111250);

(statearr_111449[(11)] = inst_111252);

return statearr_111449;
})();
return cljs.core.async.impl.ioc_helpers.take_BANG_(state_111371__$1,(19),inst_111257);
} else {
if((state_val_111372 === (52))){
var inst_111322 = (state_111371[(13)]);
var inst_111326 = (state_111371[(14)]);
var inst_111335 = (state_111371[(2)]);
var inst_111336 = (fluree.db.query.fql.flakes__GT_res.cljs$core$IFn$_invoke$arity$6 ? fluree.db.query.fql.flakes__GT_res.cljs$core$IFn$_invoke$arity$6(db,cache,fuel,max_fuel,inst_111326,inst_111322) : fluree.db.query.fql.flakes__GT_res.call(null,db,cache,fuel,max_fuel,inst_111326,inst_111322));
var state_111371__$1 = (function (){var statearr_111450 = state_111371;
(statearr_111450[(33)] = inst_111335);

return statearr_111450;
})();
return cljs.core.async.impl.ioc_helpers.take_BANG_(state_111371__$1,(53),inst_111336);
} else {
if((state_val_111372 === (42))){
var inst_111349 = (state_111371[(2)]);
var state_111371__$1 = state_111371;
var statearr_111451_111527 = state_111371__$1;
(statearr_111451_111527[(2)] = inst_111349);

(statearr_111451_111527[(1)] = (36));


return cljs.core.cst$kw$recur;
} else {
if((state_val_111372 === (37))){
var inst_111249 = (state_111371[(30)]);
var inst_111285 = (state_111371[(20)]);
var inst_111307 = (inst_111285 < inst_111249);
var state_111371__$1 = state_111371;
var statearr_111452_111528 = state_111371__$1;
(statearr_111452_111528[(2)] = inst_111307);

(statearr_111452_111528[(1)] = (39));


return cljs.core.cst$kw$recur;
} else {
if((state_val_111372 === (8))){
var inst_111217 = (state_111371[(31)]);
var inst_111227 = (state_111371[(12)]);
var inst_111226 = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(inst_111217,(0),null);
var inst_111227__$1 = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(inst_111217,(1),null);
var inst_111229 = (inst_111227__$1 == null);
var inst_111230 = cljs.core.not(inst_111229);
var state_111371__$1 = (function (){var statearr_111453 = state_111371;
(statearr_111453[(12)] = inst_111227__$1);

(statearr_111453[(32)] = inst_111226);

return statearr_111453;
})();
if(inst_111230){
var statearr_111454_111529 = state_111371__$1;
(statearr_111454_111529[(1)] = (10));

} else {
var statearr_111455_111530 = state_111371__$1;
(statearr_111455_111530[(1)] = (11));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_111372 === (49))){
var inst_111285 = (state_111371[(20)]);
var inst_111293 = (state_111371[(22)]);
var inst_111342 = (state_111371[(2)]);
var inst_111343 = (inst_111285 + (1));
var inst_111284 = inst_111293;
var inst_111285__$1 = inst_111343;
var inst_111286 = inst_111342;
var state_111371__$1 = (function (){var statearr_111456 = state_111371;
(statearr_111456[(20)] = inst_111285__$1);

(statearr_111456[(21)] = inst_111286);

(statearr_111456[(23)] = inst_111284);

return statearr_111456;
})();
var statearr_111457_111531 = state_111371__$1;
(statearr_111457_111531[(2)] = null);

(statearr_111457_111531[(1)] = (26));


return cljs.core.cst$kw$recur;
} else {
return null;
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
});})(c__99809__auto__))
;
return ((function (switch__99702__auto__,c__99809__auto__){
return (function() {
var fluree$db$query$fql$resolve_reverse_refs_$_state_machine__99703__auto__ = null;
var fluree$db$query$fql$resolve_reverse_refs_$_state_machine__99703__auto____0 = (function (){
var statearr_111458 = [null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null];
(statearr_111458[(0)] = fluree$db$query$fql$resolve_reverse_refs_$_state_machine__99703__auto__);

(statearr_111458[(1)] = (1));

return statearr_111458;
});
var fluree$db$query$fql$resolve_reverse_refs_$_state_machine__99703__auto____1 = (function (state_111371){
while(true){
var ret_value__99704__auto__ = (function (){try{while(true){
var result__99705__auto__ = switch__99702__auto__(state_111371);
if(cljs.core.keyword_identical_QMARK_(result__99705__auto__,cljs.core.cst$kw$recur)){
continue;
} else {
return result__99705__auto__;
}
break;
}
}catch (e111459){if((e111459 instanceof Object)){
var ex__99706__auto__ = e111459;
var statearr_111460_111532 = state_111371;
(statearr_111460_111532[(5)] = ex__99706__auto__);


cljs.core.async.impl.ioc_helpers.process_exception(state_111371);

return cljs.core.cst$kw$recur;
} else {
throw e111459;

}
}})();
if(cljs.core.keyword_identical_QMARK_(ret_value__99704__auto__,cljs.core.cst$kw$recur)){
var G__111533 = state_111371;
state_111371 = G__111533;
continue;
} else {
return ret_value__99704__auto__;
}
break;
}
});
fluree$db$query$fql$resolve_reverse_refs_$_state_machine__99703__auto__ = function(state_111371){
switch(arguments.length){
case 0:
return fluree$db$query$fql$resolve_reverse_refs_$_state_machine__99703__auto____0.call(this);
case 1:
return fluree$db$query$fql$resolve_reverse_refs_$_state_machine__99703__auto____1.call(this,state_111371);
}
throw(new Error('Invalid arity: ' + arguments.length));
};
fluree$db$query$fql$resolve_reverse_refs_$_state_machine__99703__auto__.cljs$core$IFn$_invoke$arity$0 = fluree$db$query$fql$resolve_reverse_refs_$_state_machine__99703__auto____0;
fluree$db$query$fql$resolve_reverse_refs_$_state_machine__99703__auto__.cljs$core$IFn$_invoke$arity$1 = fluree$db$query$fql$resolve_reverse_refs_$_state_machine__99703__auto____1;
return fluree$db$query$fql$resolve_reverse_refs_$_state_machine__99703__auto__;
})()
;})(switch__99702__auto__,c__99809__auto__))
})();
var state__99811__auto__ = (function (){var statearr_111461 = (f__99810__auto__.cljs$core$IFn$_invoke$arity$0 ? f__99810__auto__.cljs$core$IFn$_invoke$arity$0() : f__99810__auto__.call(null));
(statearr_111461[(6)] = c__99809__auto__);

return statearr_111461;
})();
return cljs.core.async.impl.ioc_helpers.run_state_machine_wrapped(state__99811__auto__);
});})(c__99809__auto__))
);

return c__99809__auto__;
});
fluree.db.query.fql.component_follow_QMARK_ = (function fluree$db$query$fql$component_follow_QMARK_(pred_spec,select_spec){
if(cljs.core.contains_QMARK_(pred_spec,cljs.core.cst$kw$componentFollow_QMARK_)){
return cljs.core.cst$kw$componentFollow_QMARK_.cljs$core$IFn$_invoke$arity$1(pred_spec);
} else {
if((!((cljs.core.cst$kw$componentFollow_QMARK_.cljs$core$IFn$_invoke$arity$1(select_spec) == null)))){
return cljs.core.cst$kw$componentFollow_QMARK_.cljs$core$IFn$_invoke$arity$1(select_spec);
} else {
if(cljs.core.truth_((function (){var or__4131__auto__ = cljs.core.cst$kw$component_QMARK_.cljs$core$IFn$_invoke$arity$1(pred_spec);
if(cljs.core.truth_(or__4131__auto__)){
return or__4131__auto__;
} else {
return cljs.core.cst$kw$wildcard_QMARK_.cljs$core$IFn$_invoke$arity$1(select_spec);
}
})())){
return true;
} else {
return null;
}
}
}
});
fluree.db.query.fql.select_spec__GT_reverse_pred_specs = (function fluree$db$query$fql$select_spec__GT_reverse_pred_specs(select_spec){
return cljs.core.reduce.cljs$core$IFn$_invoke$arity$3((function (acc,spec){
var key_spec = cljs.core.key(spec);
var val_spec = (((cljs.core.cst$kw$componentFollow_QMARK_.cljs$core$IFn$_invoke$arity$1(cljs.core.val(spec)) == null))?cljs.core.assoc.cljs$core$IFn$_invoke$arity$3(cljs.core.val(spec),cljs.core.cst$kw$componentFollow_QMARK_,cljs.core.cst$kw$componentFollow_QMARK_.cljs$core$IFn$_invoke$arity$1(select_spec)):cljs.core.val(spec));
return cljs.core.assoc.cljs$core$IFn$_invoke$arity$3(acc,key_spec,val_spec);
}),cljs.core.PersistentArrayMap.EMPTY,cljs.core.get_in.cljs$core$IFn$_invoke$arity$2(select_spec,new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [cljs.core.cst$kw$select,cljs.core.cst$kw$reverse], null)));
});
fluree.db.query.fql.get_recursion_map_multi = (function fluree$db$query$fql$get_recursion_map_multi(recursion_map,k,f,full_select_spec,seen_QMARK_){
return new cljs.core.PersistentVector(null, 3, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [fluree.db.query.fql.o(f)], null)], null),cljs.core.assoc_in(cljs.core.assoc_in(cljs.core.assoc_in(cljs.core.assoc_in(recursion_map,new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [k,fluree.db.query.fql.o(f)], null),new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [fluree.db.query.fql.o(f)], null)], null)),new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [k,cljs.core.cst$kw$depth], null),(0)),new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [cljs.core.cst$kw$pred_DASH_ids,k], null),f.p),new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [cljs.core.cst$kw$select_DASH_specs,f.p], null),full_select_spec),true], null);
});
fluree.db.query.fql.add_in_multi_flakes = (function fluree$db$query$fql$add_in_multi_flakes(acc,new_child_paths,k,f,db,cache,fuel,max_fuel,pred_spec,component_follow_QMARK_,parent_exists){
var c__99809__auto__ = cljs.core.async.chan.cljs$core$IFn$_invoke$arity$1((1));
cljs.core.async.impl.dispatch.run(((function (c__99809__auto__){
return (function (){
var f__99810__auto__ = (function (){var switch__99702__auto__ = ((function (c__99809__auto__){
return (function (state_111647){
var state_val_111648 = (state_111647[(1)]);
if((state_val_111648 === (7))){
var inst_111550 = (state_111647[(7)]);
var state_111647__$1 = state_111647;
var statearr_111649_111698 = state_111647__$1;
(statearr_111649_111698[(2)] = inst_111550);

(statearr_111649_111698[(1)] = (9));


return cljs.core.cst$kw$recur;
} else {
if((state_val_111648 === (20))){
var inst_111594 = (state_111647[(2)]);
var state_111647__$1 = state_111647;
var statearr_111650_111699 = state_111647__$1;
(statearr_111650_111699[(2)] = inst_111594);

(statearr_111650_111699[(1)] = (17));


return cljs.core.cst$kw$recur;
} else {
if((state_val_111648 === (27))){
var inst_111617 = (state_111647[(2)]);
var inst_111618 = fluree.db.util.async.throw_err(inst_111617);
var state_111647__$1 = state_111647;
var statearr_111651_111700 = state_111647__$1;
(statearr_111651_111700[(2)] = inst_111618);

(statearr_111651_111700[(1)] = (26));


return cljs.core.cst$kw$recur;
} else {
if((state_val_111648 === (1))){
var state_111647__$1 = state_111647;
var statearr_111652_111701 = state_111647__$1;
(statearr_111652_111701[(2)] = null);

(statearr_111652_111701[(1)] = (4));


return cljs.core.cst$kw$recur;
} else {
if((state_val_111648 === (24))){
var inst_111550 = (state_111647[(7)]);
var inst_111615 = fluree.db.query.fql.add_pred.cljs$core$IFn$_invoke$arity$9(db,cache,fuel,max_fuel,inst_111550,pred_spec,f,component_follow_QMARK_,true);
var state_111647__$1 = state_111647;
return cljs.core.async.impl.ioc_helpers.take_BANG_(state_111647__$1,(27),inst_111615);
} else {
if((state_val_111648 === (4))){
var _ = cljs.core.async.impl.ioc_helpers.add_exception_frame(state_111647,(3),Error,null,(2));
var inst_111546 = cljs.core.seq(new_child_paths);
var inst_111547 = cljs.core.first(inst_111546);
var inst_111548 = cljs.core.next(inst_111546);
var inst_111549 = new_child_paths;
var inst_111550 = acc;
var state_111647__$1 = (function (){var statearr_111653 = state_111647;
(statearr_111653[(8)] = inst_111547);

(statearr_111653[(7)] = inst_111550);

(statearr_111653[(9)] = inst_111549);

(statearr_111653[(10)] = inst_111548);

return statearr_111653;
})();
var statearr_111654_111702 = state_111647__$1;
(statearr_111654_111702[(2)] = null);

(statearr_111654_111702[(1)] = (5));


return cljs.core.cst$kw$recur;
} else {
if((state_val_111648 === (15))){
var inst_111599 = (state_111647[(11)]);
var inst_111599__$1 = (state_111647[(2)]);
var inst_111600 = cljs.core.count(inst_111599__$1);
var inst_111601 = (inst_111600 > (1));
var state_111647__$1 = (function (){var statearr_111655 = state_111647;
(statearr_111655[(11)] = inst_111599__$1);

return statearr_111655;
})();
if(cljs.core.truth_(inst_111601)){
var statearr_111656_111703 = state_111647__$1;
(statearr_111656_111703[(1)] = (21));

} else {
var statearr_111657_111704 = state_111647__$1;
(statearr_111657_111704[(1)] = (22));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_111648 === (21))){
var inst_111599 = (state_111647[(11)]);
var inst_111603 = cljs.core.drop_last.cljs$core$IFn$_invoke$arity$1(inst_111599);
var state_111647__$1 = state_111647;
var statearr_111658_111705 = state_111647__$1;
(statearr_111658_111705[(2)] = inst_111603);

(statearr_111658_111705[(1)] = (23));


return cljs.core.cst$kw$recur;
} else {
if((state_val_111648 === (31))){
var inst_111557 = (state_111647[(12)]);
var inst_111550 = (state_111647[(7)]);
var inst_111637 = (state_111647[(2)]);
var inst_111638 = cljs.core.conj.cljs$core$IFn$_invoke$arity$2(inst_111550,inst_111637);
var inst_111549 = inst_111557;
var inst_111550__$1 = inst_111638;
var state_111647__$1 = (function (){var statearr_111659 = state_111647;
(statearr_111659[(7)] = inst_111550__$1);

(statearr_111659[(9)] = inst_111549);

return statearr_111659;
})();
var statearr_111660_111706 = state_111647__$1;
(statearr_111660_111706[(2)] = null);

(statearr_111660_111706[(1)] = (5));


return cljs.core.cst$kw$recur;
} else {
if((state_val_111648 === (13))){
var inst_111568 = (state_111647[(13)]);
var inst_111565 = (state_111647[(14)]);
var inst_111576 = inst_111565;
var inst_111577 = inst_111568;
var state_111647__$1 = (function (){var statearr_111661 = state_111647;
(statearr_111661[(15)] = inst_111577);

(statearr_111661[(16)] = inst_111576);

return statearr_111661;
})();
var statearr_111662_111707 = state_111647__$1;
(statearr_111662_111707[(2)] = null);

(statearr_111662_111707[(1)] = (16));


return cljs.core.cst$kw$recur;
} else {
if((state_val_111648 === (22))){
var inst_111599 = (state_111647[(11)]);
var state_111647__$1 = state_111647;
var statearr_111663_111708 = state_111647__$1;
(statearr_111663_111708[(2)] = inst_111599);

(statearr_111663_111708[(1)] = (23));


return cljs.core.cst$kw$recur;
} else {
if((state_val_111648 === (29))){
var inst_111626 = (state_111647[(17)]);
var state_111647__$1 = state_111647;
var statearr_111664_111709 = state_111647__$1;
(statearr_111664_111709[(2)] = inst_111626);

(statearr_111664_111709[(1)] = (31));


return cljs.core.cst$kw$recur;
} else {
if((state_val_111648 === (6))){
var inst_111643 = (state_111647[(2)]);
var state_111647__$1 = state_111647;
var statearr_111665_111710 = state_111647__$1;
(statearr_111665_111710[(2)] = inst_111643);


cljs.core.async.impl.ioc_helpers.process_exception(state_111647__$1);

return cljs.core.cst$kw$recur;
} else {
if((state_val_111648 === (28))){
var inst_111622 = (state_111647[(2)]);
var inst_111623 = fluree.db.util.async.throw_err(inst_111622);
var state_111647__$1 = state_111647;
var statearr_111666_111711 = state_111647__$1;
(statearr_111666_111711[(2)] = inst_111623);

(statearr_111666_111711[(1)] = (26));


return cljs.core.cst$kw$recur;
} else {
if((state_val_111648 === (25))){
var inst_111607 = (state_111647[(18)]);
var inst_111620 = fluree.db.query.fql.add_pred.cljs$core$IFn$_invoke$arity$9(db,cache,fuel,max_fuel,inst_111607,pred_spec,f,component_follow_QMARK_,true);
var state_111647__$1 = state_111647;
return cljs.core.async.impl.ioc_helpers.take_BANG_(state_111647__$1,(28),inst_111620);
} else {
if((state_val_111648 === (17))){
var inst_111596 = (state_111647[(2)]);
var state_111647__$1 = state_111647;
var statearr_111667_111712 = state_111647__$1;
(statearr_111667_111712[(2)] = inst_111596);

(statearr_111667_111712[(1)] = (15));


return cljs.core.cst$kw$recur;
} else {
if((state_val_111648 === (3))){
var inst_111535 = (state_111647[(2)]);
var state_111647__$1 = state_111647;
var statearr_111668_111713 = state_111647__$1;
(statearr_111668_111713[(2)] = inst_111535);


cljs.core.async.impl.ioc_helpers.process_exception(state_111647__$1);

return cljs.core.cst$kw$recur;
} else {
if((state_val_111648 === (12))){
var inst_111550 = (state_111647[(7)]);
var inst_111565 = (state_111647[(14)]);
var inst_111565__$1 = (state_111647[(2)]);
var inst_111566 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_111567 = [k];
var inst_111568 = (new cljs.core.PersistentVector(null,1,(5),inst_111566,inst_111567,null));
var inst_111569 = cljs.core.cst$kw$_id.cljs$core$IFn$_invoke$arity$1(inst_111550);
var inst_111570 = fluree.db.query.fql.s(f);
var inst_111571 = cljs.core.not_EQ_.cljs$core$IFn$_invoke$arity$2(inst_111569,inst_111570);
var inst_111572 = cljs.core.empty_QMARK_(inst_111565__$1);
var inst_111573 = (!(inst_111572));
var inst_111574 = ((inst_111571) && (inst_111573));
var state_111647__$1 = (function (){var statearr_111669 = state_111647;
(statearr_111669[(13)] = inst_111568);

(statearr_111669[(14)] = inst_111565__$1);

return statearr_111669;
})();
if(cljs.core.truth_(inst_111574)){
var statearr_111670_111714 = state_111647__$1;
(statearr_111670_111714[(1)] = (13));

} else {
var statearr_111671_111715 = state_111647__$1;
(statearr_111671_111715[(1)] = (14));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_111648 === (2))){
var inst_111645 = (state_111647[(2)]);
var state_111647__$1 = state_111647;
return cljs.core.async.impl.ioc_helpers.return_chan(state_111647__$1,inst_111645);
} else {
if((state_val_111648 === (23))){
var inst_111550 = (state_111647[(7)]);
var inst_111606 = (state_111647[(19)]);
var inst_111606__$1 = (state_111647[(2)]);
var inst_111607 = cljs.core.get_in.cljs$core$IFn$_invoke$arity$2(inst_111550,inst_111606__$1);
var inst_111611 = cljs.core.cst$kw$_id.cljs$core$IFn$_invoke$arity$1(inst_111550);
var inst_111612 = fluree.db.query.fql.s(f);
var inst_111613 = cljs.core._EQ_.cljs$core$IFn$_invoke$arity$2(inst_111611,inst_111612);
var state_111647__$1 = (function (){var statearr_111672 = state_111647;
(statearr_111672[(18)] = inst_111607);

(statearr_111672[(19)] = inst_111606__$1);

return statearr_111672;
})();
if(inst_111613){
var statearr_111673_111716 = state_111647__$1;
(statearr_111673_111716[(1)] = (24));

} else {
var statearr_111674_111717 = state_111647__$1;
(statearr_111674_111717[(1)] = (25));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_111648 === (19))){
var inst_111585 = (state_111647[(20)]);
var state_111647__$1 = state_111647;
var statearr_111675_111718 = state_111647__$1;
(statearr_111675_111718[(2)] = inst_111585);

(statearr_111675_111718[(1)] = (20));


return cljs.core.cst$kw$recur;
} else {
if((state_val_111648 === (11))){
var inst_111556 = (state_111647[(21)]);
var inst_111563 = cljs.core.drop_last.cljs$core$IFn$_invoke$arity$1(inst_111556);
var state_111647__$1 = state_111647;
var statearr_111676_111719 = state_111647__$1;
(statearr_111676_111719[(2)] = inst_111563);

(statearr_111676_111719[(1)] = (12));


return cljs.core.cst$kw$recur;
} else {
if((state_val_111648 === (9))){
var inst_111641 = (state_111647[(2)]);
var state_111647__$1 = state_111647;
var statearr_111677_111720 = state_111647__$1;
(statearr_111677_111720[(2)] = inst_111641);

(statearr_111677_111720[(1)] = (6));


return cljs.core.cst$kw$recur;
} else {
if((state_val_111648 === (5))){
var inst_111556 = (state_111647[(21)]);
var inst_111549 = (state_111647[(9)]);
var inst_111555 = cljs.core.seq(inst_111549);
var inst_111556__$1 = cljs.core.first(inst_111555);
var inst_111557 = cljs.core.next(inst_111555);
var inst_111558 = cljs.core.not(inst_111556__$1);
var state_111647__$1 = (function (){var statearr_111678 = state_111647;
(statearr_111678[(21)] = inst_111556__$1);

(statearr_111678[(12)] = inst_111557);

return statearr_111678;
})();
if(inst_111558){
var statearr_111679_111721 = state_111647__$1;
(statearr_111679_111721[(1)] = (7));

} else {
var statearr_111680_111722 = state_111647__$1;
(statearr_111680_111722[(1)] = (8));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_111648 === (14))){
var inst_111568 = (state_111647[(13)]);
var state_111647__$1 = state_111647;
var statearr_111681_111723 = state_111647__$1;
(statearr_111681_111723[(2)] = inst_111568);

(statearr_111681_111723[(1)] = (15));


return cljs.core.cst$kw$recur;
} else {
if((state_val_111648 === (26))){
var inst_111550 = (state_111647[(7)]);
var inst_111606 = (state_111647[(19)]);
var inst_111625 = (state_111647[(2)]);
var inst_111626 = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(inst_111625,(0),null);
var inst_111627 = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(inst_111625,(1),null);
var inst_111628 = cljs.core.cst$kw$_id.cljs$core$IFn$_invoke$arity$1(inst_111550);
var inst_111629 = fluree.db.query.fql.s(f);
var inst_111630 = cljs.core._EQ_.cljs$core$IFn$_invoke$arity$2(inst_111628,inst_111629);
var inst_111631 = cljs.core.empty_QMARK_(inst_111606);
var inst_111632 = ((inst_111630) || (inst_111631));
var state_111647__$1 = (function (){var statearr_111682 = state_111647;
(statearr_111682[(22)] = inst_111627);

(statearr_111682[(17)] = inst_111626);

return statearr_111682;
})();
if(cljs.core.truth_(inst_111632)){
var statearr_111683_111724 = state_111647__$1;
(statearr_111683_111724[(1)] = (29));

} else {
var statearr_111684_111725 = state_111647__$1;
(statearr_111684_111725[(1)] = (30));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_111648 === (16))){
var inst_111556 = (state_111647[(21)]);
var inst_111557 = (state_111647[(12)]);
var inst_111577 = (state_111647[(15)]);
var inst_111547 = (state_111647[(8)]);
var inst_111550 = (state_111647[(7)]);
var inst_111549 = (state_111647[(9)]);
var inst_111548 = (state_111647[(10)]);
var inst_111576 = (state_111647[(16)]);
var inst_111579 = cljs.core.get_in.cljs$core$IFn$_invoke$arity$2(inst_111550,inst_111577);
var inst_111580 = (function (){var G__111542 = inst_111549;
var keys_SINGLEQUOTE_ = inst_111577;
var r = inst_111557;
var child_path = inst_111576;
var acc__$1 = inst_111550;
var value = inst_111579;
var seq__111553 = inst_111557;
var first__111545 = inst_111547;
var vec__111552 = inst_111549;
var first__111554 = inst_111556;
var vec__111543 = new_child_paths;
var seq__111544 = inst_111548;
return ((function (G__111542,keys_SINGLEQUOTE_,r,child_path,acc__$1,value,seq__111553,first__111545,vec__111552,first__111554,vec__111543,seq__111544,inst_111556,inst_111557,inst_111577,inst_111547,inst_111550,inst_111549,inst_111548,inst_111576,inst_111579,state_val_111648,c__99809__auto__){
return (function (p1__111534_SHARP_){
return cljs.core._EQ_.cljs$core$IFn$_invoke$arity$2(cljs.core.cst$kw$_id.cljs$core$IFn$_invoke$arity$1(p1__111534_SHARP_),cljs.core.first(child_path));
});
;})(G__111542,keys_SINGLEQUOTE_,r,child_path,acc__$1,value,seq__111553,first__111545,vec__111552,first__111554,vec__111543,seq__111544,inst_111556,inst_111557,inst_111577,inst_111547,inst_111550,inst_111549,inst_111548,inst_111576,inst_111579,state_val_111648,c__99809__auto__))
})();
var inst_111581 = cljs.core.filter.cljs$core$IFn$_invoke$arity$2(inst_111580,inst_111579);
var inst_111582 = cljs.core.first(inst_111581);
var inst_111583 = inst_111579.indexOf(inst_111582);
var inst_111584 = cljs.core.conj.cljs$core$IFn$_invoke$arity$2(inst_111577,inst_111583);
var inst_111585 = cljs.core.conj.cljs$core$IFn$_invoke$arity$2(inst_111584,k);
var inst_111586 = cljs.core.rest(inst_111576);
var inst_111587 = cljs.core.count(inst_111586);
var inst_111588 = (inst_111587 > (0));
var state_111647__$1 = (function (){var statearr_111685 = state_111647;
(statearr_111685[(20)] = inst_111585);

return statearr_111685;
})();
if(cljs.core.truth_(inst_111588)){
var statearr_111686_111726 = state_111647__$1;
(statearr_111686_111726[(1)] = (18));

} else {
var statearr_111687_111727 = state_111647__$1;
(statearr_111687_111727[(1)] = (19));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_111648 === (30))){
var inst_111550 = (state_111647[(7)]);
var inst_111606 = (state_111647[(19)]);
var inst_111626 = (state_111647[(17)]);
var inst_111635 = cljs.core.assoc_in(inst_111550,inst_111606,inst_111626);
var state_111647__$1 = state_111647;
var statearr_111688_111728 = state_111647__$1;
(statearr_111688_111728[(2)] = inst_111635);

(statearr_111688_111728[(1)] = (31));


return cljs.core.cst$kw$recur;
} else {
if((state_val_111648 === (10))){
var inst_111556 = (state_111647[(21)]);
var state_111647__$1 = state_111647;
var statearr_111689_111729 = state_111647__$1;
(statearr_111689_111729[(2)] = inst_111556);

(statearr_111689_111729[(1)] = (12));


return cljs.core.cst$kw$recur;
} else {
if((state_val_111648 === (18))){
var inst_111585 = (state_111647[(20)]);
var inst_111576 = (state_111647[(16)]);
var inst_111590 = cljs.core.rest(inst_111576);
var inst_111576__$1 = inst_111590;
var inst_111577 = inst_111585;
var state_111647__$1 = (function (){var statearr_111690 = state_111647;
(statearr_111690[(15)] = inst_111577);

(statearr_111690[(16)] = inst_111576__$1);

return statearr_111690;
})();
var statearr_111691_111730 = state_111647__$1;
(statearr_111691_111730[(2)] = null);

(statearr_111691_111730[(1)] = (16));


return cljs.core.cst$kw$recur;
} else {
if((state_val_111648 === (8))){
var state_111647__$1 = state_111647;
if(cljs.core.truth_(parent_exists)){
var statearr_111692_111731 = state_111647__$1;
(statearr_111692_111731[(1)] = (10));

} else {
var statearr_111693_111732 = state_111647__$1;
(statearr_111693_111732[(1)] = (11));

}

return cljs.core.cst$kw$recur;
} else {
return null;
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
});})(c__99809__auto__))
;
return ((function (switch__99702__auto__,c__99809__auto__){
return (function() {
var fluree$db$query$fql$add_in_multi_flakes_$_state_machine__99703__auto__ = null;
var fluree$db$query$fql$add_in_multi_flakes_$_state_machine__99703__auto____0 = (function (){
var statearr_111694 = [null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null];
(statearr_111694[(0)] = fluree$db$query$fql$add_in_multi_flakes_$_state_machine__99703__auto__);

(statearr_111694[(1)] = (1));

return statearr_111694;
});
var fluree$db$query$fql$add_in_multi_flakes_$_state_machine__99703__auto____1 = (function (state_111647){
while(true){
var ret_value__99704__auto__ = (function (){try{while(true){
var result__99705__auto__ = switch__99702__auto__(state_111647);
if(cljs.core.keyword_identical_QMARK_(result__99705__auto__,cljs.core.cst$kw$recur)){
continue;
} else {
return result__99705__auto__;
}
break;
}
}catch (e111695){if((e111695 instanceof Object)){
var ex__99706__auto__ = e111695;
var statearr_111696_111733 = state_111647;
(statearr_111696_111733[(5)] = ex__99706__auto__);


cljs.core.async.impl.ioc_helpers.process_exception(state_111647);

return cljs.core.cst$kw$recur;
} else {
throw e111695;

}
}})();
if(cljs.core.keyword_identical_QMARK_(ret_value__99704__auto__,cljs.core.cst$kw$recur)){
var G__111734 = state_111647;
state_111647 = G__111734;
continue;
} else {
return ret_value__99704__auto__;
}
break;
}
});
fluree$db$query$fql$add_in_multi_flakes_$_state_machine__99703__auto__ = function(state_111647){
switch(arguments.length){
case 0:
return fluree$db$query$fql$add_in_multi_flakes_$_state_machine__99703__auto____0.call(this);
case 1:
return fluree$db$query$fql$add_in_multi_flakes_$_state_machine__99703__auto____1.call(this,state_111647);
}
throw(new Error('Invalid arity: ' + arguments.length));
};
fluree$db$query$fql$add_in_multi_flakes_$_state_machine__99703__auto__.cljs$core$IFn$_invoke$arity$0 = fluree$db$query$fql$add_in_multi_flakes_$_state_machine__99703__auto____0;
fluree$db$query$fql$add_in_multi_flakes_$_state_machine__99703__auto__.cljs$core$IFn$_invoke$arity$1 = fluree$db$query$fql$add_in_multi_flakes_$_state_machine__99703__auto____1;
return fluree$db$query$fql$add_in_multi_flakes_$_state_machine__99703__auto__;
})()
;})(switch__99702__auto__,c__99809__auto__))
})();
var state__99811__auto__ = (function (){var statearr_111697 = (f__99810__auto__.cljs$core$IFn$_invoke$arity$0 ? f__99810__auto__.cljs$core$IFn$_invoke$arity$0() : f__99810__auto__.call(null));
(statearr_111697[(6)] = c__99809__auto__);

return statearr_111697;
})();
return cljs.core.async.impl.ioc_helpers.run_state_machine_wrapped(state__99811__auto__);
});})(c__99809__auto__))
);

return c__99809__auto__;
});
fluree.db.query.fql.flake__GT_recur_multi = (function fluree$db$query$fql$flake__GT_recur_multi(db,f,pred_spec,recursion_map,flakes,acc,fuel,max_fuel,select_spec,cache,component_follow_QMARK_){
var c__99809__auto__ = cljs.core.async.chan.cljs$core$IFn$_invoke$arity$1((1));
cljs.core.async.impl.dispatch.run(((function (c__99809__auto__){
return (function (){
var f__99810__auto__ = (function (){var switch__99702__auto__ = ((function (c__99809__auto__){
return (function (state_111844){
var state_val_111845 = (state_111844[(1)]);
if((state_val_111845 === (7))){
var inst_111755 = (state_111844[(7)]);
var inst_111744 = (state_111844[(8)]);
var inst_111759 = (state_111844[(9)]);
var inst_111755__$1 = (state_111844[(2)]);
var inst_111756 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_111757 = [inst_111755__$1,inst_111744];
var inst_111758 = (new cljs.core.PersistentVector(null,2,(5),inst_111756,inst_111757,null));
var inst_111759__$1 = cljs.core.get_in.cljs$core$IFn$_invoke$arity$2(recursion_map,inst_111758);
var state_111844__$1 = (function (){var statearr_111846 = state_111844;
(statearr_111846[(7)] = inst_111755__$1);

(statearr_111846[(9)] = inst_111759__$1);

return statearr_111846;
})();
if(cljs.core.truth_(inst_111759__$1)){
var statearr_111847_111906 = state_111844__$1;
(statearr_111847_111906[(1)] = (11));

} else {
var statearr_111848_111907 = state_111844__$1;
(statearr_111848_111907[(1)] = (12));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_111845 === (20))){
var inst_111786 = (state_111844[(10)]);
var inst_111788 = f.o;
var inst_111789 = fluree.db.query.fql.resolve_reverse_refs(db,cache,fuel,max_fuel,inst_111788,inst_111786);
var state_111844__$1 = state_111844;
return cljs.core.async.impl.ioc_helpers.take_BANG_(state_111844__$1,(23),inst_111789);
} else {
if((state_val_111845 === (27))){
var inst_111806 = (state_111844[(2)]);
var state_111844__$1 = state_111844;
if(cljs.core.truth_(inst_111806)){
var statearr_111849_111908 = state_111844__$1;
(statearr_111849_111908[(1)] = (28));

} else {
var statearr_111850_111909 = state_111844__$1;
(statearr_111850_111909[(1)] = (29));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_111845 === (1))){
var state_111844__$1 = state_111844;
var statearr_111851_111910 = state_111844__$1;
(statearr_111851_111910[(2)] = null);

(statearr_111851_111910[(1)] = (4));


return cljs.core.cst$kw$recur;
} else {
if((state_val_111845 === (24))){
var inst_111773 = (state_111844[(11)]);
var inst_111800 = (state_111844[(2)]);
var inst_111801 = fluree.db.util.async.throw_err(inst_111800);
var state_111844__$1 = (function (){var statearr_111852 = state_111844;
(statearr_111852[(12)] = inst_111801);

return statearr_111852;
})();
if(cljs.core.truth_(inst_111773)){
var statearr_111853_111911 = state_111844__$1;
(statearr_111853_111911[(1)] = (25));

} else {
var statearr_111854_111912 = state_111844__$1;
(statearr_111854_111912[(1)] = (26));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_111845 === (39))){
var inst_111823 = (state_111844[(13)]);
var state_111844__$1 = state_111844;
var statearr_111855_111913 = state_111844__$1;
(statearr_111855_111913[(2)] = inst_111823);

(statearr_111855_111913[(1)] = (40));


return cljs.core.cst$kw$recur;
} else {
if((state_val_111845 === (4))){
var inst_111745 = (state_111844[(14)]);
var _ = cljs.core.async.impl.ioc_helpers.add_exception_frame(state_111844,(3),Error,null,(2));
var inst_111742 = fluree.db.query.fql.s(f);
var inst_111743 = cljs.core.assoc.cljs$core$IFn$_invoke$arity$3(acc,cljs.core.cst$kw$_id,inst_111742);
var inst_111744 = fluree.db.query.fql.o(f);
var inst_111745__$1 = cljs.core.cst$kw$as.cljs$core$IFn$_invoke$arity$1(pred_spec);
var state_111844__$1 = (function (){var statearr_111856 = state_111844;
(statearr_111856[(8)] = inst_111744);

(statearr_111856[(14)] = inst_111745__$1);

(statearr_111856[(15)] = inst_111743);

return statearr_111856;
})();
if(cljs.core.truth_(inst_111745__$1)){
var statearr_111857_111914 = state_111844__$1;
(statearr_111857_111914[(1)] = (5));

} else {
var statearr_111858_111915 = state_111844__$1;
(statearr_111858_111915[(1)] = (6));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_111845 === (15))){
var inst_111767 = (state_111844[(16)]);
var inst_111776 = cljs.core.not(inst_111767);
var state_111844__$1 = state_111844;
var statearr_111859_111916 = state_111844__$1;
(statearr_111859_111916[(2)] = inst_111776);

(statearr_111859_111916[(1)] = (16));


return cljs.core.cst$kw$recur;
} else {
if((state_val_111845 === (21))){
var state_111844__$1 = state_111844;
var statearr_111860_111917 = state_111844__$1;
(statearr_111860_111917[(2)] = null);

(statearr_111860_111917[(1)] = (22));


return cljs.core.cst$kw$recur;
} else {
if((state_val_111845 === (31))){
var inst_111797 = (state_111844[(17)]);
var inst_111811 = cljs.core.rest(flakes);
var inst_111812 = cljs.core.concat.cljs$core$IFn$_invoke$arity$2(inst_111811,inst_111797);
var state_111844__$1 = state_111844;
var statearr_111861_111918 = state_111844__$1;
(statearr_111861_111918[(2)] = inst_111812);

(statearr_111861_111918[(1)] = (33));


return cljs.core.cst$kw$recur;
} else {
if((state_val_111845 === (32))){
var state_111844__$1 = state_111844;
var statearr_111862_111919 = state_111844__$1;
(statearr_111862_111919[(1)] = (34));



return cljs.core.cst$kw$recur;
} else {
if((state_val_111845 === (40))){
var inst_111815 = (state_111844[(18)]);
var inst_111829 = (state_111844[(2)]);
var inst_111830 = cljs.core.concat.cljs$core$IFn$_invoke$arity$2(inst_111815,inst_111829);
var state_111844__$1 = state_111844;
var statearr_111864_111920 = state_111844__$1;
(statearr_111864_111920[(2)] = inst_111830);

(statearr_111864_111920[(1)] = (36));


return cljs.core.cst$kw$recur;
} else {
if((state_val_111845 === (33))){
var inst_111835 = (state_111844[(2)]);
var state_111844__$1 = state_111844;
var statearr_111865_111921 = state_111844__$1;
(statearr_111865_111921[(2)] = inst_111835);

(statearr_111865_111921[(1)] = (30));


return cljs.core.cst$kw$recur;
} else {
if((state_val_111845 === (13))){
var inst_111773 = (state_111844[(11)]);
var inst_111766 = (state_111844[(19)]);
var inst_111755 = (state_111844[(7)]);
var inst_111763 = (state_111844[(2)]);
var inst_111764 = fluree.db.query.fql.get_recursion_map_multi(recursion_map,inst_111755,f,select_spec,inst_111763);
var inst_111765 = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(inst_111764,(0),null);
var inst_111766__$1 = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(inst_111764,(1),null);
var inst_111767 = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(inst_111764,(2),null);
var inst_111768 = cljs.core.cst$kw$recur.cljs$core$IFn$_invoke$arity$1(pred_spec);
var inst_111769 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_111770 = [inst_111755,cljs.core.cst$kw$depth];
var inst_111771 = (new cljs.core.PersistentVector(null,2,(5),inst_111769,inst_111770,null));
var inst_111772 = cljs.core.get_in.cljs$core$IFn$_invoke$arity$2(inst_111766__$1,inst_111771);
var inst_111773__$1 = (inst_111768 < inst_111772);
var state_111844__$1 = (function (){var statearr_111866 = state_111844;
(statearr_111866[(11)] = inst_111773__$1);

(statearr_111866[(16)] = inst_111767);

(statearr_111866[(19)] = inst_111766__$1);

(statearr_111866[(20)] = inst_111765);

return statearr_111866;
})();
if(cljs.core.truth_(inst_111773__$1)){
var statearr_111867_111922 = state_111844__$1;
(statearr_111867_111922[(1)] = (14));

} else {
var statearr_111868_111923 = state_111844__$1;
(statearr_111868_111923[(1)] = (15));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_111845 === (22))){
var inst_111795 = (state_111844[(2)]);
var state_111844__$1 = state_111844;
var statearr_111869_111924 = state_111844__$1;
(statearr_111869_111924[(2)] = inst_111795);

(statearr_111869_111924[(1)] = (19));


return cljs.core.cst$kw$recur;
} else {
if((state_val_111845 === (36))){
var inst_111833 = (state_111844[(2)]);
var state_111844__$1 = state_111844;
var statearr_111870_111925 = state_111844__$1;
(statearr_111870_111925[(2)] = inst_111833);

(statearr_111870_111925[(1)] = (33));


return cljs.core.cst$kw$recur;
} else {
if((state_val_111845 === (29))){
var inst_111797 = (state_111844[(17)]);
var state_111844__$1 = state_111844;
if(cljs.core.truth_(inst_111797)){
var statearr_111871_111926 = state_111844__$1;
(statearr_111871_111926[(1)] = (31));

} else {
var statearr_111872_111927 = state_111844__$1;
(statearr_111872_111927[(1)] = (32));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_111845 === (6))){
var inst_111748 = (state_111844[(21)]);
var inst_111748__$1 = cljs.core.cst$kw$name.cljs$core$IFn$_invoke$arity$1(pred_spec);
var state_111844__$1 = (function (){var statearr_111873 = state_111844;
(statearr_111873[(21)] = inst_111748__$1);

return statearr_111873;
})();
if(cljs.core.truth_(inst_111748__$1)){
var statearr_111874_111928 = state_111844__$1;
(statearr_111874_111928[(1)] = (8));

} else {
var statearr_111875_111929 = state_111844__$1;
(statearr_111875_111929[(1)] = (9));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_111845 === (28))){
var inst_111808 = cljs.core.rest(flakes);
var state_111844__$1 = state_111844;
var statearr_111876_111930 = state_111844__$1;
(statearr_111876_111930[(2)] = inst_111808);

(statearr_111876_111930[(1)] = (30));


return cljs.core.cst$kw$recur;
} else {
if((state_val_111845 === (25))){
var inst_111773 = (state_111844[(11)]);
var state_111844__$1 = state_111844;
var statearr_111877_111931 = state_111844__$1;
(statearr_111877_111931[(2)] = inst_111773);

(statearr_111877_111931[(1)] = (27));


return cljs.core.cst$kw$recur;
} else {
if((state_val_111845 === (34))){
var inst_111744 = (state_111844[(8)]);
var inst_111815 = cljs.core.rest(flakes);
var inst_111817 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_111818 = [inst_111744];
var inst_111819 = (new cljs.core.PersistentVector(null,1,(5),inst_111817,inst_111818,null));
var inst_111820 = fluree.db.query.range.index_range.cljs$core$IFn$_invoke$arity$4(db,cljs.core.cst$kw$spot,cljs.core._EQ_,inst_111819);
var state_111844__$1 = (function (){var statearr_111878 = state_111844;
(statearr_111878[(18)] = inst_111815);

return statearr_111878;
})();
return cljs.core.async.impl.ioc_helpers.take_BANG_(state_111844__$1,(37),inst_111820);
} else {
if((state_val_111845 === (17))){
var state_111844__$1 = state_111844;
var statearr_111879_111932 = state_111844__$1;
(statearr_111879_111932[(2)] = null);

(statearr_111879_111932[(1)] = (19));


return cljs.core.cst$kw$recur;
} else {
if((state_val_111845 === (3))){
var inst_111735 = (state_111844[(2)]);
var state_111844__$1 = state_111844;
var statearr_111880_111933 = state_111844__$1;
(statearr_111880_111933[(2)] = inst_111735);


cljs.core.async.impl.ioc_helpers.process_exception(state_111844__$1);

return cljs.core.cst$kw$recur;
} else {
if((state_val_111845 === (12))){
var state_111844__$1 = state_111844;
var statearr_111881_111934 = state_111844__$1;
(statearr_111881_111934[(2)] = false);

(statearr_111881_111934[(1)] = (13));


return cljs.core.cst$kw$recur;
} else {
if((state_val_111845 === (2))){
var inst_111842 = (state_111844[(2)]);
var state_111844__$1 = state_111844;
return cljs.core.async.impl.ioc_helpers.return_chan(state_111844__$1,inst_111842);
} else {
if((state_val_111845 === (23))){
var inst_111791 = (state_111844[(2)]);
var inst_111792 = fluree.db.util.async.throw_err(inst_111791);
var state_111844__$1 = state_111844;
var statearr_111882_111935 = state_111844__$1;
(statearr_111882_111935[(2)] = inst_111792);

(statearr_111882_111935[(1)] = (22));


return cljs.core.cst$kw$recur;
} else {
if((state_val_111845 === (35))){
var state_111844__$1 = state_111844;
var statearr_111883_111936 = state_111844__$1;
(statearr_111883_111936[(2)] = null);

(statearr_111883_111936[(1)] = (36));


return cljs.core.cst$kw$recur;
} else {
if((state_val_111845 === (19))){
var inst_111765 = (state_111844[(20)]);
var inst_111755 = (state_111844[(7)]);
var inst_111743 = (state_111844[(15)]);
var inst_111797 = (state_111844[(2)]);
var inst_111798 = fluree.db.query.fql.add_in_multi_flakes(inst_111743,inst_111765,inst_111755,f,db,cache,fuel,max_fuel,pred_spec,component_follow_QMARK_,false);
var state_111844__$1 = (function (){var statearr_111884 = state_111844;
(statearr_111884[(17)] = inst_111797);

return statearr_111884;
})();
return cljs.core.async.impl.ioc_helpers.take_BANG_(state_111844__$1,(24),inst_111798);
} else {
if((state_val_111845 === (11))){
var inst_111759 = (state_111844[(9)]);
var state_111844__$1 = state_111844;
var statearr_111885_111937 = state_111844__$1;
(statearr_111885_111937[(2)] = inst_111759);

(statearr_111885_111937[(1)] = (13));


return cljs.core.cst$kw$recur;
} else {
if((state_val_111845 === (9))){
var inst_111751 = cljs.core.cst$kw$p.cljs$core$IFn$_invoke$arity$1(pred_spec);
var state_111844__$1 = state_111844;
var statearr_111886_111938 = state_111844__$1;
(statearr_111886_111938[(2)] = inst_111751);

(statearr_111886_111938[(1)] = (10));


return cljs.core.cst$kw$recur;
} else {
if((state_val_111845 === (5))){
var inst_111745 = (state_111844[(14)]);
var state_111844__$1 = state_111844;
var statearr_111887_111939 = state_111844__$1;
(statearr_111887_111939[(2)] = inst_111745);

(statearr_111887_111939[(1)] = (7));


return cljs.core.cst$kw$recur;
} else {
if((state_val_111845 === (14))){
var inst_111773 = (state_111844[(11)]);
var state_111844__$1 = state_111844;
var statearr_111888_111940 = state_111844__$1;
(statearr_111888_111940[(2)] = inst_111773);

(statearr_111888_111940[(1)] = (16));


return cljs.core.cst$kw$recur;
} else {
if((state_val_111845 === (26))){
var inst_111767 = (state_111844[(16)]);
var inst_111804 = cljs.core.not(inst_111767);
var state_111844__$1 = state_111844;
var statearr_111889_111941 = state_111844__$1;
(statearr_111889_111941[(2)] = inst_111804);

(statearr_111889_111941[(1)] = (27));


return cljs.core.cst$kw$recur;
} else {
if((state_val_111845 === (16))){
var inst_111778 = (state_111844[(2)]);
var state_111844__$1 = state_111844;
if(cljs.core.truth_(inst_111778)){
var statearr_111890_111942 = state_111844__$1;
(statearr_111890_111942[(1)] = (17));

} else {
var statearr_111891_111943 = state_111844__$1;
(statearr_111891_111943[(1)] = (18));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_111845 === (38))){
var inst_111823 = (state_111844[(13)]);
var inst_111825 = fluree.db.query.fql.fuel_flake_transducer(fuel,max_fuel);
var inst_111826 = cljs.core.sequence.cljs$core$IFn$_invoke$arity$2(inst_111825,inst_111823);
var state_111844__$1 = state_111844;
var statearr_111892_111944 = state_111844__$1;
(statearr_111892_111944[(2)] = inst_111826);

(statearr_111892_111944[(1)] = (40));


return cljs.core.cst$kw$recur;
} else {
if((state_val_111845 === (30))){
var inst_111766 = (state_111844[(19)]);
var inst_111801 = (state_111844[(12)]);
var inst_111837 = (state_111844[(2)]);
var inst_111838 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_111839 = [inst_111801,inst_111837,inst_111766];
var inst_111840 = (new cljs.core.PersistentVector(null,3,(5),inst_111838,inst_111839,null));
var state_111844__$1 = state_111844;
var statearr_111893_111945 = state_111844__$1;
(statearr_111893_111945[(2)] = inst_111840);


cljs.core.async.impl.ioc_helpers.process_exception(state_111844__$1);

return cljs.core.cst$kw$recur;
} else {
if((state_val_111845 === (10))){
var inst_111753 = (state_111844[(2)]);
var state_111844__$1 = state_111844;
var statearr_111894_111946 = state_111844__$1;
(statearr_111894_111946[(2)] = inst_111753);

(statearr_111894_111946[(1)] = (7));


return cljs.core.cst$kw$recur;
} else {
if((state_val_111845 === (18))){
var inst_111766 = (state_111844[(19)]);
var inst_111786 = (state_111844[(10)]);
var inst_111781 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_111782 = f.p;
var inst_111783 = [cljs.core.cst$kw$select_DASH_specs,inst_111782];
var inst_111784 = (new cljs.core.PersistentVector(null,2,(5),inst_111781,inst_111783,null));
var inst_111785 = cljs.core.get_in.cljs$core$IFn$_invoke$arity$2(inst_111766,inst_111784);
var inst_111786__$1 = fluree.db.query.fql.select_spec__GT_reverse_pred_specs(inst_111785);
var state_111844__$1 = (function (){var statearr_111895 = state_111844;
(statearr_111895[(10)] = inst_111786__$1);

return statearr_111895;
})();
if(cljs.core.truth_(inst_111786__$1)){
var statearr_111896_111947 = state_111844__$1;
(statearr_111896_111947[(1)] = (20));

} else {
var statearr_111897_111948 = state_111844__$1;
(statearr_111897_111948[(1)] = (21));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_111845 === (37))){
var inst_111822 = (state_111844[(2)]);
var inst_111823 = fluree.db.util.async.throw_err(inst_111822);
var state_111844__$1 = (function (){var statearr_111898 = state_111844;
(statearr_111898[(13)] = inst_111823);

return statearr_111898;
})();
if(cljs.core.truth_(fuel)){
var statearr_111899_111949 = state_111844__$1;
(statearr_111899_111949[(1)] = (38));

} else {
var statearr_111900_111950 = state_111844__$1;
(statearr_111900_111950[(1)] = (39));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_111845 === (8))){
var inst_111748 = (state_111844[(21)]);
var state_111844__$1 = state_111844;
var statearr_111901_111951 = state_111844__$1;
(statearr_111901_111951[(2)] = inst_111748);

(statearr_111901_111951[(1)] = (10));


return cljs.core.cst$kw$recur;
} else {
return null;
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
});})(c__99809__auto__))
;
return ((function (switch__99702__auto__,c__99809__auto__){
return (function() {
var fluree$db$query$fql$flake__GT_recur_multi_$_state_machine__99703__auto__ = null;
var fluree$db$query$fql$flake__GT_recur_multi_$_state_machine__99703__auto____0 = (function (){
var statearr_111902 = [null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null];
(statearr_111902[(0)] = fluree$db$query$fql$flake__GT_recur_multi_$_state_machine__99703__auto__);

(statearr_111902[(1)] = (1));

return statearr_111902;
});
var fluree$db$query$fql$flake__GT_recur_multi_$_state_machine__99703__auto____1 = (function (state_111844){
while(true){
var ret_value__99704__auto__ = (function (){try{while(true){
var result__99705__auto__ = switch__99702__auto__(state_111844);
if(cljs.core.keyword_identical_QMARK_(result__99705__auto__,cljs.core.cst$kw$recur)){
continue;
} else {
return result__99705__auto__;
}
break;
}
}catch (e111903){if((e111903 instanceof Object)){
var ex__99706__auto__ = e111903;
var statearr_111904_111952 = state_111844;
(statearr_111904_111952[(5)] = ex__99706__auto__);


cljs.core.async.impl.ioc_helpers.process_exception(state_111844);

return cljs.core.cst$kw$recur;
} else {
throw e111903;

}
}})();
if(cljs.core.keyword_identical_QMARK_(ret_value__99704__auto__,cljs.core.cst$kw$recur)){
var G__111953 = state_111844;
state_111844 = G__111953;
continue;
} else {
return ret_value__99704__auto__;
}
break;
}
});
fluree$db$query$fql$flake__GT_recur_multi_$_state_machine__99703__auto__ = function(state_111844){
switch(arguments.length){
case 0:
return fluree$db$query$fql$flake__GT_recur_multi_$_state_machine__99703__auto____0.call(this);
case 1:
return fluree$db$query$fql$flake__GT_recur_multi_$_state_machine__99703__auto____1.call(this,state_111844);
}
throw(new Error('Invalid arity: ' + arguments.length));
};
fluree$db$query$fql$flake__GT_recur_multi_$_state_machine__99703__auto__.cljs$core$IFn$_invoke$arity$0 = fluree$db$query$fql$flake__GT_recur_multi_$_state_machine__99703__auto____0;
fluree$db$query$fql$flake__GT_recur_multi_$_state_machine__99703__auto__.cljs$core$IFn$_invoke$arity$1 = fluree$db$query$fql$flake__GT_recur_multi_$_state_machine__99703__auto____1;
return fluree$db$query$fql$flake__GT_recur_multi_$_state_machine__99703__auto__;
})()
;})(switch__99702__auto__,c__99809__auto__))
})();
var state__99811__auto__ = (function (){var statearr_111905 = (f__99810__auto__.cljs$core$IFn$_invoke$arity$0 ? f__99810__auto__.cljs$core$IFn$_invoke$arity$0() : f__99810__auto__.call(null));
(statearr_111905[(6)] = c__99809__auto__);

return statearr_111905;
})();
return cljs.core.async.impl.ioc_helpers.run_state_machine_wrapped(state__99811__auto__);
});})(c__99809__auto__))
);

return c__99809__auto__;
});
fluree.db.query.fql.get_recursion_map = (function fluree$db$query$fql$get_recursion_map(db,recursion_map,select_spec,cache,k,f){
var select_spec__$1 = cljs.core.get_in.cljs$core$IFn$_invoke$arity$2(select_spec,new cljs.core.PersistentVector(null, 3, 5, cljs.core.PersistentVector.EMPTY_NODE, [cljs.core.cst$kw$select,cljs.core.cst$kw$pred_DASH_id,f.p], null));
var full_select_spec = (cljs.core.truth_(fluree.db.query.fql.has_ns_lookups_QMARK_(select_spec__$1))?fluree.db.query.fql.full_select_spec(db,cache,select_spec__$1,fluree.db.query.fql.s(f)):select_spec__$1);
return cljs.core.assoc_in(cljs.core.assoc_in(cljs.core.assoc_in(recursion_map,new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [k,fluree.db.query.fql.s(f)], null),(0)),new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [cljs.core.cst$kw$pred_DASH_ids,k], null),f.p),new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [cljs.core.cst$kw$select_DASH_specs,f.p], null),full_select_spec);
});
fluree.db.query.fql.flake__GT_recur = (function fluree$db$query$fql$flake__GT_recur(db,f,pred_spec,recursion_map,flakes,acc,fuel,max_fuel,select_spec,cache){
var c__99809__auto__ = cljs.core.async.chan.cljs$core$IFn$_invoke$arity$1((1));
cljs.core.async.impl.dispatch.run(((function (c__99809__auto__){
return (function (){
var f__99810__auto__ = (function (){var switch__99702__auto__ = ((function (c__99809__auto__){
return (function (state_112113){
var state_val_112114 = (state_112113[(1)]);
if((state_val_112114 === (7))){
var inst_111970 = (state_112113[(7)]);
var inst_111958 = (state_112113[(8)]);
var inst_111978 = (state_112113[(9)]);
var inst_111970__$1 = (state_112113[(2)]);
var inst_111971 = cljs.core.PersistentVector.EMPTY;
var inst_111972 = cljs.core.repeat.cljs$core$IFn$_invoke$arity$2((0),inst_111970__$1);
var inst_111973 = cljs.core.into.cljs$core$IFn$_invoke$arity$2(inst_111971,inst_111972);
var inst_111974 = cljs.core.get_in.cljs$core$IFn$_invoke$arity$2(acc,inst_111973);
var inst_111975 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_111976 = [inst_111970__$1,inst_111958];
var inst_111977 = (new cljs.core.PersistentVector(null,2,(5),inst_111975,inst_111976,null));
var inst_111978__$1 = cljs.core.get_in.cljs$core$IFn$_invoke$arity$2(recursion_map,inst_111977);
var state_112113__$1 = (function (){var statearr_112115 = state_112113;
(statearr_112115[(7)] = inst_111970__$1);

(statearr_112115[(10)] = inst_111974);

(statearr_112115[(9)] = inst_111978__$1);

return statearr_112115;
})();
if(cljs.core.truth_(inst_111978__$1)){
var statearr_112116_112207 = state_112113__$1;
(statearr_112116_112207[(1)] = (11));

} else {
var statearr_112117_112208 = state_112113__$1;
(statearr_112117_112208[(1)] = (12));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_112114 === (59))){
var inst_112095 = (state_112113[(11)]);
var state_112113__$1 = state_112113;
var statearr_112118_112209 = state_112113__$1;
(statearr_112118_112209[(2)] = inst_112095);

(statearr_112118_112209[(1)] = (60));


return cljs.core.cst$kw$recur;
} else {
if((state_val_112114 === (20))){
var inst_112002 = (state_112113[(12)]);
var state_112113__$1 = state_112113;
var statearr_112119_112210 = state_112113__$1;
(statearr_112119_112210[(2)] = inst_112002);

(statearr_112119_112210[(1)] = (22));


return cljs.core.cst$kw$recur;
} else {
if((state_val_112114 === (58))){
var inst_112095 = (state_112113[(11)]);
var inst_112097 = fluree.db.query.fql.fuel_flake_transducer(fuel,max_fuel);
var inst_112098 = cljs.core.sequence.cljs$core$IFn$_invoke$arity$2(inst_112097,inst_112095);
var state_112113__$1 = state_112113;
var statearr_112120_112211 = state_112113__$1;
(statearr_112120_112211[(2)] = inst_112098);

(statearr_112120_112211[(1)] = (60));


return cljs.core.cst$kw$recur;
} else {
if((state_val_112114 === (60))){
var inst_112087 = (state_112113[(13)]);
var inst_112101 = (state_112113[(2)]);
var inst_112102 = cljs.core.concat.cljs$core$IFn$_invoke$arity$2(inst_112087,inst_112101);
var state_112113__$1 = state_112113;
var statearr_112121_112212 = state_112113__$1;
(statearr_112121_112212[(2)] = inst_112102);

(statearr_112121_112212[(1)] = (56));


return cljs.core.cst$kw$recur;
} else {
if((state_val_112114 === (27))){
var state_112113__$1 = state_112113;
var statearr_112122_112213 = state_112113__$1;
(statearr_112122_112213[(2)] = null);

(statearr_112122_112213[(1)] = (28));


return cljs.core.cst$kw$recur;
} else {
if((state_val_112114 === (1))){
var state_112113__$1 = state_112113;
var statearr_112123_112214 = state_112113__$1;
(statearr_112123_112214[(2)] = null);

(statearr_112123_112214[(1)] = (4));


return cljs.core.cst$kw$recur;
} else {
if((state_val_112114 === (24))){
var inst_112014 = (state_112113[(14)]);
var inst_111997 = (state_112113[(15)]);
var inst_112009 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_112010 = f.p;
var inst_112011 = [cljs.core.cst$kw$select_DASH_specs,inst_112010];
var inst_112012 = (new cljs.core.PersistentVector(null,2,(5),inst_112009,inst_112011,null));
var inst_112013 = cljs.core.get_in.cljs$core$IFn$_invoke$arity$2(inst_111997,inst_112012);
var inst_112014__$1 = fluree.db.query.fql.select_spec__GT_reverse_pred_specs(inst_112013);
var state_112113__$1 = (function (){var statearr_112124 = state_112113;
(statearr_112124[(14)] = inst_112014__$1);

return statearr_112124;
})();
if(cljs.core.truth_(inst_112014__$1)){
var statearr_112125_112215 = state_112113__$1;
(statearr_112125_112215[(1)] = (26));

} else {
var statearr_112126_112216 = state_112113__$1;
(statearr_112126_112216[(1)] = (27));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_112114 === (55))){
var inst_111958 = (state_112113[(8)]);
var inst_112087 = cljs.core.rest(flakes);
var inst_112089 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_112090 = [inst_111958];
var inst_112091 = (new cljs.core.PersistentVector(null,1,(5),inst_112089,inst_112090,null));
var inst_112092 = fluree.db.query.range.index_range.cljs$core$IFn$_invoke$arity$4(db,cljs.core.cst$kw$spot,cljs.core._EQ_,inst_112091);
var state_112113__$1 = (function (){var statearr_112127 = state_112113;
(statearr_112127[(13)] = inst_112087);

return statearr_112127;
})();
return cljs.core.async.impl.ioc_helpers.take_BANG_(state_112113__$1,(57),inst_112092);
} else {
if((state_val_112114 === (39))){
var inst_112055 = (state_112113[(16)]);
var inst_111970 = (state_112113[(7)]);
var inst_112025 = (state_112113[(17)]);
var inst_112057 = cljs.core.get.cljs$core$IFn$_invoke$arity$2(inst_112055,inst_111970);
var inst_112058 = cljs.core.merge.cljs$core$IFn$_invoke$arity$variadic(cljs.core.prim_seq.cljs$core$IFn$_invoke$arity$2([inst_112057,inst_112025], 0));
var inst_112059 = cljs.core.assoc.cljs$core$IFn$_invoke$arity$3(inst_112055,inst_111970,inst_112058);
var state_112113__$1 = state_112113;
var statearr_112128_112217 = state_112113__$1;
(statearr_112128_112217[(2)] = inst_112059);

(statearr_112128_112217[(1)] = (41));


return cljs.core.cst$kw$recur;
} else {
if((state_val_112114 === (46))){
var state_112113__$1 = state_112113;
var statearr_112129_112218 = state_112113__$1;
(statearr_112129_112218[(1)] = (48));



return cljs.core.cst$kw$recur;
} else {
if((state_val_112114 === (4))){
var inst_111960 = (state_112113[(18)]);
var _ = cljs.core.async.impl.ioc_helpers.add_exception_frame(state_112113,(3),Error,null,(2));
var inst_111958 = f.o;
var inst_111959 = cljs.core.cst$kw$multi_QMARK_.cljs$core$IFn$_invoke$arity$1(pred_spec);
var inst_111960__$1 = cljs.core.cst$kw$as.cljs$core$IFn$_invoke$arity$1(pred_spec);
var state_112113__$1 = (function (){var statearr_112131 = state_112113;
(statearr_112131[(18)] = inst_111960__$1);

(statearr_112131[(8)] = inst_111958);

(statearr_112131[(19)] = inst_111959);

return statearr_112131;
})();
if(cljs.core.truth_(inst_111960__$1)){
var statearr_112132_112219 = state_112113__$1;
(statearr_112132_112219[(1)] = (5));

} else {
var statearr_112133_112220 = state_112113__$1;
(statearr_112133_112220[(1)] = (6));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_112114 === (54))){
var inst_112085 = cljs.core.rest(flakes);
var state_112113__$1 = state_112113;
var statearr_112134_112221 = state_112113__$1;
(statearr_112134_112221[(2)] = inst_112085);

(statearr_112134_112221[(1)] = (56));


return cljs.core.cst$kw$recur;
} else {
if((state_val_112114 === (15))){
var state_112113__$1 = state_112113;
var statearr_112135_112222 = state_112113__$1;
(statearr_112135_112222[(2)] = recursion_map);

(statearr_112135_112222[(1)] = (16));


return cljs.core.cst$kw$recur;
} else {
if((state_val_112114 === (48))){
var inst_112062 = (state_112113[(20)]);
var inst_111970 = (state_112113[(7)]);
var inst_112069 = cljs.core.PersistentVector.EMPTY;
var inst_112070 = cljs.core.repeat.cljs$core$IFn$_invoke$arity$2((0),inst_111970);
var inst_112071 = cljs.core.into.cljs$core$IFn$_invoke$arity$2(inst_112069,inst_112070);
var inst_112072 = cljs.core.assoc_in(acc,inst_112071,inst_112062);
var state_112113__$1 = state_112113;
var statearr_112136_112223 = state_112113__$1;
(statearr_112136_112223[(2)] = inst_112072);

(statearr_112136_112223[(1)] = (50));


return cljs.core.cst$kw$recur;
} else {
if((state_val_112114 === (50))){
var inst_112075 = (state_112113[(2)]);
var state_112113__$1 = state_112113;
var statearr_112137_112224 = state_112113__$1;
(statearr_112137_112224[(2)] = inst_112075);

(statearr_112137_112224[(1)] = (47));


return cljs.core.cst$kw$recur;
} else {
if((state_val_112114 === (21))){
var inst_111982 = (state_112113[(21)]);
var state_112113__$1 = state_112113;
var statearr_112138_112225 = state_112113__$1;
(statearr_112138_112225[(2)] = inst_111982);

(statearr_112138_112225[(1)] = (22));


return cljs.core.cst$kw$recur;
} else {
if((state_val_112114 === (31))){
var inst_111959 = (state_112113[(19)]);
var state_112113__$1 = state_112113;
var statearr_112139_112226 = state_112113__$1;
(statearr_112139_112226[(2)] = inst_111959);

(statearr_112139_112226[(1)] = (32));


return cljs.core.cst$kw$recur;
} else {
if((state_val_112114 === (32))){
var inst_112033 = (state_112113[(2)]);
var state_112113__$1 = state_112113;
if(cljs.core.truth_(inst_112033)){
var statearr_112140_112227 = state_112113__$1;
(statearr_112140_112227[(1)] = (33));

} else {
var statearr_112141_112228 = state_112113__$1;
(statearr_112141_112228[(1)] = (34));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_112114 === (40))){
var inst_112055 = (state_112113[(16)]);
var state_112113__$1 = state_112113;
var statearr_112142_112229 = state_112113__$1;
(statearr_112142_112229[(2)] = inst_112055);

(statearr_112142_112229[(1)] = (41));


return cljs.core.cst$kw$recur;
} else {
if((state_val_112114 === (56))){
var inst_112079 = (state_112113[(22)]);
var inst_111997 = (state_112113[(15)]);
var inst_112104 = (state_112113[(2)]);
var inst_112105 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_112106 = [inst_112079,inst_112104,inst_111997];
var inst_112107 = (new cljs.core.PersistentVector(null,3,(5),inst_112105,inst_112106,null));
var state_112113__$1 = state_112113;
var statearr_112143_112230 = state_112113__$1;
(statearr_112143_112230[(2)] = inst_112107);

(statearr_112143_112230[(1)] = (35));


return cljs.core.cst$kw$recur;
} else {
if((state_val_112114 === (33))){
var inst_111997 = (state_112113[(15)]);
var inst_112035 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_112036 = cljs.core.rest(flakes);
var inst_112037 = [acc,inst_112036,inst_111997];
var inst_112038 = (new cljs.core.PersistentVector(null,3,(5),inst_112035,inst_112037,null));
var state_112113__$1 = state_112113;
var statearr_112144_112231 = state_112113__$1;
(statearr_112144_112231[(2)] = inst_112038);

(statearr_112144_112231[(1)] = (35));


return cljs.core.cst$kw$recur;
} else {
if((state_val_112114 === (13))){
var inst_111982 = (state_112113[(21)]);
var inst_111982__$1 = (state_112113[(2)]);
var inst_111983 = cljs.core.not(inst_111982__$1);
var state_112113__$1 = (function (){var statearr_112145 = state_112113;
(statearr_112145[(21)] = inst_111982__$1);

return statearr_112145;
})();
if(inst_111983){
var statearr_112146_112232 = state_112113__$1;
(statearr_112146_112232[(1)] = (14));

} else {
var statearr_112147_112233 = state_112113__$1;
(statearr_112147_112233[(1)] = (15));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_112114 === (22))){
var inst_112006 = (state_112113[(2)]);
var state_112113__$1 = state_112113;
if(cljs.core.truth_(inst_112006)){
var statearr_112148_112234 = state_112113__$1;
(statearr_112148_112234[(1)] = (23));

} else {
var statearr_112149_112235 = state_112113__$1;
(statearr_112149_112235[(1)] = (24));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_112114 === (36))){
var inst_111970 = (state_112113[(7)]);
var inst_111974 = (state_112113[(10)]);
var inst_111958 = (state_112113[(8)]);
var inst_112041 = cljs.core.PersistentVector.EMPTY;
var inst_112042 = cljs.core.get.cljs$core$IFn$_invoke$arity$2(inst_111974,inst_111970);
var inst_112043 = [cljs.core.cst$kw$_id];
var inst_112044 = [inst_111958];
var inst_112045 = cljs.core.PersistentHashMap.fromArrays(inst_112043,inst_112044);
var inst_112046 = cljs.core.conj.cljs$core$IFn$_invoke$arity$2(inst_112042,inst_112045);
var inst_112047 = cljs.core.into.cljs$core$IFn$_invoke$arity$2(inst_112041,inst_112046);
var inst_112048 = cljs.core.assoc.cljs$core$IFn$_invoke$arity$3(inst_111974,inst_111970,inst_112047);
var state_112113__$1 = state_112113;
var statearr_112150_112236 = state_112113__$1;
(statearr_112150_112236[(2)] = inst_112048);

(statearr_112150_112236[(1)] = (38));


return cljs.core.cst$kw$recur;
} else {
if((state_val_112114 === (41))){
var inst_111982 = (state_112113[(21)]);
var inst_112062 = (state_112113[(2)]);
var inst_112063 = cljs.core.not(inst_111982);
var state_112113__$1 = (function (){var statearr_112151 = state_112113;
(statearr_112151[(20)] = inst_112062);

return statearr_112151;
})();
if(inst_112063){
var statearr_112152_112237 = state_112113__$1;
(statearr_112152_112237[(1)] = (42));

} else {
var statearr_112153_112238 = state_112113__$1;
(statearr_112153_112238[(1)] = (43));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_112114 === (43))){
var inst_111982 = (state_112113[(21)]);
var state_112113__$1 = state_112113;
if(cljs.core.truth_(inst_111982)){
var statearr_112154_112239 = state_112113__$1;
(statearr_112154_112239[(1)] = (45));

} else {
var statearr_112155_112240 = state_112113__$1;
(statearr_112155_112240[(1)] = (46));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_112114 === (29))){
var inst_112019 = (state_112113[(2)]);
var inst_112020 = fluree.db.util.async.throw_err(inst_112019);
var state_112113__$1 = state_112113;
var statearr_112156_112241 = state_112113__$1;
(statearr_112156_112241[(2)] = inst_112020);

(statearr_112156_112241[(1)] = (28));


return cljs.core.cst$kw$recur;
} else {
if((state_val_112114 === (44))){
var inst_112002 = (state_112113[(12)]);
var inst_112079 = (state_112113[(2)]);
var state_112113__$1 = (function (){var statearr_112157 = state_112113;
(statearr_112157[(22)] = inst_112079);

return statearr_112157;
})();
if(cljs.core.truth_(inst_112002)){
var statearr_112158_112242 = state_112113__$1;
(statearr_112158_112242[(1)] = (51));

} else {
var statearr_112159_112243 = state_112113__$1;
(statearr_112159_112243[(1)] = (52));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_112114 === (6))){
var inst_111963 = (state_112113[(23)]);
var inst_111963__$1 = cljs.core.cst$kw$name.cljs$core$IFn$_invoke$arity$1(pred_spec);
var state_112113__$1 = (function (){var statearr_112160 = state_112113;
(statearr_112160[(23)] = inst_111963__$1);

return statearr_112160;
})();
if(cljs.core.truth_(inst_111963__$1)){
var statearr_112161_112244 = state_112113__$1;
(statearr_112161_112244[(1)] = (8));

} else {
var statearr_112162_112245 = state_112113__$1;
(statearr_112162_112245[(1)] = (9));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_112114 === (28))){
var inst_112023 = (state_112113[(2)]);
var state_112113__$1 = state_112113;
var statearr_112163_112246 = state_112113__$1;
(statearr_112163_112246[(2)] = inst_112023);

(statearr_112163_112246[(1)] = (25));


return cljs.core.cst$kw$recur;
} else {
if((state_val_112114 === (51))){
var inst_112002 = (state_112113[(12)]);
var state_112113__$1 = state_112113;
var statearr_112164_112247 = state_112113__$1;
(statearr_112164_112247[(2)] = inst_112002);

(statearr_112164_112247[(1)] = (53));


return cljs.core.cst$kw$recur;
} else {
if((state_val_112114 === (25))){
var inst_111959 = (state_112113[(19)]);
var inst_112025 = (state_112113[(2)]);
var state_112113__$1 = (function (){var statearr_112165 = state_112113;
(statearr_112165[(17)] = inst_112025);

return statearr_112165;
})();
if(cljs.core.truth_(inst_111959)){
var statearr_112166_112248 = state_112113__$1;
(statearr_112166_112248[(1)] = (30));

} else {
var statearr_112167_112249 = state_112113__$1;
(statearr_112167_112249[(1)] = (31));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_112114 === (34))){
var inst_111959 = (state_112113[(19)]);
var state_112113__$1 = state_112113;
if(cljs.core.truth_(inst_111959)){
var statearr_112168_112250 = state_112113__$1;
(statearr_112168_112250[(1)] = (36));

} else {
var statearr_112169_112251 = state_112113__$1;
(statearr_112169_112251[(1)] = (37));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_112114 === (17))){
var inst_111988 = (state_112113[(24)]);
var state_112113__$1 = state_112113;
var statearr_112170_112252 = state_112113__$1;
(statearr_112170_112252[(2)] = inst_111988);

(statearr_112170_112252[(1)] = (19));


return cljs.core.cst$kw$recur;
} else {
if((state_val_112114 === (3))){
var inst_111954 = (state_112113[(2)]);
var state_112113__$1 = state_112113;
var statearr_112171_112253 = state_112113__$1;
(statearr_112171_112253[(2)] = inst_111954);


cljs.core.async.impl.ioc_helpers.process_exception(state_112113__$1);

return cljs.core.cst$kw$recur;
} else {
if((state_val_112114 === (12))){
var state_112113__$1 = state_112113;
var statearr_112172_112254 = state_112113__$1;
(statearr_112172_112254[(2)] = false);

(statearr_112172_112254[(1)] = (13));


return cljs.core.cst$kw$recur;
} else {
if((state_val_112114 === (2))){
var inst_112111 = (state_112113[(2)]);
var state_112113__$1 = state_112113;
return cljs.core.async.impl.ioc_helpers.return_chan(state_112113__$1,inst_112111);
} else {
if((state_val_112114 === (23))){
var state_112113__$1 = state_112113;
var statearr_112173_112255 = state_112113__$1;
(statearr_112173_112255[(2)] = null);

(statearr_112173_112255[(1)] = (25));


return cljs.core.cst$kw$recur;
} else {
if((state_val_112114 === (47))){
var inst_112077 = (state_112113[(2)]);
var state_112113__$1 = state_112113;
var statearr_112174_112256 = state_112113__$1;
(statearr_112174_112256[(2)] = inst_112077);

(statearr_112174_112256[(1)] = (44));


return cljs.core.cst$kw$recur;
} else {
if((state_val_112114 === (35))){
var inst_112109 = (state_112113[(2)]);
var state_112113__$1 = state_112113;
var statearr_112175_112257 = state_112113__$1;
(statearr_112175_112257[(2)] = inst_112109);


cljs.core.async.impl.ioc_helpers.process_exception(state_112113__$1);

return cljs.core.cst$kw$recur;
} else {
if((state_val_112114 === (19))){
var inst_112002 = (state_112113[(12)]);
var inst_111970 = (state_112113[(7)]);
var inst_111997 = (state_112113[(15)]);
var inst_111997__$1 = (state_112113[(2)]);
var inst_111998 = cljs.core.cst$kw$recur.cljs$core$IFn$_invoke$arity$1(pred_spec);
var inst_111999 = cljs.core.get.cljs$core$IFn$_invoke$arity$2(inst_111997__$1,inst_111970);
var inst_112000 = cljs.core.vals(inst_111999);
var inst_112001 = cljs.core.apply.cljs$core$IFn$_invoke$arity$2(cljs.core.max,inst_112000);
var inst_112002__$1 = (inst_111998 < inst_112001);
var state_112113__$1 = (function (){var statearr_112176 = state_112113;
(statearr_112176[(12)] = inst_112002__$1);

(statearr_112176[(15)] = inst_111997__$1);

return statearr_112176;
})();
if(cljs.core.truth_(inst_112002__$1)){
var statearr_112177_112258 = state_112113__$1;
(statearr_112177_112258[(1)] = (20));

} else {
var statearr_112178_112259 = state_112113__$1;
(statearr_112178_112259[(1)] = (21));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_112114 === (57))){
var inst_112094 = (state_112113[(2)]);
var inst_112095 = fluree.db.util.async.throw_err(inst_112094);
var state_112113__$1 = (function (){var statearr_112179 = state_112113;
(statearr_112179[(11)] = inst_112095);

return statearr_112179;
})();
if(cljs.core.truth_(fuel)){
var statearr_112180_112260 = state_112113__$1;
(statearr_112180_112260[(1)] = (58));

} else {
var statearr_112181_112261 = state_112113__$1;
(statearr_112181_112261[(1)] = (59));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_112114 === (11))){
var inst_111978 = (state_112113[(9)]);
var state_112113__$1 = state_112113;
var statearr_112182_112262 = state_112113__$1;
(statearr_112182_112262[(2)] = inst_111978);

(statearr_112182_112262[(1)] = (13));


return cljs.core.cst$kw$recur;
} else {
if((state_val_112114 === (9))){
var inst_111966 = cljs.core.cst$kw$p.cljs$core$IFn$_invoke$arity$1(pred_spec);
var state_112113__$1 = state_112113;
var statearr_112183_112263 = state_112113__$1;
(statearr_112183_112263[(2)] = inst_111966);

(statearr_112183_112263[(1)] = (10));


return cljs.core.cst$kw$recur;
} else {
if((state_val_112114 === (5))){
var inst_111960 = (state_112113[(18)]);
var state_112113__$1 = state_112113;
var statearr_112184_112264 = state_112113__$1;
(statearr_112184_112264[(2)] = inst_111960);

(statearr_112184_112264[(1)] = (7));


return cljs.core.cst$kw$recur;
} else {
if((state_val_112114 === (14))){
var inst_111970 = (state_112113[(7)]);
var inst_111985 = fluree.db.query.fql.get_recursion_map(db,recursion_map,select_spec,cache,inst_111970,f);
var state_112113__$1 = state_112113;
var statearr_112185_112265 = state_112113__$1;
(statearr_112185_112265[(2)] = inst_111985);

(statearr_112185_112265[(1)] = (16));


return cljs.core.cst$kw$recur;
} else {
if((state_val_112114 === (45))){
var state_112113__$1 = state_112113;
var statearr_112186_112266 = state_112113__$1;
(statearr_112186_112266[(2)] = acc);

(statearr_112186_112266[(1)] = (47));


return cljs.core.cst$kw$recur;
} else {
if((state_val_112114 === (53))){
var inst_112083 = (state_112113[(2)]);
var state_112113__$1 = state_112113;
if(cljs.core.truth_(inst_112083)){
var statearr_112187_112267 = state_112113__$1;
(statearr_112187_112267[(1)] = (54));

} else {
var statearr_112188_112268 = state_112113__$1;
(statearr_112188_112268[(1)] = (55));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_112114 === (26))){
var inst_112014 = (state_112113[(14)]);
var inst_112016 = f.o;
var inst_112017 = fluree.db.query.fql.resolve_reverse_refs(db,cache,fuel,max_fuel,inst_112016,inst_112014);
var state_112113__$1 = state_112113;
return cljs.core.async.impl.ioc_helpers.take_BANG_(state_112113__$1,(29),inst_112017);
} else {
if((state_val_112114 === (16))){
var inst_111982 = (state_112113[(21)]);
var inst_111988 = (state_112113[(2)]);
var state_112113__$1 = (function (){var statearr_112189 = state_112113;
(statearr_112189[(24)] = inst_111988);

return statearr_112189;
})();
if(cljs.core.truth_(inst_111982)){
var statearr_112190_112269 = state_112113__$1;
(statearr_112190_112269[(1)] = (17));

} else {
var statearr_112191_112270 = state_112113__$1;
(statearr_112191_112270[(1)] = (18));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_112114 === (38))){
var inst_112025 = (state_112113[(17)]);
var inst_112055 = (state_112113[(2)]);
var state_112113__$1 = (function (){var statearr_112192 = state_112113;
(statearr_112192[(16)] = inst_112055);

return statearr_112192;
})();
if(cljs.core.truth_(inst_112025)){
var statearr_112193_112271 = state_112113__$1;
(statearr_112193_112271[(1)] = (39));

} else {
var statearr_112194_112272 = state_112113__$1;
(statearr_112194_112272[(1)] = (40));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_112114 === (30))){
var inst_111970 = (state_112113[(7)]);
var inst_111974 = (state_112113[(10)]);
var inst_112027 = cljs.core.get.cljs$core$IFn$_invoke$arity$2(inst_111974,inst_111970);
var inst_112028 = cljs.core.count(inst_112027);
var inst_112029 = cljs.core.cst$kw$limit.cljs$core$IFn$_invoke$arity$1(pred_spec);
var inst_112030 = (inst_112028 > inst_112029);
var state_112113__$1 = state_112113;
var statearr_112195_112273 = state_112113__$1;
(statearr_112195_112273[(2)] = inst_112030);

(statearr_112195_112273[(1)] = (32));


return cljs.core.cst$kw$recur;
} else {
if((state_val_112114 === (10))){
var inst_111968 = (state_112113[(2)]);
var state_112113__$1 = state_112113;
var statearr_112196_112274 = state_112113__$1;
(statearr_112196_112274[(2)] = inst_111968);

(statearr_112196_112274[(1)] = (7));


return cljs.core.cst$kw$recur;
} else {
if((state_val_112114 === (18))){
var inst_111970 = (state_112113[(7)]);
var inst_111958 = (state_112113[(8)]);
var inst_111988 = (state_112113[(24)]);
var inst_111991 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_111992 = [inst_111970,inst_111958];
var inst_111993 = (new cljs.core.PersistentVector(null,2,(5),inst_111991,inst_111992,null));
var inst_111994 = ((0) + (1));
var inst_111995 = cljs.core.assoc_in(inst_111988,inst_111993,inst_111994);
var state_112113__$1 = state_112113;
var statearr_112197_112275 = state_112113__$1;
(statearr_112197_112275[(2)] = inst_111995);

(statearr_112197_112275[(1)] = (19));


return cljs.core.cst$kw$recur;
} else {
if((state_val_112114 === (52))){
var inst_111982 = (state_112113[(21)]);
var state_112113__$1 = state_112113;
var statearr_112198_112276 = state_112113__$1;
(statearr_112198_112276[(2)] = inst_111982);

(statearr_112198_112276[(1)] = (53));


return cljs.core.cst$kw$recur;
} else {
if((state_val_112114 === (42))){
var inst_112062 = (state_112113[(20)]);
var state_112113__$1 = state_112113;
var statearr_112199_112277 = state_112113__$1;
(statearr_112199_112277[(2)] = inst_112062);

(statearr_112199_112277[(1)] = (44));


return cljs.core.cst$kw$recur;
} else {
if((state_val_112114 === (37))){
var inst_111970 = (state_112113[(7)]);
var inst_111974 = (state_112113[(10)]);
var inst_111958 = (state_112113[(8)]);
var inst_112050 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_112051 = [inst_111970,cljs.core.cst$kw$_id];
var inst_112052 = (new cljs.core.PersistentVector(null,2,(5),inst_112050,inst_112051,null));
var inst_112053 = cljs.core.assoc_in(inst_111974,inst_112052,inst_111958);
var state_112113__$1 = state_112113;
var statearr_112200_112278 = state_112113__$1;
(statearr_112200_112278[(2)] = inst_112053);

(statearr_112200_112278[(1)] = (38));


return cljs.core.cst$kw$recur;
} else {
if((state_val_112114 === (8))){
var inst_111963 = (state_112113[(23)]);
var state_112113__$1 = state_112113;
var statearr_112201_112279 = state_112113__$1;
(statearr_112201_112279[(2)] = inst_111963);

(statearr_112201_112279[(1)] = (10));


return cljs.core.cst$kw$recur;
} else {
if((state_val_112114 === (49))){
var state_112113__$1 = state_112113;
var statearr_112202_112280 = state_112113__$1;
(statearr_112202_112280[(2)] = null);

(statearr_112202_112280[(1)] = (50));


return cljs.core.cst$kw$recur;
} else {
return null;
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
});})(c__99809__auto__))
;
return ((function (switch__99702__auto__,c__99809__auto__){
return (function() {
var fluree$db$query$fql$flake__GT_recur_$_state_machine__99703__auto__ = null;
var fluree$db$query$fql$flake__GT_recur_$_state_machine__99703__auto____0 = (function (){
var statearr_112203 = [null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null];
(statearr_112203[(0)] = fluree$db$query$fql$flake__GT_recur_$_state_machine__99703__auto__);

(statearr_112203[(1)] = (1));

return statearr_112203;
});
var fluree$db$query$fql$flake__GT_recur_$_state_machine__99703__auto____1 = (function (state_112113){
while(true){
var ret_value__99704__auto__ = (function (){try{while(true){
var result__99705__auto__ = switch__99702__auto__(state_112113);
if(cljs.core.keyword_identical_QMARK_(result__99705__auto__,cljs.core.cst$kw$recur)){
continue;
} else {
return result__99705__auto__;
}
break;
}
}catch (e112204){if((e112204 instanceof Object)){
var ex__99706__auto__ = e112204;
var statearr_112205_112281 = state_112113;
(statearr_112205_112281[(5)] = ex__99706__auto__);


cljs.core.async.impl.ioc_helpers.process_exception(state_112113);

return cljs.core.cst$kw$recur;
} else {
throw e112204;

}
}})();
if(cljs.core.keyword_identical_QMARK_(ret_value__99704__auto__,cljs.core.cst$kw$recur)){
var G__112282 = state_112113;
state_112113 = G__112282;
continue;
} else {
return ret_value__99704__auto__;
}
break;
}
});
fluree$db$query$fql$flake__GT_recur_$_state_machine__99703__auto__ = function(state_112113){
switch(arguments.length){
case 0:
return fluree$db$query$fql$flake__GT_recur_$_state_machine__99703__auto____0.call(this);
case 1:
return fluree$db$query$fql$flake__GT_recur_$_state_machine__99703__auto____1.call(this,state_112113);
}
throw(new Error('Invalid arity: ' + arguments.length));
};
fluree$db$query$fql$flake__GT_recur_$_state_machine__99703__auto__.cljs$core$IFn$_invoke$arity$0 = fluree$db$query$fql$flake__GT_recur_$_state_machine__99703__auto____0;
fluree$db$query$fql$flake__GT_recur_$_state_machine__99703__auto__.cljs$core$IFn$_invoke$arity$1 = fluree$db$query$fql$flake__GT_recur_$_state_machine__99703__auto____1;
return fluree$db$query$fql$flake__GT_recur_$_state_machine__99703__auto__;
})()
;})(switch__99702__auto__,c__99809__auto__))
})();
var state__99811__auto__ = (function (){var statearr_112206 = (f__99810__auto__.cljs$core$IFn$_invoke$arity$0 ? f__99810__auto__.cljs$core$IFn$_invoke$arity$0() : f__99810__auto__.call(null));
(statearr_112206[(6)] = c__99809__auto__);

return statearr_112206;
})();
return cljs.core.async.impl.ioc_helpers.run_state_machine_wrapped(state__99811__auto__);
});})(c__99809__auto__))
);

return c__99809__auto__;
});
/**
 * Takes a sequence of flakes of the same subject and
 *   composes them into a map result based on the 'select' spec
 *   provided. Optionally, also follows components or recurs.
 */
fluree.db.query.fql.flakes__GT_res = (function fluree$db$query$fql$flakes__GT_res(db,cache,fuel,max_fuel,base_select_spec,flakes){
var c__99809__auto__ = cljs.core.async.chan.cljs$core$IFn$_invoke$arity$1((1));
cljs.core.async.impl.dispatch.run(((function (c__99809__auto__){
return (function (){
var f__99810__auto__ = (function (){var switch__99702__auto__ = ((function (c__99809__auto__){
return (function (state_112466){
var state_val_112467 = (state_112466[(1)]);
if((state_val_112467 === (7))){
var inst_112462 = (state_112466[(2)]);
var state_112466__$1 = state_112466;
var statearr_112468_112548 = state_112466__$1;
(statearr_112468_112548[(2)] = inst_112462);


cljs.core.async.impl.ioc_helpers.process_exception(state_112466__$1);

return cljs.core.cst$kw$recur;
} else {
if((state_val_112467 === (20))){
var inst_112304 = (state_112466[(7)]);
var inst_112324 = cljs.core.first(flakes);
var inst_112325 = fluree.db.query.fql.s(inst_112324);
var inst_112326 = fluree.db.query.fql.select_spec__GT_reverse_pred_specs(inst_112304);
var inst_112327 = fluree.db.query.fql.resolve_reverse_refs(db,cache,fuel,max_fuel,inst_112325,inst_112326);
var state_112466__$1 = state_112466;
return cljs.core.async.impl.ioc_helpers.take_BANG_(state_112466__$1,(23),inst_112327);
} else {
if((state_val_112467 === (27))){
var inst_112304 = (state_112466[(7)]);
var inst_112337 = (state_112466[(8)]);
var inst_112348 = (state_112466[(9)]);
var inst_112353 = (state_112466[(10)]);
var inst_112355 = (state_112466[(11)]);
var inst_112348__$1 = cljs.core.first(inst_112337);
var inst_112349 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_112350 = inst_112348__$1.p;
var inst_112351 = [cljs.core.cst$kw$select,cljs.core.cst$kw$pred_DASH_id,inst_112350];
var inst_112352 = (new cljs.core.PersistentVector(null,3,(5),inst_112349,inst_112351,null));
var inst_112353__$1 = cljs.core.get_in.cljs$core$IFn$_invoke$arity$2(inst_112304,inst_112352);
var inst_112354 = fluree.db.query.fql.component_follow_QMARK_(inst_112353__$1,inst_112304);
var inst_112355__$1 = cljs.core.cst$kw$multi_QMARK_.cljs$core$IFn$_invoke$arity$1(inst_112353__$1);
var state_112466__$1 = (function (){var statearr_112469 = state_112466;
(statearr_112469[(12)] = inst_112354);

(statearr_112469[(9)] = inst_112348__$1);

(statearr_112469[(10)] = inst_112353__$1);

(statearr_112469[(11)] = inst_112355__$1);

return statearr_112469;
})();
if(cljs.core.truth_(inst_112355__$1)){
var statearr_112470_112549 = state_112466__$1;
(statearr_112470_112549[(1)] = (29));

} else {
var statearr_112471_112550 = state_112466__$1;
(statearr_112471_112550[(1)] = (30));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_112467 === (1))){
var state_112466__$1 = state_112466;
var statearr_112472_112551 = state_112466__$1;
(statearr_112472_112551[(2)] = null);

(statearr_112472_112551[(1)] = (4));


return cljs.core.cst$kw$recur;
} else {
if((state_val_112467 === (24))){
var inst_112337 = (state_112466[(8)]);
var inst_112342 = cljs.core.empty_QMARK_(inst_112337);
var state_112466__$1 = state_112466;
if(inst_112342){
var statearr_112473_112552 = state_112466__$1;
(statearr_112473_112552[(1)] = (26));

} else {
var statearr_112474_112553 = state_112466__$1;
(statearr_112474_112553[(1)] = (27));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_112467 === (55))){
var state_112466__$1 = state_112466;
var statearr_112475_112554 = state_112466__$1;
(statearr_112475_112554[(2)] = null);

(statearr_112475_112554[(1)] = (56));


return cljs.core.cst$kw$recur;
} else {
if((state_val_112467 === (39))){
var inst_112371 = (state_112466[(2)]);
var inst_112372 = fluree.db.util.async.throw_err(inst_112371);
var state_112466__$1 = state_112466;
var statearr_112476_112555 = state_112466__$1;
(statearr_112476_112555[(2)] = inst_112372);

(statearr_112476_112555[(1)] = (38));


return cljs.core.cst$kw$recur;
} else {
if((state_val_112467 === (46))){
var inst_112429 = (state_112466[(2)]);
var state_112466__$1 = state_112466;
var statearr_112477_112556 = state_112466__$1;
(statearr_112477_112556[(2)] = inst_112429);

(statearr_112477_112556[(1)] = (42));


return cljs.core.cst$kw$recur;
} else {
if((state_val_112467 === (4))){
var _ = cljs.core.async.impl.ioc_helpers.add_exception_frame(state_112466,(3),Error,null,(2));
var inst_112287 = cljs.core.not_empty(flakes);
var state_112466__$1 = state_112466;
if(cljs.core.truth_(inst_112287)){
var statearr_112478_112557 = state_112466__$1;
(statearr_112478_112557[(1)] = (5));

} else {
var statearr_112479_112558 = state_112466__$1;
(statearr_112479_112558[(1)] = (6));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_112467 === (54))){
var inst_112339 = (state_112466[(13)]);
var inst_112340 = (state_112466[(14)]);
var inst_112337 = (state_112466[(8)]);
var inst_112338 = (state_112466[(15)]);
var inst_112419 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_112420 = cljs.core.rest(inst_112337);
var inst_112421 = [inst_112338,inst_112420,inst_112339,inst_112340];
var inst_112422 = (new cljs.core.PersistentVector(null,4,(5),inst_112419,inst_112421,null));
var state_112466__$1 = state_112466;
var statearr_112480_112559 = state_112466__$1;
(statearr_112480_112559[(2)] = inst_112422);

(statearr_112480_112559[(1)] = (56));


return cljs.core.cst$kw$recur;
} else {
if((state_val_112467 === (15))){
var inst_112304 = (state_112466[(7)]);
var inst_112308 = cljs.core.cst$kw$id_QMARK_.cljs$core$IFn$_invoke$arity$1(inst_112304);
var state_112466__$1 = state_112466;
var statearr_112481_112560 = state_112466__$1;
(statearr_112481_112560[(2)] = inst_112308);

(statearr_112481_112560[(1)] = (16));


return cljs.core.cst$kw$recur;
} else {
if((state_val_112467 === (48))){
var inst_112304 = (state_112466[(7)]);
var inst_112404 = cljs.core.cst$kw$id_QMARK_.cljs$core$IFn$_invoke$arity$1(inst_112304);
var state_112466__$1 = state_112466;
var statearr_112482_112561 = state_112466__$1;
(statearr_112482_112561[(2)] = inst_112404);

(statearr_112482_112561[(1)] = (50));


return cljs.core.cst$kw$recur;
} else {
if((state_val_112467 === (50))){
var inst_112407 = (state_112466[(2)]);
var state_112466__$1 = state_112466;
if(cljs.core.truth_(inst_112407)){
var statearr_112483_112562 = state_112466__$1;
(statearr_112483_112562[(1)] = (51));

} else {
var statearr_112484_112563 = state_112466__$1;
(statearr_112484_112563[(1)] = (52));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_112467 === (21))){
var inst_112318 = (state_112466[(16)]);
var state_112466__$1 = state_112466;
var statearr_112485_112564 = state_112466__$1;
(statearr_112485_112564[(2)] = inst_112318);

(statearr_112485_112564[(1)] = (22));


return cljs.core.cst$kw$recur;
} else {
if((state_val_112467 === (31))){
var inst_112360 = (state_112466[(2)]);
var state_112466__$1 = state_112466;
if(cljs.core.truth_(inst_112360)){
var statearr_112486_112565 = state_112466__$1;
(statearr_112486_112565[(1)] = (32));

} else {
var statearr_112487_112566 = state_112466__$1;
(statearr_112487_112566[(1)] = (33));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_112467 === (32))){
var inst_112339 = (state_112466[(13)]);
var inst_112304 = (state_112466[(7)]);
var inst_112337 = (state_112466[(8)]);
var inst_112348 = (state_112466[(9)]);
var inst_112338 = (state_112466[(15)]);
var inst_112353 = (state_112466[(10)]);
var inst_112362 = fluree.db.query.fql.flake__GT_recur_multi(db,inst_112348,inst_112353,inst_112339,inst_112337,inst_112338,fuel,max_fuel,inst_112304,cache,fluree.db.query.fql.component_follow_QMARK_);
var state_112466__$1 = state_112466;
return cljs.core.async.impl.ioc_helpers.take_BANG_(state_112466__$1,(35),inst_112362);
} else {
if((state_val_112467 === (40))){
var inst_112340 = (state_112466[(14)]);
var inst_112354 = (state_112466[(12)]);
var inst_112348 = (state_112466[(9)]);
var inst_112338 = (state_112466[(15)]);
var inst_112353 = (state_112466[(10)]);
var inst_112378 = fluree.db.query.fql.add_pred.cljs$core$IFn$_invoke$arity$10(db,cache,fuel,max_fuel,inst_112338,inst_112353,inst_112348,inst_112354,false,inst_112340);
var state_112466__$1 = state_112466;
return cljs.core.async.impl.ioc_helpers.take_BANG_(state_112466__$1,(43),inst_112378);
} else {
if((state_val_112467 === (56))){
var inst_112425 = (state_112466[(2)]);
var state_112466__$1 = state_112466;
var statearr_112488_112567 = state_112466__$1;
(statearr_112488_112567[(2)] = inst_112425);

(statearr_112488_112567[(1)] = (53));


return cljs.core.cst$kw$recur;
} else {
if((state_val_112467 === (33))){
var inst_112353 = (state_112466[(10)]);
var inst_112367 = cljs.core.cst$kw$recur.cljs$core$IFn$_invoke$arity$1(inst_112353);
var state_112466__$1 = state_112466;
if(cljs.core.truth_(inst_112367)){
var statearr_112489_112568 = state_112466__$1;
(statearr_112489_112568[(1)] = (36));

} else {
var statearr_112490_112569 = state_112466__$1;
(statearr_112490_112569[(1)] = (37));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_112467 === (13))){
var inst_112305 = (state_112466[(17)]);
var inst_112304 = (state_112466[(7)]);
var inst_112304__$1 = (state_112466[(2)]);
var inst_112305__$1 = cljs.core.cst$kw$wildcard_QMARK_.cljs$core$IFn$_invoke$arity$1(inst_112304__$1);
var state_112466__$1 = (function (){var statearr_112491 = state_112466;
(statearr_112491[(17)] = inst_112305__$1);

(statearr_112491[(7)] = inst_112304__$1);

return statearr_112491;
})();
if(cljs.core.truth_(inst_112305__$1)){
var statearr_112492_112570 = state_112466__$1;
(statearr_112492_112570[(1)] = (14));

} else {
var statearr_112493_112571 = state_112466__$1;
(statearr_112493_112571[(1)] = (15));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_112467 === (22))){
var inst_112334 = (state_112466[(18)]);
var inst_112334__$1 = (state_112466[(2)]);
var inst_112335 = cljs.core.PersistentHashMap.EMPTY;
var inst_112336 = cljs.core.PersistentHashMap.EMPTY;
var inst_112337 = flakes;
var inst_112338 = inst_112334__$1;
var inst_112339 = inst_112335;
var inst_112340 = inst_112336;
var state_112466__$1 = (function (){var statearr_112494 = state_112466;
(statearr_112494[(13)] = inst_112339);

(statearr_112494[(18)] = inst_112334__$1);

(statearr_112494[(14)] = inst_112340);

(statearr_112494[(8)] = inst_112337);

(statearr_112494[(15)] = inst_112338);

return statearr_112494;
})();
var statearr_112495_112572 = state_112466__$1;
(statearr_112495_112572[(2)] = null);

(statearr_112495_112572[(1)] = (24));


return cljs.core.cst$kw$recur;
} else {
if((state_val_112467 === (36))){
var inst_112339 = (state_112466[(13)]);
var inst_112304 = (state_112466[(7)]);
var inst_112337 = (state_112466[(8)]);
var inst_112348 = (state_112466[(9)]);
var inst_112338 = (state_112466[(15)]);
var inst_112353 = (state_112466[(10)]);
var inst_112369 = fluree.db.query.fql.flake__GT_recur(db,inst_112348,inst_112353,inst_112339,inst_112337,inst_112338,fuel,max_fuel,inst_112304,cache);
var state_112466__$1 = state_112466;
return cljs.core.async.impl.ioc_helpers.take_BANG_(state_112466__$1,(39),inst_112369);
} else {
if((state_val_112467 === (41))){
var inst_112304 = (state_112466[(7)]);
var inst_112389 = cljs.core.cst$kw$wildcard_QMARK_.cljs$core$IFn$_invoke$arity$1(inst_112304);
var state_112466__$1 = state_112466;
if(cljs.core.truth_(inst_112389)){
var statearr_112496_112573 = state_112466__$1;
(statearr_112496_112573[(1)] = (44));

} else {
var statearr_112497_112574 = state_112466__$1;
(statearr_112497_112574[(1)] = (45));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_112467 === (43))){
var inst_112339 = (state_112466[(13)]);
var inst_112337 = (state_112466[(8)]);
var inst_112380 = (state_112466[(2)]);
var inst_112381 = fluree.db.util.async.throw_err(inst_112380);
var inst_112382 = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(inst_112381,(0),null);
var inst_112383 = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(inst_112381,(1),null);
var inst_112384 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_112385 = cljs.core.rest(inst_112337);
var inst_112386 = [inst_112382,inst_112385,inst_112339,inst_112383];
var inst_112387 = (new cljs.core.PersistentVector(null,4,(5),inst_112384,inst_112386,null));
var state_112466__$1 = state_112466;
var statearr_112498_112575 = state_112466__$1;
(statearr_112498_112575[(2)] = inst_112387);

(statearr_112498_112575[(1)] = (42));


return cljs.core.cst$kw$recur;
} else {
if((state_val_112467 === (29))){
var inst_112353 = (state_112466[(10)]);
var inst_112357 = cljs.core.cst$kw$recur.cljs$core$IFn$_invoke$arity$1(inst_112353);
var state_112466__$1 = state_112466;
var statearr_112499_112576 = state_112466__$1;
(statearr_112499_112576[(2)] = inst_112357);

(statearr_112499_112576[(1)] = (31));


return cljs.core.cst$kw$recur;
} else {
if((state_val_112467 === (44))){
var inst_112304 = (state_112466[(7)]);
var inst_112354 = (state_112466[(12)]);
var inst_112348 = (state_112466[(9)]);
var inst_112338 = (state_112466[(15)]);
var inst_112391 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_112392 = fluree.db.query.fql.add_pred.cljs$core$IFn$_invoke$arity$9(db,cache,fuel,max_fuel,inst_112338,inst_112304,inst_112348,inst_112354,false);
var state_112466__$1 = (function (){var statearr_112500 = state_112466;
(statearr_112500[(19)] = inst_112391);

return statearr_112500;
})();
return cljs.core.async.impl.ioc_helpers.take_BANG_(state_112466__$1,(47),inst_112392);
} else {
if((state_val_112467 === (6))){
var state_112466__$1 = state_112466;
var statearr_112501_112577 = state_112466__$1;
(statearr_112501_112577[(2)] = null);

(statearr_112501_112577[(1)] = (7));


return cljs.core.cst$kw$recur;
} else {
if((state_val_112467 === (28))){
var inst_112444 = (state_112466[(2)]);
var state_112466__$1 = state_112466;
var statearr_112502_112578 = state_112466__$1;
(statearr_112502_112578[(2)] = inst_112444);

(statearr_112502_112578[(1)] = (25));


return cljs.core.cst$kw$recur;
} else {
if((state_val_112467 === (51))){
var inst_112339 = (state_112466[(13)]);
var inst_112340 = (state_112466[(14)]);
var inst_112337 = (state_112466[(8)]);
var inst_112348 = (state_112466[(9)]);
var inst_112409 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_112410 = ["_id"];
var inst_112411 = inst_112348.s;
var inst_112412 = [inst_112411];
var inst_112413 = cljs.core.PersistentHashMap.fromArrays(inst_112410,inst_112412);
var inst_112414 = cljs.core.rest(inst_112337);
var inst_112415 = [inst_112413,inst_112414,inst_112339,inst_112340];
var inst_112416 = (new cljs.core.PersistentVector(null,4,(5),inst_112409,inst_112415,null));
var state_112466__$1 = state_112466;
var statearr_112503_112579 = state_112466__$1;
(statearr_112503_112579[(2)] = inst_112416);

(statearr_112503_112579[(1)] = (53));


return cljs.core.cst$kw$recur;
} else {
if((state_val_112467 === (25))){
var inst_112304 = (state_112466[(7)]);
var inst_112334 = (state_112466[(18)]);
var inst_112298 = (state_112466[(20)]);
var inst_112318 = (state_112466[(16)]);
var inst_112446 = (state_112466[(2)]);
var inst_112447 = (function (){var top_level_subject = inst_112298;
var select_spec = inst_112304;
var base_acc = inst_112318;
var acc_PLUS_refs = inst_112334;
var result = inst_112446;
return ((function (top_level_subject,select_spec,base_acc,acc_PLUS_refs,result,inst_112304,inst_112334,inst_112298,inst_112318,inst_112446,state_val_112467,c__99809__auto__){
return (function (acc,spec){
if(cljs.core.truth_((function (){var or__4131__auto__ = (function (){var and__4120__auto__ = cljs.core.cst$kw$multi_QMARK_.cljs$core$IFn$_invoke$arity$1(spec);
if(cljs.core.truth_(and__4120__auto__)){
return cljs.core.cst$kw$orderBy.cljs$core$IFn$_invoke$arity$1(spec);
} else {
return and__4120__auto__;
}
})();
if(cljs.core.truth_(or__4131__auto__)){
return or__4131__auto__;
} else {
var and__4120__auto__ = cljs.core.cst$kw$reverse_QMARK_.cljs$core$IFn$_invoke$arity$1(spec);
if(cljs.core.truth_(and__4120__auto__)){
return cljs.core.cst$kw$orderBy.cljs$core$IFn$_invoke$arity$1(spec);
} else {
return and__4120__auto__;
}
}
})())){
return cljs.core.conj.cljs$core$IFn$_invoke$arity$2(acc,new cljs.core.PersistentVector(null, 4, 5, cljs.core.PersistentVector.EMPTY_NODE, [cljs.core.cst$kw$as.cljs$core$IFn$_invoke$arity$1(spec),cljs.core.cst$kw$order.cljs$core$IFn$_invoke$arity$1(cljs.core.cst$kw$orderBy.cljs$core$IFn$_invoke$arity$1(spec)),cljs.core.cst$kw$predicate.cljs$core$IFn$_invoke$arity$1(cljs.core.cst$kw$orderBy.cljs$core$IFn$_invoke$arity$1(spec)),cljs.core.cst$kw$limit.cljs$core$IFn$_invoke$arity$1(spec)], null));
} else {
return acc;
}
});
;})(top_level_subject,select_spec,base_acc,acc_PLUS_refs,result,inst_112304,inst_112334,inst_112298,inst_112318,inst_112446,state_val_112467,c__99809__auto__))
})();
var inst_112448 = cljs.core.PersistentVector.EMPTY;
var inst_112449 = cljs.core.cst$kw$select.cljs$core$IFn$_invoke$arity$1(inst_112304);
var inst_112450 = cljs.core.cst$kw$pred_DASH_id.cljs$core$IFn$_invoke$arity$1(inst_112449);
var inst_112451 = cljs.core.vals(inst_112450);
var inst_112452 = cljs.core.cst$kw$select.cljs$core$IFn$_invoke$arity$1(inst_112304);
var inst_112453 = cljs.core.cst$kw$reverse.cljs$core$IFn$_invoke$arity$1(inst_112452);
var inst_112454 = cljs.core.vals(inst_112453);
var inst_112455 = cljs.core.concat.cljs$core$IFn$_invoke$arity$2(inst_112451,inst_112454);
var inst_112456 = cljs.core.reduce.cljs$core$IFn$_invoke$arity$3(inst_112447,inst_112448,inst_112455);
var inst_112458 = (function (){var top_level_subject = inst_112298;
var select_spec = inst_112304;
var base_acc = inst_112318;
var acc_PLUS_refs = inst_112334;
var result = inst_112446;
var sort_preds = inst_112456;
return ((function (top_level_subject,select_spec,base_acc,acc_PLUS_refs,result,sort_preds,inst_112304,inst_112334,inst_112298,inst_112318,inst_112446,inst_112447,inst_112448,inst_112449,inst_112450,inst_112451,inst_112452,inst_112453,inst_112454,inst_112455,inst_112456,state_val_112467,c__99809__auto__){
return (function (acc,p__112457){
var vec__112504 = p__112457;
var selectPred = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(vec__112504,(0),null);
var sortOrder = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(vec__112504,(1),null);
var sortPred = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(vec__112504,(2),null);
var limit = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(vec__112504,(3),null);
return cljs.core.assoc.cljs$core$IFn$_invoke$arity$3(acc,selectPred,fluree.db.query.fql.sort_offset_and_limit_res(sortPred,sortOrder,(0),limit,cljs.core.get.cljs$core$IFn$_invoke$arity$2(acc,selectPred)));
});
;})(top_level_subject,select_spec,base_acc,acc_PLUS_refs,result,sort_preds,inst_112304,inst_112334,inst_112298,inst_112318,inst_112446,inst_112447,inst_112448,inst_112449,inst_112450,inst_112451,inst_112452,inst_112453,inst_112454,inst_112455,inst_112456,state_val_112467,c__99809__auto__))
})();
var inst_112459 = cljs.core.reduce.cljs$core$IFn$_invoke$arity$3(inst_112458,inst_112446,inst_112456);
var state_112466__$1 = state_112466;
var statearr_112507_112580 = state_112466__$1;
(statearr_112507_112580[(2)] = inst_112459);

(statearr_112507_112580[(1)] = (7));


return cljs.core.cst$kw$recur;
} else {
if((state_val_112467 === (34))){
var inst_112348 = (state_112466[(9)]);
var inst_112435 = (state_112466[(2)]);
var inst_112436 = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(inst_112435,(0),null);
var inst_112437 = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(inst_112435,(1),null);
var inst_112438 = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(inst_112435,(2),null);
var inst_112439 = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(inst_112435,(3),null);
var inst_112440 = inst_112348.s;
var inst_112441 = cljs.core.assoc.cljs$core$IFn$_invoke$arity$3(inst_112436,cljs.core.cst$kw$_id,inst_112440);
var inst_112337 = inst_112437;
var inst_112338 = inst_112441;
var inst_112339 = inst_112438;
var inst_112340 = inst_112439;
var state_112466__$1 = (function (){var statearr_112508 = state_112466;
(statearr_112508[(13)] = inst_112339);

(statearr_112508[(14)] = inst_112340);

(statearr_112508[(8)] = inst_112337);

(statearr_112508[(15)] = inst_112338);

return statearr_112508;
})();
var statearr_112509_112581 = state_112466__$1;
(statearr_112509_112581[(2)] = null);

(statearr_112509_112581[(1)] = (24));


return cljs.core.cst$kw$recur;
} else {
if((state_val_112467 === (17))){
var inst_112298 = (state_112466[(20)]);
var inst_112312 = ["_id"];
var inst_112313 = [inst_112298];
var inst_112314 = cljs.core.PersistentHashMap.fromArrays(inst_112312,inst_112313);
var state_112466__$1 = state_112466;
var statearr_112510_112582 = state_112466__$1;
(statearr_112510_112582[(2)] = inst_112314);

(statearr_112510_112582[(1)] = (19));


return cljs.core.cst$kw$recur;
} else {
if((state_val_112467 === (3))){
var inst_112283 = (state_112466[(2)]);
var state_112466__$1 = state_112466;
var statearr_112511_112583 = state_112466__$1;
(statearr_112511_112583[(2)] = inst_112283);


cljs.core.async.impl.ioc_helpers.process_exception(state_112466__$1);

return cljs.core.cst$kw$recur;
} else {
if((state_val_112467 === (12))){
var state_112466__$1 = state_112466;
var statearr_112512_112584 = state_112466__$1;
(statearr_112512_112584[(2)] = base_select_spec);

(statearr_112512_112584[(1)] = (13));


return cljs.core.cst$kw$recur;
} else {
if((state_val_112467 === (2))){
var inst_112464 = (state_112466[(2)]);
var state_112466__$1 = state_112466;
return cljs.core.async.impl.ioc_helpers.return_chan(state_112466__$1,inst_112464);
} else {
if((state_val_112467 === (23))){
var inst_112318 = (state_112466[(16)]);
var inst_112329 = (state_112466[(2)]);
var inst_112330 = fluree.db.util.async.throw_err(inst_112329);
var inst_112331 = cljs.core.merge.cljs$core$IFn$_invoke$arity$variadic(cljs.core.prim_seq.cljs$core$IFn$_invoke$arity$2([inst_112318,inst_112330], 0));
var state_112466__$1 = state_112466;
var statearr_112513_112585 = state_112466__$1;
(statearr_112513_112585[(2)] = inst_112331);

(statearr_112513_112585[(1)] = (22));


return cljs.core.cst$kw$recur;
} else {
if((state_val_112467 === (47))){
var inst_112339 = (state_112466[(13)]);
var inst_112391 = (state_112466[(19)]);
var inst_112340 = (state_112466[(14)]);
var inst_112337 = (state_112466[(8)]);
var inst_112394 = (state_112466[(2)]);
var inst_112395 = fluree.db.util.async.throw_err(inst_112394);
var inst_112396 = cljs.core.first(inst_112395);
var inst_112397 = cljs.core.rest(inst_112337);
var inst_112398 = [inst_112396,inst_112397,inst_112339,inst_112340];
var inst_112399 = (new cljs.core.PersistentVector(null,4,(5),inst_112391,inst_112398,null));
var state_112466__$1 = state_112466;
var statearr_112514_112586 = state_112466__$1;
(statearr_112514_112586[(2)] = inst_112399);

(statearr_112514_112586[(1)] = (46));


return cljs.core.cst$kw$recur;
} else {
if((state_val_112467 === (35))){
var inst_112364 = (state_112466[(2)]);
var inst_112365 = fluree.db.util.async.throw_err(inst_112364);
var state_112466__$1 = state_112466;
var statearr_112515_112587 = state_112466__$1;
(statearr_112515_112587[(2)] = inst_112365);

(statearr_112515_112587[(1)] = (34));


return cljs.core.cst$kw$recur;
} else {
if((state_val_112467 === (19))){
var inst_112304 = (state_112466[(7)]);
var inst_112318 = (state_112466[(2)]);
var inst_112319 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_112320 = [cljs.core.cst$kw$select,cljs.core.cst$kw$reverse];
var inst_112321 = (new cljs.core.PersistentVector(null,2,(5),inst_112319,inst_112320,null));
var inst_112322 = cljs.core.get_in.cljs$core$IFn$_invoke$arity$2(inst_112304,inst_112321);
var state_112466__$1 = (function (){var statearr_112516 = state_112466;
(statearr_112516[(16)] = inst_112318);

return statearr_112516;
})();
if(cljs.core.truth_(inst_112322)){
var statearr_112517_112588 = state_112466__$1;
(statearr_112517_112588[(1)] = (20));

} else {
var statearr_112518_112589 = state_112466__$1;
(statearr_112518_112589[(1)] = (21));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_112467 === (11))){
var inst_112298 = (state_112466[(20)]);
var inst_112301 = fluree.db.query.fql.full_select_spec(db,cache,base_select_spec,inst_112298);
var state_112466__$1 = state_112466;
var statearr_112519_112590 = state_112466__$1;
(statearr_112519_112590[(2)] = inst_112301);

(statearr_112519_112590[(1)] = (13));


return cljs.core.cst$kw$recur;
} else {
if((state_val_112467 === (9))){
var inst_112289 = (state_112466[(2)]);
var inst_112290 = fluree.db.util.log.error.cljs$core$IFn$_invoke$arity$variadic(cljs.core.prim_seq.cljs$core$IFn$_invoke$arity$2([inst_112289], 0));
var inst_112291 = (function(){throw inst_112289})();
var state_112466__$1 = (function (){var statearr_112520 = state_112466;
(statearr_112520[(21)] = inst_112290);

return statearr_112520;
})();
var statearr_112521_112591 = state_112466__$1;
(statearr_112521_112591[(2)] = inst_112291);


cljs.core.async.impl.ioc_helpers.process_exception(state_112466__$1);

return cljs.core.cst$kw$recur;
} else {
if((state_val_112467 === (5))){
var state_112466__$1 = state_112466;
var statearr_112522_112592 = state_112466__$1;
(statearr_112522_112592[(2)] = null);

(statearr_112522_112592[(1)] = (10));


return cljs.core.cst$kw$recur;
} else {
if((state_val_112467 === (14))){
var inst_112305 = (state_112466[(17)]);
var state_112466__$1 = state_112466;
var statearr_112523_112593 = state_112466__$1;
(statearr_112523_112593[(2)] = inst_112305);

(statearr_112523_112593[(1)] = (16));


return cljs.core.cst$kw$recur;
} else {
if((state_val_112467 === (45))){
var inst_112304 = (state_112466[(7)]);
var inst_112402 = (state_112466[(22)]);
var inst_112401 = cljs.core.cst$kw$select.cljs$core$IFn$_invoke$arity$1(inst_112304);
var inst_112402__$1 = cljs.core.empty_QMARK_(inst_112401);
var state_112466__$1 = (function (){var statearr_112524 = state_112466;
(statearr_112524[(22)] = inst_112402__$1);

return statearr_112524;
})();
if(inst_112402__$1){
var statearr_112525_112594 = state_112466__$1;
(statearr_112525_112594[(1)] = (48));

} else {
var statearr_112526_112595 = state_112466__$1;
(statearr_112526_112595[(1)] = (49));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_112467 === (53))){
var inst_112427 = (state_112466[(2)]);
var state_112466__$1 = state_112466;
var statearr_112527_112596 = state_112466__$1;
(statearr_112527_112596[(2)] = inst_112427);

(statearr_112527_112596[(1)] = (46));


return cljs.core.cst$kw$recur;
} else {
if((state_val_112467 === (26))){
var inst_112338 = (state_112466[(15)]);
var state_112466__$1 = state_112466;
var statearr_112528_112597 = state_112466__$1;
(statearr_112528_112597[(2)] = inst_112338);

(statearr_112528_112597[(1)] = (28));


return cljs.core.cst$kw$recur;
} else {
if((state_val_112467 === (16))){
var inst_112310 = (state_112466[(2)]);
var state_112466__$1 = state_112466;
if(cljs.core.truth_(inst_112310)){
var statearr_112529_112598 = state_112466__$1;
(statearr_112529_112598[(1)] = (17));

} else {
var statearr_112530_112599 = state_112466__$1;
(statearr_112530_112599[(1)] = (18));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_112467 === (38))){
var inst_112433 = (state_112466[(2)]);
var state_112466__$1 = state_112466;
var statearr_112531_112600 = state_112466__$1;
(statearr_112531_112600[(2)] = inst_112433);

(statearr_112531_112600[(1)] = (34));


return cljs.core.cst$kw$recur;
} else {
if((state_val_112467 === (30))){
var inst_112355 = (state_112466[(11)]);
var state_112466__$1 = state_112466;
var statearr_112532_112601 = state_112466__$1;
(statearr_112532_112601[(2)] = inst_112355);

(statearr_112532_112601[(1)] = (31));


return cljs.core.cst$kw$recur;
} else {
if((state_val_112467 === (10))){
var _ = cljs.core.async.impl.ioc_helpers.add_exception_frame(state_112466,(9),cljs.core.cst$kw$default,null,(8));
var inst_112295 = cljs.core.first(flakes);
var inst_112296 = fluree.db.query.fql.s(inst_112295);
var state_112466__$1 = state_112466;
var statearr_112533_112602 = state_112466__$1;
(statearr_112533_112602[(2)] = inst_112296);


cljs.core.async.impl.ioc_helpers.process_exception(state_112466__$1);

return cljs.core.cst$kw$recur;
} else {
if((state_val_112467 === (18))){
var inst_112316 = cljs.core.PersistentHashMap.EMPTY;
var state_112466__$1 = state_112466;
var statearr_112534_112603 = state_112466__$1;
(statearr_112534_112603[(2)] = inst_112316);

(statearr_112534_112603[(1)] = (19));


return cljs.core.cst$kw$recur;
} else {
if((state_val_112467 === (52))){
var state_112466__$1 = state_112466;
var statearr_112535_112604 = state_112466__$1;
(statearr_112535_112604[(1)] = (54));



return cljs.core.cst$kw$recur;
} else {
if((state_val_112467 === (42))){
var inst_112431 = (state_112466[(2)]);
var state_112466__$1 = state_112466;
var statearr_112537_112605 = state_112466__$1;
(statearr_112537_112605[(2)] = inst_112431);

(statearr_112537_112605[(1)] = (38));


return cljs.core.cst$kw$recur;
} else {
if((state_val_112467 === (37))){
var inst_112353 = (state_112466[(10)]);
var state_112466__$1 = state_112466;
if(cljs.core.truth_(inst_112353)){
var statearr_112538_112606 = state_112466__$1;
(statearr_112538_112606[(1)] = (40));

} else {
var statearr_112539_112607 = state_112466__$1;
(statearr_112539_112607[(1)] = (41));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_112467 === (8))){
var inst_112298 = (state_112466[(2)]);
var inst_112299 = fluree.db.query.fql.has_ns_lookups_QMARK_(base_select_spec);
var state_112466__$1 = (function (){var statearr_112540 = state_112466;
(statearr_112540[(20)] = inst_112298);

return statearr_112540;
})();
if(cljs.core.truth_(inst_112299)){
var statearr_112541_112608 = state_112466__$1;
(statearr_112541_112608[(1)] = (11));

} else {
var statearr_112542_112609 = state_112466__$1;
(statearr_112542_112609[(1)] = (12));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_112467 === (49))){
var inst_112402 = (state_112466[(22)]);
var state_112466__$1 = state_112466;
var statearr_112543_112610 = state_112466__$1;
(statearr_112543_112610[(2)] = inst_112402);

(statearr_112543_112610[(1)] = (50));


return cljs.core.cst$kw$recur;
} else {
return null;
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
});})(c__99809__auto__))
;
return ((function (switch__99702__auto__,c__99809__auto__){
return (function() {
var fluree$db$query$fql$flakes__GT_res_$_state_machine__99703__auto__ = null;
var fluree$db$query$fql$flakes__GT_res_$_state_machine__99703__auto____0 = (function (){
var statearr_112544 = [null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null];
(statearr_112544[(0)] = fluree$db$query$fql$flakes__GT_res_$_state_machine__99703__auto__);

(statearr_112544[(1)] = (1));

return statearr_112544;
});
var fluree$db$query$fql$flakes__GT_res_$_state_machine__99703__auto____1 = (function (state_112466){
while(true){
var ret_value__99704__auto__ = (function (){try{while(true){
var result__99705__auto__ = switch__99702__auto__(state_112466);
if(cljs.core.keyword_identical_QMARK_(result__99705__auto__,cljs.core.cst$kw$recur)){
continue;
} else {
return result__99705__auto__;
}
break;
}
}catch (e112545){if((e112545 instanceof Object)){
var ex__99706__auto__ = e112545;
var statearr_112546_112611 = state_112466;
(statearr_112546_112611[(5)] = ex__99706__auto__);


cljs.core.async.impl.ioc_helpers.process_exception(state_112466);

return cljs.core.cst$kw$recur;
} else {
throw e112545;

}
}})();
if(cljs.core.keyword_identical_QMARK_(ret_value__99704__auto__,cljs.core.cst$kw$recur)){
var G__112612 = state_112466;
state_112466 = G__112612;
continue;
} else {
return ret_value__99704__auto__;
}
break;
}
});
fluree$db$query$fql$flakes__GT_res_$_state_machine__99703__auto__ = function(state_112466){
switch(arguments.length){
case 0:
return fluree$db$query$fql$flakes__GT_res_$_state_machine__99703__auto____0.call(this);
case 1:
return fluree$db$query$fql$flakes__GT_res_$_state_machine__99703__auto____1.call(this,state_112466);
}
throw(new Error('Invalid arity: ' + arguments.length));
};
fluree$db$query$fql$flakes__GT_res_$_state_machine__99703__auto__.cljs$core$IFn$_invoke$arity$0 = fluree$db$query$fql$flakes__GT_res_$_state_machine__99703__auto____0;
fluree$db$query$fql$flakes__GT_res_$_state_machine__99703__auto__.cljs$core$IFn$_invoke$arity$1 = fluree$db$query$fql$flakes__GT_res_$_state_machine__99703__auto____1;
return fluree$db$query$fql$flakes__GT_res_$_state_machine__99703__auto__;
})()
;})(switch__99702__auto__,c__99809__auto__))
})();
var state__99811__auto__ = (function (){var statearr_112547 = (f__99810__auto__.cljs$core$IFn$_invoke$arity$0 ? f__99810__auto__.cljs$core$IFn$_invoke$arity$0() : f__99810__auto__.call(null));
(statearr_112547[(6)] = c__99809__auto__);

return statearr_112547;
})();
return cljs.core.async.impl.ioc_helpers.run_state_machine_wrapped(state__99811__auto__);
});})(c__99809__auto__))
);

return c__99809__auto__;
});
/**
 * Runs a select statement based on a sequence of flakes.
 */
fluree.db.query.fql.flake_select = (function fluree$db$query$fql$flake_select(var_args){
var G__112615 = arguments.length;
switch (G__112615) {
case 6:
return fluree.db.query.fql.flake_select.cljs$core$IFn$_invoke$arity$6((arguments[(0)]),(arguments[(1)]),(arguments[(2)]),(arguments[(3)]),(arguments[(4)]),(arguments[(5)]));

break;
case 7:
return fluree.db.query.fql.flake_select.cljs$core$IFn$_invoke$arity$7((arguments[(0)]),(arguments[(1)]),(arguments[(2)]),(arguments[(3)]),(arguments[(4)]),(arguments[(5)]),(arguments[(6)]));

break;
case 8:
return fluree.db.query.fql.flake_select.cljs$core$IFn$_invoke$arity$8((arguments[(0)]),(arguments[(1)]),(arguments[(2)]),(arguments[(3)]),(arguments[(4)]),(arguments[(5)]),(arguments[(6)]),(arguments[(7)]));

break;
default:
throw (new Error(["Invalid arity: ",cljs.core.str.cljs$core$IFn$_invoke$arity$1(arguments.length)].join('')));

}
});

fluree.db.query.fql.flake_select.cljs$core$IFn$_invoke$arity$6 = (function (db,cache,fuel,max_fuel,select_spec,flakes){
return fluree.db.query.fql.flake_select.cljs$core$IFn$_invoke$arity$8(db,cache,fuel,max_fuel,select_spec,flakes,null,null);
});

fluree.db.query.fql.flake_select.cljs$core$IFn$_invoke$arity$7 = (function (db,cache,fuel,max_fuel,select_spec,flakes,limit){
return fluree.db.query.fql.flake_select.cljs$core$IFn$_invoke$arity$8(db,cache,fuel,max_fuel,select_spec,flakes,limit,null);
});

fluree.db.query.fql.flake_select.cljs$core$IFn$_invoke$arity$8 = (function (db,cache,fuel,max_fuel,select_spec,flakes,limit,offset){
var c__99809__auto__ = cljs.core.async.chan.cljs$core$IFn$_invoke$arity$1((1));
cljs.core.async.impl.dispatch.run(((function (c__99809__auto__){
return (function (){
var f__99810__auto__ = (function (){var switch__99702__auto__ = ((function (c__99809__auto__){
return (function (state_112654){
var state_val_112655 = (state_112654[(1)]);
if((state_val_112655 === (7))){
var inst_112627 = (state_112654[(2)]);
var state_112654__$1 = (function (){var statearr_112656 = state_112654;
(statearr_112656[(7)] = inst_112627);

return statearr_112656;
})();
if(cljs.core.truth_(offset)){
var statearr_112657_112679 = state_112654__$1;
(statearr_112657_112679[(1)] = (8));

} else {
var statearr_112658_112680 = state_112654__$1;
(statearr_112658_112680[(1)] = (9));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_112655 === (1))){
var state_112654__$1 = state_112654;
var statearr_112659_112681 = state_112654__$1;
(statearr_112659_112681[(2)] = null);

(statearr_112659_112681[(1)] = (4));


return cljs.core.cst$kw$recur;
} else {
if((state_val_112655 === (4))){
var _ = cljs.core.async.impl.ioc_helpers.add_exception_frame(state_112654,(3),Error,null,(2));
var inst_112621 = cljs.core.partition_by.cljs$core$IFn$_invoke$arity$1(fluree.db.query.fql.s);
var state_112654__$1 = (function (){var statearr_112660 = state_112654;
(statearr_112660[(8)] = inst_112621);

return statearr_112660;
})();
if(cljs.core.truth_(fuel)){
var statearr_112661_112682 = state_112654__$1;
(statearr_112661_112682[(1)] = (5));

} else {
var statearr_112662_112683 = state_112654__$1;
(statearr_112662_112683[(1)] = (6));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_112655 === (13))){
var inst_112639 = (state_112654[(2)]);
var inst_112640 = (function (){return ((function (inst_112639,state_val_112655,c__99809__auto__){
return (function (x){
var and__4120__auto__ = max_fuel;
if(cljs.core.truth_(and__4120__auto__)){
return (cljs.core.deref(fuel) >= max_fuel);
} else {
return and__4120__auto__;
}
});
;})(inst_112639,state_val_112655,c__99809__auto__))
})();
var inst_112641 = cljs.core.halt_when.cljs$core$IFn$_invoke$arity$1(inst_112640);
var inst_112642 = cljs.core.comp.cljs$core$IFn$_invoke$arity$2(inst_112639,inst_112641);
var inst_112643 = cljs.core.sequence.cljs$core$IFn$_invoke$arity$2(inst_112642,flakes);
var inst_112644 = cljs.core.PersistentVector.EMPTY;
var inst_112645 = (function (){var xf = inst_112642;
var flakes_by_sub = inst_112643;
return ((function (xf,flakes_by_sub,inst_112639,inst_112640,inst_112641,inst_112642,inst_112643,inst_112644,state_val_112655,c__99809__auto__){
return (function (p1__112613_SHARP_){
return fluree.db.query.fql.flakes__GT_res(db,cache,fuel,max_fuel,select_spec,p1__112613_SHARP_);
});
;})(xf,flakes_by_sub,inst_112639,inst_112640,inst_112641,inst_112642,inst_112643,inst_112644,state_val_112655,c__99809__auto__))
})();
var inst_112646 = cljs.core.map.cljs$core$IFn$_invoke$arity$2(inst_112645,inst_112643);
var inst_112647 = fluree.db.util.async.merge_into_QMARK_(inst_112644,inst_112646);
var state_112654__$1 = state_112654;
return cljs.core.async.impl.ioc_helpers.take_BANG_(state_112654__$1,(14),inst_112647);
} else {
if((state_val_112655 === (6))){
var inst_112621 = (state_112654[(8)]);
var state_112654__$1 = state_112654;
var statearr_112663_112684 = state_112654__$1;
(statearr_112663_112684[(2)] = inst_112621);

(statearr_112663_112684[(1)] = (7));


return cljs.core.cst$kw$recur;
} else {
if((state_val_112655 === (3))){
var inst_112616 = (state_112654[(2)]);
var state_112654__$1 = state_112654;
var statearr_112664_112685 = state_112654__$1;
(statearr_112664_112685[(2)] = inst_112616);


cljs.core.async.impl.ioc_helpers.process_exception(state_112654__$1);

return cljs.core.cst$kw$recur;
} else {
if((state_val_112655 === (12))){
var inst_112633 = (state_112654[(9)]);
var state_112654__$1 = state_112654;
var statearr_112665_112686 = state_112654__$1;
(statearr_112665_112686[(2)] = inst_112633);

(statearr_112665_112686[(1)] = (13));


return cljs.core.cst$kw$recur;
} else {
if((state_val_112655 === (2))){
var inst_112652 = (state_112654[(2)]);
var state_112654__$1 = state_112654;
return cljs.core.async.impl.ioc_helpers.return_chan(state_112654__$1,inst_112652);
} else {
if((state_val_112655 === (11))){
var inst_112633 = (state_112654[(9)]);
var inst_112635 = cljs.core.take.cljs$core$IFn$_invoke$arity$1(limit);
var inst_112636 = cljs.core.comp.cljs$core$IFn$_invoke$arity$2(inst_112633,inst_112635);
var state_112654__$1 = state_112654;
var statearr_112666_112687 = state_112654__$1;
(statearr_112666_112687[(2)] = inst_112636);

(statearr_112666_112687[(1)] = (13));


return cljs.core.cst$kw$recur;
} else {
if((state_val_112655 === (9))){
var inst_112627 = (state_112654[(7)]);
var state_112654__$1 = state_112654;
var statearr_112667_112688 = state_112654__$1;
(statearr_112667_112688[(2)] = inst_112627);

(statearr_112667_112688[(1)] = (10));


return cljs.core.cst$kw$recur;
} else {
if((state_val_112655 === (5))){
var inst_112621 = (state_112654[(8)]);
var inst_112623 = fluree.db.query.fql.fuel_flakes_transducer(fuel,max_fuel);
var inst_112624 = cljs.core.comp.cljs$core$IFn$_invoke$arity$2(inst_112621,inst_112623);
var state_112654__$1 = state_112654;
var statearr_112668_112689 = state_112654__$1;
(statearr_112668_112689[(2)] = inst_112624);

(statearr_112668_112689[(1)] = (7));


return cljs.core.cst$kw$recur;
} else {
if((state_val_112655 === (14))){
var inst_112649 = (state_112654[(2)]);
var inst_112650 = fluree.db.util.async.throw_err(inst_112649);
var state_112654__$1 = state_112654;
var statearr_112669_112690 = state_112654__$1;
(statearr_112669_112690[(2)] = inst_112650);


cljs.core.async.impl.ioc_helpers.process_exception(state_112654__$1);

return cljs.core.cst$kw$recur;
} else {
if((state_val_112655 === (10))){
var inst_112633 = (state_112654[(2)]);
var state_112654__$1 = (function (){var statearr_112670 = state_112654;
(statearr_112670[(9)] = inst_112633);

return statearr_112670;
})();
if(cljs.core.truth_(limit)){
var statearr_112671_112691 = state_112654__$1;
(statearr_112671_112691[(1)] = (11));

} else {
var statearr_112672_112692 = state_112654__$1;
(statearr_112672_112692[(1)] = (12));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_112655 === (8))){
var inst_112627 = (state_112654[(7)]);
var inst_112629 = cljs.core.drop.cljs$core$IFn$_invoke$arity$1(offset);
var inst_112630 = cljs.core.comp.cljs$core$IFn$_invoke$arity$2(inst_112627,inst_112629);
var state_112654__$1 = state_112654;
var statearr_112673_112693 = state_112654__$1;
(statearr_112673_112693[(2)] = inst_112630);

(statearr_112673_112693[(1)] = (10));


return cljs.core.cst$kw$recur;
} else {
return null;
}
}
}
}
}
}
}
}
}
}
}
}
}
}
});})(c__99809__auto__))
;
return ((function (switch__99702__auto__,c__99809__auto__){
return (function() {
var fluree$db$query$fql$state_machine__99703__auto__ = null;
var fluree$db$query$fql$state_machine__99703__auto____0 = (function (){
var statearr_112674 = [null,null,null,null,null,null,null,null,null,null];
(statearr_112674[(0)] = fluree$db$query$fql$state_machine__99703__auto__);

(statearr_112674[(1)] = (1));

return statearr_112674;
});
var fluree$db$query$fql$state_machine__99703__auto____1 = (function (state_112654){
while(true){
var ret_value__99704__auto__ = (function (){try{while(true){
var result__99705__auto__ = switch__99702__auto__(state_112654);
if(cljs.core.keyword_identical_QMARK_(result__99705__auto__,cljs.core.cst$kw$recur)){
continue;
} else {
return result__99705__auto__;
}
break;
}
}catch (e112675){if((e112675 instanceof Object)){
var ex__99706__auto__ = e112675;
var statearr_112676_112694 = state_112654;
(statearr_112676_112694[(5)] = ex__99706__auto__);


cljs.core.async.impl.ioc_helpers.process_exception(state_112654);

return cljs.core.cst$kw$recur;
} else {
throw e112675;

}
}})();
if(cljs.core.keyword_identical_QMARK_(ret_value__99704__auto__,cljs.core.cst$kw$recur)){
var G__112695 = state_112654;
state_112654 = G__112695;
continue;
} else {
return ret_value__99704__auto__;
}
break;
}
});
fluree$db$query$fql$state_machine__99703__auto__ = function(state_112654){
switch(arguments.length){
case 0:
return fluree$db$query$fql$state_machine__99703__auto____0.call(this);
case 1:
return fluree$db$query$fql$state_machine__99703__auto____1.call(this,state_112654);
}
throw(new Error('Invalid arity: ' + arguments.length));
};
fluree$db$query$fql$state_machine__99703__auto__.cljs$core$IFn$_invoke$arity$0 = fluree$db$query$fql$state_machine__99703__auto____0;
fluree$db$query$fql$state_machine__99703__auto__.cljs$core$IFn$_invoke$arity$1 = fluree$db$query$fql$state_machine__99703__auto____1;
return fluree$db$query$fql$state_machine__99703__auto__;
})()
;})(switch__99702__auto__,c__99809__auto__))
})();
var state__99811__auto__ = (function (){var statearr_112677 = (f__99810__auto__.cljs$core$IFn$_invoke$arity$0 ? f__99810__auto__.cljs$core$IFn$_invoke$arity$0() : f__99810__auto__.call(null));
(statearr_112677[(6)] = c__99809__auto__);

return statearr_112677;
})();
return cljs.core.async.impl.ioc_helpers.run_state_machine_wrapped(state__99811__auto__);
});})(c__99809__auto__))
);

return c__99809__auto__;
});

fluree.db.query.fql.flake_select.cljs$lang$maxFixedArity = 8;

/**
 * Like flake select, but takes a collection of subject ids which we
 *   then find collections of flakes for.
 */
fluree.db.query.fql.subject_select = (function fluree$db$query$fql$subject_select(var_args){
var G__112697 = arguments.length;
switch (G__112697) {
case 6:
return fluree.db.query.fql.subject_select.cljs$core$IFn$_invoke$arity$6((arguments[(0)]),(arguments[(1)]),(arguments[(2)]),(arguments[(3)]),(arguments[(4)]),(arguments[(5)]));

break;
case 7:
return fluree.db.query.fql.subject_select.cljs$core$IFn$_invoke$arity$7((arguments[(0)]),(arguments[(1)]),(arguments[(2)]),(arguments[(3)]),(arguments[(4)]),(arguments[(5)]),(arguments[(6)]));

break;
case 8:
return fluree.db.query.fql.subject_select.cljs$core$IFn$_invoke$arity$8((arguments[(0)]),(arguments[(1)]),(arguments[(2)]),(arguments[(3)]),(arguments[(4)]),(arguments[(5)]),(arguments[(6)]),(arguments[(7)]));

break;
default:
throw (new Error(["Invalid arity: ",cljs.core.str.cljs$core$IFn$_invoke$arity$1(arguments.length)].join('')));

}
});

fluree.db.query.fql.subject_select.cljs$core$IFn$_invoke$arity$6 = (function (db,cache,fuel,max_fuel,select_spec,subjects){
return fluree.db.query.fql.subject_select.cljs$core$IFn$_invoke$arity$8(db,cache,fuel,max_fuel,select_spec,subjects,null,null);
});

fluree.db.query.fql.subject_select.cljs$core$IFn$_invoke$arity$7 = (function (db,cache,fuel,max_fuel,select_spec,subjects,limit){
return fluree.db.query.fql.subject_select.cljs$core$IFn$_invoke$arity$8(db,cache,fuel,max_fuel,select_spec,subjects,limit,null);
});

fluree.db.query.fql.subject_select.cljs$core$IFn$_invoke$arity$8 = (function (db,cache,fuel,max_fuel,select_spec,subjects,limit,offset){
var c__99809__auto__ = cljs.core.async.chan.cljs$core$IFn$_invoke$arity$1((1));
cljs.core.async.impl.dispatch.run(((function (c__99809__auto__){
return (function (){
var f__99810__auto__ = (function (){var switch__99702__auto__ = ((function (c__99809__auto__){
return (function (state_112775){
var state_val_112776 = (state_112775[(1)]);
if((state_val_112776 === (7))){
var inst_112723 = (state_112775[(7)]);
var state_112775__$1 = state_112775;
var statearr_112777_112817 = state_112775__$1;
(statearr_112777_112817[(2)] = inst_112723);

(statearr_112777_112817[(1)] = (9));


return cljs.core.cst$kw$recur;
} else {
if((state_val_112776 === (20))){
var state_112775__$1 = state_112775;
var statearr_112778_112818 = state_112775__$1;
(statearr_112778_112818[(1)] = (22));



return cljs.core.cst$kw$recur;
} else {
if((state_val_112776 === (1))){
var state_112775__$1 = state_112775;
var statearr_112780_112819 = state_112775__$1;
(statearr_112780_112819[(2)] = null);

(statearr_112780_112819[(1)] = (4));


return cljs.core.cst$kw$recur;
} else {
if((state_val_112776 === (24))){
var inst_112765 = (state_112775[(2)]);
var state_112775__$1 = state_112775;
var statearr_112781_112820 = state_112775__$1;
(statearr_112781_112820[(2)] = inst_112765);

(statearr_112781_112820[(1)] = (21));


return cljs.core.cst$kw$recur;
} else {
if((state_val_112776 === (4))){
var _ = cljs.core.async.impl.ioc_helpers.add_exception_frame(state_112775,(3),Error,null,(2));
var inst_112709 = cljs.core.seq(subjects);
var inst_112710 = cljs.core.first(inst_112709);
var inst_112711 = cljs.core.next(inst_112709);
var inst_112712 = cljs.core.PersistentVector.EMPTY;
var inst_112713 = subjects;
var inst_112714 = (0);
var inst_112715 = inst_112712;
var state_112775__$1 = (function (){var statearr_112782 = state_112775;
(statearr_112782[(8)] = inst_112710);

(statearr_112782[(9)] = inst_112711);

(statearr_112782[(10)] = inst_112713);

(statearr_112782[(11)] = inst_112715);

(statearr_112782[(12)] = inst_112714);

return statearr_112782;
})();
var statearr_112783_112821 = state_112775__$1;
(statearr_112783_112821[(2)] = null);

(statearr_112783_112821[(1)] = (5));


return cljs.core.cst$kw$recur;
} else {
if((state_val_112776 === (15))){
var inst_112769 = (state_112775[(2)]);
var state_112775__$1 = state_112775;
var statearr_112784_112822 = state_112775__$1;
(statearr_112784_112822[(2)] = inst_112769);

(statearr_112784_112822[(1)] = (6));


return cljs.core.cst$kw$recur;
} else {
if((state_val_112776 === (21))){
var inst_112767 = (state_112775[(2)]);
var state_112775__$1 = state_112775;
var statearr_112785_112823 = state_112775__$1;
(statearr_112785_112823[(2)] = inst_112767);

(statearr_112785_112823[(1)] = (15));


return cljs.core.cst$kw$recur;
} else {
if((state_val_112776 === (13))){
var inst_112715 = (state_112775[(11)]);
var state_112775__$1 = state_112775;
var statearr_112786_112824 = state_112775__$1;
(statearr_112786_112824[(2)] = inst_112715);

(statearr_112786_112824[(1)] = (15));


return cljs.core.cst$kw$recur;
} else {
if((state_val_112776 === (22))){
var inst_112710 = (state_112775[(8)]);
var inst_112711 = (state_112775[(9)]);
var inst_112722 = (state_112775[(13)]);
var inst_112713 = (state_112775[(10)]);
var inst_112715 = (state_112775[(11)]);
var inst_112714 = (state_112775[(12)]);
var inst_112721 = (state_112775[(14)]);
var inst_112745 = (inst_112714 + (1));
var inst_112746 = (function (){var seq__112707 = inst_112711;
var first__112708 = inst_112710;
var seq__112718 = inst_112722;
var r = inst_112722;
var acc = inst_112715;
var n = inst_112714;
var s = inst_112721;
var vec__112717 = inst_112713;
var vec__112706 = subjects;
var first__112719 = inst_112721;
var G__112705 = inst_112713;
return ((function (seq__112707,first__112708,seq__112718,r,acc,n,s,vec__112717,vec__112706,first__112719,G__112705,inst_112710,inst_112711,inst_112722,inst_112713,inst_112715,inst_112714,inst_112721,inst_112745,state_val_112776,c__99809__auto__){
return (function (n__$1){
return fluree.db.query.fql.flakes__GT_res(db,cache,fuel,max_fuel,select_spec,n__$1);
});
;})(seq__112707,first__112708,seq__112718,r,acc,n,s,vec__112717,vec__112706,first__112719,G__112705,inst_112710,inst_112711,inst_112722,inst_112713,inst_112715,inst_112714,inst_112721,inst_112745,state_val_112776,c__99809__auto__))
})();
var inst_112747 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_112748 = [inst_112721];
var inst_112749 = (new cljs.core.PersistentVector(null,1,(5),inst_112747,inst_112748,null));
var inst_112750 = [cljs.core.cst$kw$limit];
var inst_112751 = [limit];
var inst_112752 = cljs.core.PersistentHashMap.fromArrays(inst_112750,inst_112751);
var inst_112753 = fluree.db.query.range.index_range.cljs$core$IFn$_invoke$arity$5(db,cljs.core.cst$kw$spot,cljs.core._EQ_,inst_112749,inst_112752);
var state_112775__$1 = (function (){var statearr_112787 = state_112775;
(statearr_112787[(15)] = inst_112746);

(statearr_112787[(16)] = inst_112745);

return statearr_112787;
})();
return cljs.core.async.impl.ioc_helpers.take_BANG_(state_112775__$1,(26),inst_112753);
} else {
if((state_val_112776 === (6))){
var inst_112771 = (state_112775[(2)]);
var state_112775__$1 = state_112775;
var statearr_112788_112825 = state_112775__$1;
(statearr_112788_112825[(2)] = inst_112771);


cljs.core.async.impl.ioc_helpers.process_exception(state_112775__$1);

return cljs.core.cst$kw$recur;
} else {
if((state_val_112776 === (25))){
var inst_112722 = (state_112775[(13)]);
var inst_112715 = (state_112775[(11)]);
var inst_112745 = (state_112775[(16)]);
var inst_112759 = (state_112775[(2)]);
var inst_112760 = fluree.db.util.async.throw_err(inst_112759);
var inst_112761 = cljs.core.conj.cljs$core$IFn$_invoke$arity$2(inst_112715,inst_112760);
var inst_112713 = inst_112722;
var inst_112714 = inst_112745;
var inst_112715__$1 = inst_112761;
var state_112775__$1 = (function (){var statearr_112789 = state_112775;
(statearr_112789[(10)] = inst_112713);

(statearr_112789[(11)] = inst_112715__$1);

(statearr_112789[(12)] = inst_112714);

return statearr_112789;
})();
var statearr_112790_112826 = state_112775__$1;
(statearr_112790_112826[(2)] = null);

(statearr_112790_112826[(1)] = (5));


return cljs.core.cst$kw$recur;
} else {
if((state_val_112776 === (17))){
var state_112775__$1 = state_112775;
var statearr_112791_112827 = state_112775__$1;
(statearr_112791_112827[(2)] = offset);

(statearr_112791_112827[(1)] = (18));


return cljs.core.cst$kw$recur;
} else {
if((state_val_112776 === (3))){
var inst_112698 = (state_112775[(2)]);
var state_112775__$1 = state_112775;
var statearr_112792_112828 = state_112775__$1;
(statearr_112792_112828[(2)] = inst_112698);


cljs.core.async.impl.ioc_helpers.process_exception(state_112775__$1);

return cljs.core.cst$kw$recur;
} else {
if((state_val_112776 === (12))){
var inst_112730 = (state_112775[(2)]);
var state_112775__$1 = state_112775;
var statearr_112793_112829 = state_112775__$1;
(statearr_112793_112829[(2)] = inst_112730);

(statearr_112793_112829[(1)] = (9));


return cljs.core.cst$kw$recur;
} else {
if((state_val_112776 === (2))){
var inst_112773 = (state_112775[(2)]);
var state_112775__$1 = state_112775;
return cljs.core.async.impl.ioc_helpers.return_chan(state_112775__$1,inst_112773);
} else {
if((state_val_112776 === (23))){
var state_112775__$1 = state_112775;
var statearr_112795_112830 = state_112775__$1;
(statearr_112795_112830[(2)] = null);

(statearr_112795_112830[(1)] = (24));


return cljs.core.cst$kw$recur;
} else {
if((state_val_112776 === (19))){
var inst_112722 = (state_112775[(13)]);
var inst_112715 = (state_112775[(11)]);
var inst_112714 = (state_112775[(12)]);
var inst_112741 = (inst_112714 + (1));
var tmp112794 = inst_112715;
var inst_112713 = inst_112722;
var inst_112714__$1 = inst_112741;
var inst_112715__$1 = tmp112794;
var state_112775__$1 = (function (){var statearr_112796 = state_112775;
(statearr_112796[(10)] = inst_112713);

(statearr_112796[(11)] = inst_112715__$1);

(statearr_112796[(12)] = inst_112714__$1);

return statearr_112796;
})();
var statearr_112797_112831 = state_112775__$1;
(statearr_112797_112831[(2)] = null);

(statearr_112797_112831[(1)] = (5));


return cljs.core.cst$kw$recur;
} else {
if((state_val_112776 === (11))){
var state_112775__$1 = state_112775;
var statearr_112798_112832 = state_112775__$1;
(statearr_112798_112832[(2)] = limit);

(statearr_112798_112832[(1)] = (12));


return cljs.core.cst$kw$recur;
} else {
if((state_val_112776 === (9))){
var inst_112732 = (state_112775[(2)]);
var state_112775__$1 = state_112775;
if(cljs.core.truth_(inst_112732)){
var statearr_112799_112833 = state_112775__$1;
(statearr_112799_112833[(1)] = (13));

} else {
var statearr_112800_112834 = state_112775__$1;
(statearr_112800_112834[(1)] = (14));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_112776 === (5))){
var inst_112723 = (state_112775[(7)]);
var inst_112713 = (state_112775[(10)]);
var inst_112721 = (state_112775[(14)]);
var inst_112720 = cljs.core.seq(inst_112713);
var inst_112721__$1 = cljs.core.first(inst_112720);
var inst_112722 = cljs.core.next(inst_112720);
var inst_112723__$1 = (inst_112721__$1 == null);
var state_112775__$1 = (function (){var statearr_112801 = state_112775;
(statearr_112801[(7)] = inst_112723__$1);

(statearr_112801[(13)] = inst_112722);

(statearr_112801[(14)] = inst_112721__$1);

return statearr_112801;
})();
if(cljs.core.truth_(inst_112723__$1)){
var statearr_112802_112835 = state_112775__$1;
(statearr_112802_112835[(1)] = (7));

} else {
var statearr_112803_112836 = state_112775__$1;
(statearr_112803_112836[(1)] = (8));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_112776 === (14))){
var state_112775__$1 = state_112775;
if(cljs.core.truth_(offset)){
var statearr_112804_112837 = state_112775__$1;
(statearr_112804_112837[(1)] = (16));

} else {
var statearr_112805_112838 = state_112775__$1;
(statearr_112805_112838[(1)] = (17));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_112776 === (26))){
var inst_112746 = (state_112775[(15)]);
var inst_112755 = (state_112775[(2)]);
var inst_112756 = fluree.db.util.async.throw_err(inst_112755);
var inst_112757 = (inst_112746.cljs$core$IFn$_invoke$arity$1 ? inst_112746.cljs$core$IFn$_invoke$arity$1(inst_112756) : inst_112746.call(null,inst_112756));
var state_112775__$1 = state_112775;
return cljs.core.async.impl.ioc_helpers.take_BANG_(state_112775__$1,(25),inst_112757);
} else {
if((state_val_112776 === (16))){
var inst_112714 = (state_112775[(12)]);
var inst_112736 = (inst_112714 < offset);
var state_112775__$1 = state_112775;
var statearr_112806_112839 = state_112775__$1;
(statearr_112806_112839[(2)] = inst_112736);

(statearr_112806_112839[(1)] = (18));


return cljs.core.cst$kw$recur;
} else {
if((state_val_112776 === (10))){
var inst_112714 = (state_112775[(12)]);
var inst_112727 = (inst_112714 > limit);
var state_112775__$1 = state_112775;
var statearr_112807_112840 = state_112775__$1;
(statearr_112807_112840[(2)] = inst_112727);

(statearr_112807_112840[(1)] = (12));


return cljs.core.cst$kw$recur;
} else {
if((state_val_112776 === (18))){
var inst_112739 = (state_112775[(2)]);
var state_112775__$1 = state_112775;
if(cljs.core.truth_(inst_112739)){
var statearr_112808_112841 = state_112775__$1;
(statearr_112808_112841[(1)] = (19));

} else {
var statearr_112809_112842 = state_112775__$1;
(statearr_112809_112842[(1)] = (20));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_112776 === (8))){
var state_112775__$1 = state_112775;
if(cljs.core.truth_(limit)){
var statearr_112810_112843 = state_112775__$1;
(statearr_112810_112843[(1)] = (10));

} else {
var statearr_112811_112844 = state_112775__$1;
(statearr_112811_112844[(1)] = (11));

}

return cljs.core.cst$kw$recur;
} else {
return null;
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
});})(c__99809__auto__))
;
return ((function (switch__99702__auto__,c__99809__auto__){
return (function() {
var fluree$db$query$fql$state_machine__99703__auto__ = null;
var fluree$db$query$fql$state_machine__99703__auto____0 = (function (){
var statearr_112812 = [null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null];
(statearr_112812[(0)] = fluree$db$query$fql$state_machine__99703__auto__);

(statearr_112812[(1)] = (1));

return statearr_112812;
});
var fluree$db$query$fql$state_machine__99703__auto____1 = (function (state_112775){
while(true){
var ret_value__99704__auto__ = (function (){try{while(true){
var result__99705__auto__ = switch__99702__auto__(state_112775);
if(cljs.core.keyword_identical_QMARK_(result__99705__auto__,cljs.core.cst$kw$recur)){
continue;
} else {
return result__99705__auto__;
}
break;
}
}catch (e112813){if((e112813 instanceof Object)){
var ex__99706__auto__ = e112813;
var statearr_112814_112845 = state_112775;
(statearr_112814_112845[(5)] = ex__99706__auto__);


cljs.core.async.impl.ioc_helpers.process_exception(state_112775);

return cljs.core.cst$kw$recur;
} else {
throw e112813;

}
}})();
if(cljs.core.keyword_identical_QMARK_(ret_value__99704__auto__,cljs.core.cst$kw$recur)){
var G__112846 = state_112775;
state_112775 = G__112846;
continue;
} else {
return ret_value__99704__auto__;
}
break;
}
});
fluree$db$query$fql$state_machine__99703__auto__ = function(state_112775){
switch(arguments.length){
case 0:
return fluree$db$query$fql$state_machine__99703__auto____0.call(this);
case 1:
return fluree$db$query$fql$state_machine__99703__auto____1.call(this,state_112775);
}
throw(new Error('Invalid arity: ' + arguments.length));
};
fluree$db$query$fql$state_machine__99703__auto__.cljs$core$IFn$_invoke$arity$0 = fluree$db$query$fql$state_machine__99703__auto____0;
fluree$db$query$fql$state_machine__99703__auto__.cljs$core$IFn$_invoke$arity$1 = fluree$db$query$fql$state_machine__99703__auto____1;
return fluree$db$query$fql$state_machine__99703__auto__;
})()
;})(switch__99702__auto__,c__99809__auto__))
})();
var state__99811__auto__ = (function (){var statearr_112815 = (f__99810__auto__.cljs$core$IFn$_invoke$arity$0 ? f__99810__auto__.cljs$core$IFn$_invoke$arity$0() : f__99810__auto__.call(null));
(statearr_112815[(6)] = c__99809__auto__);

return statearr_112815;
})();
return cljs.core.async.impl.ioc_helpers.run_state_machine_wrapped(state__99811__auto__);
});})(c__99809__auto__))
);

return c__99809__auto__;
});

fluree.db.query.fql.subject_select.cljs$lang$maxFixedArity = 8;

fluree.db.query.fql.valid_where_predicate_QMARK_ = (function fluree$db$query$fql$valid_where_predicate_QMARK_(db,p){
var or__4131__auto__ = fluree.db.dbproto._p_prop(db,cljs.core.cst$kw$idx_QMARK_,p);
if(cljs.core.truth_(or__4131__auto__)){
return or__4131__auto__;
} else {
var or__4131__auto____$1 = fluree.db.dbproto._p_prop(db,cljs.core.cst$kw$ref_QMARK_,p);
if(cljs.core.truth_(or__4131__auto____$1)){
return or__4131__auto____$1;
} else {
return cljs.core._EQ_.cljs$core$IFn$_invoke$arity$2(cljs.core.cst$kw$tag,fluree.db.dbproto._p_prop(db,cljs.core.cst$kw$type,p));
}
}
});
/**
 * Takes a where clause and returns subjects that match.
 */
fluree.db.query.fql.where_filter = (function fluree$db$query$fql$where_filter(var_args){
var G__112848 = arguments.length;
switch (G__112848) {
case 2:
return fluree.db.query.fql.where_filter.cljs$core$IFn$_invoke$arity$2((arguments[(0)]),(arguments[(1)]));

break;
case 3:
return fluree.db.query.fql.where_filter.cljs$core$IFn$_invoke$arity$3((arguments[(0)]),(arguments[(1)]),(arguments[(2)]));

break;
default:
throw (new Error(["Invalid arity: ",cljs.core.str.cljs$core$IFn$_invoke$arity$1(arguments.length)].join('')));

}
});

fluree.db.query.fql.where_filter.cljs$core$IFn$_invoke$arity$2 = (function (db,where_clause){
return fluree.db.query.fql.where_filter.cljs$core$IFn$_invoke$arity$3(db,where_clause,null);
});

fluree.db.query.fql.where_filter.cljs$core$IFn$_invoke$arity$3 = (function (db,where_clause,default_collection){
var c__99809__auto__ = cljs.core.async.chan.cljs$core$IFn$_invoke$arity$1((1));
cljs.core.async.impl.dispatch.run(((function (c__99809__auto__){
return (function (){
var f__99810__auto__ = (function (){var switch__99702__auto__ = ((function (c__99809__auto__){
return (function (state_113032){
var state_val_113033 = (state_113032[(1)]);
if((state_val_113033 === (7))){
var inst_113028 = (state_113032[(2)]);
var state_113032__$1 = state_113032;
var statearr_113034_113098 = state_113032__$1;
(statearr_113034_113098[(2)] = inst_113028);


cljs.core.async.impl.ioc_helpers.process_exception(state_113032__$1);

return cljs.core.cst$kw$recur;
} else {
if((state_val_113033 === (20))){
var inst_112917 = (state_113032[(7)]);
var inst_112926 = (state_113032[(2)]);
var inst_112927 = fluree.db.util.async.throw_err(inst_112926);
var inst_112928 = cljs.core.concat.cljs$core$IFn$_invoke$arity$2(inst_112917,inst_112927);
var state_113032__$1 = state_113032;
var statearr_113035_113099 = state_113032__$1;
(statearr_113035_113099[(2)] = inst_112928);

(statearr_113035_113099[(1)] = (18));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113033 === (27))){
var inst_113000 = (state_113032[(2)]);
var state_113032__$1 = state_113032;
var statearr_113036_113100 = state_113032__$1;
(statearr_113036_113100[(2)] = inst_113000);

(statearr_113036_113100[(1)] = (23));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113033 === (1))){
var state_113032__$1 = state_113032;
var statearr_113037_113101 = state_113032__$1;
(statearr_113037_113101[(2)] = null);

(statearr_113037_113101[(1)] = (4));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113033 === (24))){
var inst_112937 = (state_113032[(2)]);
var inst_112938 = fluree.db.util.async.throw_err(inst_112937);
var state_113032__$1 = state_113032;
var statearr_113038_113102 = state_113032__$1;
(statearr_113038_113102[(2)] = inst_112938);

(statearr_113038_113102[(1)] = (23));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113033 === (39))){
var inst_112994 = (state_113032[(2)]);
var state_113032__$1 = state_113032;
var statearr_113039_113103 = state_113032__$1;
(statearr_113039_113103[(2)] = inst_112994);

(statearr_113039_113103[(1)] = (35));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113033 === (46))){
var inst_113021 = (state_113032[(2)]);
var state_113032__$1 = state_113032;
var statearr_113040_113104 = state_113032__$1;
(statearr_113040_113104[(2)] = inst_113021);

(statearr_113040_113104[(1)] = (12));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113033 === (4))){
var inst_112858 = (state_113032[(8)]);
var _ = cljs.core.async.impl.ioc_helpers.add_exception_frame(state_113032,(3),Error,null,(2));
var inst_112856 = fluree.db.query.fql_parser.parse_where.cljs$core$IFn$_invoke$arity$3(db,where_clause,default_collection);
var inst_112857 = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(inst_112856,(0),null);
var inst_112858__$1 = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(inst_112856,(1),null);
var inst_112859 = cljs.core.not_empty(inst_112858__$1);
var state_113032__$1 = (function (){var statearr_113041 = state_113032;
(statearr_113041[(8)] = inst_112858__$1);

(statearr_113041[(9)] = inst_112857);

return statearr_113041;
})();
if(cljs.core.truth_(inst_112859)){
var statearr_113042_113105 = state_113032__$1;
(statearr_113042_113105[(1)] = (5));

} else {
var statearr_113043_113106 = state_113032__$1;
(statearr_113043_113106[(1)] = (6));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_113033 === (15))){
var inst_112888 = (state_113032[(10)]);
var inst_112902 = (state_113032[(2)]);
var inst_112906 = (cljs.core.not_EQ_ === inst_112888);
var state_113032__$1 = (function (){var statearr_113044 = state_113032;
(statearr_113044[(11)] = inst_112902);

return statearr_113044;
})();
if(inst_112906){
var statearr_113045_113107 = state_113032__$1;
(statearr_113045_113107[(1)] = (16));

} else {
var statearr_113046_113108 = state_113032__$1;
(statearr_113046_113108[(1)] = (17));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_113033 === (21))){
var inst_112889 = (state_113032[(12)]);
var inst_112887 = (state_113032[(13)]);
var inst_112932 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_112933 = [inst_112887,inst_112889];
var inst_112934 = (new cljs.core.PersistentVector(null,2,(5),inst_112932,inst_112933,null));
var inst_112935 = fluree.db.query.range.index_range.cljs$core$IFn$_invoke$arity$4(db,cljs.core.cst$kw$post,cljs.core._EQ_,inst_112934);
var state_113032__$1 = state_113032;
return cljs.core.async.impl.ioc_helpers.take_BANG_(state_113032__$1,(24),inst_112935);
} else {
if((state_val_113033 === (31))){
var inst_112998 = (state_113032[(2)]);
var state_113032__$1 = state_113032;
var statearr_113047_113109 = state_113032__$1;
(statearr_113047_113109[(2)] = inst_112998);

(statearr_113047_113109[(1)] = (27));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113033 === (32))){
var inst_112963 = (state_113032[(2)]);
var inst_112964 = fluree.db.util.async.throw_err(inst_112963);
var state_113032__$1 = state_113032;
var statearr_113048_113110 = state_113032__$1;
(statearr_113048_113110[(2)] = inst_112964);

(statearr_113048_113110[(1)] = (31));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113033 === (40))){
var inst_112989 = (state_113032[(2)]);
var inst_112990 = fluree.db.util.async.throw_err(inst_112989);
var state_113032__$1 = state_113032;
var statearr_113049_113111 = state_113032__$1;
(statearr_113049_113111[(2)] = inst_112990);

(statearr_113049_113111[(1)] = (39));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113033 === (33))){
var inst_112889 = (state_113032[(12)]);
var inst_112887 = (state_113032[(13)]);
var inst_112968 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_112969 = [inst_112887];
var inst_112970 = (new cljs.core.PersistentVector(null,1,(5),inst_112968,inst_112969,null));
var inst_112971 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_112972 = [inst_112887,inst_112889];
var inst_112973 = (new cljs.core.PersistentVector(null,2,(5),inst_112971,inst_112972,null));
var inst_112974 = fluree.db.query.range.index_range.cljs$core$IFn$_invoke$arity$6(db,cljs.core.cst$kw$post,cljs.core._GT__EQ_,inst_112970,cljs.core._LT_,inst_112973);
var state_113032__$1 = state_113032;
return cljs.core.async.impl.ioc_helpers.take_BANG_(state_113032__$1,(36),inst_112974);
} else {
if((state_val_113033 === (13))){
var inst_112887 = (state_113032[(13)]);
var inst_112893 = fluree.db.dbproto._p_prop(db,cljs.core.cst$kw$name,inst_112887);
var inst_112894 = ["Non-indexed predicates are not valid in where clause statements. Provided: ",cljs.core.str.cljs$core$IFn$_invoke$arity$1(inst_112893)].join('');
var inst_112895 = [cljs.core.cst$kw$status,cljs.core.cst$kw$error];
var inst_112896 = [(400),cljs.core.cst$kw$db_SLASH_invalid_DASH_query];
var inst_112897 = cljs.core.PersistentHashMap.fromArrays(inst_112895,inst_112896);
var inst_112898 = cljs.core.ex_info.cljs$core$IFn$_invoke$arity$2(inst_112894,inst_112897);
var inst_112899 = (function(){throw inst_112898})();
var state_113032__$1 = state_113032;
var statearr_113050_113112 = state_113032__$1;
(statearr_113050_113112[(2)] = inst_112899);

(statearr_113050_113112[(1)] = (15));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113033 === (22))){
var inst_112888 = (state_113032[(10)]);
var inst_112940 = (cljs.core._GT_ === inst_112888);
var state_113032__$1 = state_113032;
if(inst_112940){
var statearr_113051_113113 = state_113032__$1;
(statearr_113051_113113[(1)] = (25));

} else {
var statearr_113052_113114 = state_113032__$1;
(statearr_113052_113114[(1)] = (26));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_113033 === (36))){
var inst_112976 = (state_113032[(2)]);
var inst_112977 = fluree.db.util.async.throw_err(inst_112976);
var state_113032__$1 = state_113032;
var statearr_113053_113115 = state_113032__$1;
(statearr_113053_113115[(2)] = inst_112977);

(statearr_113053_113115[(1)] = (35));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113033 === (41))){
var inst_112857 = (state_113032[(9)]);
var inst_113013 = (state_113032[(14)]);
var inst_113013__$1 = (state_113032[(2)]);
var inst_113014 = cljs.core._EQ_.cljs$core$IFn$_invoke$arity$2(cljs.core.cst$kw$and,inst_112857);
var inst_113015 = cljs.core.empty_QMARK_(inst_113013__$1);
var inst_113016 = ((inst_113014) && (inst_113015));
var state_113032__$1 = (function (){var statearr_113054 = state_113032;
(statearr_113054[(14)] = inst_113013__$1);

return statearr_113054;
})();
if(cljs.core.truth_(inst_113016)){
var statearr_113055_113116 = state_113032__$1;
(statearr_113055_113116[(1)] = (44));

} else {
var statearr_113056_113117 = state_113032__$1;
(statearr_113056_113117[(1)] = (45));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_113033 === (43))){
var inst_112873 = (state_113032[(15)]);
var inst_113005 = (state_113032[(16)]);
var inst_113008 = cljs.core.PersistentHashSet.EMPTY;
var inst_113009 = cljs.core.into.cljs$core$IFn$_invoke$arity$2(inst_113008,inst_113005);
var inst_113010 = clojure.set.intersection.cljs$core$IFn$_invoke$arity$2(inst_112873,inst_113009);
var state_113032__$1 = state_113032;
var statearr_113057_113118 = state_113032__$1;
(statearr_113057_113118[(2)] = inst_113010);

(statearr_113057_113118[(1)] = (41));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113033 === (29))){
var inst_112889 = (state_113032[(12)]);
var inst_112887 = (state_113032[(13)]);
var inst_112955 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_112956 = [inst_112887,inst_112889];
var inst_112957 = (new cljs.core.PersistentVector(null,2,(5),inst_112955,inst_112956,null));
var inst_112958 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_112959 = [inst_112887];
var inst_112960 = (new cljs.core.PersistentVector(null,1,(5),inst_112958,inst_112959,null));
var inst_112961 = fluree.db.query.range.index_range.cljs$core$IFn$_invoke$arity$6(db,cljs.core.cst$kw$post,cljs.core._GT__EQ_,inst_112957,cljs.core._LT__EQ_,inst_112960);
var state_113032__$1 = state_113032;
return cljs.core.async.impl.ioc_helpers.take_BANG_(state_113032__$1,(32),inst_112961);
} else {
if((state_val_113033 === (44))){
var inst_113013 = (state_113032[(14)]);
var state_113032__$1 = state_113032;
var statearr_113058_113119 = state_113032__$1;
(statearr_113058_113119[(2)] = inst_113013);

(statearr_113058_113119[(1)] = (46));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113033 === (6))){
var state_113032__$1 = state_113032;
var statearr_113059_113120 = state_113032__$1;
(statearr_113059_113120[(2)] = null);

(statearr_113059_113120[(1)] = (7));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113033 === (28))){
var inst_112950 = (state_113032[(2)]);
var inst_112951 = fluree.db.util.async.throw_err(inst_112950);
var state_113032__$1 = state_113032;
var statearr_113060_113121 = state_113032__$1;
(statearr_113060_113121[(2)] = inst_112951);

(statearr_113060_113121[(1)] = (27));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113033 === (25))){
var inst_112889 = (state_113032[(12)]);
var inst_112887 = (state_113032[(13)]);
var inst_112942 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_112943 = [inst_112887,inst_112889];
var inst_112944 = (new cljs.core.PersistentVector(null,2,(5),inst_112942,inst_112943,null));
var inst_112945 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_112946 = [inst_112887];
var inst_112947 = (new cljs.core.PersistentVector(null,1,(5),inst_112945,inst_112946,null));
var inst_112948 = fluree.db.query.range.index_range.cljs$core$IFn$_invoke$arity$6(db,cljs.core.cst$kw$post,cljs.core._GT_,inst_112944,cljs.core._LT__EQ_,inst_112947);
var state_113032__$1 = state_113032;
return cljs.core.async.impl.ioc_helpers.take_BANG_(state_113032__$1,(28),inst_112948);
} else {
if((state_val_113033 === (34))){
var inst_112888 = (state_113032[(10)]);
var inst_112979 = (cljs.core._LT__EQ_ === inst_112888);
var state_113032__$1 = state_113032;
if(inst_112979){
var statearr_113061_113122 = state_113032__$1;
(statearr_113061_113122[(1)] = (37));

} else {
var statearr_113062_113123 = state_113032__$1;
(statearr_113062_113123[(1)] = (38));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_113033 === (17))){
var inst_112888 = (state_113032[(10)]);
var inst_112930 = (cljs.core._EQ_ === inst_112888);
var state_113032__$1 = state_113032;
if(inst_112930){
var statearr_113063_113124 = state_113032__$1;
(statearr_113063_113124[(1)] = (21));

} else {
var statearr_113064_113125 = state_113032__$1;
(statearr_113064_113125[(1)] = (22));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_113033 === (3))){
var inst_112849 = (state_113032[(2)]);
var state_113032__$1 = state_113032;
var statearr_113065_113126 = state_113032__$1;
(statearr_113065_113126[(2)] = inst_112849);


cljs.core.async.impl.ioc_helpers.process_exception(state_113032__$1);

return cljs.core.cst$kw$recur;
} else {
if((state_val_113033 === (12))){
var inst_113023 = (state_113032[(2)]);
var state_113032__$1 = state_113032;
var statearr_113066_113127 = state_113032__$1;
(statearr_113066_113127[(2)] = inst_113023);

(statearr_113066_113127[(1)] = (9));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113033 === (2))){
var inst_113030 = (state_113032[(2)]);
var state_113032__$1 = state_113032;
return cljs.core.async.impl.ioc_helpers.return_chan(state_113032__$1,inst_113030);
} else {
if((state_val_113033 === (23))){
var inst_113002 = (state_113032[(2)]);
var state_113032__$1 = state_113032;
var statearr_113067_113128 = state_113032__$1;
(statearr_113067_113128[(2)] = inst_113002);

(statearr_113067_113128[(1)] = (18));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113033 === (35))){
var inst_112996 = (state_113032[(2)]);
var state_113032__$1 = state_113032;
var statearr_113068_113129 = state_113032__$1;
(statearr_113068_113129[(2)] = inst_112996);

(statearr_113068_113129[(1)] = (31));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113033 === (19))){
var inst_112889 = (state_113032[(12)]);
var inst_112887 = (state_113032[(13)]);
var inst_112916 = (state_113032[(2)]);
var inst_112917 = fluree.db.util.async.throw_err(inst_112916);
var inst_112918 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_112919 = [inst_112887];
var inst_112920 = (new cljs.core.PersistentVector(null,1,(5),inst_112918,inst_112919,null));
var inst_112921 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_112922 = [inst_112887,inst_112889];
var inst_112923 = (new cljs.core.PersistentVector(null,2,(5),inst_112921,inst_112922,null));
var inst_112924 = fluree.db.query.range.index_range.cljs$core$IFn$_invoke$arity$6(db,cljs.core.cst$kw$post,cljs.core._GT__EQ_,inst_112920,cljs.core._LT_,inst_112923);
var state_113032__$1 = (function (){var statearr_113069 = state_113032;
(statearr_113069[(7)] = inst_112917);

return statearr_113069;
})();
return cljs.core.async.impl.ioc_helpers.take_BANG_(state_113032__$1,(20),inst_112924);
} else {
if((state_val_113033 === (11))){
var inst_112879 = (state_113032[(17)]);
var inst_112887 = (state_113032[(13)]);
var inst_112887__$1 = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(inst_112879,(0),null);
var inst_112888 = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(inst_112879,(1),null);
var inst_112889 = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(inst_112879,(2),null);
var inst_112890 = fluree.db.query.fql.valid_where_predicate_QMARK_(db,inst_112887__$1);
var inst_112891 = cljs.core.not(inst_112890);
var state_113032__$1 = (function (){var statearr_113070 = state_113032;
(statearr_113070[(10)] = inst_112888);

(statearr_113070[(12)] = inst_112889);

(statearr_113070[(13)] = inst_112887__$1);

return statearr_113070;
})();
if(inst_112891){
var statearr_113071_113130 = state_113032__$1;
(statearr_113071_113130[(1)] = (13));

} else {
var statearr_113072_113131 = state_113032__$1;
(statearr_113072_113131[(1)] = (14));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_113033 === (9))){
var inst_113025 = (state_113032[(2)]);
var state_113032__$1 = state_113032;
var statearr_113073_113132 = state_113032__$1;
(statearr_113073_113132[(2)] = inst_113025);

(statearr_113073_113132[(1)] = (7));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113033 === (5))){
var inst_112858 = (state_113032[(8)]);
var inst_112868 = cljs.core.seq(inst_112858);
var inst_112869 = cljs.core.first(inst_112868);
var inst_112870 = cljs.core.next(inst_112868);
var inst_112871 = cljs.core.PersistentHashSet.EMPTY;
var inst_112872 = inst_112858;
var inst_112873 = inst_112871;
var state_113032__$1 = (function (){var statearr_113074 = state_113032;
(statearr_113074[(18)] = inst_112872);

(statearr_113074[(15)] = inst_112873);

(statearr_113074[(19)] = inst_112869);

(statearr_113074[(20)] = inst_112870);

return statearr_113074;
})();
var statearr_113075_113133 = state_113032__$1;
(statearr_113075_113133[(2)] = null);

(statearr_113075_113133[(1)] = (8));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113033 === (14))){
var state_113032__$1 = state_113032;
var statearr_113076_113134 = state_113032__$1;
(statearr_113076_113134[(2)] = null);

(statearr_113076_113134[(1)] = (15));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113033 === (45))){
var inst_113013 = (state_113032[(14)]);
var inst_112880 = (state_113032[(21)]);
var inst_112872 = inst_112880;
var inst_112873 = inst_113013;
var state_113032__$1 = (function (){var statearr_113077 = state_113032;
(statearr_113077[(18)] = inst_112872);

(statearr_113077[(15)] = inst_112873);

return statearr_113077;
})();
var statearr_113078_113135 = state_113032__$1;
(statearr_113078_113135[(2)] = null);

(statearr_113078_113135[(1)] = (8));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113033 === (26))){
var inst_112888 = (state_113032[(10)]);
var inst_112953 = (cljs.core._GT__EQ_ === inst_112888);
var state_113032__$1 = state_113032;
if(inst_112953){
var statearr_113079_113136 = state_113032__$1;
(statearr_113079_113136[(1)] = (29));

} else {
var statearr_113080_113137 = state_113032__$1;
(statearr_113080_113137[(1)] = (30));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_113033 === (16))){
var inst_112889 = (state_113032[(12)]);
var inst_112887 = (state_113032[(13)]);
var inst_112908 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_112909 = [inst_112887,inst_112889];
var inst_112910 = (new cljs.core.PersistentVector(null,2,(5),inst_112908,inst_112909,null));
var inst_112911 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_112912 = [inst_112887];
var inst_112913 = (new cljs.core.PersistentVector(null,1,(5),inst_112911,inst_112912,null));
var inst_112914 = fluree.db.query.range.index_range.cljs$core$IFn$_invoke$arity$6(db,cljs.core.cst$kw$post,cljs.core._GT_,inst_112910,cljs.core._LT__EQ_,inst_112913);
var state_113032__$1 = state_113032;
return cljs.core.async.impl.ioc_helpers.take_BANG_(state_113032__$1,(19),inst_112914);
} else {
if((state_val_113033 === (38))){
var inst_112992 = null;
var state_113032__$1 = state_113032;
var statearr_113081_113138 = state_113032__$1;
(statearr_113081_113138[(2)] = inst_112992);

(statearr_113081_113138[(1)] = (39));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113033 === (30))){
var inst_112888 = (state_113032[(10)]);
var inst_112966 = (cljs.core._LT_ === inst_112888);
var state_113032__$1 = state_113032;
if(inst_112966){
var statearr_113082_113139 = state_113032__$1;
(statearr_113082_113139[(1)] = (33));

} else {
var statearr_113083_113140 = state_113032__$1;
(statearr_113083_113140[(1)] = (34));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_113033 === (10))){
var inst_112873 = (state_113032[(15)]);
var state_113032__$1 = state_113032;
var statearr_113084_113141 = state_113032__$1;
(statearr_113084_113141[(2)] = inst_112873);

(statearr_113084_113141[(1)] = (12));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113033 === (18))){
var inst_112857 = (state_113032[(9)]);
var inst_113004 = (state_113032[(2)]);
var inst_113005 = cljs.core.map.cljs$core$IFn$_invoke$arity$2(fluree.db.query.fql.s,inst_113004);
var state_113032__$1 = (function (){var statearr_113085 = state_113032;
(statearr_113085[(16)] = inst_113005);

return statearr_113085;
})();
var G__113086_113142 = inst_112857;
var G__113086_113143__$1 = (((G__113086_113142 instanceof cljs.core.Keyword))?G__113086_113142.fqn:null);
switch (G__113086_113143__$1) {
case "or":
var statearr_113087_113145 = state_113032__$1;
(statearr_113087_113145[(1)] = (42));


break;
case "and":
var statearr_113088_113146 = state_113032__$1;
(statearr_113088_113146[(1)] = (43));


break;
default:
throw (new Error(["No matching clause: ",cljs.core.str.cljs$core$IFn$_invoke$arity$1(G__113086_113143__$1)].join('')));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_113033 === (42))){
var inst_112873 = (state_113032[(15)]);
var inst_113005 = (state_113032[(16)]);
var inst_113006 = cljs.core.into.cljs$core$IFn$_invoke$arity$2(inst_112873,inst_113005);
var state_113032__$1 = state_113032;
var statearr_113089_113147 = state_113032__$1;
(statearr_113089_113147[(2)] = inst_113006);

(statearr_113089_113147[(1)] = (41));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113033 === (37))){
var inst_112889 = (state_113032[(12)]);
var inst_112887 = (state_113032[(13)]);
var inst_112981 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_112982 = [inst_112887];
var inst_112983 = (new cljs.core.PersistentVector(null,1,(5),inst_112981,inst_112982,null));
var inst_112984 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_112985 = [inst_112887,inst_112889];
var inst_112986 = (new cljs.core.PersistentVector(null,2,(5),inst_112984,inst_112985,null));
var inst_112987 = fluree.db.query.range.index_range.cljs$core$IFn$_invoke$arity$6(db,cljs.core.cst$kw$post,cljs.core._GT__EQ_,inst_112983,cljs.core._LT__EQ_,inst_112986);
var state_113032__$1 = state_113032;
return cljs.core.async.impl.ioc_helpers.take_BANG_(state_113032__$1,(40),inst_112987);
} else {
if((state_val_113033 === (8))){
var inst_112879 = (state_113032[(17)]);
var inst_112872 = (state_113032[(18)]);
var inst_112878 = cljs.core.seq(inst_112872);
var inst_112879__$1 = cljs.core.first(inst_112878);
var inst_112880 = cljs.core.next(inst_112878);
var inst_112881 = cljs.core.not(inst_112879__$1);
var state_113032__$1 = (function (){var statearr_113090 = state_113032;
(statearr_113090[(17)] = inst_112879__$1);

(statearr_113090[(21)] = inst_112880);

return statearr_113090;
})();
if(inst_112881){
var statearr_113091_113148 = state_113032__$1;
(statearr_113091_113148[(1)] = (10));

} else {
var statearr_113092_113149 = state_113032__$1;
(statearr_113092_113149[(1)] = (11));

}

return cljs.core.cst$kw$recur;
} else {
return null;
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
});})(c__99809__auto__))
;
return ((function (switch__99702__auto__,c__99809__auto__){
return (function() {
var fluree$db$query$fql$state_machine__99703__auto__ = null;
var fluree$db$query$fql$state_machine__99703__auto____0 = (function (){
var statearr_113093 = [null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null];
(statearr_113093[(0)] = fluree$db$query$fql$state_machine__99703__auto__);

(statearr_113093[(1)] = (1));

return statearr_113093;
});
var fluree$db$query$fql$state_machine__99703__auto____1 = (function (state_113032){
while(true){
var ret_value__99704__auto__ = (function (){try{while(true){
var result__99705__auto__ = switch__99702__auto__(state_113032);
if(cljs.core.keyword_identical_QMARK_(result__99705__auto__,cljs.core.cst$kw$recur)){
continue;
} else {
return result__99705__auto__;
}
break;
}
}catch (e113094){if((e113094 instanceof Object)){
var ex__99706__auto__ = e113094;
var statearr_113095_113150 = state_113032;
(statearr_113095_113150[(5)] = ex__99706__auto__);


cljs.core.async.impl.ioc_helpers.process_exception(state_113032);

return cljs.core.cst$kw$recur;
} else {
throw e113094;

}
}})();
if(cljs.core.keyword_identical_QMARK_(ret_value__99704__auto__,cljs.core.cst$kw$recur)){
var G__113151 = state_113032;
state_113032 = G__113151;
continue;
} else {
return ret_value__99704__auto__;
}
break;
}
});
fluree$db$query$fql$state_machine__99703__auto__ = function(state_113032){
switch(arguments.length){
case 0:
return fluree$db$query$fql$state_machine__99703__auto____0.call(this);
case 1:
return fluree$db$query$fql$state_machine__99703__auto____1.call(this,state_113032);
}
throw(new Error('Invalid arity: ' + arguments.length));
};
fluree$db$query$fql$state_machine__99703__auto__.cljs$core$IFn$_invoke$arity$0 = fluree$db$query$fql$state_machine__99703__auto____0;
fluree$db$query$fql$state_machine__99703__auto__.cljs$core$IFn$_invoke$arity$1 = fluree$db$query$fql$state_machine__99703__auto____1;
return fluree$db$query$fql$state_machine__99703__auto__;
})()
;})(switch__99702__auto__,c__99809__auto__))
})();
var state__99811__auto__ = (function (){var statearr_113096 = (f__99810__auto__.cljs$core$IFn$_invoke$arity$0 ? f__99810__auto__.cljs$core$IFn$_invoke$arity$0() : f__99810__auto__.call(null));
(statearr_113096[(6)] = c__99809__auto__);

return statearr_113096;
})();
return cljs.core.async.impl.ioc_helpers.run_state_machine_wrapped(state__99811__auto__);
});})(c__99809__auto__))
);

return c__99809__auto__;
});

fluree.db.query.fql.where_filter.cljs$lang$maxFixedArity = 3;

/**
 * Order By can be:
 *  - Single variable, ?favNums
 *  - Two-tuple,  [ASC, ?favNums]
 */
fluree.db.query.fql.order_offset_and_limit_results = (function fluree$db$query$fql$order_offset_and_limit_results(orderBy,p__113153,offset,limit){
var map__113154 = p__113153;
var map__113154__$1 = (((((!((map__113154 == null))))?(((((map__113154.cljs$lang$protocol_mask$partition0$ & (64))) || ((cljs.core.PROTOCOL_SENTINEL === map__113154.cljs$core$ISeq$))))?true:false):false))?cljs.core.apply.cljs$core$IFn$_invoke$arity$2(cljs.core.hash_map,map__113154):map__113154);
var res = map__113154__$1;
var headers = cljs.core.get.cljs$core$IFn$_invoke$arity$2(map__113154__$1,cljs.core.cst$kw$headers);
var tuples = cljs.core.get.cljs$core$IFn$_invoke$arity$2(map__113154__$1,cljs.core.cst$kw$tuples);
var vec__113156 = orderBy;
var order = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(vec__113156,(0),null);
var var$ = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(vec__113156,(1),null);
var indexOfFind = (function (){var or__4131__auto__ = fluree.db.util.core.index_of(headers,cljs.core.symbol.cljs$core$IFn$_invoke$arity$1(var$));
if(cljs.core.truth_(or__4131__auto__)){
return or__4131__auto__;
} else {
return (-1);
}
})();
var tuples__$1 = ((((0) <= indexOfFind))?(function (){var G__113159 = cljs.core.sort_by.cljs$core$IFn$_invoke$arity$3(((function (vec__113156,order,var$,indexOfFind,map__113154,map__113154__$1,res,headers,tuples){
return (function (p1__113152_SHARP_){
return cljs.core.nth.cljs$core$IFn$_invoke$arity$2(p1__113152_SHARP_,indexOfFind);
});})(vec__113156,order,var$,indexOfFind,map__113154,map__113154__$1,res,headers,tuples))
,fluree.db.query.fql.compare_fn,tuples);
var G__113159__$1 = ((cljs.core._EQ_.cljs$core$IFn$_invoke$arity$2("DESC",order))?cljs.core.reverse(G__113159):G__113159);
var G__113159__$2 = (cljs.core.truth_(offset)?cljs.core.drop.cljs$core$IFn$_invoke$arity$2(offset,G__113159__$1):G__113159__$1);
if(cljs.core.truth_(limit)){
return cljs.core.take.cljs$core$IFn$_invoke$arity$2(limit,G__113159__$2);
} else {
return G__113159__$2;
}
})():tuples);
return new cljs.core.PersistentArrayMap(null, 2, [cljs.core.cst$kw$headers,headers,cljs.core.cst$kw$tuples,tuples__$1], null);
});
fluree.db.query.fql.parse_map = (function fluree$db$query$fql$parse_map(x,valid_var){
var _ = ((cljs.core._EQ_.cljs$core$IFn$_invoke$arity$2((1),cljs.core.count(cljs.core.keys(x))))?null:(function(){throw cljs.core.ex_info.cljs$core$IFn$_invoke$arity$2(["Invalid aggregate selection, provided: ",cljs.core.str.cljs$core$IFn$_invoke$arity$1(x)].join(''),new cljs.core.PersistentArrayMap(null, 2, [cljs.core.cst$kw$status,(400),cljs.core.cst$kw$error,cljs.core.cst$kw$db_SLASH_invalid_DASH_query], null))})());
var var_as_symbol = cljs.core.symbol.cljs$core$IFn$_invoke$arity$1(cljs.core.first(cljs.core.keys(x)));
var ___$1 = (cljs.core.truth_((valid_var.cljs$core$IFn$_invoke$arity$1 ? valid_var.cljs$core$IFn$_invoke$arity$1(var_as_symbol) : valid_var.call(null,var_as_symbol)))?null:(function(){throw cljs.core.ex_info.cljs$core$IFn$_invoke$arity$2(["Invalid select variable in aggregate select, provided: ",cljs.core.str.cljs$core$IFn$_invoke$arity$1(x)].join(''),new cljs.core.PersistentArrayMap(null, 2, [cljs.core.cst$kw$status,(400),cljs.core.cst$kw$error,cljs.core.cst$kw$db_SLASH_invalid_DASH_query], null))})());
return new cljs.core.PersistentArrayMap(null, 2, [cljs.core.cst$kw$variable,var_as_symbol,cljs.core.cst$kw$selection,cljs.core.first(cljs.core.vals(x))], null);
});
fluree.db.query.fql.parse_select = (function fluree$db$query$fql$parse_select(vars,interim_vars,select_smt){
var _ = (function (){var or__4131__auto__ = cljs.core.every_QMARK_((function (p1__113160_SHARP_){
return ((typeof p1__113160_SHARP_ === 'string') || (cljs.core.map_QMARK_(p1__113160_SHARP_)));
}),select_smt);
if(or__4131__auto__){
return or__4131__auto__;
} else {
throw cljs.core.ex_info.cljs$core$IFn$_invoke$arity$2(["Invalid select statement. Every selection must be a string or map. Provided: ",cljs.core.str.cljs$core$IFn$_invoke$arity$1(select_smt)].join(''),new cljs.core.PersistentArrayMap(null, 2, [cljs.core.cst$kw$status,(400),cljs.core.cst$kw$error,cljs.core.cst$kw$db_SLASH_invalid_DASH_query], null));
}
})();
var vars__$1 = cljs.core.set(vars);
var all_vars = cljs.core.set(cljs.core.concat.cljs$core$IFn$_invoke$arity$2(vars__$1,cljs.core.keys(interim_vars)));
return cljs.core.map.cljs$core$IFn$_invoke$arity$2(((function (_,vars__$1,all_vars){
return (function (select){
var var_symbol = ((cljs.core.map_QMARK_(select))?null:cljs.core.symbol.cljs$core$IFn$_invoke$arity$1(select));
if(cljs.core.truth_((vars__$1.cljs$core$IFn$_invoke$arity$1 ? vars__$1.cljs$core$IFn$_invoke$arity$1(var_symbol) : vars__$1.call(null,var_symbol)))){
return new cljs.core.PersistentArrayMap(null, 1, [cljs.core.cst$kw$variable,var_symbol], null);
} else {
if(cljs.core.truth_(fluree.db.query.analytical.aggregate_QMARK_(select))){
return fluree.db.query.analytical.parse_aggregate(select,vars__$1);
} else {
if(cljs.core.map_QMARK_(select)){
return fluree.db.query.fql.parse_map(select,all_vars);
} else {
if(cljs.core.truth_(cljs.core.get.cljs$core$IFn$_invoke$arity$2(interim_vars,var_symbol))){
return new cljs.core.PersistentArrayMap(null, 1, [cljs.core.cst$kw$value,cljs.core.get.cljs$core$IFn$_invoke$arity$2(interim_vars,var_symbol)], null);
} else {
throw cljs.core.ex_info.cljs$core$IFn$_invoke$arity$2(["Invalid select in statement, provided: ",cljs.core.str.cljs$core$IFn$_invoke$arity$1(select)].join(''),new cljs.core.PersistentArrayMap(null, 2, [cljs.core.cst$kw$status,(400),cljs.core.cst$kw$error,cljs.core.cst$kw$db_SLASH_invalid_DASH_query], null));

}
}
}
}
});})(_,vars__$1,all_vars))
,select_smt);
});
fluree.db.query.fql.get_pretty_print_keys = (function fluree$db$query$fql$get_pretty_print_keys(select){
var vars = cljs.core.map.cljs$core$IFn$_invoke$arity$2((function (select__$1){
if(cljs.core.truth_(cljs.core.cst$kw$as.cljs$core$IFn$_invoke$arity$1(select__$1))){
return cljs.core.subs.cljs$core$IFn$_invoke$arity$2(cljs.core.str.cljs$core$IFn$_invoke$arity$1(cljs.core.cst$kw$as.cljs$core$IFn$_invoke$arity$1(select__$1)),(1));
} else {
if(cljs.core.truth_(cljs.core.cst$kw$code.cljs$core$IFn$_invoke$arity$1(select__$1))){
return cljs.core.str.cljs$core$IFn$_invoke$arity$1(cljs.core.cst$kw$code.cljs$core$IFn$_invoke$arity$1(select__$1));
} else {
if(cljs.core.truth_(cljs.core.cst$kw$variable.cljs$core$IFn$_invoke$arity$1(select__$1))){
return cljs.core.subs.cljs$core$IFn$_invoke$arity$2(cljs.core.str.cljs$core$IFn$_invoke$arity$1(cljs.core.cst$kw$variable.cljs$core$IFn$_invoke$arity$1(select__$1)),(1));
} else {
return null;
}
}
}
}),select);
var freqs = cljs.core.frequencies(vars);
if(cljs.core.every_QMARK_(((function (vars,freqs){
return (function (p1__113161_SHARP_){
return cljs.core._EQ_.cljs$core$IFn$_invoke$arity$2((1),p1__113161_SHARP_);
});})(vars,freqs))
,cljs.core.vals(freqs))){
return vars;
} else {
var G__113165 = vars;
var vec__113166 = G__113165;
var seq__113167 = cljs.core.seq(vec__113166);
var first__113168 = cljs.core.first(seq__113167);
var seq__113167__$1 = cljs.core.next(seq__113167);
var var$ = first__113168;
var r = seq__113167__$1;
var all_vars = cljs.core.PersistentVector.EMPTY;
var G__113165__$1 = G__113165;
var all_vars__$1 = all_vars;
while(true){
var vec__113173 = G__113165__$1;
var seq__113174 = cljs.core.seq(vec__113173);
var first__113175 = cljs.core.first(seq__113174);
var seq__113174__$1 = cljs.core.next(seq__113174);
var var$__$1 = first__113175;
var r__$1 = seq__113174__$1;
var all_vars__$2 = all_vars__$1;
if(cljs.core.not(var$__$1)){
return all_vars__$2;
} else {
if(cljs.core.truth_((function (){var fexpr__113176 = cljs.core.set(all_vars__$2);
return (fexpr__113176.cljs$core$IFn$_invoke$arity$1 ? fexpr__113176.cljs$core$IFn$_invoke$arity$1(var$__$1) : fexpr__113176.call(null,var$__$1));
})())){
var G__113177 = r__$1;
var G__113178 = cljs.core.conj.cljs$core$IFn$_invoke$arity$2(all_vars__$2,[cljs.core.str.cljs$core$IFn$_invoke$arity$1(var$__$1),"$",cljs.core.str.cljs$core$IFn$_invoke$arity$1(cljs.core.count(all_vars__$2))].join(''));
G__113165__$1 = G__113177;
all_vars__$1 = G__113178;
continue;
} else {
var G__113179 = r__$1;
var G__113180 = cljs.core.conj.cljs$core$IFn$_invoke$arity$2(all_vars__$2,var$__$1);
G__113165__$1 = G__113179;
all_vars__$1 = G__113180;
continue;

}
}
break;
}
}
});
fluree.db.query.fql.format_tuple = (function fluree$db$query$fql$format_tuple(functionArray,tuple){
var c__99809__auto__ = cljs.core.async.chan.cljs$core$IFn$_invoke$arity$1((1));
cljs.core.async.impl.dispatch.run(((function (c__99809__auto__){
return (function (){
var f__99810__auto__ = (function (){var switch__99702__auto__ = ((function (c__99809__auto__){
return (function (state_113214){
var state_val_113215 = (state_113214[(1)]);
if((state_val_113215 === (1))){
var inst_113188 = cljs.core.seq(functionArray);
var inst_113189 = cljs.core.first(inst_113188);
var inst_113190 = cljs.core.next(inst_113188);
var inst_113191 = cljs.core.PersistentVector.EMPTY;
var inst_113192 = functionArray;
var inst_113193 = inst_113191;
var state_113214__$1 = (function (){var statearr_113216 = state_113214;
(statearr_113216[(7)] = inst_113192);

(statearr_113216[(8)] = inst_113193);

(statearr_113216[(9)] = inst_113190);

(statearr_113216[(10)] = inst_113189);

return statearr_113216;
})();
var statearr_113217_113229 = state_113214__$1;
(statearr_113217_113229[(2)] = null);

(statearr_113217_113229[(1)] = (2));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113215 === (2))){
var inst_113199 = (state_113214[(11)]);
var inst_113192 = (state_113214[(7)]);
var inst_113198 = cljs.core.seq(inst_113192);
var inst_113199__$1 = cljs.core.first(inst_113198);
var inst_113200 = cljs.core.next(inst_113198);
var state_113214__$1 = (function (){var statearr_113218 = state_113214;
(statearr_113218[(11)] = inst_113199__$1);

(statearr_113218[(12)] = inst_113200);

return statearr_113218;
})();
if(cljs.core.truth_(inst_113199__$1)){
var statearr_113219_113230 = state_113214__$1;
(statearr_113219_113230[(1)] = (4));

} else {
var statearr_113220_113231 = state_113214__$1;
(statearr_113220_113231[(1)] = (5));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_113215 === (3))){
var inst_113212 = (state_113214[(2)]);
var state_113214__$1 = state_113214;
return cljs.core.async.impl.ioc_helpers.return_chan(state_113214__$1,inst_113212);
} else {
if((state_val_113215 === (4))){
var inst_113199 = (state_113214[(11)]);
var inst_113202 = (inst_113199.cljs$core$IFn$_invoke$arity$1 ? inst_113199.cljs$core$IFn$_invoke$arity$1(tuple) : inst_113199.call(null,tuple));
var state_113214__$1 = state_113214;
return cljs.core.async.impl.ioc_helpers.take_BANG_(state_113214__$1,(7),inst_113202);
} else {
if((state_val_113215 === (5))){
var inst_113193 = (state_113214[(8)]);
var state_113214__$1 = state_113214;
var statearr_113221_113232 = state_113214__$1;
(statearr_113221_113232[(2)] = inst_113193);

(statearr_113221_113232[(1)] = (6));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113215 === (6))){
var inst_113210 = (state_113214[(2)]);
var state_113214__$1 = state_113214;
var statearr_113222_113233 = state_113214__$1;
(statearr_113222_113233[(2)] = inst_113210);

(statearr_113222_113233[(1)] = (3));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113215 === (7))){
var inst_113200 = (state_113214[(12)]);
var inst_113193 = (state_113214[(8)]);
var inst_113204 = (state_113214[(2)]);
var inst_113205 = fluree.db.util.async.throw_err(inst_113204);
var inst_113206 = cljs.core.conj.cljs$core$IFn$_invoke$arity$2(inst_113193,inst_113205);
var inst_113192 = inst_113200;
var inst_113193__$1 = inst_113206;
var state_113214__$1 = (function (){var statearr_113223 = state_113214;
(statearr_113223[(7)] = inst_113192);

(statearr_113223[(8)] = inst_113193__$1);

return statearr_113223;
})();
var statearr_113224_113234 = state_113214__$1;
(statearr_113224_113234[(2)] = null);

(statearr_113224_113234[(1)] = (2));


return cljs.core.cst$kw$recur;
} else {
return null;
}
}
}
}
}
}
}
});})(c__99809__auto__))
;
return ((function (switch__99702__auto__,c__99809__auto__){
return (function() {
var fluree$db$query$fql$format_tuple_$_state_machine__99703__auto__ = null;
var fluree$db$query$fql$format_tuple_$_state_machine__99703__auto____0 = (function (){
var statearr_113225 = [null,null,null,null,null,null,null,null,null,null,null,null,null];
(statearr_113225[(0)] = fluree$db$query$fql$format_tuple_$_state_machine__99703__auto__);

(statearr_113225[(1)] = (1));

return statearr_113225;
});
var fluree$db$query$fql$format_tuple_$_state_machine__99703__auto____1 = (function (state_113214){
while(true){
var ret_value__99704__auto__ = (function (){try{while(true){
var result__99705__auto__ = switch__99702__auto__(state_113214);
if(cljs.core.keyword_identical_QMARK_(result__99705__auto__,cljs.core.cst$kw$recur)){
continue;
} else {
return result__99705__auto__;
}
break;
}
}catch (e113226){if((e113226 instanceof Object)){
var ex__99706__auto__ = e113226;
var statearr_113227_113235 = state_113214;
(statearr_113227_113235[(5)] = ex__99706__auto__);


cljs.core.async.impl.ioc_helpers.process_exception(state_113214);

return cljs.core.cst$kw$recur;
} else {
throw e113226;

}
}})();
if(cljs.core.keyword_identical_QMARK_(ret_value__99704__auto__,cljs.core.cst$kw$recur)){
var G__113236 = state_113214;
state_113214 = G__113236;
continue;
} else {
return ret_value__99704__auto__;
}
break;
}
});
fluree$db$query$fql$format_tuple_$_state_machine__99703__auto__ = function(state_113214){
switch(arguments.length){
case 0:
return fluree$db$query$fql$format_tuple_$_state_machine__99703__auto____0.call(this);
case 1:
return fluree$db$query$fql$format_tuple_$_state_machine__99703__auto____1.call(this,state_113214);
}
throw(new Error('Invalid arity: ' + arguments.length));
};
fluree$db$query$fql$format_tuple_$_state_machine__99703__auto__.cljs$core$IFn$_invoke$arity$0 = fluree$db$query$fql$format_tuple_$_state_machine__99703__auto____0;
fluree$db$query$fql$format_tuple_$_state_machine__99703__auto__.cljs$core$IFn$_invoke$arity$1 = fluree$db$query$fql$format_tuple_$_state_machine__99703__auto____1;
return fluree$db$query$fql$format_tuple_$_state_machine__99703__auto__;
})()
;})(switch__99702__auto__,c__99809__auto__))
})();
var state__99811__auto__ = (function (){var statearr_113228 = (f__99810__auto__.cljs$core$IFn$_invoke$arity$0 ? f__99810__auto__.cljs$core$IFn$_invoke$arity$0() : f__99810__auto__.call(null));
(statearr_113228[(6)] = c__99809__auto__);

return statearr_113228;
})();
return cljs.core.async.impl.ioc_helpers.run_state_machine_wrapped(state__99811__auto__);
});})(c__99809__auto__))
);

return c__99809__auto__;
});
fluree.db.query.fql.get_header_idx = (function fluree$db$query$fql$get_header_idx(headers,select){
if(cljs.core.truth_(cljs.core.cst$kw$as.cljs$core$IFn$_invoke$arity$1(select))){
return fluree.db.util.core.index_of(headers,cljs.core.cst$kw$as.cljs$core$IFn$_invoke$arity$1(select));
} else {
if(cljs.core.truth_(cljs.core.cst$kw$code.cljs$core$IFn$_invoke$arity$1(select))){
return fluree.db.util.core.index_of(cljs.core.map.cljs$core$IFn$_invoke$arity$2(cljs.core.str,headers),cljs.core.str.cljs$core$IFn$_invoke$arity$1(cljs.core.cst$kw$code.cljs$core$IFn$_invoke$arity$1(select)));
} else {
if(cljs.core.truth_(cljs.core.cst$kw$variable.cljs$core$IFn$_invoke$arity$1(select))){
return fluree.db.util.core.index_of(headers,cljs.core.cst$kw$variable.cljs$core$IFn$_invoke$arity$1(select));
} else {
return null;
}
}
}
});
fluree.db.query.fql.format_filter_tuples = (function fluree$db$query$fql$format_filter_tuples(db,tuples,p__113238,headers,vars,opts){
var map__113239 = p__113238;
var map__113239__$1 = (((((!((map__113239 == null))))?(((((map__113239.cljs$lang$protocol_mask$partition0$ & (64))) || ((cljs.core.PROTOCOL_SENTINEL === map__113239.cljs$core$ISeq$))))?true:false):false))?cljs.core.apply.cljs$core$IFn$_invoke$arity$2(cljs.core.hash_map,map__113239):map__113239);
var select_spec = map__113239__$1;
var prettyPrint = cljs.core.get.cljs$core$IFn$_invoke$arity$2(map__113239__$1,cljs.core.cst$kw$prettyPrint);
var select = cljs.core.get.cljs$core$IFn$_invoke$arity$2(map__113239__$1,cljs.core.cst$kw$select);
var inVector_QMARK_ = cljs.core.get.cljs$core$IFn$_invoke$arity$2(map__113239__$1,cljs.core.cst$kw$inVector_QMARK_);
var expandMaps_QMARK_ = cljs.core.get.cljs$core$IFn$_invoke$arity$2(map__113239__$1,cljs.core.cst$kw$expandMaps_QMARK_);
var c__99809__auto__ = cljs.core.async.chan.cljs$core$IFn$_invoke$arity$1((1));
cljs.core.async.impl.dispatch.run(((function (c__99809__auto__,map__113239,map__113239__$1,select_spec,prettyPrint,select,inVector_QMARK_,expandMaps_QMARK_){
return (function (){
var f__99810__auto__ = (function (){var switch__99702__auto__ = ((function (c__99809__auto__,map__113239,map__113239__$1,select_spec,prettyPrint,select,inVector_QMARK_,expandMaps_QMARK_){
return (function (state_113322){
var state_val_113323 = (state_113322[(1)]);
if((state_val_113323 === (7))){
var inst_113249 = (state_113322[(2)]);
var state_113322__$1 = (function (){var statearr_113324 = state_113322;
(statearr_113324[(7)] = inst_113249);

return statearr_113324;
})();
if(cljs.core.truth_(expandMaps_QMARK_)){
var statearr_113325_113439 = state_113322__$1;
(statearr_113325_113439[(1)] = (8));

} else {
var statearr_113326_113440 = state_113322__$1;
(statearr_113326_113440[(1)] = (9));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_113323 === (1))){
var state_113322__$1 = state_113322;
var statearr_113327_113441 = state_113322__$1;
(statearr_113327_113441[(2)] = null);

(statearr_113327_113441[(1)] = (4));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113323 === (4))){
var _ = cljs.core.async.impl.ioc_helpers.add_exception_frame(state_113322,(3),Error,null,(2));
var state_113322__$1 = state_113322;
if(cljs.core.truth_(prettyPrint)){
var statearr_113328_113442 = state_113322__$1;
(statearr_113328_113442[(1)] = (5));

} else {
var statearr_113329_113443 = state_113322__$1;
(statearr_113329_113443[(1)] = (6));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_113323 === (13))){
var inst_113318 = (state_113322[(2)]);
var state_113322__$1 = state_113322;
var statearr_113330_113444 = state_113322__$1;
(statearr_113330_113444[(2)] = inst_113318);


cljs.core.async.impl.ioc_helpers.process_exception(state_113322__$1);

return cljs.core.cst$kw$recur;
} else {
if((state_val_113323 === (6))){
var state_113322__$1 = state_113322;
var statearr_113331_113445 = state_113322__$1;
(statearr_113331_113445[(2)] = null);

(statearr_113331_113445[(1)] = (7));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113323 === (3))){
var inst_113241 = (state_113322[(2)]);
var state_113322__$1 = state_113322;
var statearr_113332_113446 = state_113322__$1;
(statearr_113332_113446[(2)] = inst_113241);


cljs.core.async.impl.ioc_helpers.process_exception(state_113322__$1);

return cljs.core.cst$kw$recur;
} else {
if((state_val_113323 === (12))){
var inst_113257 = (state_113322[(8)]);
var inst_113249 = (state_113322[(7)]);
var inst_113315 = (function (){var pp = inst_113249;
var functionArray = inst_113257;
return ((function (pp,functionArray,inst_113257,inst_113249,state_val_113323,c__99809__auto__,map__113239,map__113239__$1,select_spec,prettyPrint,select,inVector_QMARK_,expandMaps_QMARK_){
return (function (tuple){
var tuple_res = cljs.core.map.cljs$core$IFn$_invoke$arity$2(((function (pp,functionArray,inst_113257,inst_113249,state_val_113323,c__99809__auto__,map__113239,map__113239__$1,select_spec,prettyPrint,select,inVector_QMARK_,expandMaps_QMARK_){
return (function (p1__113237_SHARP_){
return (p1__113237_SHARP_.cljs$core$IFn$_invoke$arity$1 ? p1__113237_SHARP_.cljs$core$IFn$_invoke$arity$1(tuple) : p1__113237_SHARP_.call(null,tuple));
});})(pp,functionArray,inst_113257,inst_113249,state_val_113323,c__99809__auto__,map__113239,map__113239__$1,select_spec,prettyPrint,select,inVector_QMARK_,expandMaps_QMARK_))
,functionArray);
if(cljs.core.truth_(pp)){
return cljs.core.zipmap(pp,tuple_res);
} else {
if(cljs.core.truth_(inVector_QMARK_)){
return tuple_res;
} else {
return cljs.core.first(tuple_res);

}
}
});
;})(pp,functionArray,inst_113257,inst_113249,state_val_113323,c__99809__auto__,map__113239,map__113239__$1,select_spec,prettyPrint,select,inVector_QMARK_,expandMaps_QMARK_))
})();
var inst_113316 = cljs.core.map.cljs$core$IFn$_invoke$arity$2(inst_113315,tuples);
var state_113322__$1 = state_113322;
var statearr_113333_113447 = state_113322__$1;
(statearr_113333_113447[(2)] = inst_113316);

(statearr_113333_113447[(1)] = (13));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113323 === (2))){
var inst_113320 = (state_113322[(2)]);
var state_113322__$1 = state_113322;
return cljs.core.async.impl.ioc_helpers.return_chan(state_113322__$1,inst_113320);
} else {
if((state_val_113323 === (11))){
var inst_113257 = (state_113322[(8)]);
var inst_113249 = (state_113322[(7)]);
var inst_113308 = cljs.core.async.chan.cljs$core$IFn$_invoke$arity$1((1));
var inst_113309 = (function (){var pp = inst_113249;
var functionArray = inst_113257;
var c__99809__auto____$1 = inst_113308;
return ((function (pp,functionArray,c__99809__auto____$1,inst_113257,inst_113249,inst_113308,state_val_113323,c__99809__auto__,map__113239,map__113239__$1,select_spec,prettyPrint,select,inVector_QMARK_,expandMaps_QMARK_){
return (function (){
var f__99810__auto__ = (function (){var switch__99702__auto__ = ((function (pp,functionArray,c__99809__auto____$1,inst_113257,inst_113249,inst_113308,state_val_113323,c__99809__auto__,map__113239,map__113239__$1,select_spec,prettyPrint,select,inVector_QMARK_,expandMaps_QMARK_){
return (function (state_113306){
var state_val_113307 = (state_113306[(1)]);
if((state_val_113307 === (7))){
var inst_113282 = (state_113306[(2)]);
var inst_113283 = fluree.db.util.async.throw_err(inst_113282);
var state_113306__$1 = (function (){var statearr_113334 = state_113306;
(statearr_113334[(7)] = inst_113283);

return statearr_113334;
})();
if(cljs.core.truth_(pp)){
var statearr_113335_113448 = state_113306__$1;
(statearr_113335_113448[(1)] = (8));

} else {
var statearr_113336_113449 = state_113306__$1;
(statearr_113336_113449[(1)] = (9));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_113307 === (1))){
var inst_113266 = cljs.core.seq(tuples);
var inst_113267 = cljs.core.first(inst_113266);
var inst_113268 = cljs.core.next(inst_113266);
var inst_113269 = cljs.core.PersistentVector.EMPTY;
var inst_113270 = tuples;
var inst_113271 = inst_113269;
var state_113306__$1 = (function (){var statearr_113337 = state_113306;
(statearr_113337[(8)] = inst_113270);

(statearr_113337[(9)] = inst_113267);

(statearr_113337[(10)] = inst_113271);

(statearr_113337[(11)] = inst_113268);

return statearr_113337;
})();
var statearr_113338_113450 = state_113306__$1;
(statearr_113338_113450[(2)] = null);

(statearr_113338_113450[(1)] = (2));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113307 === (4))){
var inst_113277 = (state_113306[(12)]);
var inst_113280 = fluree.db.query.fql.format_tuple(functionArray,inst_113277);
var state_113306__$1 = state_113306;
return cljs.core.async.impl.ioc_helpers.take_BANG_(state_113306__$1,(7),inst_113280);
} else {
if((state_val_113307 === (15))){
var state_113306__$1 = state_113306;
var statearr_113339_113451 = state_113306__$1;
(statearr_113339_113451[(2)] = null);

(statearr_113339_113451[(1)] = (16));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113307 === (13))){
var inst_113295 = (state_113306[(2)]);
var state_113306__$1 = state_113306;
var statearr_113340_113452 = state_113306__$1;
(statearr_113340_113452[(2)] = inst_113295);

(statearr_113340_113452[(1)] = (10));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113307 === (6))){
var inst_113302 = (state_113306[(2)]);
var state_113306__$1 = state_113306;
var statearr_113341_113453 = state_113306__$1;
(statearr_113341_113453[(2)] = inst_113302);

(statearr_113341_113453[(1)] = (3));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113307 === (3))){
var inst_113304 = (state_113306[(2)]);
var state_113306__$1 = state_113306;
return cljs.core.async.impl.ioc_helpers.return_chan(state_113306__$1,inst_113304);
} else {
if((state_val_113307 === (12))){
var state_113306__$1 = state_113306;
var statearr_113342_113454 = state_113306__$1;
(statearr_113342_113454[(1)] = (14));



return cljs.core.cst$kw$recur;
} else {
if((state_val_113307 === (2))){
var inst_113270 = (state_113306[(8)]);
var inst_113277 = (state_113306[(12)]);
var inst_113276 = cljs.core.seq(inst_113270);
var inst_113277__$1 = cljs.core.first(inst_113276);
var inst_113278 = cljs.core.next(inst_113276);
var state_113306__$1 = (function (){var statearr_113344 = state_113306;
(statearr_113344[(12)] = inst_113277__$1);

(statearr_113344[(13)] = inst_113278);

return statearr_113344;
})();
if(cljs.core.truth_(inst_113277__$1)){
var statearr_113345_113455 = state_113306__$1;
(statearr_113345_113455[(1)] = (4));

} else {
var statearr_113346_113456 = state_113306__$1;
(statearr_113346_113456[(1)] = (5));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_113307 === (11))){
var inst_113283 = (state_113306[(7)]);
var state_113306__$1 = state_113306;
var statearr_113347_113457 = state_113306__$1;
(statearr_113347_113457[(2)] = inst_113283);

(statearr_113347_113457[(1)] = (13));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113307 === (9))){
var state_113306__$1 = state_113306;
if(cljs.core.truth_(inVector_QMARK_)){
var statearr_113348_113458 = state_113306__$1;
(statearr_113348_113458[(1)] = (11));

} else {
var statearr_113349_113459 = state_113306__$1;
(statearr_113349_113459[(1)] = (12));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_113307 === (5))){
var inst_113271 = (state_113306[(10)]);
var state_113306__$1 = state_113306;
var statearr_113350_113460 = state_113306__$1;
(statearr_113350_113460[(2)] = inst_113271);

(statearr_113350_113460[(1)] = (6));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113307 === (14))){
var inst_113283 = (state_113306[(7)]);
var inst_113290 = cljs.core.first(inst_113283);
var state_113306__$1 = state_113306;
var statearr_113351_113461 = state_113306__$1;
(statearr_113351_113461[(2)] = inst_113290);

(statearr_113351_113461[(1)] = (16));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113307 === (16))){
var inst_113293 = (state_113306[(2)]);
var state_113306__$1 = state_113306;
var statearr_113352_113462 = state_113306__$1;
(statearr_113352_113462[(2)] = inst_113293);

(statearr_113352_113462[(1)] = (13));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113307 === (10))){
var inst_113271 = (state_113306[(10)]);
var inst_113278 = (state_113306[(13)]);
var inst_113297 = (state_113306[(2)]);
var inst_113298 = cljs.core.conj.cljs$core$IFn$_invoke$arity$2(inst_113271,inst_113297);
var inst_113270 = inst_113278;
var inst_113271__$1 = inst_113298;
var state_113306__$1 = (function (){var statearr_113353 = state_113306;
(statearr_113353[(8)] = inst_113270);

(statearr_113353[(10)] = inst_113271__$1);

return statearr_113353;
})();
var statearr_113354_113463 = state_113306__$1;
(statearr_113354_113463[(2)] = null);

(statearr_113354_113463[(1)] = (2));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113307 === (8))){
var inst_113283 = (state_113306[(7)]);
var inst_113285 = cljs.core.zipmap(pp,inst_113283);
var state_113306__$1 = state_113306;
var statearr_113355_113464 = state_113306__$1;
(statearr_113355_113464[(2)] = inst_113285);

(statearr_113355_113464[(1)] = (10));


return cljs.core.cst$kw$recur;
} else {
return null;
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
});})(pp,functionArray,c__99809__auto____$1,inst_113257,inst_113249,inst_113308,state_val_113323,c__99809__auto__,map__113239,map__113239__$1,select_spec,prettyPrint,select,inVector_QMARK_,expandMaps_QMARK_))
;
return ((function (switch__99702__auto__,pp,functionArray,c__99809__auto____$1,inst_113257,inst_113249,inst_113308,state_val_113323,c__99809__auto__,map__113239,map__113239__$1,select_spec,prettyPrint,select,inVector_QMARK_,expandMaps_QMARK_){
return (function() {
var fluree$db$query$fql$format_filter_tuples_$_state_machine__99703__auto__ = null;
var fluree$db$query$fql$format_filter_tuples_$_state_machine__99703__auto____0 = (function (){
var statearr_113356 = [null,null,null,null,null,null,null,null,null,null,null,null,null,null];
(statearr_113356[(0)] = fluree$db$query$fql$format_filter_tuples_$_state_machine__99703__auto__);

(statearr_113356[(1)] = (1));

return statearr_113356;
});
var fluree$db$query$fql$format_filter_tuples_$_state_machine__99703__auto____1 = (function (state_113306){
while(true){
var ret_value__99704__auto__ = (function (){try{while(true){
var result__99705__auto__ = switch__99702__auto__(state_113306);
if(cljs.core.keyword_identical_QMARK_(result__99705__auto__,cljs.core.cst$kw$recur)){
continue;
} else {
return result__99705__auto__;
}
break;
}
}catch (e113357){if((e113357 instanceof Object)){
var ex__99706__auto__ = e113357;
var statearr_113358_113465 = state_113306;
(statearr_113358_113465[(5)] = ex__99706__auto__);


cljs.core.async.impl.ioc_helpers.process_exception(state_113306);

return cljs.core.cst$kw$recur;
} else {
throw e113357;

}
}})();
if(cljs.core.keyword_identical_QMARK_(ret_value__99704__auto__,cljs.core.cst$kw$recur)){
var G__113466 = state_113306;
state_113306 = G__113466;
continue;
} else {
return ret_value__99704__auto__;
}
break;
}
});
fluree$db$query$fql$format_filter_tuples_$_state_machine__99703__auto__ = function(state_113306){
switch(arguments.length){
case 0:
return fluree$db$query$fql$format_filter_tuples_$_state_machine__99703__auto____0.call(this);
case 1:
return fluree$db$query$fql$format_filter_tuples_$_state_machine__99703__auto____1.call(this,state_113306);
}
throw(new Error('Invalid arity: ' + arguments.length));
};
fluree$db$query$fql$format_filter_tuples_$_state_machine__99703__auto__.cljs$core$IFn$_invoke$arity$0 = fluree$db$query$fql$format_filter_tuples_$_state_machine__99703__auto____0;
fluree$db$query$fql$format_filter_tuples_$_state_machine__99703__auto__.cljs$core$IFn$_invoke$arity$1 = fluree$db$query$fql$format_filter_tuples_$_state_machine__99703__auto____1;
return fluree$db$query$fql$format_filter_tuples_$_state_machine__99703__auto__;
})()
;})(switch__99702__auto__,pp,functionArray,c__99809__auto____$1,inst_113257,inst_113249,inst_113308,state_val_113323,c__99809__auto__,map__113239,map__113239__$1,select_spec,prettyPrint,select,inVector_QMARK_,expandMaps_QMARK_))
})();
var state__99811__auto__ = (function (){var statearr_113359 = (f__99810__auto__.cljs$core$IFn$_invoke$arity$0 ? f__99810__auto__.cljs$core$IFn$_invoke$arity$0() : f__99810__auto__.call(null));
(statearr_113359[(6)] = c__99809__auto____$1);

return statearr_113359;
})();
return cljs.core.async.impl.ioc_helpers.run_state_machine_wrapped(state__99811__auto__);
});
;})(pp,functionArray,c__99809__auto____$1,inst_113257,inst_113249,inst_113308,state_val_113323,c__99809__auto__,map__113239,map__113239__$1,select_spec,prettyPrint,select,inVector_QMARK_,expandMaps_QMARK_))
})();
var inst_113310 = cljs.core.async.impl.dispatch.run(inst_113309);
var state_113322__$1 = (function (){var statearr_113360 = state_113322;
(statearr_113360[(9)] = inst_113310);

return statearr_113360;
})();
return cljs.core.async.impl.ioc_helpers.take_BANG_(state_113322__$1,(14),inst_113308);
} else {
if((state_val_113323 === (9))){
var inst_113249 = (state_113322[(7)]);
var inst_113254 = (function (){var pp = inst_113249;
return ((function (pp,inst_113249,state_val_113323,c__99809__auto__,map__113239,map__113239__$1,select_spec,prettyPrint,select,inVector_QMARK_,expandMaps_QMARK_){
return (function (select__$1){
var temp__5733__auto__ = cljs.core.cst$kw$value.cljs$core$IFn$_invoke$arity$1(select__$1);
if(cljs.core.truth_(temp__5733__auto__)){
var val = temp__5733__auto__;
return ((function (val,temp__5733__auto__,pp,inst_113249,state_val_113323,c__99809__auto__,map__113239,map__113239__$1,select_spec,prettyPrint,select,inVector_QMARK_,expandMaps_QMARK_){
return (function (x){
return val;
});
;})(val,temp__5733__auto__,pp,inst_113249,state_val_113323,c__99809__auto__,map__113239,map__113239__$1,select_spec,prettyPrint,select,inVector_QMARK_,expandMaps_QMARK_))
} else {
var idx = fluree.db.query.fql.get_header_idx(headers,select__$1);
return ((function (idx,temp__5733__auto__,pp,inst_113249,state_val_113323,c__99809__auto__,map__113239,map__113239__$1,select_spec,prettyPrint,select,inVector_QMARK_,expandMaps_QMARK_){
return (function (tuple){
return cljs.core.nth.cljs$core$IFn$_invoke$arity$2(tuple,idx);
});
;})(idx,temp__5733__auto__,pp,inst_113249,state_val_113323,c__99809__auto__,map__113239,map__113239__$1,select_spec,prettyPrint,select,inVector_QMARK_,expandMaps_QMARK_))
}
});
;})(pp,inst_113249,state_val_113323,c__99809__auto__,map__113239,map__113239__$1,select_spec,prettyPrint,select,inVector_QMARK_,expandMaps_QMARK_))
})();
var inst_113255 = cljs.core.map.cljs$core$IFn$_invoke$arity$2(inst_113254,select);
var state_113322__$1 = state_113322;
var statearr_113361_113467 = state_113322__$1;
(statearr_113361_113467[(2)] = inst_113255);

(statearr_113361_113467[(1)] = (10));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113323 === (5))){
var inst_113246 = fluree.db.query.fql.get_pretty_print_keys(select);
var state_113322__$1 = state_113322;
var statearr_113362_113468 = state_113322__$1;
(statearr_113362_113468[(2)] = inst_113246);

(statearr_113362_113468[(1)] = (7));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113323 === (14))){
var inst_113312 = (state_113322[(2)]);
var inst_113313 = fluree.db.util.async.throw_err(inst_113312);
var state_113322__$1 = state_113322;
var statearr_113363_113469 = state_113322__$1;
(statearr_113363_113469[(2)] = inst_113313);

(statearr_113363_113469[(1)] = (13));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113323 === (10))){
var inst_113257 = (state_113322[(2)]);
var state_113322__$1 = (function (){var statearr_113364 = state_113322;
(statearr_113364[(8)] = inst_113257);

return statearr_113364;
})();
if(cljs.core.truth_(expandMaps_QMARK_)){
var statearr_113365_113470 = state_113322__$1;
(statearr_113365_113470[(1)] = (11));

} else {
var statearr_113366_113471 = state_113322__$1;
(statearr_113366_113471[(1)] = (12));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_113323 === (8))){
var inst_113249 = (state_113322[(7)]);
var inst_113251 = (function (){var pp = inst_113249;
return ((function (pp,inst_113249,state_val_113323,c__99809__auto__,map__113239,map__113239__$1,select_spec,prettyPrint,select,inVector_QMARK_,expandMaps_QMARK_){
return (function (select__$1){
var select_val = (function (){var or__4131__auto__ = cljs.core.cst$kw$as.cljs$core$IFn$_invoke$arity$1(select__$1);
if(cljs.core.truth_(or__4131__auto__)){
return or__4131__auto__;
} else {
return cljs.core.cst$kw$variable.cljs$core$IFn$_invoke$arity$1(select__$1);
}
})();
var idx = (cljs.core.truth_(select_val)?fluree.db.util.core.index_of(headers,select_val):null);
var select_fn = (cljs.core.truth_(idx)?((function (select_val,idx,pp,inst_113249,state_val_113323,c__99809__auto__,map__113239,map__113239__$1,select_spec,prettyPrint,select,inVector_QMARK_,expandMaps_QMARK_){
return (function (tuple){
return cljs.core.nth.cljs$core$IFn$_invoke$arity$2(tuple,idx);
});})(select_val,idx,pp,inst_113249,state_val_113323,c__99809__auto__,map__113239,map__113239__$1,select_spec,prettyPrint,select,inVector_QMARK_,expandMaps_QMARK_))
:(cljs.core.truth_(cljs.core.cst$kw$value.cljs$core$IFn$_invoke$arity$1(select__$1))?((function (select_val,idx,pp,inst_113249,state_val_113323,c__99809__auto__,map__113239,map__113239__$1,select_spec,prettyPrint,select,inVector_QMARK_,expandMaps_QMARK_){
return (function (tuple){
return cljs.core.cst$kw$value.cljs$core$IFn$_invoke$arity$1(select__$1);
});})(select_val,idx,pp,inst_113249,state_val_113323,c__99809__auto__,map__113239,map__113239__$1,select_spec,prettyPrint,select,inVector_QMARK_,expandMaps_QMARK_))
:(cljs.core.truth_(cljs.core.get.cljs$core$IFn$_invoke$arity$2(vars,select_val))?((function (select_val,idx,pp,inst_113249,state_val_113323,c__99809__auto__,map__113239,map__113239__$1,select_spec,prettyPrint,select,inVector_QMARK_,expandMaps_QMARK_){
return (function (tuple){
return cljs.core.get.cljs$core$IFn$_invoke$arity$2(vars,select_val);
});})(select_val,idx,pp,inst_113249,state_val_113323,c__99809__auto__,map__113239,map__113239__$1,select_spec,prettyPrint,select,inVector_QMARK_,expandMaps_QMARK_))
:null)));
if(cljs.core.truth_(cljs.core.cst$kw$selection.cljs$core$IFn$_invoke$arity$1(select__$1))){
return ((function (select_val,idx,select_fn,pp,inst_113249,state_val_113323,c__99809__auto__,map__113239,map__113239__$1,select_spec,prettyPrint,select,inVector_QMARK_,expandMaps_QMARK_){
return (function (tuple){
var c__99809__auto____$1 = cljs.core.async.chan.cljs$core$IFn$_invoke$arity$1((1));
cljs.core.async.impl.dispatch.run(((function (c__99809__auto____$1,select_val,idx,select_fn,pp,inst_113249,state_val_113323,c__99809__auto__,map__113239,map__113239__$1,select_spec,prettyPrint,select,inVector_QMARK_,expandMaps_QMARK_){
return (function (){
var f__99810__auto__ = (function (){var switch__99702__auto__ = ((function (c__99809__auto____$1,select_val,idx,select_fn,pp,inst_113249,state_val_113323,c__99809__auto__,map__113239,map__113239__$1,select_spec,prettyPrint,select,inVector_QMARK_,expandMaps_QMARK_){
return (function (state_113399){
var state_val_113400 = (state_113399[(1)]);
if((state_val_113400 === (7))){
var inst_113395 = (state_113399[(2)]);
var state_113399__$1 = state_113399;
var statearr_113401_113472 = state_113399__$1;
(statearr_113401_113472[(2)] = inst_113395);


cljs.core.async.impl.ioc_helpers.process_exception(state_113399__$1);

return cljs.core.cst$kw$recur;
} else {
if((state_val_113400 === (1))){
var state_113399__$1 = state_113399;
var statearr_113402_113473 = state_113399__$1;
(statearr_113402_113473[(2)] = null);

(statearr_113402_113473[(1)] = (4));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113400 === (4))){
var _ = cljs.core.async.impl.ioc_helpers.add_exception_frame(state_113399,(3),Error,null,(2));
var inst_113371 = (select_fn.cljs$core$IFn$_invoke$arity$1 ? select_fn.cljs$core$IFn$_invoke$arity$1(tuple) : select_fn.call(null,tuple));
var state_113399__$1 = state_113399;
if(cljs.core.truth_(inst_113371)){
var statearr_113403_113474 = state_113399__$1;
(statearr_113403_113474[(1)] = (5));

} else {
var statearr_113404_113475 = state_113399__$1;
(statearr_113404_113475[(1)] = (6));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_113400 === (6))){
var state_113399__$1 = state_113399;
var statearr_113405_113476 = state_113399__$1;
(statearr_113405_113476[(2)] = null);

(statearr_113405_113476[(1)] = (7));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113400 === (3))){
var inst_113367 = (state_113399[(2)]);
var state_113399__$1 = state_113399;
var statearr_113406_113477 = state_113399__$1;
(statearr_113406_113477[(2)] = inst_113367);


cljs.core.async.impl.ioc_helpers.process_exception(state_113399__$1);

return cljs.core.cst$kw$recur;
} else {
if((state_val_113400 === (2))){
var inst_113397 = (state_113399[(2)]);
var state_113399__$1 = state_113399;
return cljs.core.async.impl.ioc_helpers.return_chan(state_113399__$1,inst_113397);
} else {
if((state_val_113400 === (11))){
var inst_113392 = (state_113399[(2)]);
var state_113399__$1 = state_113399;
var statearr_113407_113478 = state_113399__$1;
(statearr_113407_113478[(2)] = inst_113392);

(statearr_113407_113478[(1)] = (7));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113400 === (9))){
var inst_113384 = (state_113399[(7)]);
var state_113399__$1 = state_113399;
var statearr_113408_113479 = state_113399__$1;
(statearr_113408_113479[(2)] = inst_113384);

(statearr_113408_113479[(1)] = (11));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113400 === (5))){
var inst_113376 = [cljs.core.cst$kw$selectOne,cljs.core.cst$kw$from];
var inst_113377 = cljs.core.cst$kw$selection.cljs$core$IFn$_invoke$arity$1(select__$1);
var inst_113378 = (select_fn.cljs$core$IFn$_invoke$arity$1 ? select_fn.cljs$core$IFn$_invoke$arity$1(tuple) : select_fn.call(null,tuple));
var inst_113379 = [inst_113377,inst_113378];
var inst_113380 = cljs.core.PersistentHashMap.fromArrays(inst_113376,inst_113379);
var inst_113381 = (fluree.db.query.fql.query.cljs$core$IFn$_invoke$arity$3 ? fluree.db.query.fql.query.cljs$core$IFn$_invoke$arity$3(db,inst_113380,opts) : fluree.db.query.fql.query.call(null,db,inst_113380,opts));
var state_113399__$1 = state_113399;
return cljs.core.async.impl.ioc_helpers.take_BANG_(state_113399__$1,(8),inst_113381);
} else {
if((state_val_113400 === (10))){
var inst_113387 = [cljs.core.cst$kw$_id];
var inst_113388 = (select_fn.cljs$core$IFn$_invoke$arity$1 ? select_fn.cljs$core$IFn$_invoke$arity$1(tuple) : select_fn.call(null,tuple));
var inst_113389 = [inst_113388];
var inst_113390 = cljs.core.PersistentHashMap.fromArrays(inst_113387,inst_113389);
var state_113399__$1 = state_113399;
var statearr_113409_113480 = state_113399__$1;
(statearr_113409_113480[(2)] = inst_113390);

(statearr_113409_113480[(1)] = (11));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113400 === (8))){
var inst_113384 = (state_113399[(7)]);
var inst_113383 = (state_113399[(2)]);
var inst_113384__$1 = fluree.db.util.async.throw_err(inst_113383);
var state_113399__$1 = (function (){var statearr_113410 = state_113399;
(statearr_113410[(7)] = inst_113384__$1);

return statearr_113410;
})();
if(cljs.core.truth_(inst_113384__$1)){
var statearr_113411_113481 = state_113399__$1;
(statearr_113411_113481[(1)] = (9));

} else {
var statearr_113412_113482 = state_113399__$1;
(statearr_113412_113482[(1)] = (10));

}

return cljs.core.cst$kw$recur;
} else {
return null;
}
}
}
}
}
}
}
}
}
}
}
});})(c__99809__auto____$1,select_val,idx,select_fn,pp,inst_113249,state_val_113323,c__99809__auto__,map__113239,map__113239__$1,select_spec,prettyPrint,select,inVector_QMARK_,expandMaps_QMARK_))
;
return ((function (switch__99702__auto__,c__99809__auto____$1,select_val,idx,select_fn,pp,inst_113249,state_val_113323,c__99809__auto__,map__113239,map__113239__$1,select_spec,prettyPrint,select,inVector_QMARK_,expandMaps_QMARK_){
return (function() {
var fluree$db$query$fql$format_filter_tuples_$_state_machine__99703__auto__ = null;
var fluree$db$query$fql$format_filter_tuples_$_state_machine__99703__auto____0 = (function (){
var statearr_113413 = [null,null,null,null,null,null,null,null];
(statearr_113413[(0)] = fluree$db$query$fql$format_filter_tuples_$_state_machine__99703__auto__);

(statearr_113413[(1)] = (1));

return statearr_113413;
});
var fluree$db$query$fql$format_filter_tuples_$_state_machine__99703__auto____1 = (function (state_113399){
while(true){
var ret_value__99704__auto__ = (function (){try{while(true){
var result__99705__auto__ = switch__99702__auto__(state_113399);
if(cljs.core.keyword_identical_QMARK_(result__99705__auto__,cljs.core.cst$kw$recur)){
continue;
} else {
return result__99705__auto__;
}
break;
}
}catch (e113414){if((e113414 instanceof Object)){
var ex__99706__auto__ = e113414;
var statearr_113415_113483 = state_113399;
(statearr_113415_113483[(5)] = ex__99706__auto__);


cljs.core.async.impl.ioc_helpers.process_exception(state_113399);

return cljs.core.cst$kw$recur;
} else {
throw e113414;

}
}})();
if(cljs.core.keyword_identical_QMARK_(ret_value__99704__auto__,cljs.core.cst$kw$recur)){
var G__113484 = state_113399;
state_113399 = G__113484;
continue;
} else {
return ret_value__99704__auto__;
}
break;
}
});
fluree$db$query$fql$format_filter_tuples_$_state_machine__99703__auto__ = function(state_113399){
switch(arguments.length){
case 0:
return fluree$db$query$fql$format_filter_tuples_$_state_machine__99703__auto____0.call(this);
case 1:
return fluree$db$query$fql$format_filter_tuples_$_state_machine__99703__auto____1.call(this,state_113399);
}
throw(new Error('Invalid arity: ' + arguments.length));
};
fluree$db$query$fql$format_filter_tuples_$_state_machine__99703__auto__.cljs$core$IFn$_invoke$arity$0 = fluree$db$query$fql$format_filter_tuples_$_state_machine__99703__auto____0;
fluree$db$query$fql$format_filter_tuples_$_state_machine__99703__auto__.cljs$core$IFn$_invoke$arity$1 = fluree$db$query$fql$format_filter_tuples_$_state_machine__99703__auto____1;
return fluree$db$query$fql$format_filter_tuples_$_state_machine__99703__auto__;
})()
;})(switch__99702__auto__,c__99809__auto____$1,select_val,idx,select_fn,pp,inst_113249,state_val_113323,c__99809__auto__,map__113239,map__113239__$1,select_spec,prettyPrint,select,inVector_QMARK_,expandMaps_QMARK_))
})();
var state__99811__auto__ = (function (){var statearr_113416 = (f__99810__auto__.cljs$core$IFn$_invoke$arity$0 ? f__99810__auto__.cljs$core$IFn$_invoke$arity$0() : f__99810__auto__.call(null));
(statearr_113416[(6)] = c__99809__auto____$1);

return statearr_113416;
})();
return cljs.core.async.impl.ioc_helpers.run_state_machine_wrapped(state__99811__auto__);
});})(c__99809__auto____$1,select_val,idx,select_fn,pp,inst_113249,state_val_113323,c__99809__auto__,map__113239,map__113239__$1,select_spec,prettyPrint,select,inVector_QMARK_,expandMaps_QMARK_))
);

return c__99809__auto____$1;
});
;})(select_val,idx,select_fn,pp,inst_113249,state_val_113323,c__99809__auto__,map__113239,map__113239__$1,select_spec,prettyPrint,select,inVector_QMARK_,expandMaps_QMARK_))
} else {
return ((function (select_val,idx,select_fn,pp,inst_113249,state_val_113323,c__99809__auto__,map__113239,map__113239__$1,select_spec,prettyPrint,select,inVector_QMARK_,expandMaps_QMARK_){
return (function (tuple){
var c__99809__auto____$1 = cljs.core.async.chan.cljs$core$IFn$_invoke$arity$1((1));
cljs.core.async.impl.dispatch.run(((function (c__99809__auto____$1,select_val,idx,select_fn,pp,inst_113249,state_val_113323,c__99809__auto__,map__113239,map__113239__$1,select_spec,prettyPrint,select,inVector_QMARK_,expandMaps_QMARK_){
return (function (){
var f__99810__auto__ = (function (){var switch__99702__auto__ = ((function (c__99809__auto____$1,select_val,idx,select_fn,pp,inst_113249,state_val_113323,c__99809__auto__,map__113239,map__113239__$1,select_spec,prettyPrint,select,inVector_QMARK_,expandMaps_QMARK_){
return (function (state_113425){
var state_val_113426 = (state_113425[(1)]);
if((state_val_113426 === (1))){
var state_113425__$1 = state_113425;
var statearr_113427_113485 = state_113425__$1;
(statearr_113427_113485[(2)] = null);

(statearr_113427_113485[(1)] = (4));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113426 === (2))){
var inst_113423 = (state_113425[(2)]);
var state_113425__$1 = state_113425;
return cljs.core.async.impl.ioc_helpers.return_chan(state_113425__$1,inst_113423);
} else {
if((state_val_113426 === (3))){
var inst_113417 = (state_113425[(2)]);
var state_113425__$1 = state_113425;
var statearr_113428_113486 = state_113425__$1;
(statearr_113428_113486[(2)] = inst_113417);


cljs.core.async.impl.ioc_helpers.process_exception(state_113425__$1);

return cljs.core.cst$kw$recur;
} else {
if((state_val_113426 === (4))){
var _ = cljs.core.async.impl.ioc_helpers.add_exception_frame(state_113425,(3),Error,null,(2));
var inst_113421 = (select_fn.cljs$core$IFn$_invoke$arity$1 ? select_fn.cljs$core$IFn$_invoke$arity$1(tuple) : select_fn.call(null,tuple));
var state_113425__$1 = state_113425;
var statearr_113429_113487 = state_113425__$1;
(statearr_113429_113487[(2)] = inst_113421);


cljs.core.async.impl.ioc_helpers.process_exception(state_113425__$1);

return cljs.core.cst$kw$recur;
} else {
return null;
}
}
}
}
});})(c__99809__auto____$1,select_val,idx,select_fn,pp,inst_113249,state_val_113323,c__99809__auto__,map__113239,map__113239__$1,select_spec,prettyPrint,select,inVector_QMARK_,expandMaps_QMARK_))
;
return ((function (switch__99702__auto__,c__99809__auto____$1,select_val,idx,select_fn,pp,inst_113249,state_val_113323,c__99809__auto__,map__113239,map__113239__$1,select_spec,prettyPrint,select,inVector_QMARK_,expandMaps_QMARK_){
return (function() {
var fluree$db$query$fql$format_filter_tuples_$_state_machine__99703__auto__ = null;
var fluree$db$query$fql$format_filter_tuples_$_state_machine__99703__auto____0 = (function (){
var statearr_113430 = [null,null,null,null,null,null,null];
(statearr_113430[(0)] = fluree$db$query$fql$format_filter_tuples_$_state_machine__99703__auto__);

(statearr_113430[(1)] = (1));

return statearr_113430;
});
var fluree$db$query$fql$format_filter_tuples_$_state_machine__99703__auto____1 = (function (state_113425){
while(true){
var ret_value__99704__auto__ = (function (){try{while(true){
var result__99705__auto__ = switch__99702__auto__(state_113425);
if(cljs.core.keyword_identical_QMARK_(result__99705__auto__,cljs.core.cst$kw$recur)){
continue;
} else {
return result__99705__auto__;
}
break;
}
}catch (e113431){if((e113431 instanceof Object)){
var ex__99706__auto__ = e113431;
var statearr_113432_113488 = state_113425;
(statearr_113432_113488[(5)] = ex__99706__auto__);


cljs.core.async.impl.ioc_helpers.process_exception(state_113425);

return cljs.core.cst$kw$recur;
} else {
throw e113431;

}
}})();
if(cljs.core.keyword_identical_QMARK_(ret_value__99704__auto__,cljs.core.cst$kw$recur)){
var G__113489 = state_113425;
state_113425 = G__113489;
continue;
} else {
return ret_value__99704__auto__;
}
break;
}
});
fluree$db$query$fql$format_filter_tuples_$_state_machine__99703__auto__ = function(state_113425){
switch(arguments.length){
case 0:
return fluree$db$query$fql$format_filter_tuples_$_state_machine__99703__auto____0.call(this);
case 1:
return fluree$db$query$fql$format_filter_tuples_$_state_machine__99703__auto____1.call(this,state_113425);
}
throw(new Error('Invalid arity: ' + arguments.length));
};
fluree$db$query$fql$format_filter_tuples_$_state_machine__99703__auto__.cljs$core$IFn$_invoke$arity$0 = fluree$db$query$fql$format_filter_tuples_$_state_machine__99703__auto____0;
fluree$db$query$fql$format_filter_tuples_$_state_machine__99703__auto__.cljs$core$IFn$_invoke$arity$1 = fluree$db$query$fql$format_filter_tuples_$_state_machine__99703__auto____1;
return fluree$db$query$fql$format_filter_tuples_$_state_machine__99703__auto__;
})()
;})(switch__99702__auto__,c__99809__auto____$1,select_val,idx,select_fn,pp,inst_113249,state_val_113323,c__99809__auto__,map__113239,map__113239__$1,select_spec,prettyPrint,select,inVector_QMARK_,expandMaps_QMARK_))
})();
var state__99811__auto__ = (function (){var statearr_113433 = (f__99810__auto__.cljs$core$IFn$_invoke$arity$0 ? f__99810__auto__.cljs$core$IFn$_invoke$arity$0() : f__99810__auto__.call(null));
(statearr_113433[(6)] = c__99809__auto____$1);

return statearr_113433;
})();
return cljs.core.async.impl.ioc_helpers.run_state_machine_wrapped(state__99811__auto__);
});})(c__99809__auto____$1,select_val,idx,select_fn,pp,inst_113249,state_val_113323,c__99809__auto__,map__113239,map__113239__$1,select_spec,prettyPrint,select,inVector_QMARK_,expandMaps_QMARK_))
);

return c__99809__auto____$1;
});
;})(select_val,idx,select_fn,pp,inst_113249,state_val_113323,c__99809__auto__,map__113239,map__113239__$1,select_spec,prettyPrint,select,inVector_QMARK_,expandMaps_QMARK_))
}
});
;})(pp,inst_113249,state_val_113323,c__99809__auto__,map__113239,map__113239__$1,select_spec,prettyPrint,select,inVector_QMARK_,expandMaps_QMARK_))
})();
var inst_113252 = cljs.core.map.cljs$core$IFn$_invoke$arity$2(inst_113251,select);
var state_113322__$1 = state_113322;
var statearr_113434_113490 = state_113322__$1;
(statearr_113434_113490[(2)] = inst_113252);

(statearr_113434_113490[(1)] = (10));


return cljs.core.cst$kw$recur;
} else {
return null;
}
}
}
}
}
}
}
}
}
}
}
}
}
}
});})(c__99809__auto__,map__113239,map__113239__$1,select_spec,prettyPrint,select,inVector_QMARK_,expandMaps_QMARK_))
;
return ((function (switch__99702__auto__,c__99809__auto__,map__113239,map__113239__$1,select_spec,prettyPrint,select,inVector_QMARK_,expandMaps_QMARK_){
return (function() {
var fluree$db$query$fql$format_filter_tuples_$_state_machine__99703__auto__ = null;
var fluree$db$query$fql$format_filter_tuples_$_state_machine__99703__auto____0 = (function (){
var statearr_113435 = [null,null,null,null,null,null,null,null,null,null];
(statearr_113435[(0)] = fluree$db$query$fql$format_filter_tuples_$_state_machine__99703__auto__);

(statearr_113435[(1)] = (1));

return statearr_113435;
});
var fluree$db$query$fql$format_filter_tuples_$_state_machine__99703__auto____1 = (function (state_113322){
while(true){
var ret_value__99704__auto__ = (function (){try{while(true){
var result__99705__auto__ = switch__99702__auto__(state_113322);
if(cljs.core.keyword_identical_QMARK_(result__99705__auto__,cljs.core.cst$kw$recur)){
continue;
} else {
return result__99705__auto__;
}
break;
}
}catch (e113436){if((e113436 instanceof Object)){
var ex__99706__auto__ = e113436;
var statearr_113437_113491 = state_113322;
(statearr_113437_113491[(5)] = ex__99706__auto__);


cljs.core.async.impl.ioc_helpers.process_exception(state_113322);

return cljs.core.cst$kw$recur;
} else {
throw e113436;

}
}})();
if(cljs.core.keyword_identical_QMARK_(ret_value__99704__auto__,cljs.core.cst$kw$recur)){
var G__113492 = state_113322;
state_113322 = G__113492;
continue;
} else {
return ret_value__99704__auto__;
}
break;
}
});
fluree$db$query$fql$format_filter_tuples_$_state_machine__99703__auto__ = function(state_113322){
switch(arguments.length){
case 0:
return fluree$db$query$fql$format_filter_tuples_$_state_machine__99703__auto____0.call(this);
case 1:
return fluree$db$query$fql$format_filter_tuples_$_state_machine__99703__auto____1.call(this,state_113322);
}
throw(new Error('Invalid arity: ' + arguments.length));
};
fluree$db$query$fql$format_filter_tuples_$_state_machine__99703__auto__.cljs$core$IFn$_invoke$arity$0 = fluree$db$query$fql$format_filter_tuples_$_state_machine__99703__auto____0;
fluree$db$query$fql$format_filter_tuples_$_state_machine__99703__auto__.cljs$core$IFn$_invoke$arity$1 = fluree$db$query$fql$format_filter_tuples_$_state_machine__99703__auto____1;
return fluree$db$query$fql$format_filter_tuples_$_state_machine__99703__auto__;
})()
;})(switch__99702__auto__,c__99809__auto__,map__113239,map__113239__$1,select_spec,prettyPrint,select,inVector_QMARK_,expandMaps_QMARK_))
})();
var state__99811__auto__ = (function (){var statearr_113438 = (f__99810__auto__.cljs$core$IFn$_invoke$arity$0 ? f__99810__auto__.cljs$core$IFn$_invoke$arity$0() : f__99810__auto__.call(null));
(statearr_113438[(6)] = c__99809__auto__);

return statearr_113438;
})();
return cljs.core.async.impl.ioc_helpers.run_state_machine_wrapped(state__99811__auto__);
});})(c__99809__auto__,map__113239,map__113239__$1,select_spec,prettyPrint,select,inVector_QMARK_,expandMaps_QMARK_))
);

return c__99809__auto__;
});
fluree.db.query.fql.process_ad_hoc_group = (function fluree$db$query$fql$process_ad_hoc_group(var_args){
var G__113494 = arguments.length;
switch (G__113494) {
case 4:
return fluree.db.query.fql.process_ad_hoc_group.cljs$core$IFn$_invoke$arity$4((arguments[(0)]),(arguments[(1)]),(arguments[(2)]),(arguments[(3)]));

break;
case 5:
return fluree.db.query.fql.process_ad_hoc_group.cljs$core$IFn$_invoke$arity$5((arguments[(0)]),(arguments[(1)]),(arguments[(2)]),(arguments[(3)]),(arguments[(4)]));

break;
default:
throw (new Error(["Invalid arity: ",cljs.core.str.cljs$core$IFn$_invoke$arity$1(arguments.length)].join('')));

}
});

fluree.db.query.fql.process_ad_hoc_group.cljs$core$IFn$_invoke$arity$4 = (function (db,res,select_spec,opts){
return fluree.db.query.fql.process_ad_hoc_group.cljs$core$IFn$_invoke$arity$5(db,res,select_spec,null,opts);
});

fluree.db.query.fql.process_ad_hoc_group.cljs$core$IFn$_invoke$arity$5 = (function (db,p__113495,p__113496,group_limit,opts){
var map__113497 = p__113495;
var map__113497__$1 = (((((!((map__113497 == null))))?(((((map__113497.cljs$lang$protocol_mask$partition0$ & (64))) || ((cljs.core.PROTOCOL_SENTINEL === map__113497.cljs$core$ISeq$))))?true:false):false))?cljs.core.apply.cljs$core$IFn$_invoke$arity$2(cljs.core.hash_map,map__113497):map__113497);
var res = map__113497__$1;
var vars = cljs.core.get.cljs$core$IFn$_invoke$arity$2(map__113497__$1,cljs.core.cst$kw$vars);
var map__113498 = p__113496;
var map__113498__$1 = (((((!((map__113498 == null))))?(((((map__113498.cljs$lang$protocol_mask$partition0$ & (64))) || ((cljs.core.PROTOCOL_SENTINEL === map__113498.cljs$core$ISeq$))))?true:false):false))?cljs.core.apply.cljs$core$IFn$_invoke$arity$2(cljs.core.hash_map,map__113498):map__113498);
var select_spec = map__113498__$1;
var inVector_QMARK_ = cljs.core.get.cljs$core$IFn$_invoke$arity$2(map__113498__$1,cljs.core.cst$kw$inVector_QMARK_);
var select = cljs.core.get.cljs$core$IFn$_invoke$arity$2(map__113498__$1,cljs.core.cst$kw$select);
var orderBy = cljs.core.get.cljs$core$IFn$_invoke$arity$2(map__113498__$1,cljs.core.cst$kw$orderBy);
var limit = cljs.core.get.cljs$core$IFn$_invoke$arity$2(map__113498__$1,cljs.core.cst$kw$limit);
var offset = cljs.core.get.cljs$core$IFn$_invoke$arity$2(map__113498__$1,cljs.core.cst$kw$offset);
var aggregates = cljs.core.get.cljs$core$IFn$_invoke$arity$2(map__113498__$1,cljs.core.cst$kw$aggregates);
var prettyPrint = cljs.core.get.cljs$core$IFn$_invoke$arity$2(map__113498__$1,cljs.core.cst$kw$prettyPrint);
var selectDistinct_QMARK_ = cljs.core.get.cljs$core$IFn$_invoke$arity$2(map__113498__$1,cljs.core.cst$kw$selectDistinct_QMARK_);
var groupBy = cljs.core.get.cljs$core$IFn$_invoke$arity$2(map__113498__$1,cljs.core.cst$kw$groupBy);
var c__99809__auto__ = cljs.core.async.chan.cljs$core$IFn$_invoke$arity$1((1));
cljs.core.async.impl.dispatch.run(((function (c__99809__auto__,map__113497,map__113497__$1,res,vars,map__113498,map__113498__$1,select_spec,inVector_QMARK_,select,orderBy,limit,offset,aggregates,prettyPrint,selectDistinct_QMARK_,groupBy){
return (function (){
var f__99810__auto__ = (function (){var switch__99702__auto__ = ((function (c__99809__auto__,map__113497,map__113497__$1,res,vars,map__113498,map__113498__$1,select_spec,inVector_QMARK_,select,orderBy,limit,offset,aggregates,prettyPrint,selectDistinct_QMARK_,groupBy){
return (function (state_113604){
var state_val_113605 = (state_113604[(1)]);
if((state_val_113605 === (7))){
var inst_113510 = (state_113604[(2)]);
var state_113604__$1 = state_113604;
if(cljs.core.truth_(inst_113510)){
var statearr_113606_113677 = state_113604__$1;
(statearr_113606_113677[(1)] = (8));

} else {
var statearr_113607_113678 = state_113604__$1;
(statearr_113607_113678[(1)] = (9));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_113605 === (20))){
var state_113604__$1 = state_113604;
var statearr_113608_113679 = state_113604__$1;
(statearr_113608_113679[(2)] = (0));

(statearr_113608_113679[(1)] = (22));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113605 === (27))){
var state_113604__$1 = state_113604;
var statearr_113609_113680 = state_113604__$1;
(statearr_113609_113680[(2)] = false);

(statearr_113609_113680[(1)] = (28));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113605 === (1))){
var state_113604__$1 = state_113604;
var statearr_113610_113681 = state_113604__$1;
(statearr_113610_113681[(2)] = null);

(statearr_113610_113681[(1)] = (4));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113605 === (24))){
var inst_113539 = (state_113604[(7)]);
var state_113604__$1 = state_113604;
var statearr_113611_113682 = state_113604__$1;
(statearr_113611_113682[(2)] = inst_113539);

(statearr_113611_113682[(1)] = (25));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113605 === (39))){
var inst_113543 = (state_113604[(8)]);
var state_113604__$1 = state_113604;
var statearr_113612_113683 = state_113604__$1;
(statearr_113612_113683[(2)] = inst_113543);

(statearr_113612_113683[(1)] = (40));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113605 === (46))){
var inst_113590 = (state_113604[(9)]);
var state_113604__$1 = state_113604;
var statearr_113613_113684 = state_113604__$1;
(statearr_113613_113684[(2)] = inst_113590);

(statearr_113613_113684[(1)] = (47));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113605 === (4))){
var _ = cljs.core.async.impl.ioc_helpers.add_exception_frame(state_113604,(3),Error,null,(2));
var state_113604__$1 = state_113604;
if(cljs.core.truth_(aggregates)){
var statearr_113614_113685 = state_113604__$1;
(statearr_113614_113685[(1)] = (5));

} else {
var statearr_113615_113686 = state_113604__$1;
(statearr_113615_113686[(1)] = (6));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_113605 === (15))){
var inst_113525 = (state_113604[(10)]);
var state_113604__$1 = state_113604;
var statearr_113616_113687 = state_113604__$1;
(statearr_113616_113687[(2)] = inst_113525);

(statearr_113616_113687[(1)] = (16));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113605 === (21))){
var state_113604__$1 = state_113604;
var statearr_113617_113688 = state_113604__$1;
(statearr_113617_113688[(2)] = offset);

(statearr_113617_113688[(1)] = (22));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113605 === (31))){
var inst_113561 = (state_113604[(2)]);
var state_113604__$1 = state_113604;
var statearr_113618_113689 = state_113604__$1;
(statearr_113618_113689[(2)] = inst_113561);

(statearr_113618_113689[(1)] = (28));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113605 === (32))){
var inst_113548 = (state_113604[(11)]);
var inst_113566 = cljs.core.apply.cljs$core$IFn$_invoke$arity$2(cljs.core.hash_map,inst_113548);
var state_113604__$1 = state_113604;
var statearr_113619_113690 = state_113604__$1;
(statearr_113619_113690[(2)] = inst_113566);

(statearr_113619_113690[(1)] = (34));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113605 === (40))){
var inst_113577 = (state_113604[(2)]);
var state_113604__$1 = state_113604;
var statearr_113620_113691 = state_113604__$1;
(statearr_113620_113691[(2)] = inst_113577);

(statearr_113620_113691[(1)] = (37));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113605 === (33))){
var inst_113548 = (state_113604[(11)]);
var state_113604__$1 = state_113604;
var statearr_113621_113692 = state_113604__$1;
(statearr_113621_113692[(2)] = inst_113548);

(statearr_113621_113692[(1)] = (34));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113605 === (13))){
var inst_113525 = (state_113604[(2)]);
var state_113604__$1 = (function (){var statearr_113622 = state_113604;
(statearr_113622[(10)] = inst_113525);

return statearr_113622;
})();
if(cljs.core.truth_(inVector_QMARK_)){
var statearr_113623_113693 = state_113604__$1;
(statearr_113623_113693[(1)] = (14));

} else {
var statearr_113624_113694 = state_113604__$1;
(statearr_113624_113694[(1)] = (15));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_113605 === (22))){
var inst_113543 = (state_113604[(2)]);
var state_113604__$1 = (function (){var statearr_113625 = state_113604;
(statearr_113625[(8)] = inst_113543);

return statearr_113625;
})();
if(cljs.core.truth_(orderBy)){
var statearr_113626_113695 = state_113604__$1;
(statearr_113626_113695[(1)] = (23));

} else {
var statearr_113627_113696 = state_113604__$1;
(statearr_113627_113696[(1)] = (24));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_113605 === (36))){
var inst_113572 = (state_113604[(12)]);
var state_113604__$1 = state_113604;
var statearr_113628_113697 = state_113604__$1;
(statearr_113628_113697[(2)] = inst_113572);

(statearr_113628_113697[(1)] = (37));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113605 === (41))){
var inst_113543 = (state_113604[(8)]);
var inst_113571 = (state_113604[(13)]);
var inst_113582 = cljs.core.drop.cljs$core$IFn$_invoke$arity$2(inst_113543,inst_113571);
var inst_113583 = cljs.core.take.cljs$core$IFn$_invoke$arity$2(limit,inst_113582);
var state_113604__$1 = state_113604;
var statearr_113629_113698 = state_113604__$1;
(statearr_113629_113698[(2)] = inst_113583);

(statearr_113629_113698[(1)] = (43));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113605 === (43))){
var inst_113570 = (state_113604[(14)]);
var inst_113586 = (state_113604[(2)]);
var inst_113587 = fluree.db.query.fql.format_filter_tuples(db,inst_113586,select_spec,inst_113570,vars,opts);
var state_113604__$1 = state_113604;
return cljs.core.async.impl.ioc_helpers.take_BANG_(state_113604__$1,(44),inst_113587);
} else {
if((state_val_113605 === (29))){
var state_113604__$1 = state_113604;
var statearr_113630_113699 = state_113604__$1;
(statearr_113630_113699[(2)] = true);

(statearr_113630_113699[(1)] = (31));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113605 === (44))){
var inst_113589 = (state_113604[(2)]);
var inst_113590 = fluree.db.util.async.throw_err(inst_113589);
var state_113604__$1 = (function (){var statearr_113631 = state_113604;
(statearr_113631[(9)] = inst_113590);

return statearr_113631;
})();
if(cljs.core.truth_(selectDistinct_QMARK_)){
var statearr_113632_113700 = state_113604__$1;
(statearr_113632_113700[(1)] = (45));

} else {
var statearr_113633_113701 = state_113604__$1;
(statearr_113633_113701[(1)] = (46));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_113605 === (6))){
var state_113604__$1 = state_113604;
var statearr_113634_113702 = state_113604__$1;
(statearr_113634_113702[(2)] = aggregates);

(statearr_113634_113702[(1)] = (7));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113605 === (28))){
var inst_113564 = (state_113604[(2)]);
var state_113604__$1 = state_113604;
if(cljs.core.truth_(inst_113564)){
var statearr_113635_113703 = state_113604__$1;
(statearr_113635_113703[(1)] = (32));

} else {
var statearr_113636_113704 = state_113604__$1;
(statearr_113636_113704[(1)] = (33));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_113605 === (25))){
var inst_113548 = (state_113604[(11)]);
var inst_113548__$1 = (state_113604[(2)]);
var inst_113550 = (inst_113548__$1 == null);
var inst_113551 = cljs.core.not(inst_113550);
var state_113604__$1 = (function (){var statearr_113637 = state_113604;
(statearr_113637[(11)] = inst_113548__$1);

return statearr_113637;
})();
if(inst_113551){
var statearr_113638_113705 = state_113604__$1;
(statearr_113638_113705[(1)] = (26));

} else {
var statearr_113639_113706 = state_113604__$1;
(statearr_113639_113706[(1)] = (27));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_113605 === (34))){
var inst_113572 = (state_113604[(12)]);
var inst_113569 = (state_113604[(2)]);
var inst_113570 = cljs.core.get.cljs$core$IFn$_invoke$arity$2(inst_113569,cljs.core.cst$kw$headers);
var inst_113571 = cljs.core.get.cljs$core$IFn$_invoke$arity$2(inst_113569,cljs.core.cst$kw$tuples);
var inst_113572__$1 = cljs.core.not(orderBy);
var state_113604__$1 = (function (){var statearr_113640 = state_113604;
(statearr_113640[(14)] = inst_113570);

(statearr_113640[(13)] = inst_113571);

(statearr_113640[(12)] = inst_113572__$1);

return statearr_113640;
})();
if(inst_113572__$1){
var statearr_113641_113707 = state_113604__$1;
(statearr_113641_113707[(1)] = (35));

} else {
var statearr_113642_113708 = state_113604__$1;
(statearr_113642_113708[(1)] = (36));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_113605 === (17))){
var inst_113536 = fluree.db.query.analytical.add_aggregate_cols(res,aggregates);
var state_113604__$1 = state_113604;
var statearr_113643_113709 = state_113604__$1;
(statearr_113643_113709[(2)] = inst_113536);

(statearr_113643_113709[(1)] = (19));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113605 === (3))){
var inst_113501 = (state_113604[(2)]);
var state_113604__$1 = state_113604;
var statearr_113644_113710 = state_113604__$1;
(statearr_113644_113710[(2)] = inst_113501);


cljs.core.async.impl.ioc_helpers.process_exception(state_113604__$1);

return cljs.core.cst$kw$recur;
} else {
if((state_val_113605 === (12))){
var inst_113514 = (state_113604[(15)]);
var state_113604__$1 = state_113604;
var statearr_113645_113711 = state_113604__$1;
(statearr_113645_113711[(2)] = inst_113514);

(statearr_113645_113711[(1)] = (13));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113605 === (2))){
var inst_113602 = (state_113604[(2)]);
var state_113604__$1 = state_113604;
return cljs.core.async.impl.ioc_helpers.return_chan(state_113604__$1,inst_113602);
} else {
if((state_val_113605 === (23))){
var inst_113539 = (state_113604[(7)]);
var inst_113543 = (state_113604[(8)]);
var inst_113545 = fluree.db.query.fql.order_offset_and_limit_results(orderBy,inst_113539,inst_113543,group_limit);
var state_113604__$1 = state_113604;
var statearr_113646_113712 = state_113604__$1;
(statearr_113646_113712[(2)] = inst_113545);

(statearr_113646_113712[(1)] = (25));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113605 === (47))){
var inst_113598 = (state_113604[(2)]);
var state_113604__$1 = state_113604;
var statearr_113647_113713 = state_113604__$1;
(statearr_113647_113713[(2)] = inst_113598);

(statearr_113647_113713[(1)] = (10));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113605 === (35))){
var state_113604__$1 = state_113604;
if(cljs.core.truth_(limit)){
var statearr_113648_113714 = state_113604__$1;
(statearr_113648_113714[(1)] = (38));

} else {
var statearr_113649_113715 = state_113604__$1;
(statearr_113649_113715[(1)] = (39));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_113605 === (19))){
var inst_113539 = (state_113604[(2)]);
var state_113604__$1 = (function (){var statearr_113650 = state_113604;
(statearr_113650[(7)] = inst_113539);

return statearr_113650;
})();
if(cljs.core.truth_(groupBy)){
var statearr_113651_113716 = state_113604__$1;
(statearr_113651_113716[(1)] = (20));

} else {
var statearr_113652_113717 = state_113604__$1;
(statearr_113652_113717[(1)] = (21));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_113605 === (11))){
var inst_113514 = (state_113604[(15)]);
var inst_113516 = cljs.core.first(select);
var inst_113517 = cljs.core.cst$kw$as.cljs$core$IFn$_invoke$arity$1(inst_113516);
var inst_113518 = cljs.core.str.cljs$core$IFn$_invoke$arity$1(inst_113517);
var inst_113519 = cljs.core.subs.cljs$core$IFn$_invoke$arity$2(inst_113518,(1));
var inst_113520 = [inst_113519];
var inst_113521 = [inst_113514];
var inst_113522 = cljs.core.PersistentHashMap.fromArrays(inst_113520,inst_113521);
var state_113604__$1 = state_113604;
var statearr_113653_113718 = state_113604__$1;
(statearr_113653_113718[(2)] = inst_113522);

(statearr_113653_113718[(1)] = (13));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113605 === (9))){
var state_113604__$1 = state_113604;
if(cljs.core.truth_(aggregates)){
var statearr_113654_113719 = state_113604__$1;
(statearr_113654_113719[(1)] = (17));

} else {
var statearr_113655_113720 = state_113604__$1;
(statearr_113655_113720[(1)] = (18));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_113605 === (5))){
var inst_113506 = cljs.core.count(select);
var inst_113507 = cljs.core._EQ_.cljs$core$IFn$_invoke$arity$2((1),inst_113506);
var state_113604__$1 = state_113604;
var statearr_113656_113721 = state_113604__$1;
(statearr_113656_113721[(2)] = inst_113507);

(statearr_113656_113721[(1)] = (7));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113605 === (14))){
var inst_113525 = (state_113604[(10)]);
var inst_113527 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_113528 = [inst_113525];
var inst_113529 = (new cljs.core.PersistentVector(null,1,(5),inst_113527,inst_113528,null));
var state_113604__$1 = state_113604;
var statearr_113657_113722 = state_113604__$1;
(statearr_113657_113722[(2)] = inst_113529);

(statearr_113657_113722[(1)] = (16));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113605 === (45))){
var inst_113590 = (state_113604[(9)]);
var inst_113592 = cljs.core.PersistentVector.EMPTY;
var inst_113593 = cljs.core.PersistentHashSet.EMPTY;
var inst_113594 = cljs.core.into.cljs$core$IFn$_invoke$arity$2(inst_113593,inst_113590);
var inst_113595 = cljs.core.into.cljs$core$IFn$_invoke$arity$2(inst_113592,inst_113594);
var state_113604__$1 = state_113604;
var statearr_113658_113723 = state_113604__$1;
(statearr_113658_113723[(2)] = inst_113595);

(statearr_113658_113723[(1)] = (47));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113605 === (26))){
var inst_113548 = (state_113604[(11)]);
var inst_113553 = inst_113548.cljs$lang$protocol_mask$partition0$;
var inst_113554 = (inst_113553 & (64));
var inst_113555 = inst_113548.cljs$core$ISeq$;
var inst_113556 = (cljs.core.PROTOCOL_SENTINEL === inst_113555);
var inst_113557 = ((inst_113554) || (inst_113556));
var state_113604__$1 = state_113604;
if(cljs.core.truth_(inst_113557)){
var statearr_113659_113724 = state_113604__$1;
(statearr_113659_113724[(1)] = (29));

} else {
var statearr_113660_113725 = state_113604__$1;
(statearr_113660_113725[(1)] = (30));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_113605 === (16))){
var inst_113532 = (state_113604[(2)]);
var state_113604__$1 = state_113604;
var statearr_113661_113726 = state_113604__$1;
(statearr_113661_113726[(2)] = inst_113532);

(statearr_113661_113726[(1)] = (10));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113605 === (38))){
var state_113604__$1 = state_113604;
var statearr_113662_113727 = state_113604__$1;
(statearr_113662_113727[(2)] = limit);

(statearr_113662_113727[(1)] = (40));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113605 === (30))){
var state_113604__$1 = state_113604;
var statearr_113663_113728 = state_113604__$1;
(statearr_113663_113728[(2)] = false);

(statearr_113663_113728[(1)] = (31));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113605 === (10))){
var inst_113600 = (state_113604[(2)]);
var state_113604__$1 = state_113604;
var statearr_113664_113729 = state_113604__$1;
(statearr_113664_113729[(2)] = inst_113600);


cljs.core.async.impl.ioc_helpers.process_exception(state_113604__$1);

return cljs.core.cst$kw$recur;
} else {
if((state_val_113605 === (18))){
var state_113604__$1 = state_113604;
var statearr_113665_113730 = state_113604__$1;
(statearr_113665_113730[(2)] = res);

(statearr_113665_113730[(1)] = (19));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113605 === (42))){
var inst_113571 = (state_113604[(13)]);
var state_113604__$1 = state_113604;
var statearr_113666_113731 = state_113604__$1;
(statearr_113666_113731[(2)] = inst_113571);

(statearr_113666_113731[(1)] = (43));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113605 === (37))){
var inst_113580 = (state_113604[(2)]);
var state_113604__$1 = state_113604;
if(cljs.core.truth_(inst_113580)){
var statearr_113667_113732 = state_113604__$1;
(statearr_113667_113732[(1)] = (41));

} else {
var statearr_113668_113733 = state_113604__$1;
(statearr_113668_113733[(1)] = (42));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_113605 === (8))){
var inst_113512 = cljs.core.first(aggregates);
var inst_113513 = fluree.db.query.analytical.calculate_aggregate(res,inst_113512);
var inst_113514 = cljs.core.second(inst_113513);
var state_113604__$1 = (function (){var statearr_113669 = state_113604;
(statearr_113669[(15)] = inst_113514);

return statearr_113669;
})();
if(cljs.core.truth_(prettyPrint)){
var statearr_113670_113734 = state_113604__$1;
(statearr_113670_113734[(1)] = (11));

} else {
var statearr_113671_113735 = state_113604__$1;
(statearr_113671_113735[(1)] = (12));

}

return cljs.core.cst$kw$recur;
} else {
return null;
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
});})(c__99809__auto__,map__113497,map__113497__$1,res,vars,map__113498,map__113498__$1,select_spec,inVector_QMARK_,select,orderBy,limit,offset,aggregates,prettyPrint,selectDistinct_QMARK_,groupBy))
;
return ((function (switch__99702__auto__,c__99809__auto__,map__113497,map__113497__$1,res,vars,map__113498,map__113498__$1,select_spec,inVector_QMARK_,select,orderBy,limit,offset,aggregates,prettyPrint,selectDistinct_QMARK_,groupBy){
return (function() {
var fluree$db$query$fql$state_machine__99703__auto__ = null;
var fluree$db$query$fql$state_machine__99703__auto____0 = (function (){
var statearr_113672 = [null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null];
(statearr_113672[(0)] = fluree$db$query$fql$state_machine__99703__auto__);

(statearr_113672[(1)] = (1));

return statearr_113672;
});
var fluree$db$query$fql$state_machine__99703__auto____1 = (function (state_113604){
while(true){
var ret_value__99704__auto__ = (function (){try{while(true){
var result__99705__auto__ = switch__99702__auto__(state_113604);
if(cljs.core.keyword_identical_QMARK_(result__99705__auto__,cljs.core.cst$kw$recur)){
continue;
} else {
return result__99705__auto__;
}
break;
}
}catch (e113673){if((e113673 instanceof Object)){
var ex__99706__auto__ = e113673;
var statearr_113674_113736 = state_113604;
(statearr_113674_113736[(5)] = ex__99706__auto__);


cljs.core.async.impl.ioc_helpers.process_exception(state_113604);

return cljs.core.cst$kw$recur;
} else {
throw e113673;

}
}})();
if(cljs.core.keyword_identical_QMARK_(ret_value__99704__auto__,cljs.core.cst$kw$recur)){
var G__113737 = state_113604;
state_113604 = G__113737;
continue;
} else {
return ret_value__99704__auto__;
}
break;
}
});
fluree$db$query$fql$state_machine__99703__auto__ = function(state_113604){
switch(arguments.length){
case 0:
return fluree$db$query$fql$state_machine__99703__auto____0.call(this);
case 1:
return fluree$db$query$fql$state_machine__99703__auto____1.call(this,state_113604);
}
throw(new Error('Invalid arity: ' + arguments.length));
};
fluree$db$query$fql$state_machine__99703__auto__.cljs$core$IFn$_invoke$arity$0 = fluree$db$query$fql$state_machine__99703__auto____0;
fluree$db$query$fql$state_machine__99703__auto__.cljs$core$IFn$_invoke$arity$1 = fluree$db$query$fql$state_machine__99703__auto____1;
return fluree$db$query$fql$state_machine__99703__auto__;
})()
;})(switch__99702__auto__,c__99809__auto__,map__113497,map__113497__$1,res,vars,map__113498,map__113498__$1,select_spec,inVector_QMARK_,select,orderBy,limit,offset,aggregates,prettyPrint,selectDistinct_QMARK_,groupBy))
})();
var state__99811__auto__ = (function (){var statearr_113675 = (f__99810__auto__.cljs$core$IFn$_invoke$arity$0 ? f__99810__auto__.cljs$core$IFn$_invoke$arity$0() : f__99810__auto__.call(null));
(statearr_113675[(6)] = c__99809__auto__);

return statearr_113675;
})();
return cljs.core.async.impl.ioc_helpers.run_state_machine_wrapped(state__99811__auto__);
});})(c__99809__auto__,map__113497,map__113497__$1,res,vars,map__113498,map__113498__$1,select_spec,inVector_QMARK_,select,orderBy,limit,offset,aggregates,prettyPrint,selectDistinct_QMARK_,groupBy))
);

return c__99809__auto__;
});

fluree.db.query.fql.process_ad_hoc_group.cljs$lang$maxFixedArity = 5;

fluree.db.query.fql.ad_hoc_group_by = (function fluree$db$query$fql$ad_hoc_group_by(p__113740,groupBy){
var map__113741 = p__113740;
var map__113741__$1 = (((((!((map__113741 == null))))?(((((map__113741.cljs$lang$protocol_mask$partition0$ & (64))) || ((cljs.core.PROTOCOL_SENTINEL === map__113741.cljs$core$ISeq$))))?true:false):false))?cljs.core.apply.cljs$core$IFn$_invoke$arity$2(cljs.core.hash_map,map__113741):map__113741);
var res = map__113741__$1;
var headers = cljs.core.get.cljs$core$IFn$_invoke$arity$2(map__113741__$1,cljs.core.cst$kw$headers);
var tuples = cljs.core.get.cljs$core$IFn$_invoke$arity$2(map__113741__$1,cljs.core.cst$kw$tuples);
var vec__113743 = ((cljs.core.vector_QMARK_(groupBy))?new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [true,cljs.core.map.cljs$core$IFn$_invoke$arity$2(cljs.core.symbol,groupBy)], null):((typeof groupBy === 'string')?new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [false,new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [cljs.core.symbol.cljs$core$IFn$_invoke$arity$1(groupBy)], null)], null):(function(){throw cljs.core.ex_info.cljs$core$IFn$_invoke$arity$2(["Invalid groupBy clause, must be a string or vector. Provided: ",cljs.core.str.cljs$core$IFn$_invoke$arity$1(groupBy)].join(''),new cljs.core.PersistentArrayMap(null, 2, [cljs.core.cst$kw$status,(400),cljs.core.cst$kw$error,cljs.core.cst$kw$db_SLASH_invalid_DASH_query], null))})()
));
var inVector_QMARK_ = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(vec__113743,(0),null);
var groupBy__$1 = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(vec__113743,(1),null);
var group_idxs = cljs.core.map.cljs$core$IFn$_invoke$arity$2(((function (vec__113743,inVector_QMARK_,groupBy__$1,map__113741,map__113741__$1,res,headers,tuples){
return (function (p1__113738_SHARP_){
return fluree.db.util.core.index_of(headers,p1__113738_SHARP_);
});})(vec__113743,inVector_QMARK_,groupBy__$1,map__113741,map__113741__$1,res,headers,tuples))
,groupBy__$1);
var _ = (cljs.core.truth_(cljs.core.some(cljs.core.nil_QMARK_,group_idxs))?(function(){throw cljs.core.ex_info.cljs$core$IFn$_invoke$arity$2(["Invalid groupBy clause - are all groupBy vars declared in the where clause. Provided: ",cljs.core.str.cljs$core$IFn$_invoke$arity$1(groupBy__$1)].join(''),new cljs.core.PersistentArrayMap(null, 2, [cljs.core.cst$kw$status,(400),cljs.core.cst$kw$error,cljs.core.cst$kw$db_SLASH_invalid_DASH_query], null))})():null);
return cljs.core.reduce.cljs$core$IFn$_invoke$arity$3(((function (vec__113743,inVector_QMARK_,groupBy__$1,group_idxs,_,map__113741,map__113741__$1,res,headers,tuples){
return (function (res__$1,tuple){
var k = cljs.core.map.cljs$core$IFn$_invoke$arity$2(((function (vec__113743,inVector_QMARK_,groupBy__$1,group_idxs,_,map__113741,map__113741__$1,res,headers,tuples){
return (function (p1__113739_SHARP_){
return cljs.core.nth.cljs$core$IFn$_invoke$arity$2(tuple,p1__113739_SHARP_);
});})(vec__113743,inVector_QMARK_,groupBy__$1,group_idxs,_,map__113741,map__113741__$1,res,headers,tuples))
,group_idxs);
var k_SINGLEQUOTE_ = (cljs.core.truth_(inVector_QMARK_)?cljs.core.into.cljs$core$IFn$_invoke$arity$2(cljs.core.PersistentVector.EMPTY,k):cljs.core.first(k));
var v = tuple;
return cljs.core.assoc.cljs$core$IFn$_invoke$arity$3(res__$1,k_SINGLEQUOTE_,cljs.core.conj.cljs$core$IFn$_invoke$arity$2(cljs.core.get.cljs$core$IFn$_invoke$arity$3(res__$1,k_SINGLEQUOTE_,cljs.core.PersistentVector.EMPTY),v));
});})(vec__113743,inVector_QMARK_,groupBy__$1,group_idxs,_,map__113741,map__113741__$1,res,headers,tuples))
,cljs.core.PersistentArrayMap.EMPTY,tuples);
});
fluree.db.query.fql.process_ad_hoc_res = (function fluree$db$query$fql$process_ad_hoc_res(db,p__113746,p__113747,opts){
var map__113748 = p__113746;
var map__113748__$1 = (((((!((map__113748 == null))))?(((((map__113748.cljs$lang$protocol_mask$partition0$ & (64))) || ((cljs.core.PROTOCOL_SENTINEL === map__113748.cljs$core$ISeq$))))?true:false):false))?cljs.core.apply.cljs$core$IFn$_invoke$arity$2(cljs.core.hash_map,map__113748):map__113748);
var res = map__113748__$1;
var headers = cljs.core.get.cljs$core$IFn$_invoke$arity$2(map__113748__$1,cljs.core.cst$kw$headers);
var vars = cljs.core.get.cljs$core$IFn$_invoke$arity$2(map__113748__$1,cljs.core.cst$kw$vars);
var map__113749 = p__113747;
var map__113749__$1 = (((((!((map__113749 == null))))?(((((map__113749.cljs$lang$protocol_mask$partition0$ & (64))) || ((cljs.core.PROTOCOL_SENTINEL === map__113749.cljs$core$ISeq$))))?true:false):false))?cljs.core.apply.cljs$core$IFn$_invoke$arity$2(cljs.core.hash_map,map__113749):map__113749);
var select_spec = map__113749__$1;
var groupBy = cljs.core.get.cljs$core$IFn$_invoke$arity$2(map__113749__$1,cljs.core.cst$kw$groupBy);
var orderBy = cljs.core.get.cljs$core$IFn$_invoke$arity$2(map__113749__$1,cljs.core.cst$kw$orderBy);
var limit = cljs.core.get.cljs$core$IFn$_invoke$arity$2(map__113749__$1,cljs.core.cst$kw$limit);
var selectOne_QMARK_ = cljs.core.get.cljs$core$IFn$_invoke$arity$2(map__113749__$1,cljs.core.cst$kw$selectOne_QMARK_);
var selectDistinct_QMARK_ = cljs.core.get.cljs$core$IFn$_invoke$arity$2(map__113749__$1,cljs.core.cst$kw$selectDistinct_QMARK_);
var inVector_QMARK_ = cljs.core.get.cljs$core$IFn$_invoke$arity$2(map__113749__$1,cljs.core.cst$kw$inVector_QMARK_);
var offset = cljs.core.get.cljs$core$IFn$_invoke$arity$2(map__113749__$1,cljs.core.cst$kw$offset);
var c__99809__auto__ = cljs.core.async.chan.cljs$core$IFn$_invoke$arity$1((1));
cljs.core.async.impl.dispatch.run(((function (c__99809__auto__,map__113748,map__113748__$1,res,headers,vars,map__113749,map__113749__$1,select_spec,groupBy,orderBy,limit,selectOne_QMARK_,selectDistinct_QMARK_,inVector_QMARK_,offset){
return (function (){
var f__99810__auto__ = (function (){var switch__99702__auto__ = ((function (c__99809__auto__,map__113748,map__113748__$1,res,headers,vars,map__113749,map__113749__$1,select_spec,groupBy,orderBy,limit,selectOne_QMARK_,selectDistinct_QMARK_,inVector_QMARK_,offset){
return (function (state_113968){
var state_val_113969 = (state_113968[(1)]);
if((state_val_113969 === (65))){
var inst_113935 = (state_113968[(7)]);
var inst_113934 = (state_113968[(2)]);
var inst_113935__$1 = fluree.db.util.async.throw_err(inst_113934);
var inst_113936 = cljs.core.coll_QMARK_(inst_113935__$1);
var inst_113937 = (!(inst_113936));
var state_113968__$1 = (function (){var statearr_113970 = state_113968;
(statearr_113970[(7)] = inst_113935__$1);

return statearr_113970;
})();
if(inst_113937){
var statearr_113971_114085 = state_113968__$1;
(statearr_113971_114085[(1)] = (66));

} else {
var statearr_113972_114086 = state_113968__$1;
(statearr_113972_114086[(1)] = (67));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_113969 === (70))){
var inst_113935 = (state_113968[(7)]);
var state_113968__$1 = state_113968;
var statearr_113973_114087 = state_113968__$1;
(statearr_113973_114087[(2)] = inst_113935);

(statearr_113973_114087[(1)] = (71));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113969 === (62))){
var state_113968__$1 = state_113968;
var statearr_113974_114088 = state_113968__$1;
(statearr_113974_114088[(2)] = (1));

(statearr_113974_114088[(1)] = (64));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113969 === (74))){
var inst_113960 = (state_113968[(2)]);
var state_113968__$1 = state_113968;
var statearr_113975_114089 = state_113968__$1;
(statearr_113975_114089[(2)] = inst_113960);

(statearr_113975_114089[(1)] = (68));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113969 === (7))){
var inst_113964 = (state_113968[(2)]);
var state_113968__$1 = state_113968;
var statearr_113976_114090 = state_113968__$1;
(statearr_113976_114090[(2)] = inst_113964);


cljs.core.async.impl.ioc_helpers.process_exception(state_113968__$1);

return cljs.core.cst$kw$recur;
} else {
if((state_val_113969 === (59))){
var inst_113918 = (state_113968[(8)]);
var inst_113804 = (state_113968[(9)]);
var inst_113920 = cljs.core.sorted_map_by(inst_113804);
var inst_113921 = cljs.core.into.cljs$core$IFn$_invoke$arity$2(inst_113920,inst_113918);
var state_113968__$1 = state_113968;
var statearr_113977_114091 = state_113968__$1;
(statearr_113977_114091[(2)] = inst_113921);

(statearr_113977_114091[(1)] = (61));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113969 === (20))){
var inst_113777 = cljs.core.set(groupBy);
var inst_113778 = cljs.core.second(orderBy);
var inst_113779 = (inst_113777.cljs$core$IFn$_invoke$arity$1 ? inst_113777.cljs$core$IFn$_invoke$arity$1(inst_113778) : inst_113777.call(null,inst_113778));
var state_113968__$1 = state_113968;
var statearr_113978_114092 = state_113968__$1;
(statearr_113978_114092[(2)] = inst_113779);

(statearr_113978_114092[(1)] = (22));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113969 === (72))){
var inst_113935 = (state_113968[(7)]);
var inst_113948 = cljs.core.first(inst_113935);
var state_113968__$1 = state_113968;
var statearr_113979_114093 = state_113968__$1;
(statearr_113979_114093[(2)] = inst_113948);

(statearr_113979_114093[(1)] = (74));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113969 === (58))){
var inst_113848 = (state_113968[(10)]);
var inst_113857 = (state_113968[(11)]);
var inst_113900 = (state_113968[(2)]);
var inst_113901 = fluree.db.util.async.throw_err(inst_113900);
var inst_113902 = cljs.core.assoc.cljs$core$IFn$_invoke$arity$3(inst_113848,inst_113857,inst_113901);
var state_113968__$1 = state_113968;
var statearr_113980_114094 = state_113968__$1;
(statearr_113980_114094[(2)] = inst_113902);

(statearr_113980_114094[(1)] = (57));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113969 === (60))){
var inst_113918 = (state_113968[(8)]);
var state_113968__$1 = state_113968;
var statearr_113981_114095 = state_113968__$1;
(statearr_113981_114095[(2)] = inst_113918);

(statearr_113981_114095[(1)] = (61));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113969 === (27))){
var inst_113757 = (state_113968[(12)]);
var inst_113785 = (state_113968[(13)]);
var inst_113786 = (state_113968[(14)]);
var inst_113791 = (function (){var group_map = inst_113757;
var orderByIdx = inst_113785;
var orderDirection = inst_113786;
return ((function (group_map,orderByIdx,orderDirection,inst_113757,inst_113785,inst_113786,state_val_113969,c__99809__auto__,map__113748,map__113748__$1,res,headers,vars,map__113749,map__113749__$1,select_spec,groupBy,orderBy,limit,selectOne_QMARK_,selectDistinct_QMARK_,inVector_QMARK_,offset){
return (function (x,y){
return fluree.db.query.fql.compare_fn(cljs.core.nth.cljs$core$IFn$_invoke$arity$2(x,orderByIdx),cljs.core.nth.cljs$core$IFn$_invoke$arity$2(y,orderByIdx));
});
;})(group_map,orderByIdx,orderDirection,inst_113757,inst_113785,inst_113786,state_val_113969,c__99809__auto__,map__113748,map__113748__$1,res,headers,vars,map__113749,map__113749__$1,select_spec,groupBy,orderBy,limit,selectOne_QMARK_,selectDistinct_QMARK_,inVector_QMARK_,offset))
})();
var state_113968__$1 = state_113968;
var statearr_113982_114096 = state_113968__$1;
(statearr_113982_114096[(2)] = inst_113791);

(statearr_113982_114096[(1)] = (28));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113969 === (1))){
var state_113968__$1 = state_113968;
var statearr_113983_114097 = state_113968__$1;
(statearr_113983_114097[(2)] = null);

(statearr_113983_114097[(1)] = (4));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113969 === (69))){
var inst_113935 = (state_113968[(7)]);
var inst_113940 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_113941 = [inst_113935];
var inst_113942 = (new cljs.core.PersistentVector(null,1,(5),inst_113940,inst_113941,null));
var state_113968__$1 = state_113968;
var statearr_113984_114098 = state_113968__$1;
(statearr_113984_114098[(2)] = inst_113942);

(statearr_113984_114098[(1)] = (71));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113969 === (24))){
var state_113968__$1 = state_113968;
var statearr_113985_114099 = state_113968__$1;
(statearr_113985_114099[(1)] = (29));



return cljs.core.cst$kw$recur;
} else {
if((state_val_113969 === (55))){
var inst_113875 = (state_113968[(15)]);
var inst_113860 = (state_113968[(16)]);
var inst_113872 = (state_113968[(17)]);
var inst_113895 = cljs.core.count(inst_113860);
var inst_113896 = (inst_113872 - limit);
var inst_113897 = (inst_113895 - inst_113896);
var inst_113898 = fluree.db.query.fql.process_ad_hoc_group.cljs$core$IFn$_invoke$arity$5(db,inst_113875,select_spec,inst_113897,opts);
var state_113968__$1 = state_113968;
return cljs.core.async.impl.ioc_helpers.take_BANG_(state_113968__$1,(58),inst_113898);
} else {
if((state_val_113969 === (39))){
var inst_113847 = (state_113968[(18)]);
var inst_113865 = (inst_113847 > (0));
var state_113968__$1 = state_113968;
if(cljs.core.truth_(inst_113865)){
var statearr_113987_114100 = state_113968__$1;
(statearr_113987_114100[(1)] = (41));

} else {
var statearr_113988_114101 = state_113968__$1;
(statearr_113988_114101[(1)] = (42));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_113969 === (46))){
var inst_113912 = (state_113968[(2)]);
var state_113968__$1 = state_113968;
var statearr_113989_114102 = state_113968__$1;
(statearr_113989_114102[(2)] = inst_113912);

(statearr_113989_114102[(1)] = (43));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113969 === (4))){
var _ = cljs.core.async.impl.ioc_helpers.add_exception_frame(state_113968,(3),Error,null,(2));
var state_113968__$1 = state_113968;
if(cljs.core.truth_(groupBy)){
var statearr_113990_114103 = state_113968__$1;
(statearr_113990_114103[(1)] = (5));

} else {
var statearr_113991_114104 = state_113968__$1;
(statearr_113991_114104[(1)] = (6));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_113969 === (77))){
var inst_113958 = (state_113968[(2)]);
var state_113968__$1 = state_113968;
var statearr_113992_114105 = state_113968__$1;
(statearr_113992_114105[(2)] = inst_113958);

(statearr_113992_114105[(1)] = (74));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113969 === (54))){
var inst_113848 = (state_113968[(10)]);
var inst_113857 = (state_113968[(11)]);
var inst_113889 = (state_113968[(2)]);
var inst_113890 = fluree.db.util.async.throw_err(inst_113889);
var inst_113891 = cljs.core.assoc.cljs$core$IFn$_invoke$arity$3(inst_113848,inst_113857,inst_113890);
var state_113968__$1 = state_113968;
var statearr_113993_114106 = state_113968__$1;
(statearr_113993_114106[(2)] = inst_113891);

(statearr_113993_114106[(1)] = (53));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113969 === (15))){
var state_113968__$1 = state_113968;
var statearr_113995_114107 = state_113968__$1;
(statearr_113995_114107[(2)] = fluree.db.query.fql.compare_fn);

(statearr_113995_114107[(1)] = (16));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113969 === (48))){
var inst_113872 = (state_113968[(17)]);
var inst_113885 = cljs.core._EQ_.cljs$core$IFn$_invoke$arity$2(limit,inst_113872);
var state_113968__$1 = state_113968;
if(inst_113885){
var statearr_113996_114108 = state_113968__$1;
(statearr_113996_114108[(1)] = (51));

} else {
var statearr_113997_114109 = state_113968__$1;
(statearr_113997_114109[(1)] = (52));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_113969 === (50))){
var inst_113847 = (state_113968[(18)]);
var inst_113858 = (state_113968[(19)]);
var inst_113861 = (state_113968[(20)]);
var inst_113872 = (state_113968[(17)]);
var inst_113848 = (state_113968[(10)]);
var inst_113857 = (state_113968[(11)]);
var inst_113880 = (state_113968[(2)]);
var inst_113881 = fluree.db.util.async.throw_err(inst_113880);
var inst_113882 = cljs.core.assoc.cljs$core$IFn$_invoke$arity$3(inst_113848,inst_113857,inst_113881);
var tmp113994 = inst_113847;
var inst_113844 = inst_113858;
var inst_113845 = inst_113861;
var inst_113846 = inst_113872;
var inst_113847__$1 = tmp113994;
var inst_113848__$1 = inst_113882;
var state_113968__$1 = (function (){var statearr_113998 = state_113968;
(statearr_113998[(21)] = inst_113844);

(statearr_113998[(18)] = inst_113847__$1);

(statearr_113998[(22)] = inst_113846);

(statearr_113998[(23)] = inst_113845);

(statearr_113998[(10)] = inst_113848__$1);

return statearr_113998;
})();
var statearr_113999_114110 = state_113968__$1;
(statearr_113999_114110[(2)] = null);

(statearr_113999_114110[(1)] = (36));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113969 === (75))){
var inst_113935 = (state_113968[(7)]);
var inst_113951 = cljs.core.distinct.cljs$core$IFn$_invoke$arity$1(inst_113935);
var state_113968__$1 = state_113968;
var statearr_114000_114111 = state_113968__$1;
(statearr_114000_114111[(2)] = inst_113951);

(statearr_114000_114111[(1)] = (77));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113969 === (21))){
var state_113968__$1 = state_113968;
var statearr_114001_114112 = state_113968__$1;
(statearr_114001_114112[(2)] = orderBy);

(statearr_114001_114112[(1)] = (22));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113969 === (31))){
var inst_113798 = (state_113968[(2)]);
var state_113968__$1 = state_113968;
var statearr_114002_114113 = state_113968__$1;
(statearr_114002_114113[(2)] = inst_113798);

(statearr_114002_114113[(1)] = (25));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113969 === (32))){
var inst_113757 = (state_113968[(12)]);
var inst_113806 = cljs.core.keys(inst_113757);
var inst_113807 = cljs.core.first(inst_113806);
var inst_113808 = [cljs.core.cst$kw$headers,cljs.core.cst$kw$vars,cljs.core.cst$kw$tuples];
var inst_113809 = cljs.core.vals(inst_113757);
var inst_113810 = cljs.core.first(inst_113809);
var inst_113811 = [headers,vars,inst_113810];
var inst_113812 = cljs.core.PersistentHashMap.fromArrays(inst_113808,inst_113811);
var inst_113813 = fluree.db.query.fql.process_ad_hoc_group.cljs$core$IFn$_invoke$arity$5(db,inst_113812,select_spec,limit,opts);
var state_113968__$1 = (function (){var statearr_114003 = state_113968;
(statearr_114003[(24)] = inst_113807);

return statearr_114003;
})();
return cljs.core.async.impl.ioc_helpers.take_BANG_(state_113968__$1,(35),inst_113813);
} else {
if((state_val_113969 === (40))){
var inst_113916 = (state_113968[(2)]);
var state_113968__$1 = state_113968;
var statearr_114004_114114 = state_113968__$1;
(statearr_114004_114114[(2)] = inst_113916);

(statearr_114004_114114[(1)] = (37));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113969 === (56))){
var state_113968__$1 = state_113968;
var statearr_114005_114115 = state_113968__$1;
(statearr_114005_114115[(2)] = null);

(statearr_114005_114115[(1)] = (57));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113969 === (33))){
var inst_113757 = (state_113968[(12)]);
var inst_113835 = cljs.core.keys(inst_113757);
var inst_113836 = cljs.core.seq(inst_113835);
var inst_113837 = cljs.core.first(inst_113836);
var inst_113838 = cljs.core.next(inst_113836);
var inst_113839 = cljs.core.vals(inst_113757);
var inst_113840 = cljs.core.seq(inst_113839);
var inst_113841 = cljs.core.first(inst_113840);
var inst_113842 = cljs.core.next(inst_113840);
var inst_113843 = cljs.core.PersistentHashMap.EMPTY;
var inst_113844 = inst_113835;
var inst_113845 = inst_113839;
var inst_113846 = (0);
var inst_113847 = offset;
var inst_113848 = inst_113843;
var state_113968__$1 = (function (){var statearr_114006 = state_113968;
(statearr_114006[(25)] = inst_113838);

(statearr_114006[(21)] = inst_113844);

(statearr_114006[(18)] = inst_113847);

(statearr_114006[(26)] = inst_113837);

(statearr_114006[(22)] = inst_113846);

(statearr_114006[(27)] = inst_113841);

(statearr_114006[(23)] = inst_113845);

(statearr_114006[(28)] = inst_113842);

(statearr_114006[(10)] = inst_113848);

return statearr_114006;
})();
var statearr_114007_114116 = state_113968__$1;
(statearr_114007_114116[(2)] = null);

(statearr_114007_114116[(1)] = (36));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113969 === (13))){
var inst_113804 = (state_113968[(2)]);
var state_113968__$1 = (function (){var statearr_114008 = state_113968;
(statearr_114008[(9)] = inst_113804);

return statearr_114008;
})();
if(cljs.core.truth_(selectOne_QMARK_)){
var statearr_114009_114117 = state_113968__$1;
(statearr_114009_114117[(1)] = (32));

} else {
var statearr_114010_114118 = state_113968__$1;
(statearr_114010_114118[(1)] = (33));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_113969 === (22))){
var inst_113782 = (state_113968[(2)]);
var state_113968__$1 = state_113968;
if(cljs.core.truth_(inst_113782)){
var statearr_114013_114119 = state_113968__$1;
(statearr_114013_114119[(1)] = (23));

} else {
var statearr_114014_114120 = state_113968__$1;
(statearr_114014_114120[(1)] = (24));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_113969 === (36))){
var inst_113844 = (state_113968[(21)]);
var inst_113845 = (state_113968[(23)]);
var inst_113860 = (state_113968[(16)]);
var inst_113856 = cljs.core.seq(inst_113844);
var inst_113857 = cljs.core.first(inst_113856);
var inst_113858 = cljs.core.next(inst_113856);
var inst_113859 = cljs.core.seq(inst_113845);
var inst_113860__$1 = cljs.core.first(inst_113859);
var inst_113861 = cljs.core.next(inst_113859);
var inst_113862 = (inst_113860__$1 == null);
var state_113968__$1 = (function (){var statearr_114015 = state_113968;
(statearr_114015[(16)] = inst_113860__$1);

(statearr_114015[(19)] = inst_113858);

(statearr_114015[(20)] = inst_113861);

(statearr_114015[(11)] = inst_113857);

return statearr_114015;
})();
if(cljs.core.truth_(inst_113862)){
var statearr_114016_114121 = state_113968__$1;
(statearr_114016_114121[(1)] = (38));

} else {
var statearr_114017_114122 = state_113968__$1;
(statearr_114017_114122[(1)] = (39));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_113969 === (41))){
var inst_113847 = (state_113968[(18)]);
var inst_113846 = (state_113968[(22)]);
var inst_113858 = (state_113968[(19)]);
var inst_113861 = (state_113968[(20)]);
var inst_113848 = (state_113968[(10)]);
var inst_113867 = (inst_113847 - (1));
var tmp114011 = inst_113846;
var tmp114012 = inst_113848;
var inst_113844 = inst_113858;
var inst_113845 = inst_113861;
var inst_113846__$1 = tmp114011;
var inst_113847__$1 = inst_113867;
var inst_113848__$1 = tmp114012;
var state_113968__$1 = (function (){var statearr_114018 = state_113968;
(statearr_114018[(21)] = inst_113844);

(statearr_114018[(18)] = inst_113847__$1);

(statearr_114018[(22)] = inst_113846__$1);

(statearr_114018[(23)] = inst_113845);

(statearr_114018[(10)] = inst_113848__$1);

return statearr_114018;
})();
var statearr_114019_114123 = state_113968__$1;
(statearr_114019_114123[(2)] = null);

(statearr_114019_114123[(1)] = (36));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113969 === (43))){
var inst_113914 = (state_113968[(2)]);
var state_113968__$1 = state_113968;
var statearr_114020_114124 = state_113968__$1;
(statearr_114020_114124[(2)] = inst_113914);

(statearr_114020_114124[(1)] = (40));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113969 === (61))){
var inst_113924 = (state_113968[(2)]);
var state_113968__$1 = state_113968;
var statearr_114021_114125 = state_113968__$1;
(statearr_114021_114125[(2)] = inst_113924);

(statearr_114021_114125[(1)] = (34));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113969 === (29))){
var state_113968__$1 = state_113968;
var statearr_114022_114126 = state_113968__$1;
(statearr_114022_114126[(2)] = null);

(statearr_114022_114126[(1)] = (31));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113969 === (44))){
var inst_113846 = (state_113968[(22)]);
var inst_113860 = (state_113968[(16)]);
var inst_113872 = (state_113968[(17)]);
var inst_113871 = cljs.core.count(inst_113860);
var inst_113872__$1 = (inst_113846 + inst_113871);
var inst_113873 = [cljs.core.cst$kw$headers,cljs.core.cst$kw$vars,cljs.core.cst$kw$tuples];
var inst_113874 = [headers,vars,inst_113860];
var inst_113875 = cljs.core.PersistentHashMap.fromArrays(inst_113873,inst_113874);
var inst_113876 = (limit > inst_113872__$1);
var state_113968__$1 = (function (){var statearr_114023 = state_113968;
(statearr_114023[(15)] = inst_113875);

(statearr_114023[(17)] = inst_113872__$1);

return statearr_114023;
})();
if(cljs.core.truth_(inst_113876)){
var statearr_114024_114127 = state_113968__$1;
(statearr_114024_114127[(1)] = (47));

} else {
var statearr_114025_114128 = state_113968__$1;
(statearr_114025_114128[(1)] = (48));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_113969 === (6))){
var state_113968__$1 = state_113968;
if(cljs.core.truth_(selectOne_QMARK_)){
var statearr_114026_114129 = state_113968__$1;
(statearr_114026_114129[(1)] = (62));

} else {
var statearr_114027_114130 = state_113968__$1;
(statearr_114027_114130[(1)] = (63));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_113969 === (28))){
var inst_113793 = (state_113968[(2)]);
var state_113968__$1 = state_113968;
var statearr_114028_114131 = state_113968__$1;
(statearr_114028_114131[(2)] = inst_113793);

(statearr_114028_114131[(1)] = (25));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113969 === (64))){
var inst_113931 = (state_113968[(2)]);
var inst_113932 = fluree.db.query.fql.process_ad_hoc_group.cljs$core$IFn$_invoke$arity$5(db,res,select_spec,inst_113931,opts);
var state_113968__$1 = state_113968;
return cljs.core.async.impl.ioc_helpers.take_BANG_(state_113968__$1,(65),inst_113932);
} else {
if((state_val_113969 === (51))){
var inst_113875 = (state_113968[(15)]);
var inst_113887 = fluree.db.query.fql.process_ad_hoc_group.cljs$core$IFn$_invoke$arity$4(db,inst_113875,select_spec,opts);
var state_113968__$1 = state_113968;
return cljs.core.async.impl.ioc_helpers.take_BANG_(state_113968__$1,(54),inst_113887);
} else {
if((state_val_113969 === (25))){
var inst_113800 = (state_113968[(2)]);
var state_113968__$1 = state_113968;
var statearr_114029_114132 = state_113968__$1;
(statearr_114029_114132[(2)] = inst_113800);

(statearr_114029_114132[(1)] = (19));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113969 === (34))){
var inst_113926 = (state_113968[(2)]);
var state_113968__$1 = state_113968;
var statearr_114030_114133 = state_113968__$1;
(statearr_114030_114133[(2)] = inst_113926);

(statearr_114030_114133[(1)] = (7));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113969 === (17))){
var state_113968__$1 = state_113968;
var statearr_114031_114134 = state_113968__$1;
(statearr_114031_114134[(2)] = null);

(statearr_114031_114134[(1)] = (19));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113969 === (3))){
var inst_113752 = (state_113968[(2)]);
var state_113968__$1 = state_113968;
var statearr_114032_114135 = state_113968__$1;
(statearr_114032_114135[(2)] = inst_113752);


cljs.core.async.impl.ioc_helpers.process_exception(state_113968__$1);

return cljs.core.cst$kw$recur;
} else {
if((state_val_113969 === (12))){
var inst_113773 = cljs.core.not(orderBy);
var state_113968__$1 = state_113968;
if(inst_113773){
var statearr_114033_114136 = state_113968__$1;
(statearr_114033_114136[(1)] = (17));

} else {
var statearr_114034_114137 = state_113968__$1;
(statearr_114034_114137[(1)] = (18));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_113969 === (2))){
var inst_113966 = (state_113968[(2)]);
var state_113968__$1 = state_113968;
return cljs.core.async.impl.ioc_helpers.return_chan(state_113968__$1,inst_113966);
} else {
if((state_val_113969 === (66))){
var state_113968__$1 = state_113968;
if(cljs.core.truth_(inVector_QMARK_)){
var statearr_114035_114138 = state_113968__$1;
(statearr_114035_114138[(1)] = (69));

} else {
var statearr_114036_114139 = state_113968__$1;
(statearr_114036_114139[(1)] = (70));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_113969 === (23))){
var inst_113786 = (state_113968[(14)]);
var inst_113784 = cljs.core.second(orderBy);
var inst_113785 = fluree.db.util.core.index_of(groupBy,inst_113784);
var inst_113786__$1 = cljs.core.first(orderBy);
var inst_113787 = cljs.core._EQ_.cljs$core$IFn$_invoke$arity$2("DESC",inst_113786__$1);
var state_113968__$1 = (function (){var statearr_114037 = state_113968;
(statearr_114037[(13)] = inst_113785);

(statearr_114037[(14)] = inst_113786__$1);

return statearr_114037;
})();
if(inst_113787){
var statearr_114038_114140 = state_113968__$1;
(statearr_114038_114140[(1)] = (26));

} else {
var statearr_114039_114141 = state_113968__$1;
(statearr_114039_114141[(1)] = (27));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_113969 === (47))){
var inst_113875 = (state_113968[(15)]);
var inst_113878 = fluree.db.query.fql.process_ad_hoc_group.cljs$core$IFn$_invoke$arity$4(db,inst_113875,select_spec,opts);
var state_113968__$1 = state_113968;
return cljs.core.async.impl.ioc_helpers.take_BANG_(state_113968__$1,(50),inst_113878);
} else {
if((state_val_113969 === (35))){
var inst_113807 = (state_113968[(24)]);
var inst_113815 = (state_113968[(2)]);
var inst_113816 = fluree.db.util.async.throw_err(inst_113815);
var inst_113817 = [inst_113807];
var inst_113818 = [inst_113816];
var inst_113819 = cljs.core.PersistentHashMap.fromArrays(inst_113817,inst_113818);
var state_113968__$1 = state_113968;
var statearr_114040_114142 = state_113968__$1;
(statearr_114040_114142[(2)] = inst_113819);

(statearr_114040_114142[(1)] = (34));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113969 === (76))){
var state_113968__$1 = state_113968;
var statearr_114041_114143 = state_113968__$1;
(statearr_114041_114143[(1)] = (78));



return cljs.core.cst$kw$recur;
} else {
if((state_val_113969 === (19))){
var inst_113802 = (state_113968[(2)]);
var state_113968__$1 = state_113968;
var statearr_114043_114144 = state_113968__$1;
(statearr_114043_114144[(2)] = inst_113802);

(statearr_114043_114144[(1)] = (13));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113969 === (57))){
var inst_113905 = (state_113968[(2)]);
var state_113968__$1 = state_113968;
var statearr_114044_114145 = state_113968__$1;
(statearr_114044_114145[(2)] = inst_113905);

(statearr_114044_114145[(1)] = (53));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113969 === (68))){
var inst_113962 = (state_113968[(2)]);
var state_113968__$1 = state_113968;
var statearr_114045_114146 = state_113968__$1;
(statearr_114045_114146[(2)] = inst_113962);

(statearr_114045_114146[(1)] = (7));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113969 === (11))){
var inst_113765 = cljs.core.first(orderBy);
var inst_113766 = cljs.core._EQ_.cljs$core$IFn$_invoke$arity$2(inst_113765,"DESC");
var state_113968__$1 = state_113968;
if(inst_113766){
var statearr_114046_114147 = state_113968__$1;
(statearr_114046_114147[(1)] = (14));

} else {
var statearr_114047_114148 = state_113968__$1;
(statearr_114047_114148[(1)] = (15));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_113969 === (9))){
var state_113968__$1 = state_113968;
var statearr_114048_114149 = state_113968__$1;
(statearr_114048_114149[(2)] = orderBy);

(statearr_114048_114149[(1)] = (10));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113969 === (5))){
var inst_113757 = fluree.db.query.fql.ad_hoc_group_by(res,groupBy);
var state_113968__$1 = (function (){var statearr_114049 = state_113968;
(statearr_114049[(12)] = inst_113757);

return statearr_114049;
})();
if(cljs.core.truth_(orderBy)){
var statearr_114050_114150 = state_113968__$1;
(statearr_114050_114150[(1)] = (8));

} else {
var statearr_114051_114151 = state_113968__$1;
(statearr_114051_114151[(1)] = (9));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_113969 === (14))){
var inst_113757 = (state_113968[(12)]);
var inst_113768 = (function (){var group_map = inst_113757;
return ((function (group_map,inst_113757,state_val_113969,c__99809__auto__,map__113748,map__113748__$1,res,headers,vars,map__113749,map__113749__$1,select_spec,groupBy,orderBy,limit,selectOne_QMARK_,selectDistinct_QMARK_,inVector_QMARK_,offset){
return (function (x,y){
return ((-1) * fluree.db.query.fql.compare_fn(x,y));
});
;})(group_map,inst_113757,state_val_113969,c__99809__auto__,map__113748,map__113748__$1,res,headers,vars,map__113749,map__113749__$1,select_spec,groupBy,orderBy,limit,selectOne_QMARK_,selectDistinct_QMARK_,inVector_QMARK_,offset))
})();
var state_113968__$1 = state_113968;
var statearr_114052_114152 = state_113968__$1;
(statearr_114052_114152[(2)] = inst_113768);

(statearr_114052_114152[(1)] = (16));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113969 === (45))){
var state_113968__$1 = state_113968;
var statearr_114053_114153 = state_113968__$1;
(statearr_114053_114153[(2)] = null);

(statearr_114053_114153[(1)] = (46));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113969 === (53))){
var inst_113907 = (state_113968[(2)]);
var state_113968__$1 = state_113968;
var statearr_114054_114154 = state_113968__$1;
(statearr_114054_114154[(2)] = inst_113907);

(statearr_114054_114154[(1)] = (49));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113969 === (78))){
var inst_113935 = (state_113968[(7)]);
var state_113968__$1 = state_113968;
var statearr_114055_114155 = state_113968__$1;
(statearr_114055_114155[(2)] = inst_113935);

(statearr_114055_114155[(1)] = (80));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113969 === (26))){
var inst_113757 = (state_113968[(12)]);
var inst_113785 = (state_113968[(13)]);
var inst_113786 = (state_113968[(14)]);
var inst_113789 = (function (){var group_map = inst_113757;
var orderByIdx = inst_113785;
var orderDirection = inst_113786;
return ((function (group_map,orderByIdx,orderDirection,inst_113757,inst_113785,inst_113786,state_val_113969,c__99809__auto__,map__113748,map__113748__$1,res,headers,vars,map__113749,map__113749__$1,select_spec,groupBy,orderBy,limit,selectOne_QMARK_,selectDistinct_QMARK_,inVector_QMARK_,offset){
return (function (x,y){
return ((-1) * fluree.db.query.fql.compare_fn(cljs.core.nth.cljs$core$IFn$_invoke$arity$2(x,orderByIdx),cljs.core.nth.cljs$core$IFn$_invoke$arity$2(y,orderByIdx)));
});
;})(group_map,orderByIdx,orderDirection,inst_113757,inst_113785,inst_113786,state_val_113969,c__99809__auto__,map__113748,map__113748__$1,res,headers,vars,map__113749,map__113749__$1,select_spec,groupBy,orderBy,limit,selectOne_QMARK_,selectDistinct_QMARK_,inVector_QMARK_,offset))
})();
var state_113968__$1 = state_113968;
var statearr_114056_114156 = state_113968__$1;
(statearr_114056_114156[(2)] = inst_113789);

(statearr_114056_114156[(1)] = (28));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113969 === (16))){
var inst_113771 = (state_113968[(2)]);
var state_113968__$1 = state_113968;
var statearr_114057_114157 = state_113968__$1;
(statearr_114057_114157[(2)] = inst_113771);

(statearr_114057_114157[(1)] = (13));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113969 === (79))){
var state_113968__$1 = state_113968;
var statearr_114058_114158 = state_113968__$1;
(statearr_114058_114158[(2)] = null);

(statearr_114058_114158[(1)] = (80));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113969 === (38))){
var inst_113848 = (state_113968[(10)]);
var state_113968__$1 = state_113968;
var statearr_114059_114159 = state_113968__$1;
(statearr_114059_114159[(2)] = inst_113848);

(statearr_114059_114159[(1)] = (40));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113969 === (30))){
var state_113968__$1 = state_113968;
var statearr_114060_114160 = state_113968__$1;
(statearr_114060_114160[(2)] = null);

(statearr_114060_114160[(1)] = (31));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113969 === (73))){
var state_113968__$1 = state_113968;
if(cljs.core.truth_(selectDistinct_QMARK_)){
var statearr_114061_114161 = state_113968__$1;
(statearr_114061_114161[(1)] = (75));

} else {
var statearr_114062_114162 = state_113968__$1;
(statearr_114062_114162[(1)] = (76));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_113969 === (10))){
var inst_113763 = (state_113968[(2)]);
var state_113968__$1 = state_113968;
if(cljs.core.truth_(inst_113763)){
var statearr_114063_114163 = state_113968__$1;
(statearr_114063_114163[(1)] = (11));

} else {
var statearr_114064_114164 = state_113968__$1;
(statearr_114064_114164[(1)] = (12));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_113969 === (18))){
var state_113968__$1 = state_113968;
if(cljs.core.truth_(orderBy)){
var statearr_114065_114165 = state_113968__$1;
(statearr_114065_114165[(1)] = (20));

} else {
var statearr_114066_114166 = state_113968__$1;
(statearr_114066_114166[(1)] = (21));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_113969 === (52))){
var inst_113872 = (state_113968[(17)]);
var inst_113893 = (limit < inst_113872);
var state_113968__$1 = state_113968;
if(cljs.core.truth_(inst_113893)){
var statearr_114067_114167 = state_113968__$1;
(statearr_114067_114167[(1)] = (55));

} else {
var statearr_114068_114168 = state_113968__$1;
(statearr_114068_114168[(1)] = (56));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_113969 === (67))){
var state_113968__$1 = state_113968;
if(cljs.core.truth_(selectOne_QMARK_)){
var statearr_114069_114169 = state_113968__$1;
(statearr_114069_114169[(1)] = (72));

} else {
var statearr_114070_114170 = state_113968__$1;
(statearr_114070_114170[(1)] = (73));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_113969 === (71))){
var inst_113945 = (state_113968[(2)]);
var state_113968__$1 = state_113968;
var statearr_114071_114171 = state_113968__$1;
(statearr_114071_114171[(2)] = inst_113945);

(statearr_114071_114171[(1)] = (68));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113969 === (42))){
var state_113968__$1 = state_113968;
var statearr_114072_114172 = state_113968__$1;
(statearr_114072_114172[(1)] = (44));



return cljs.core.cst$kw$recur;
} else {
if((state_val_113969 === (80))){
var inst_113956 = (state_113968[(2)]);
var state_113968__$1 = state_113968;
var statearr_114074_114173 = state_113968__$1;
(statearr_114074_114173[(2)] = inst_113956);

(statearr_114074_114173[(1)] = (77));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113969 === (37))){
var inst_113804 = (state_113968[(9)]);
var inst_113918 = (state_113968[(2)]);
var state_113968__$1 = (function (){var statearr_114075 = state_113968;
(statearr_114075[(8)] = inst_113918);

return statearr_114075;
})();
if(cljs.core.truth_(inst_113804)){
var statearr_114076_114174 = state_113968__$1;
(statearr_114076_114174[(1)] = (59));

} else {
var statearr_114077_114175 = state_113968__$1;
(statearr_114077_114175[(1)] = (60));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_113969 === (63))){
var state_113968__$1 = state_113968;
var statearr_114078_114176 = state_113968__$1;
(statearr_114078_114176[(2)] = limit);

(statearr_114078_114176[(1)] = (64));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113969 === (8))){
var inst_113759 = cljs.core.second(orderBy);
var inst_113760 = cljs.core._EQ_.cljs$core$IFn$_invoke$arity$2(inst_113759,groupBy);
var state_113968__$1 = state_113968;
var statearr_114079_114177 = state_113968__$1;
(statearr_114079_114177[(2)] = inst_113760);

(statearr_114079_114177[(1)] = (10));


return cljs.core.cst$kw$recur;
} else {
if((state_val_113969 === (49))){
var inst_113909 = (state_113968[(2)]);
var state_113968__$1 = state_113968;
var statearr_114080_114178 = state_113968__$1;
(statearr_114080_114178[(2)] = inst_113909);

(statearr_114080_114178[(1)] = (46));


return cljs.core.cst$kw$recur;
} else {
return null;
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
});})(c__99809__auto__,map__113748,map__113748__$1,res,headers,vars,map__113749,map__113749__$1,select_spec,groupBy,orderBy,limit,selectOne_QMARK_,selectDistinct_QMARK_,inVector_QMARK_,offset))
;
return ((function (switch__99702__auto__,c__99809__auto__,map__113748,map__113748__$1,res,headers,vars,map__113749,map__113749__$1,select_spec,groupBy,orderBy,limit,selectOne_QMARK_,selectDistinct_QMARK_,inVector_QMARK_,offset){
return (function() {
var fluree$db$query$fql$process_ad_hoc_res_$_state_machine__99703__auto__ = null;
var fluree$db$query$fql$process_ad_hoc_res_$_state_machine__99703__auto____0 = (function (){
var statearr_114081 = [null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null];
(statearr_114081[(0)] = fluree$db$query$fql$process_ad_hoc_res_$_state_machine__99703__auto__);

(statearr_114081[(1)] = (1));

return statearr_114081;
});
var fluree$db$query$fql$process_ad_hoc_res_$_state_machine__99703__auto____1 = (function (state_113968){
while(true){
var ret_value__99704__auto__ = (function (){try{while(true){
var result__99705__auto__ = switch__99702__auto__(state_113968);
if(cljs.core.keyword_identical_QMARK_(result__99705__auto__,cljs.core.cst$kw$recur)){
continue;
} else {
return result__99705__auto__;
}
break;
}
}catch (e114082){if((e114082 instanceof Object)){
var ex__99706__auto__ = e114082;
var statearr_114083_114179 = state_113968;
(statearr_114083_114179[(5)] = ex__99706__auto__);


cljs.core.async.impl.ioc_helpers.process_exception(state_113968);

return cljs.core.cst$kw$recur;
} else {
throw e114082;

}
}})();
if(cljs.core.keyword_identical_QMARK_(ret_value__99704__auto__,cljs.core.cst$kw$recur)){
var G__114180 = state_113968;
state_113968 = G__114180;
continue;
} else {
return ret_value__99704__auto__;
}
break;
}
});
fluree$db$query$fql$process_ad_hoc_res_$_state_machine__99703__auto__ = function(state_113968){
switch(arguments.length){
case 0:
return fluree$db$query$fql$process_ad_hoc_res_$_state_machine__99703__auto____0.call(this);
case 1:
return fluree$db$query$fql$process_ad_hoc_res_$_state_machine__99703__auto____1.call(this,state_113968);
}
throw(new Error('Invalid arity: ' + arguments.length));
};
fluree$db$query$fql$process_ad_hoc_res_$_state_machine__99703__auto__.cljs$core$IFn$_invoke$arity$0 = fluree$db$query$fql$process_ad_hoc_res_$_state_machine__99703__auto____0;
fluree$db$query$fql$process_ad_hoc_res_$_state_machine__99703__auto__.cljs$core$IFn$_invoke$arity$1 = fluree$db$query$fql$process_ad_hoc_res_$_state_machine__99703__auto____1;
return fluree$db$query$fql$process_ad_hoc_res_$_state_machine__99703__auto__;
})()
;})(switch__99702__auto__,c__99809__auto__,map__113748,map__113748__$1,res,headers,vars,map__113749,map__113749__$1,select_spec,groupBy,orderBy,limit,selectOne_QMARK_,selectDistinct_QMARK_,inVector_QMARK_,offset))
})();
var state__99811__auto__ = (function (){var statearr_114084 = (f__99810__auto__.cljs$core$IFn$_invoke$arity$0 ? f__99810__auto__.cljs$core$IFn$_invoke$arity$0() : f__99810__auto__.call(null));
(statearr_114084[(6)] = c__99809__auto__);

return statearr_114084;
})();
return cljs.core.async.impl.ioc_helpers.run_state_machine_wrapped(state__99811__auto__);
});})(c__99809__auto__,map__113748,map__113748__$1,res,headers,vars,map__113749,map__113749__$1,select_spec,groupBy,orderBy,limit,selectOne_QMARK_,selectDistinct_QMARK_,inVector_QMARK_,offset))
);

return c__99809__auto__;
});
fluree.db.query.fql.get_ad_hoc_select_spec = (function fluree$db$query$fql$get_ad_hoc_select_spec(headers,vars,p__114183,opts){
var map__114184 = p__114183;
var map__114184__$1 = (((((!((map__114184 == null))))?(((((map__114184.cljs$lang$protocol_mask$partition0$ & (64))) || ((cljs.core.PROTOCOL_SENTINEL === map__114184.cljs$core$ISeq$))))?true:false):false))?cljs.core.apply.cljs$core$IFn$_invoke$arity$2(cljs.core.hash_map,map__114184):map__114184);
var query_map = map__114184__$1;
var select = cljs.core.get.cljs$core$IFn$_invoke$arity$2(map__114184__$1,cljs.core.cst$kw$select);
var orderBy = cljs.core.get.cljs$core$IFn$_invoke$arity$2(map__114184__$1,cljs.core.cst$kw$orderBy);
var limit = cljs.core.get.cljs$core$IFn$_invoke$arity$2(map__114184__$1,cljs.core.cst$kw$limit);
var offset = cljs.core.get.cljs$core$IFn$_invoke$arity$2(map__114184__$1,cljs.core.cst$kw$offset);
var selectDistinct = cljs.core.get.cljs$core$IFn$_invoke$arity$2(map__114184__$1,cljs.core.cst$kw$selectDistinct);
var prettyPrint = cljs.core.get.cljs$core$IFn$_invoke$arity$2(map__114184__$1,cljs.core.cst$kw$prettyPrint);
var selectOne = cljs.core.get.cljs$core$IFn$_invoke$arity$2(map__114184__$1,cljs.core.cst$kw$selectOne);
var groupBy = cljs.core.get.cljs$core$IFn$_invoke$arity$2(map__114184__$1,cljs.core.cst$kw$groupBy);
var selectReduced = cljs.core.get.cljs$core$IFn$_invoke$arity$2(map__114184__$1,cljs.core.cst$kw$selectReduced);
var _ = (cljs.core.truth_((function (){var or__4131__auto__ = orderBy;
if(cljs.core.truth_(or__4131__auto__)){
return or__4131__auto__;
} else {
var or__4131__auto____$1 = groupBy;
if(cljs.core.truth_(or__4131__auto____$1)){
return or__4131__auto____$1;
} else {
var or__4131__auto____$2 = limit;
if(cljs.core.truth_(or__4131__auto____$2)){
return or__4131__auto____$2;
} else {
var or__4131__auto____$3 = offset;
if(cljs.core.truth_(or__4131__auto____$3)){
return or__4131__auto____$3;
} else {
return prettyPrint;
}
}
}
}
})())?fluree.db.util.log.warn.cljs$core$IFn$_invoke$arity$variadic(cljs.core.prim_seq.cljs$core$IFn$_invoke$arity$2([["The query options: limit, offset, groupBy, prettyPrint, and orderBy should be included in the opts map. Top-level options are being deprecated. Provided: ",cljs.core.pr_str.cljs$core$IFn$_invoke$arity$variadic(cljs.core.prim_seq.cljs$core$IFn$_invoke$arity$2([query_map], 0))].join('')], 0)):null);
var select_smt = (function (){var or__4131__auto__ = selectOne;
if(cljs.core.truth_(or__4131__auto__)){
return or__4131__auto__;
} else {
var or__4131__auto____$1 = select;
if(cljs.core.truth_(or__4131__auto____$1)){
return or__4131__auto____$1;
} else {
var or__4131__auto____$2 = selectDistinct;
if(cljs.core.truth_(or__4131__auto____$2)){
return or__4131__auto____$2;
} else {
return selectReduced;
}
}
}
})();
var inVector_QMARK_ = cljs.core.vector_QMARK_(select_smt);
var select_smt__$1 = ((inVector_QMARK_)?select_smt:new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [select_smt], null));
var parsed_select = fluree.db.query.fql.parse_select(headers,vars,select_smt__$1);
var aggregates = cljs.core.filter.cljs$core$IFn$_invoke$arity$2(((function (_,select_smt,inVector_QMARK_,select_smt__$1,parsed_select,map__114184,map__114184__$1,query_map,select,orderBy,limit,offset,selectDistinct,prettyPrint,selectOne,groupBy,selectReduced){
return (function (p1__114181_SHARP_){
return cljs.core.contains_QMARK_(p1__114181_SHARP_,cljs.core.cst$kw$code);
});})(_,select_smt,inVector_QMARK_,select_smt__$1,parsed_select,map__114184,map__114184__$1,query_map,select,orderBy,limit,offset,selectDistinct,prettyPrint,selectOne,groupBy,selectReduced))
,parsed_select);
var expandMap_QMARK_ = cljs.core.some(((function (_,select_smt,inVector_QMARK_,select_smt__$1,parsed_select,aggregates,map__114184,map__114184__$1,query_map,select,orderBy,limit,offset,selectDistinct,prettyPrint,selectOne,groupBy,selectReduced){
return (function (p1__114182_SHARP_){
return cljs.core.contains_QMARK_(p1__114182_SHARP_,cljs.core.cst$kw$selection);
});})(_,select_smt,inVector_QMARK_,select_smt__$1,parsed_select,aggregates,map__114184,map__114184__$1,query_map,select,orderBy,limit,offset,selectDistinct,prettyPrint,selectOne,groupBy,selectReduced))
,parsed_select);
var aggregates__$1 = ((cljs.core.empty_QMARK_(aggregates))?null:aggregates);
var orderBy__$1 = (function (){var temp__5735__auto__ = cljs.core.cst$kw$orderBy.cljs$core$IFn$_invoke$arity$1(opts);
if(cljs.core.truth_(temp__5735__auto__)){
var orderBy__$1 = temp__5735__auto__;
if(cljs.core.truth_((function (){var or__4131__auto__ = typeof orderBy__$1 === 'string';
if(or__4131__auto__){
return or__4131__auto__;
} else {
var and__4120__auto__ = cljs.core.vector_QMARK_(orderBy__$1);
if(and__4120__auto__){
var G__114193 = cljs.core.first(orderBy__$1);
var fexpr__114192 = new cljs.core.PersistentHashSet(null, new cljs.core.PersistentArrayMap(null, 2, ["DESC",null,"ASC",null], null), null);
return (fexpr__114192.cljs$core$IFn$_invoke$arity$1 ? fexpr__114192.cljs$core$IFn$_invoke$arity$1(G__114193) : fexpr__114192.call(null,G__114193));
} else {
return and__4120__auto__;
}
}
})())){
if(cljs.core.vector_QMARK_(orderBy__$1)){
return orderBy__$1;
} else {
return new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, ["ASC",orderBy__$1], null);
}
} else {
throw cljs.core.ex_info.cljs$core$IFn$_invoke$arity$2(["Invalid orderBy clause, must by variable or two-tuple formatted ['ASC' or 'DESC', var]. Provided: ",cljs.core.str.cljs$core$IFn$_invoke$arity$1(orderBy__$1)].join(''),new cljs.core.PersistentArrayMap(null, 2, [cljs.core.cst$kw$status,(400),cljs.core.cst$kw$error,cljs.core.cst$kw$db_SLASH_invalid_DASH_query], null));
}
} else {
return null;
}
})();
return cljs.core.PersistentHashMap.fromArrays([cljs.core.cst$kw$expandMaps_QMARK_,cljs.core.cst$kw$limit,cljs.core.cst$kw$offset,cljs.core.cst$kw$aggregates,cljs.core.cst$kw$selectOne_QMARK_,cljs.core.cst$kw$prettyPrint,cljs.core.cst$kw$groupBy,cljs.core.cst$kw$selectDistinct_QMARK_,cljs.core.cst$kw$select,cljs.core.cst$kw$orderBy,cljs.core.cst$kw$inVector_QMARK_],[expandMap_QMARK_,(function (){var or__4131__auto__ = cljs.core.cst$kw$limit.cljs$core$IFn$_invoke$arity$1(opts);
if(cljs.core.truth_(or__4131__auto__)){
return or__4131__auto__;
} else {
return (100);
}
})(),(function (){var or__4131__auto__ = cljs.core.cst$kw$offset.cljs$core$IFn$_invoke$arity$1(opts);
if(cljs.core.truth_(or__4131__auto__)){
return or__4131__auto__;
} else {
return (0);
}
})(),aggregates__$1,cljs.core.boolean$(selectOne),(function (){var or__4131__auto__ = cljs.core.cst$kw$prettyPrint.cljs$core$IFn$_invoke$arity$1(opts);
if(cljs.core.truth_(or__4131__auto__)){
return or__4131__auto__;
} else {
return false;
}
})(),cljs.core.cst$kw$groupBy.cljs$core$IFn$_invoke$arity$1(opts),cljs.core.boolean$((function (){var or__4131__auto__ = selectDistinct;
if(cljs.core.truth_(or__4131__auto__)){
return or__4131__auto__;
} else {
return selectReduced;
}
})()),parsed_select,orderBy__$1,inVector_QMARK_]);
});
fluree.db.query.fql.construct_triples = (function fluree$db$query$fql$construct_triples(p__114194,p__114195){
var map__114196 = p__114194;
var map__114196__$1 = (((((!((map__114196 == null))))?(((((map__114196.cljs$lang$protocol_mask$partition0$ & (64))) || ((cljs.core.PROTOCOL_SENTINEL === map__114196.cljs$core$ISeq$))))?true:false):false))?cljs.core.apply.cljs$core$IFn$_invoke$arity$2(cljs.core.hash_map,map__114196):map__114196);
var query_map = map__114196__$1;
var construct = cljs.core.get.cljs$core$IFn$_invoke$arity$2(map__114196__$1,cljs.core.cst$kw$construct);
var map__114197 = p__114195;
var map__114197__$1 = (((((!((map__114197 == null))))?(((((map__114197.cljs$lang$protocol_mask$partition0$ & (64))) || ((cljs.core.PROTOCOL_SENTINEL === map__114197.cljs$core$ISeq$))))?true:false):false))?cljs.core.apply.cljs$core$IFn$_invoke$arity$2(cljs.core.hash_map,map__114197):map__114197);
var where_result = map__114197__$1;
var headers = cljs.core.get.cljs$core$IFn$_invoke$arity$2(map__114197__$1,cljs.core.cst$kw$headers);
var tuples = cljs.core.get.cljs$core$IFn$_invoke$arity$2(map__114197__$1,cljs.core.cst$kw$tuples);
var vec__114200 = cljs.core.map.cljs$core$IFn$_invoke$arity$2(((function (map__114196,map__114196__$1,query_map,construct,map__114197,map__114197__$1,where_result,headers,tuples){
return (function (construct_item){
var temp__5733__auto__ = fluree.db.util.core.index_of(headers,cljs.core.symbol.cljs$core$IFn$_invoke$arity$1(construct_item));
if(cljs.core.truth_(temp__5733__auto__)){
var index_of = temp__5733__auto__;
return ((function (index_of,temp__5733__auto__,map__114196,map__114196__$1,query_map,construct,map__114197,map__114197__$1,where_result,headers,tuples){
return (function (row){
return cljs.core.nth.cljs$core$IFn$_invoke$arity$2(row,index_of);
});
;})(index_of,temp__5733__auto__,map__114196,map__114196__$1,query_map,construct,map__114197,map__114197__$1,where_result,headers,tuples))
} else {
return ((function (temp__5733__auto__,map__114196,map__114196__$1,query_map,construct,map__114197,map__114197__$1,where_result,headers,tuples){
return (function (row){
return construct_item;
});
;})(temp__5733__auto__,map__114196,map__114196__$1,query_map,construct,map__114197,map__114197__$1,where_result,headers,tuples))
}
});})(map__114196,map__114196__$1,query_map,construct,map__114197,map__114197__$1,where_result,headers,tuples))
,construct);
var fn1 = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(vec__114200,(0),null);
var fn2 = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(vec__114200,(1),null);
var fn3 = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(vec__114200,(2),null);
return cljs.core.map.cljs$core$IFn$_invoke$arity$2(((function (vec__114200,fn1,fn2,fn3,map__114196,map__114196__$1,query_map,construct,map__114197,map__114197__$1,where_result,headers,tuples){
return (function (res){
return new cljs.core.PersistentVector(null, 3, 5, cljs.core.PersistentVector.EMPTY_NODE, [(fn1.cljs$core$IFn$_invoke$arity$1 ? fn1.cljs$core$IFn$_invoke$arity$1(res) : fn1.call(null,res)),(fn2.cljs$core$IFn$_invoke$arity$1 ? fn2.cljs$core$IFn$_invoke$arity$1(res) : fn2.call(null,res)),(fn3.cljs$core$IFn$_invoke$arity$1 ? fn3.cljs$core$IFn$_invoke$arity$1(res) : fn3.call(null,res))], null);
});})(vec__114200,fn1,fn2,fn3,map__114196,map__114196__$1,query_map,construct,map__114197,map__114197__$1,where_result,headers,tuples))
,tuples);
});
fluree.db.query.fql.ad_hoc_query = (function fluree$db$query$fql$ad_hoc_query(db,fuel,max_fuel,query_map,opts){
var c__99809__auto__ = cljs.core.async.chan.cljs$core$IFn$_invoke$arity$1((1));
cljs.core.async.impl.dispatch.run(((function (c__99809__auto__){
return (function (){
var f__99810__auto__ = (function (){var switch__99702__auto__ = ((function (c__99809__auto__){
return (function (state_114230){
var state_val_114231 = (state_114230[(1)]);
if((state_val_114231 === (7))){
var state_114230__$1 = state_114230;
var statearr_114232_114248 = state_114230__$1;
(statearr_114232_114248[(1)] = (9));



return cljs.core.cst$kw$recur;
} else {
if((state_val_114231 === (1))){
var state_114230__$1 = state_114230;
var statearr_114234_114249 = state_114230__$1;
(statearr_114234_114249[(2)] = null);

(statearr_114234_114249[(1)] = (4));


return cljs.core.cst$kw$recur;
} else {
if((state_val_114231 === (4))){
var _ = cljs.core.async.impl.ioc_helpers.add_exception_frame(state_114230,(3),Error,null,(2));
var inst_114207 = fluree.db.query.analytical.q(query_map,fuel,max_fuel,db,opts);
var state_114230__$1 = state_114230;
return cljs.core.async.impl.ioc_helpers.take_BANG_(state_114230__$1,(5),inst_114207);
} else {
if((state_val_114231 === (6))){
var inst_114210 = (state_114230[(7)]);
var state_114230__$1 = state_114230;
var statearr_114235_114250 = state_114230__$1;
(statearr_114235_114250[(2)] = inst_114210);

(statearr_114235_114250[(1)] = (8));


return cljs.core.cst$kw$recur;
} else {
if((state_val_114231 === (3))){
var inst_114203 = (state_114230[(2)]);
var state_114230__$1 = state_114230;
var statearr_114236_114251 = state_114230__$1;
(statearr_114236_114251[(2)] = inst_114203);


cljs.core.async.impl.ioc_helpers.process_exception(state_114230__$1);

return cljs.core.cst$kw$recur;
} else {
if((state_val_114231 === (12))){
var inst_114220 = (state_114230[(2)]);
var inst_114221 = fluree.db.util.async.throw_err(inst_114220);
var state_114230__$1 = state_114230;
var statearr_114237_114252 = state_114230__$1;
(statearr_114237_114252[(2)] = inst_114221);

(statearr_114237_114252[(1)] = (11));


return cljs.core.cst$kw$recur;
} else {
if((state_val_114231 === (2))){
var inst_114228 = (state_114230[(2)]);
var state_114230__$1 = state_114230;
return cljs.core.async.impl.ioc_helpers.return_chan(state_114230__$1,inst_114228);
} else {
if((state_val_114231 === (11))){
var inst_114224 = (state_114230[(2)]);
var state_114230__$1 = state_114230;
var statearr_114238_114253 = state_114230__$1;
(statearr_114238_114253[(2)] = inst_114224);

(statearr_114238_114253[(1)] = (8));


return cljs.core.cst$kw$recur;
} else {
if((state_val_114231 === (9))){
var inst_114210 = (state_114230[(7)]);
var inst_114215 = cljs.core.cst$kw$headers.cljs$core$IFn$_invoke$arity$1(inst_114210);
var inst_114216 = cljs.core.cst$kw$vars.cljs$core$IFn$_invoke$arity$1(inst_114210);
var inst_114217 = fluree.db.query.fql.get_ad_hoc_select_spec(inst_114215,inst_114216,query_map,opts);
var inst_114218 = fluree.db.query.fql.process_ad_hoc_res(db,inst_114210,inst_114217,opts);
var state_114230__$1 = state_114230;
return cljs.core.async.impl.ioc_helpers.take_BANG_(state_114230__$1,(12),inst_114218);
} else {
if((state_val_114231 === (5))){
var inst_114210 = (state_114230[(7)]);
var inst_114209 = (state_114230[(2)]);
var inst_114210__$1 = fluree.db.util.async.throw_err(inst_114209);
var inst_114211 = fluree.db.util.core.exception_QMARK_(inst_114210__$1);
var state_114230__$1 = (function (){var statearr_114239 = state_114230;
(statearr_114239[(7)] = inst_114210__$1);

return statearr_114239;
})();
if(inst_114211){
var statearr_114240_114254 = state_114230__$1;
(statearr_114240_114254[(1)] = (6));

} else {
var statearr_114241_114255 = state_114230__$1;
(statearr_114241_114255[(1)] = (7));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_114231 === (10))){
var state_114230__$1 = state_114230;
var statearr_114242_114256 = state_114230__$1;
(statearr_114242_114256[(2)] = null);

(statearr_114242_114256[(1)] = (11));


return cljs.core.cst$kw$recur;
} else {
if((state_val_114231 === (8))){
var inst_114226 = (state_114230[(2)]);
var state_114230__$1 = state_114230;
var statearr_114243_114257 = state_114230__$1;
(statearr_114243_114257[(2)] = inst_114226);


cljs.core.async.impl.ioc_helpers.process_exception(state_114230__$1);

return cljs.core.cst$kw$recur;
} else {
return null;
}
}
}
}
}
}
}
}
}
}
}
}
});})(c__99809__auto__))
;
return ((function (switch__99702__auto__,c__99809__auto__){
return (function() {
var fluree$db$query$fql$ad_hoc_query_$_state_machine__99703__auto__ = null;
var fluree$db$query$fql$ad_hoc_query_$_state_machine__99703__auto____0 = (function (){
var statearr_114244 = [null,null,null,null,null,null,null,null];
(statearr_114244[(0)] = fluree$db$query$fql$ad_hoc_query_$_state_machine__99703__auto__);

(statearr_114244[(1)] = (1));

return statearr_114244;
});
var fluree$db$query$fql$ad_hoc_query_$_state_machine__99703__auto____1 = (function (state_114230){
while(true){
var ret_value__99704__auto__ = (function (){try{while(true){
var result__99705__auto__ = switch__99702__auto__(state_114230);
if(cljs.core.keyword_identical_QMARK_(result__99705__auto__,cljs.core.cst$kw$recur)){
continue;
} else {
return result__99705__auto__;
}
break;
}
}catch (e114245){if((e114245 instanceof Object)){
var ex__99706__auto__ = e114245;
var statearr_114246_114258 = state_114230;
(statearr_114246_114258[(5)] = ex__99706__auto__);


cljs.core.async.impl.ioc_helpers.process_exception(state_114230);

return cljs.core.cst$kw$recur;
} else {
throw e114245;

}
}})();
if(cljs.core.keyword_identical_QMARK_(ret_value__99704__auto__,cljs.core.cst$kw$recur)){
var G__114259 = state_114230;
state_114230 = G__114259;
continue;
} else {
return ret_value__99704__auto__;
}
break;
}
});
fluree$db$query$fql$ad_hoc_query_$_state_machine__99703__auto__ = function(state_114230){
switch(arguments.length){
case 0:
return fluree$db$query$fql$ad_hoc_query_$_state_machine__99703__auto____0.call(this);
case 1:
return fluree$db$query$fql$ad_hoc_query_$_state_machine__99703__auto____1.call(this,state_114230);
}
throw(new Error('Invalid arity: ' + arguments.length));
};
fluree$db$query$fql$ad_hoc_query_$_state_machine__99703__auto__.cljs$core$IFn$_invoke$arity$0 = fluree$db$query$fql$ad_hoc_query_$_state_machine__99703__auto____0;
fluree$db$query$fql$ad_hoc_query_$_state_machine__99703__auto__.cljs$core$IFn$_invoke$arity$1 = fluree$db$query$fql$ad_hoc_query_$_state_machine__99703__auto____1;
return fluree$db$query$fql$ad_hoc_query_$_state_machine__99703__auto__;
})()
;})(switch__99702__auto__,c__99809__auto__))
})();
var state__99811__auto__ = (function (){var statearr_114247 = (f__99810__auto__.cljs$core$IFn$_invoke$arity$0 ? f__99810__auto__.cljs$core$IFn$_invoke$arity$0() : f__99810__auto__.call(null));
(statearr_114247[(6)] = c__99809__auto__);

return statearr_114247;
})();
return cljs.core.async.impl.ioc_helpers.run_state_machine_wrapped(state__99811__auto__);
});})(c__99809__auto__))
);

return c__99809__auto__;
});
/**
 * Returns core async channel with results
 */
fluree.db.query.fql.query = (function fluree$db$query$fql$query(var_args){
var G__114261 = arguments.length;
switch (G__114261) {
case 2:
return fluree.db.query.fql.query.cljs$core$IFn$_invoke$arity$2((arguments[(0)]),(arguments[(1)]));

break;
case 3:
return fluree.db.query.fql.query.cljs$core$IFn$_invoke$arity$3((arguments[(0)]),(arguments[(1)]),(arguments[(2)]));

break;
default:
throw (new Error(["Invalid arity: ",cljs.core.str.cljs$core$IFn$_invoke$arity$1(arguments.length)].join('')));

}
});

fluree.db.query.fql.query.cljs$core$IFn$_invoke$arity$2 = (function (db,query_map){
return fluree.db.query.fql.query.cljs$core$IFn$_invoke$arity$3(db,query_map,null);
});

fluree.db.query.fql.query.cljs$core$IFn$_invoke$arity$3 = (function (db,query_map,opts){
var map__114262 = query_map;
var map__114262__$1 = (((((!((map__114262 == null))))?(((((map__114262.cljs$lang$protocol_mask$partition0$ & (64))) || ((cljs.core.PROTOCOL_SENTINEL === map__114262.cljs$core$ISeq$))))?true:false):false))?cljs.core.apply.cljs$core$IFn$_invoke$arity$2(cljs.core.hash_map,map__114262):map__114262);
var select = cljs.core.get.cljs$core$IFn$_invoke$arity$2(map__114262__$1,cljs.core.cst$kw$select);
var orderBy = cljs.core.get.cljs$core$IFn$_invoke$arity$2(map__114262__$1,cljs.core.cst$kw$orderBy);
var where = cljs.core.get.cljs$core$IFn$_invoke$arity$2(map__114262__$1,cljs.core.cst$kw$where);
var limit = cljs.core.get.cljs$core$IFn$_invoke$arity$2(map__114262__$1,cljs.core.cst$kw$limit);
var offset = cljs.core.get.cljs$core$IFn$_invoke$arity$2(map__114262__$1,cljs.core.cst$kw$offset);
var component = cljs.core.get.cljs$core$IFn$_invoke$arity$2(map__114262__$1,cljs.core.cst$kw$component);
var selectDistinct = cljs.core.get.cljs$core$IFn$_invoke$arity$2(map__114262__$1,cljs.core.cst$kw$selectDistinct);
var prettyPrint = cljs.core.get.cljs$core$IFn$_invoke$arity$2(map__114262__$1,cljs.core.cst$kw$prettyPrint);
var selectOne = cljs.core.get.cljs$core$IFn$_invoke$arity$2(map__114262__$1,cljs.core.cst$kw$selectOne);
var from = cljs.core.get.cljs$core$IFn$_invoke$arity$2(map__114262__$1,cljs.core.cst$kw$from);
var groupBy = cljs.core.get.cljs$core$IFn$_invoke$arity$2(map__114262__$1,cljs.core.cst$kw$groupBy);
var opts_SINGLEQUOTE_ = cljs.core.merge.cljs$core$IFn$_invoke$arity$variadic(cljs.core.prim_seq.cljs$core$IFn$_invoke$arity$2([new cljs.core.PersistentArrayMap(null, 6, [cljs.core.cst$kw$limit,limit,cljs.core.cst$kw$offset,(function (){var or__4131__auto__ = offset;
if(cljs.core.truth_(or__4131__auto__)){
return or__4131__auto__;
} else {
return (0);
}
})(),cljs.core.cst$kw$component,component,cljs.core.cst$kw$orderBy,orderBy,cljs.core.cst$kw$groupBy,groupBy,cljs.core.cst$kw$prettyPrint,prettyPrint], null),opts,cljs.core.cst$kw$opts.cljs$core$IFn$_invoke$arity$1(query_map)], 0));
var opts_SINGLEQUOTE__SINGLEQUOTE_ = (cljs.core.truth_(selectOne)?cljs.core.assoc.cljs$core$IFn$_invoke$arity$3(opts_SINGLEQUOTE_,cljs.core.cst$kw$limit,(1)):opts_SINGLEQUOTE_);
var opts_STAR_ = cljs.core.dissoc.cljs$core$IFn$_invoke$arity$2(opts_SINGLEQUOTE__SINGLEQUOTE_,cljs.core.cst$kw$cache);
if(cljs.core.truth_(cljs.core.cst$kw$cache.cljs$core$IFn$_invoke$arity$1(opts_STAR_))){
var oc = cljs.core.get_in.cljs$core$IFn$_invoke$arity$2(db,new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [cljs.core.cst$kw$conn,cljs.core.cst$kw$object_DASH_cache], null));
var G__114264 = new cljs.core.PersistentVector(null, 5, 5, cljs.core.PersistentVector.EMPTY_NODE, [cljs.core.cst$kw$query,cljs.core.cst$kw$block.cljs$core$IFn$_invoke$arity$1(db),query_map,cljs.core.dissoc.cljs$core$IFn$_invoke$arity$2(opts,cljs.core.cst$kw$fuel),cljs.core.cst$kw$auth.cljs$core$IFn$_invoke$arity$1(db)], null);
var G__114265 = ((function (G__114264,oc,map__114262,map__114262__$1,select,orderBy,where,limit,offset,component,selectDistinct,prettyPrint,selectOne,from,groupBy,opts_SINGLEQUOTE_,opts_SINGLEQUOTE__SINGLEQUOTE_,opts_STAR_){
return (function (_){
var pc = cljs.core.async.promise_chan.cljs$core$IFn$_invoke$arity$0();
var G__114266_114779 = (function (){var res = (function (){var G__114267 = fluree.db.query.fql.query.cljs$core$IFn$_invoke$arity$3(db,query_map,cljs.core.assoc.cljs$core$IFn$_invoke$arity$3(opts,cljs.core.cst$kw$cache,false));
return (cljs.core.async._LT__BANG__BANG_.cljs$core$IFn$_invoke$arity$1 ? cljs.core.async._LT__BANG__BANG_.cljs$core$IFn$_invoke$arity$1(G__114267) : cljs.core.async._LT__BANG__BANG_.call(null,G__114267));
})();
return cljs.core.async.put_BANG_.cljs$core$IFn$_invoke$arity$2(pc,res);
})();
(fluree.db.query.fql.future.cljs$core$IFn$_invoke$arity$1 ? fluree.db.query.fql.future.cljs$core$IFn$_invoke$arity$1(G__114266_114779) : fluree.db.query.fql.future.call(null,G__114266_114779));

return pc;
});})(G__114264,oc,map__114262,map__114262__$1,select,orderBy,where,limit,offset,component,selectDistinct,prettyPrint,selectOne,from,groupBy,opts_SINGLEQUOTE_,opts_SINGLEQUOTE__SINGLEQUOTE_,opts_STAR_))
;
return (oc.cljs$core$IFn$_invoke$arity$2 ? oc.cljs$core$IFn$_invoke$arity$2(G__114264,G__114265) : oc.call(null,G__114264,G__114265));
} else {
var max_fuel = cljs.core.cst$kw$max_DASH_fuel.cljs$core$IFn$_invoke$arity$1(opts_STAR_);
var fuel = (function (){var or__4131__auto__ = cljs.core.cst$kw$fuel.cljs$core$IFn$_invoke$arity$1(opts);
if(cljs.core.truth_(or__4131__auto__)){
return or__4131__auto__;
} else {
if(cljs.core.truth_((function (){var or__4131__auto____$1 = max_fuel;
if(cljs.core.truth_(or__4131__auto____$1)){
return or__4131__auto____$1;
} else {
return cljs.core.cst$kw$meta.cljs$core$IFn$_invoke$arity$1(opts);
}
})())){
return cljs.core.volatile_BANG_((0));
} else {
return null;
}
}
})();
if(cljs.core.sequential_QMARK_(where)){
return fluree.db.query.fql.ad_hoc_query(db,fuel,max_fuel,query_map,opts_STAR_);
} else {
var c__99809__auto__ = cljs.core.async.chan.cljs$core$IFn$_invoke$arity$1((1));
cljs.core.async.impl.dispatch.run(((function (c__99809__auto__,max_fuel,fuel,map__114262,map__114262__$1,select,orderBy,where,limit,offset,component,selectDistinct,prettyPrint,selectOne,from,groupBy,opts_SINGLEQUOTE_,opts_SINGLEQUOTE__SINGLEQUOTE_,opts_STAR_){
return (function (){
var f__99810__auto__ = (function (){var switch__99702__auto__ = ((function (c__99809__auto__,max_fuel,fuel,map__114262,map__114262__$1,select,orderBy,where,limit,offset,component,selectDistinct,prettyPrint,selectOne,from,groupBy,opts_SINGLEQUOTE_,opts_SINGLEQUOTE__SINGLEQUOTE_,opts_STAR_){
return (function (state_114603){
var state_val_114604 = (state_114603[(1)]);
if((state_val_114604 === (121))){
var inst_114586 = (state_114603[(7)]);
var inst_114588 = cljs.core.coll_QMARK_(inst_114586);
var inst_114589 = fluree.db.util.core.exception_QMARK_(inst_114586);
var inst_114590 = (!(inst_114589));
var inst_114591 = ((inst_114588) && (inst_114590));
var state_114603__$1 = state_114603;
var statearr_114605_114780 = state_114603__$1;
(statearr_114605_114780[(2)] = inst_114591);

(statearr_114605_114780[(1)] = (123));


return cljs.core.cst$kw$recur;
} else {
if((state_val_114604 === (65))){
var inst_114431 = (state_114603[(2)]);
var state_114603__$1 = state_114603;
if(cljs.core.truth_(inst_114431)){
var statearr_114606_114781 = state_114603__$1;
(statearr_114606_114781[(1)] = (66));

} else {
var statearr_114607_114782 = state_114603__$1;
(statearr_114607_114782[(1)] = (67));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_114604 === (70))){
var inst_114315 = (state_114603[(8)]);
var inst_114317 = (state_114603[(9)]);
var inst_114436 = [cljs.core.cst$kw$limit,cljs.core.cst$kw$offset];
var inst_114437 = [inst_114315,inst_114317];
var inst_114438 = cljs.core.PersistentHashMap.fromArrays(inst_114436,inst_114437);
var state_114603__$1 = state_114603;
var statearr_114608_114783 = state_114603__$1;
(statearr_114608_114783[(2)] = inst_114438);

(statearr_114608_114783[(1)] = (71));


return cljs.core.cst$kw$recur;
} else {
if((state_val_114604 === (62))){
var inst_114419 = (state_114603[(2)]);
var inst_114420 = fluree.db.util.async.throw_err(inst_114419);
var state_114603__$1 = state_114603;
var statearr_114609_114784 = state_114603__$1;
(statearr_114609_114784[(2)] = inst_114420);

(statearr_114609_114784[(1)] = (51));


return cljs.core.cst$kw$recur;
} else {
if((state_val_114604 === (74))){
var inst_114314 = (state_114603[(10)]);
var state_114603__$1 = state_114603;
if(cljs.core.truth_(inst_114314)){
var statearr_114610_114785 = state_114603__$1;
(statearr_114610_114785[(1)] = (77));

} else {
var statearr_114611_114786 = state_114603__$1;
(statearr_114611_114786[(1)] = (78));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_114604 === (110))){
var inst_114519 = (state_114603[(11)]);
var inst_114543 = (state_114603[(2)]);
var inst_114511 = inst_114519;
var inst_114512 = inst_114543;
var state_114603__$1 = (function (){var statearr_114612 = state_114603;
(statearr_114612[(12)] = inst_114512);

(statearr_114612[(13)] = inst_114511);

return statearr_114612;
})();
var statearr_114613_114787 = state_114603__$1;
(statearr_114613_114787[(2)] = null);

(statearr_114613_114787[(1)] = (96));


return cljs.core.cst$kw$recur;
} else {
if((state_val_114604 === (7))){
var inst_114292 = (state_114603[(2)]);
var inst_114294 = (opts_STAR_ == null);
var inst_114295 = cljs.core.not(inst_114294);
var state_114603__$1 = (function (){var statearr_114614 = state_114603;
(statearr_114614[(14)] = inst_114292);

return statearr_114614;
})();
if(inst_114295){
var statearr_114615_114788 = state_114603__$1;
(statearr_114615_114788[(1)] = (14));

} else {
var statearr_114616_114789 = state_114603__$1;
(statearr_114616_114789[(1)] = (15));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_114604 === (59))){
var inst_114315 = (state_114603[(8)]);
var inst_114317 = (state_114603[(9)]);
var inst_114404 = [cljs.core.cst$kw$limit,cljs.core.cst$kw$offset];
var inst_114405 = [inst_114315,inst_114317];
var inst_114406 = cljs.core.PersistentHashMap.fromArrays(inst_114404,inst_114405);
var state_114603__$1 = state_114603;
var statearr_114617_114790 = state_114603__$1;
(statearr_114617_114790[(2)] = inst_114406);

(statearr_114617_114790[(1)] = (60));


return cljs.core.cst$kw$recur;
} else {
if((state_val_114604 === (86))){
var state_114603__$1 = state_114603;
var statearr_114618_114791 = state_114603__$1;
(statearr_114618_114791[(2)] = null);

(statearr_114618_114791[(1)] = (88));


return cljs.core.cst$kw$recur;
} else {
if((state_val_114604 === (20))){
var inst_114310 = cljs.core.apply.cljs$core$IFn$_invoke$arity$2(cljs.core.hash_map,opts_STAR_);
var state_114603__$1 = state_114603;
var statearr_114619_114792 = state_114603__$1;
(statearr_114619_114792[(2)] = inst_114310);

(statearr_114619_114792[(1)] = (22));


return cljs.core.cst$kw$recur;
} else {
if((state_val_114604 === (72))){
var inst_114325 = (state_114603[(15)]);
var inst_114327 = (state_114603[(16)]);
var inst_114443 = (state_114603[(2)]);
var inst_114444 = fluree.db.util.async.throw_err(inst_114443);
var inst_114445 = fluree.db.query.fql.flake_select.cljs$core$IFn$_invoke$arity$6(db,inst_114327,fuel,max_fuel,inst_114325,inst_114444);
var state_114603__$1 = state_114603;
return cljs.core.async.impl.ioc_helpers.take_BANG_(state_114603__$1,(73),inst_114445);
} else {
if((state_val_114604 === (58))){
var inst_114402 = cljs.core.PersistentHashMap.EMPTY;
var state_114603__$1 = state_114603;
var statearr_114620_114793 = state_114603__$1;
(statearr_114620_114793[(2)] = inst_114402);

(statearr_114620_114793[(1)] = (60));


return cljs.core.cst$kw$recur;
} else {
if((state_val_114604 === (60))){
var inst_114408 = (state_114603[(2)]);
var inst_114409 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_114410 = [from];
var inst_114411 = (new cljs.core.PersistentVector(null,1,(5),inst_114409,inst_114410,null));
var inst_114412 = fluree.db.query.range.index_range.cljs$core$IFn$_invoke$arity$5(db,cljs.core.cst$kw$psot,cljs.core._EQ_,inst_114411,inst_114408);
var state_114603__$1 = state_114603;
return cljs.core.async.impl.ioc_helpers.take_BANG_(state_114603__$1,(61),inst_114412);
} else {
if((state_val_114604 === (27))){
var inst_114355 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_114356 = [null,null];
var inst_114357 = (new cljs.core.PersistentVector(null,2,(5),inst_114355,inst_114356,null));
var state_114603__$1 = state_114603;
var statearr_114621_114794 = state_114603__$1;
(statearr_114621_114794[(2)] = inst_114357);

(statearr_114621_114794[(1)] = (28));


return cljs.core.cst$kw$recur;
} else {
if((state_val_114604 === (1))){
var state_114603__$1 = state_114603;
var statearr_114622_114795 = state_114603__$1;
(statearr_114622_114795[(2)] = null);

(statearr_114622_114795[(1)] = (4));


return cljs.core.cst$kw$recur;
} else {
if((state_val_114604 === (69))){
var inst_114434 = cljs.core.PersistentHashMap.EMPTY;
var state_114603__$1 = state_114603;
var statearr_114623_114796 = state_114603__$1;
(statearr_114623_114796[(2)] = inst_114434);

(statearr_114623_114796[(1)] = (71));


return cljs.core.cst$kw$recur;
} else {
if((state_val_114604 === (101))){
var inst_114518 = (state_114603[(17)]);
var state_114603__$1 = state_114603;
var statearr_114624_114797 = state_114603__$1;
(statearr_114624_114797[(2)] = inst_114518);

(statearr_114624_114797[(1)] = (103));


return cljs.core.cst$kw$recur;
} else {
if((state_val_114604 === (24))){
var inst_114318 = (state_114603[(18)]);
var state_114603__$1 = state_114603;
var statearr_114625_114798 = state_114603__$1;
(statearr_114625_114798[(2)] = inst_114318);

(statearr_114625_114798[(1)] = (25));


return cljs.core.cst$kw$recur;
} else {
if((state_val_114604 === (102))){
var state_114603__$1 = state_114603;
if(cljs.core.truth_(fuel)){
var statearr_114626_114799 = state_114603__$1;
(statearr_114626_114799[(1)] = (104));

} else {
var statearr_114627_114800 = state_114603__$1;
(statearr_114627_114800[(1)] = (105));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_114604 === (55))){
var inst_114394 = (state_114603[(19)]);
var inst_114396 = cljs.core.distinct.cljs$core$IFn$_invoke$arity$0();
var inst_114397 = cljs.core.comp.cljs$core$IFn$_invoke$arity$2(inst_114394,inst_114396);
var state_114603__$1 = state_114603;
var statearr_114628_114801 = state_114603__$1;
(statearr_114628_114801[(2)] = inst_114397);

(statearr_114628_114801[(1)] = (57));


return cljs.core.cst$kw$recur;
} else {
if((state_val_114604 === (85))){
var inst_114475 = (state_114603[(20)]);
var inst_114474 = (state_114603[(2)]);
var inst_114475__$1 = fluree.db.util.async.throw_err(inst_114474);
var inst_114476 = (inst_114475__$1 == null);
var state_114603__$1 = (function (){var statearr_114629 = state_114603;
(statearr_114629[(20)] = inst_114475__$1);

return statearr_114629;
})();
if(cljs.core.truth_(inst_114476)){
var statearr_114630_114802 = state_114603__$1;
(statearr_114630_114802[(1)] = (86));

} else {
var statearr_114631_114803 = state_114603__$1;
(statearr_114631_114803[(1)] = (87));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_114604 === (39))){
var inst_114382 = typeof from === 'string';
var inst_114383 = cljs.core.str.cljs$core$IFn$_invoke$arity$1(from);
var inst_114384 = clojure.string.includes_QMARK_(inst_114383,"/");
var inst_114385 = ((inst_114382) && (inst_114384));
var state_114603__$1 = state_114603;
if(cljs.core.truth_(inst_114385)){
var statearr_114632_114804 = state_114603__$1;
(statearr_114632_114804[(1)] = (49));

} else {
var statearr_114633_114805 = state_114603__$1;
(statearr_114633_114805[(1)] = (50));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_114604 === (88))){
var inst_114315 = (state_114603[(8)]);
var inst_114325 = (state_114603[(15)]);
var inst_114327 = (state_114603[(16)]);
var inst_114317 = (state_114603[(9)]);
var inst_114483 = (state_114603[(2)]);
var inst_114484 = fluree.db.query.fql.subject_select.cljs$core$IFn$_invoke$arity$8(db,inst_114327,fuel,max_fuel,inst_114325,inst_114483,inst_114315,inst_114317);
var state_114603__$1 = state_114603;
return cljs.core.async.impl.ioc_helpers.take_BANG_(state_114603__$1,(89),inst_114484);
} else {
if((state_val_114604 === (46))){
var state_114603__$1 = state_114603;
var statearr_114634_114806 = state_114603__$1;
(statearr_114634_114806[(2)] = null);

(statearr_114634_114806[(1)] = (48));


return cljs.core.cst$kw$recur;
} else {
if((state_val_114604 === (4))){
var _ = cljs.core.async.impl.ioc_helpers.add_exception_frame(state_114603,(3),Error,null,(2));
var state_114603__$1 = state_114603;
if(cljs.core.truth_(select)){
var statearr_114635_114807 = state_114603__$1;
(statearr_114635_114807[(1)] = (5));

} else {
var statearr_114636_114808 = state_114603__$1;
(statearr_114636_114808[(1)] = (6));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_114604 === (77))){
var inst_114453 = cljs.core.PersistentHashMap.EMPTY;
var state_114603__$1 = state_114603;
var statearr_114637_114809 = state_114603__$1;
(statearr_114637_114809[(2)] = inst_114453);

(statearr_114637_114809[(1)] = (79));


return cljs.core.cst$kw$recur;
} else {
if((state_val_114604 === (106))){
var inst_114518 = (state_114603[(17)]);
var inst_114532 = (state_114603[(2)]);
var inst_114533 = fluree.db.dbproto._subid.cljs$core$IFn$_invoke$arity$3(db,inst_114518,false);
var state_114603__$1 = (function (){var statearr_114638 = state_114603;
(statearr_114638[(21)] = inst_114532);

return statearr_114638;
})();
return cljs.core.async.impl.ioc_helpers.take_BANG_(state_114603__$1,(107),inst_114533);
} else {
if((state_val_114604 === (119))){
var inst_114581 = (state_114603[(22)]);
var state_114603__$1 = state_114603;
var statearr_114639_114810 = state_114603__$1;
(statearr_114639_114810[(2)] = inst_114581);

(statearr_114639_114810[(1)] = (120));


return cljs.core.cst$kw$recur;
} else {
if((state_val_114604 === (95))){
var inst_114571 = (state_114603[(2)]);
var state_114603__$1 = state_114603;
var statearr_114640_114811 = state_114603__$1;
(statearr_114640_114811[(2)] = inst_114571);

(statearr_114640_114811[(1)] = (84));


return cljs.core.cst$kw$recur;
} else {
if((state_val_114604 === (54))){
var inst_114394 = (state_114603[(2)]);
var state_114603__$1 = (function (){var statearr_114641 = state_114603;
(statearr_114641[(19)] = inst_114394);

return statearr_114641;
})();
var statearr_114642_114812 = state_114603__$1;
(statearr_114642_114812[(1)] = (55));



return cljs.core.cst$kw$recur;
} else {
if((state_val_114604 === (92))){
var inst_114487 = (state_114603[(23)]);
var inst_114494 = (state_114603[(2)]);
var state_114603__$1 = (function (){var statearr_114644 = state_114603;
(statearr_114644[(24)] = inst_114494);

return statearr_114644;
})();
var statearr_114645_114813 = state_114603__$1;
(statearr_114645_114813[(2)] = inst_114487);

(statearr_114645_114813[(1)] = (84));


return cljs.core.cst$kw$recur;
} else {
if((state_val_114604 === (104))){
var inst_114527 = cljs.core._deref(fuel);
var inst_114528 = (inst_114527 + (1));
var inst_114529 = cljs.core._vreset_BANG_(fuel,inst_114528);
var state_114603__$1 = state_114603;
var statearr_114646_114814 = state_114603__$1;
(statearr_114646_114814[(2)] = inst_114529);

(statearr_114646_114814[(1)] = (106));


return cljs.core.cst$kw$recur;
} else {
if((state_val_114604 === (15))){
var state_114603__$1 = state_114603;
var statearr_114647_114815 = state_114603__$1;
(statearr_114647_114815[(2)] = false);

(statearr_114647_114815[(1)] = (16));


return cljs.core.cst$kw$recur;
} else {
if((state_val_114604 === (48))){
var inst_114325 = (state_114603[(15)]);
var inst_114372 = (state_114603[(25)]);
var inst_114327 = (state_114603[(16)]);
var inst_114317 = (state_114603[(9)]);
var inst_114376 = (state_114603[(2)]);
var inst_114377 = fluree.db.query.fql.subject_select.cljs$core$IFn$_invoke$arity$8(db,inst_114327,fuel,max_fuel,inst_114325,inst_114372,inst_114376,inst_114317);
var state_114603__$1 = state_114603;
return cljs.core.async.impl.ioc_helpers.take_BANG_(state_114603__$1,(45),inst_114377);
} else {
if((state_val_114604 === (50))){
var inst_114423 = (state_114603[(26)]);
var inst_114423__$1 = typeof from === 'string';
var state_114603__$1 = (function (){var statearr_114648 = state_114603;
(statearr_114648[(26)] = inst_114423__$1);

return statearr_114648;
})();
if(cljs.core.truth_(inst_114423__$1)){
var statearr_114649_114816 = state_114603__$1;
(statearr_114649_114816[(1)] = (63));

} else {
var statearr_114650_114817 = state_114603__$1;
(statearr_114650_114817[(1)] = (64));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_114604 === (116))){
var state_114603__$1 = state_114603;
var statearr_114651_114818 = state_114603__$1;
(statearr_114651_114818[(2)] = null);

(statearr_114651_114818[(1)] = (117));


return cljs.core.cst$kw$recur;
} else {
if((state_val_114604 === (75))){
var inst_114469 = fluree.db.util.core.subj_ident_QMARK_(from);
var state_114603__$1 = state_114603;
if(inst_114469){
var statearr_114652_114819 = state_114603__$1;
(statearr_114652_114819[(1)] = (82));

} else {
var statearr_114653_114820 = state_114603__$1;
(statearr_114653_114820[(1)] = (83));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_114604 === (99))){
var inst_114518 = (state_114603[(17)]);
var inst_114523 = cljs.core.int_QMARK_(inst_114518);
var state_114603__$1 = state_114603;
if(inst_114523){
var statearr_114654_114821 = state_114603__$1;
(statearr_114654_114821[(1)] = (101));

} else {
var statearr_114655_114822 = state_114603__$1;
(statearr_114655_114822[(1)] = (102));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_114604 === (21))){
var state_114603__$1 = state_114603;
var statearr_114656_114823 = state_114603__$1;
(statearr_114656_114823[(2)] = opts_STAR_);

(statearr_114656_114823[(1)] = (22));


return cljs.core.cst$kw$recur;
} else {
if((state_val_114604 === (31))){
var inst_114353 = (state_114603[(2)]);
var state_114603__$1 = state_114603;
var statearr_114657_114824 = state_114603__$1;
(statearr_114657_114824[(2)] = inst_114353);

(statearr_114657_114824[(1)] = (28));


return cljs.core.cst$kw$recur;
} else {
if((state_val_114604 === (113))){
var inst_114315 = (state_114603[(8)]);
var state_114603__$1 = state_114603;
var statearr_114658_114825 = state_114603__$1;
(statearr_114658_114825[(2)] = inst_114315);

(statearr_114658_114825[(1)] = (114));


return cljs.core.cst$kw$recur;
} else {
if((state_val_114604 === (32))){
var inst_114314 = (state_114603[(10)]);
var inst_114339 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_114340 = [inst_114314,"ASC"];
var inst_114341 = (new cljs.core.PersistentVector(null,2,(5),inst_114339,inst_114340,null));
var state_114603__$1 = state_114603;
var statearr_114659_114826 = state_114603__$1;
(statearr_114659_114826[(2)] = inst_114341);

(statearr_114659_114826[(1)] = (34));


return cljs.core.cst$kw$recur;
} else {
if((state_val_114604 === (40))){
var inst_114360 = (state_114603[(27)]);
var inst_114581 = (state_114603[(2)]);
var state_114603__$1 = (function (){var statearr_114660 = state_114603;
(statearr_114660[(22)] = inst_114581);

return statearr_114660;
})();
if(cljs.core.truth_(inst_114360)){
var statearr_114661_114827 = state_114603__$1;
(statearr_114661_114827[(1)] = (118));

} else {
var statearr_114662_114828 = state_114603__$1;
(statearr_114662_114828[(1)] = (119));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_114604 === (91))){
var state_114603__$1 = state_114603;
var statearr_114663_114829 = state_114603__$1;
(statearr_114663_114829[(2)] = null);

(statearr_114663_114829[(1)] = (92));


return cljs.core.cst$kw$recur;
} else {
if((state_val_114604 === (117))){
var inst_114569 = (state_114603[(2)]);
var state_114603__$1 = state_114603;
var statearr_114664_114830 = state_114603__$1;
(statearr_114664_114830[(2)] = inst_114569);

(statearr_114664_114830[(1)] = (95));


return cljs.core.cst$kw$recur;
} else {
if((state_val_114604 === (108))){
var inst_114512 = (state_114603[(12)]);
var inst_114538 = (state_114603[(28)]);
var inst_114540 = cljs.core.conj.cljs$core$IFn$_invoke$arity$2(inst_114512,inst_114538);
var state_114603__$1 = state_114603;
var statearr_114665_114831 = state_114603__$1;
(statearr_114665_114831[(2)] = inst_114540);

(statearr_114665_114831[(1)] = (110));


return cljs.core.cst$kw$recur;
} else {
if((state_val_114604 === (56))){
var inst_114394 = (state_114603[(19)]);
var state_114603__$1 = state_114603;
var statearr_114666_114832 = state_114603__$1;
(statearr_114666_114832[(2)] = inst_114394);

(statearr_114666_114832[(1)] = (57));


return cljs.core.cst$kw$recur;
} else {
if((state_val_114604 === (33))){
var state_114603__$1 = state_114603;
var statearr_114667_114833 = state_114603__$1;
(statearr_114667_114833[(1)] = (35));



return cljs.core.cst$kw$recur;
} else {
if((state_val_114604 === (13))){
var inst_114288 = (state_114603[(2)]);
var state_114603__$1 = state_114603;
var statearr_114669_114834 = state_114603__$1;
(statearr_114669_114834[(2)] = inst_114288);

(statearr_114669_114834[(1)] = (10));


return cljs.core.cst$kw$recur;
} else {
if((state_val_114604 === (22))){
var inst_114316 = (state_114603[(29)]);
var inst_114292 = (state_114603[(14)]);
var inst_114313 = (state_114603[(2)]);
var inst_114314 = cljs.core.get.cljs$core$IFn$_invoke$arity$2(inst_114313,cljs.core.cst$kw$orderBy);
var inst_114315 = cljs.core.get.cljs$core$IFn$_invoke$arity$2(inst_114313,cljs.core.cst$kw$limit);
var inst_114316__$1 = cljs.core.get.cljs$core$IFn$_invoke$arity$2(inst_114313,cljs.core.cst$kw$component);
var inst_114317 = cljs.core.get.cljs$core$IFn$_invoke$arity$2(inst_114313,cljs.core.cst$kw$offset);
var inst_114318 = fluree.db.query.fql_parser.parse_db(db,inst_114292,opts_STAR_);
var inst_114319 = (inst_114316__$1 == null);
var inst_114320 = cljs.core.not(inst_114319);
var state_114603__$1 = (function (){var statearr_114670 = state_114603;
(statearr_114670[(8)] = inst_114315);

(statearr_114670[(29)] = inst_114316__$1);

(statearr_114670[(18)] = inst_114318);

(statearr_114670[(10)] = inst_114314);

(statearr_114670[(9)] = inst_114317);

return statearr_114670;
})();
if(inst_114320){
var statearr_114671_114835 = state_114603__$1;
(statearr_114671_114835[(1)] = (23));

} else {
var statearr_114672_114836 = state_114603__$1;
(statearr_114672_114836[(1)] = (24));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_114604 === (90))){
var inst_114489 = cljs.core._deref(fuel);
var inst_114490 = (inst_114489 + (1));
var inst_114491 = cljs.core._vreset_BANG_(fuel,inst_114490);
var state_114603__$1 = state_114603;
var statearr_114673_114837 = state_114603__$1;
(statearr_114673_114837[(2)] = inst_114491);

(statearr_114673_114837[(1)] = (92));


return cljs.core.cst$kw$recur;
} else {
if((state_val_114604 === (109))){
var inst_114512 = (state_114603[(12)]);
var state_114603__$1 = state_114603;
var statearr_114674_114838 = state_114603__$1;
(statearr_114674_114838[(2)] = inst_114512);

(statearr_114674_114838[(1)] = (110));


return cljs.core.cst$kw$recur;
} else {
if((state_val_114604 === (36))){
var state_114603__$1 = state_114603;
var statearr_114675_114839 = state_114603__$1;
(statearr_114675_114839[(2)] = null);

(statearr_114675_114839[(1)] = (37));


return cljs.core.cst$kw$recur;
} else {
if((state_val_114604 === (41))){
var state_114603__$1 = state_114603;
var statearr_114676_114840 = state_114603__$1;
(statearr_114676_114840[(2)] = from);

(statearr_114676_114840[(1)] = (43));


return cljs.core.cst$kw$recur;
} else {
if((state_val_114604 === (118))){
var inst_114315 = (state_114603[(8)]);
var inst_114360 = (state_114603[(27)]);
var inst_114581 = (state_114603[(22)]);
var inst_114317 = (state_114603[(9)]);
var inst_114361 = (state_114603[(30)]);
var inst_114583 = fluree.db.query.fql.sort_offset_and_limit_res(inst_114360,inst_114361,inst_114317,inst_114315,inst_114581);
var state_114603__$1 = state_114603;
var statearr_114677_114841 = state_114603__$1;
(statearr_114677_114841[(2)] = inst_114583);

(statearr_114677_114841[(1)] = (120));


return cljs.core.cst$kw$recur;
} else {
if((state_val_114604 === (89))){
var inst_114486 = (state_114603[(2)]);
var inst_114487 = fluree.db.util.async.throw_err(inst_114486);
var state_114603__$1 = (function (){var statearr_114678 = state_114603;
(statearr_114678[(23)] = inst_114487);

return statearr_114678;
})();
if(cljs.core.truth_(fuel)){
var statearr_114679_114842 = state_114603__$1;
(statearr_114679_114842[(1)] = (90));

} else {
var statearr_114680_114843 = state_114603__$1;
(statearr_114680_114843[(1)] = (91));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_114604 === (100))){
var inst_114546 = (state_114603[(2)]);
var state_114603__$1 = state_114603;
var statearr_114681_114844 = state_114603__$1;
(statearr_114681_114844[(2)] = inst_114546);

(statearr_114681_114844[(1)] = (97));


return cljs.core.cst$kw$recur;
} else {
if((state_val_114604 === (122))){
var state_114603__$1 = state_114603;
var statearr_114682_114845 = state_114603__$1;
(statearr_114682_114845[(2)] = selectOne);

(statearr_114682_114845[(1)] = (123));


return cljs.core.cst$kw$recur;
} else {
if((state_val_114604 === (43))){
var inst_114368 = (state_114603[(2)]);
var inst_114369 = fluree.db.query.fql.where_filter.cljs$core$IFn$_invoke$arity$3(db,where,inst_114368);
var state_114603__$1 = state_114603;
return cljs.core.async.impl.ioc_helpers.take_BANG_(state_114603__$1,(44),inst_114369);
} else {
if((state_val_114604 === (61))){
var inst_114315 = (state_114603[(8)]);
var inst_114325 = (state_114603[(15)]);
var inst_114327 = (state_114603[(16)]);
var inst_114400 = (state_114603[(31)]);
var inst_114414 = (state_114603[(2)]);
var inst_114415 = fluree.db.util.async.throw_err(inst_114414);
var inst_114416 = cljs.core.sequence.cljs$core$IFn$_invoke$arity$2(inst_114400,inst_114415);
var inst_114417 = fluree.db.query.fql.subject_select.cljs$core$IFn$_invoke$arity$7(db,inst_114327,fuel,max_fuel,inst_114325,inst_114416,inst_114315);
var state_114603__$1 = state_114603;
return cljs.core.async.impl.ioc_helpers.take_BANG_(state_114603__$1,(62),inst_114417);
} else {
if((state_val_114604 === (29))){
var inst_114314 = (state_114603[(10)]);
var inst_114331 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_114332 = cljs.core.second(inst_114314);
var inst_114333 = cljs.core.first(inst_114314);
var inst_114334 = [inst_114332,inst_114333];
var inst_114335 = (new cljs.core.PersistentVector(null,2,(5),inst_114331,inst_114334,null));
var state_114603__$1 = state_114603;
var statearr_114683_114846 = state_114603__$1;
(statearr_114683_114846[(2)] = inst_114335);

(statearr_114683_114846[(1)] = (31));


return cljs.core.cst$kw$recur;
} else {
if((state_val_114604 === (44))){
var inst_114314 = (state_114603[(10)]);
var inst_114371 = (state_114603[(2)]);
var inst_114372 = fluree.db.util.async.throw_err(inst_114371);
var state_114603__$1 = (function (){var statearr_114684 = state_114603;
(statearr_114684[(25)] = inst_114372);

return statearr_114684;
})();
if(cljs.core.truth_(inst_114314)){
var statearr_114685_114847 = state_114603__$1;
(statearr_114685_114847[(1)] = (46));

} else {
var statearr_114686_114848 = state_114603__$1;
(statearr_114686_114848[(1)] = (47));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_114604 === (93))){
var inst_114507 = cljs.core.seq(from);
var inst_114508 = cljs.core.first(inst_114507);
var inst_114509 = cljs.core.next(inst_114507);
var inst_114510 = cljs.core.PersistentVector.EMPTY;
var inst_114511 = from;
var inst_114512 = inst_114510;
var state_114603__$1 = (function (){var statearr_114687 = state_114603;
(statearr_114687[(12)] = inst_114512);

(statearr_114687[(32)] = inst_114509);

(statearr_114687[(33)] = inst_114508);

(statearr_114687[(13)] = inst_114511);

return statearr_114687;
})();
var statearr_114688_114849 = state_114603__$1;
(statearr_114688_114849[(2)] = null);

(statearr_114688_114849[(1)] = (96));


return cljs.core.cst$kw$recur;
} else {
if((state_val_114604 === (6))){
var state_114603__$1 = state_114603;
if(cljs.core.truth_(selectOne)){
var statearr_114689_114850 = state_114603__$1;
(statearr_114689_114850[(1)] = (8));

} else {
var statearr_114690_114851 = state_114603__$1;
(statearr_114690_114851[(1)] = (9));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_114604 === (111))){
var inst_114557 = (state_114603[(2)]);
var inst_114558 = fluree.db.util.async.throw_err(inst_114557);
var state_114603__$1 = state_114603;
var statearr_114691_114852 = state_114603__$1;
(statearr_114691_114852[(2)] = inst_114558);

(statearr_114691_114852[(1)] = (95));


return cljs.core.cst$kw$recur;
} else {
if((state_val_114604 === (28))){
var inst_114359 = (state_114603[(2)]);
var inst_114360 = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(inst_114359,(0),null);
var inst_114361 = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(inst_114359,(1),null);
var inst_114362 = typeof where === 'string';
var state_114603__$1 = (function (){var statearr_114692 = state_114603;
(statearr_114692[(27)] = inst_114360);

(statearr_114692[(30)] = inst_114361);

return statearr_114692;
})();
if(cljs.core.truth_(inst_114362)){
var statearr_114693_114853 = state_114603__$1;
(statearr_114693_114853[(1)] = (38));

} else {
var statearr_114694_114854 = state_114603__$1;
(statearr_114694_114854[(1)] = (39));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_114604 === (64))){
var inst_114423 = (state_114603[(26)]);
var state_114603__$1 = state_114603;
var statearr_114695_114855 = state_114603__$1;
(statearr_114695_114855[(2)] = inst_114423);

(statearr_114695_114855[(1)] = (65));


return cljs.core.cst$kw$recur;
} else {
if((state_val_114604 === (103))){
var inst_114538 = (state_114603[(28)]);
var inst_114538__$1 = (state_114603[(2)]);
var state_114603__$1 = (function (){var statearr_114696 = state_114603;
(statearr_114696[(28)] = inst_114538__$1);

return statearr_114696;
})();
if(cljs.core.truth_(inst_114538__$1)){
var statearr_114697_114856 = state_114603__$1;
(statearr_114697_114856[(1)] = (108));

} else {
var statearr_114698_114857 = state_114603__$1;
(statearr_114698_114857[(1)] = (109));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_114604 === (51))){
var inst_114579 = (state_114603[(2)]);
var state_114603__$1 = state_114603;
var statearr_114699_114858 = state_114603__$1;
(statearr_114699_114858[(2)] = inst_114579);

(statearr_114699_114858[(1)] = (40));


return cljs.core.cst$kw$recur;
} else {
if((state_val_114604 === (25))){
var inst_114314 = (state_114603[(10)]);
var inst_114325 = (state_114603[(2)]);
var inst_114326 = cljs.core.PersistentHashMap.EMPTY;
var inst_114327 = cljs.core.volatile_BANG_(inst_114326);
var state_114603__$1 = (function (){var statearr_114700 = state_114603;
(statearr_114700[(15)] = inst_114325);

(statearr_114700[(16)] = inst_114327);

return statearr_114700;
})();
if(cljs.core.truth_(inst_114314)){
var statearr_114701_114859 = state_114603__$1;
(statearr_114701_114859[(1)] = (26));

} else {
var statearr_114702_114860 = state_114603__$1;
(statearr_114702_114860[(1)] = (27));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_114604 === (34))){
var inst_114351 = (state_114603[(2)]);
var state_114603__$1 = state_114603;
var statearr_114703_114861 = state_114603__$1;
(statearr_114703_114861[(2)] = inst_114351);

(statearr_114703_114861[(1)] = (31));


return cljs.core.cst$kw$recur;
} else {
if((state_val_114604 === (125))){
var inst_114586 = (state_114603[(7)]);
var state_114603__$1 = state_114603;
var statearr_114704_114862 = state_114603__$1;
(statearr_114704_114862[(2)] = inst_114586);

(statearr_114704_114862[(1)] = (126));


return cljs.core.cst$kw$recur;
} else {
if((state_val_114604 === (17))){
var state_114603__$1 = state_114603;
var statearr_114705_114863 = state_114603__$1;
(statearr_114705_114863[(2)] = true);

(statearr_114705_114863[(1)] = (19));


return cljs.core.cst$kw$recur;
} else {
if((state_val_114604 === (3))){
var inst_114268 = (state_114603[(2)]);
var state_114603__$1 = state_114603;
var statearr_114706_114864 = state_114603__$1;
(statearr_114706_114864[(2)] = inst_114268);


cljs.core.async.impl.ioc_helpers.process_exception(state_114603__$1);

return cljs.core.cst$kw$recur;
} else {
if((state_val_114604 === (12))){
var inst_114282 = [cljs.core.cst$kw$status,cljs.core.cst$kw$error];
var inst_114283 = [(400),cljs.core.cst$kw$db_SLASH_invalid_DASH_query];
var inst_114284 = cljs.core.PersistentHashMap.fromArrays(inst_114282,inst_114283);
var inst_114285 = cljs.core.ex_info.cljs$core$IFn$_invoke$arity$2("Query missing :select or :selectOne.",inst_114284);
var inst_114286 = (function(){throw inst_114285})();
var state_114603__$1 = state_114603;
var statearr_114707_114865 = state_114603__$1;
(statearr_114707_114865[(2)] = inst_114286);

(statearr_114707_114865[(1)] = (13));


return cljs.core.cst$kw$recur;
} else {
if((state_val_114604 === (2))){
var inst_114601 = (state_114603[(2)]);
var state_114603__$1 = state_114603;
return cljs.core.async.impl.ioc_helpers.return_chan(state_114603__$1,inst_114601);
} else {
if((state_val_114604 === (66))){
var inst_114314 = (state_114603[(10)]);
var state_114603__$1 = state_114603;
if(cljs.core.truth_(inst_114314)){
var statearr_114708_114866 = state_114603__$1;
(statearr_114708_114866[(1)] = (69));

} else {
var statearr_114709_114867 = state_114603__$1;
(statearr_114709_114867[(1)] = (70));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_114604 === (107))){
var inst_114535 = (state_114603[(2)]);
var inst_114536 = fluree.db.util.async.throw_err(inst_114535);
var state_114603__$1 = state_114603;
var statearr_114710_114868 = state_114603__$1;
(statearr_114710_114868[(2)] = inst_114536);

(statearr_114710_114868[(1)] = (103));


return cljs.core.cst$kw$recur;
} else {
if((state_val_114604 === (23))){
var inst_114316 = (state_114603[(29)]);
var inst_114318 = (state_114603[(18)]);
var inst_114322 = cljs.core.assoc.cljs$core$IFn$_invoke$arity$3(inst_114318,cljs.core.cst$kw$componentFollow_QMARK_,inst_114316);
var state_114603__$1 = state_114603;
var statearr_114711_114869 = state_114603__$1;
(statearr_114711_114869[(2)] = inst_114322);

(statearr_114711_114869[(1)] = (25));


return cljs.core.cst$kw$recur;
} else {
if((state_val_114604 === (47))){
var inst_114315 = (state_114603[(8)]);
var state_114603__$1 = state_114603;
var statearr_114712_114870 = state_114603__$1;
(statearr_114712_114870[(2)] = inst_114315);

(statearr_114712_114870[(1)] = (48));


return cljs.core.cst$kw$recur;
} else {
if((state_val_114604 === (35))){
var inst_114344 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_114345 = [null,null];
var inst_114346 = (new cljs.core.PersistentVector(null,2,(5),inst_114344,inst_114345,null));
var state_114603__$1 = state_114603;
var statearr_114713_114871 = state_114603__$1;
(statearr_114713_114871[(2)] = inst_114346);

(statearr_114713_114871[(1)] = (37));


return cljs.core.cst$kw$recur;
} else {
if((state_val_114604 === (82))){
var inst_114472 = fluree.db.dbproto._subid.cljs$core$IFn$_invoke$arity$3(db,from,false);
var state_114603__$1 = state_114603;
return cljs.core.async.impl.ioc_helpers.take_BANG_(state_114603__$1,(85),inst_114472);
} else {
if((state_val_114604 === (76))){
var inst_114575 = (state_114603[(2)]);
var state_114603__$1 = state_114603;
var statearr_114714_114872 = state_114603__$1;
(statearr_114714_114872[(2)] = inst_114575);

(statearr_114714_114872[(1)] = (68));


return cljs.core.cst$kw$recur;
} else {
if((state_val_114604 === (97))){
var inst_114314 = (state_114603[(10)]);
var inst_114548 = (state_114603[(2)]);
var inst_114549 = cljs.core.PersistentVector.EMPTY;
var inst_114550 = cljs.core.into.cljs$core$IFn$_invoke$arity$2(inst_114549,inst_114548);
var state_114603__$1 = (function (){var statearr_114715 = state_114603;
(statearr_114715[(34)] = inst_114550);

return statearr_114715;
})();
if(cljs.core.truth_(inst_114314)){
var statearr_114716_114873 = state_114603__$1;
(statearr_114716_114873[(1)] = (112));

} else {
var statearr_114717_114874 = state_114603__$1;
(statearr_114717_114874[(1)] = (113));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_114604 === (19))){
var inst_114305 = (state_114603[(2)]);
var state_114603__$1 = state_114603;
var statearr_114718_114875 = state_114603__$1;
(statearr_114718_114875[(2)] = inst_114305);

(statearr_114718_114875[(1)] = (16));


return cljs.core.cst$kw$recur;
} else {
if((state_val_114604 === (57))){
var inst_114314 = (state_114603[(10)]);
var inst_114400 = (state_114603[(2)]);
var state_114603__$1 = (function (){var statearr_114719 = state_114603;
(statearr_114719[(31)] = inst_114400);

return statearr_114719;
})();
if(cljs.core.truth_(inst_114314)){
var statearr_114720_114876 = state_114603__$1;
(statearr_114720_114876[(1)] = (58));

} else {
var statearr_114721_114877 = state_114603__$1;
(statearr_114721_114877[(1)] = (59));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_114604 === (68))){
var inst_114577 = (state_114603[(2)]);
var state_114603__$1 = state_114603;
var statearr_114722_114878 = state_114603__$1;
(statearr_114722_114878[(2)] = inst_114577);

(statearr_114722_114878[(1)] = (51));


return cljs.core.cst$kw$recur;
} else {
if((state_val_114604 === (11))){
var state_114603__$1 = state_114603;
var statearr_114723_114879 = state_114603__$1;
(statearr_114723_114879[(2)] = selectDistinct);

(statearr_114723_114879[(1)] = (13));


return cljs.core.cst$kw$recur;
} else {
if((state_val_114604 === (115))){
var inst_114561 = cljs.core.pr_str.cljs$core$IFn$_invoke$arity$variadic(cljs.core.prim_seq.cljs$core$IFn$_invoke$arity$2([query_map], 0));
var inst_114562 = ["Invalid 'from' in query:",inst_114561].join('');
var inst_114563 = [cljs.core.cst$kw$status,cljs.core.cst$kw$error];
var inst_114564 = [(400),cljs.core.cst$kw$db_SLASH_invalid_DASH_query];
var inst_114565 = cljs.core.PersistentHashMap.fromArrays(inst_114563,inst_114564);
var inst_114566 = cljs.core.ex_info.cljs$core$IFn$_invoke$arity$2(inst_114562,inst_114565);
var state_114603__$1 = state_114603;
var statearr_114724_114880 = state_114603__$1;
(statearr_114724_114880[(2)] = inst_114566);

(statearr_114724_114880[(1)] = (117));


return cljs.core.cst$kw$recur;
} else {
if((state_val_114604 === (9))){
var state_114603__$1 = state_114603;
if(cljs.core.truth_(selectDistinct)){
var statearr_114725_114881 = state_114603__$1;
(statearr_114725_114881[(1)] = (11));

} else {
var statearr_114726_114882 = state_114603__$1;
(statearr_114726_114882[(1)] = (12));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_114604 === (5))){
var state_114603__$1 = state_114603;
var statearr_114727_114883 = state_114603__$1;
(statearr_114727_114883[(2)] = select);

(statearr_114727_114883[(1)] = (7));


return cljs.core.cst$kw$recur;
} else {
if((state_val_114604 === (112))){
var state_114603__$1 = state_114603;
var statearr_114728_114884 = state_114603__$1;
(statearr_114728_114884[(2)] = null);

(statearr_114728_114884[(1)] = (114));


return cljs.core.cst$kw$recur;
} else {
if((state_val_114604 === (83))){
var inst_114496 = cljs.core.sequential_QMARK_(from);
var inst_114497 = cljs.core.every_QMARK_(fluree.db.util.core.subj_ident_QMARK_,from);
var inst_114498 = ((inst_114496) && (inst_114497));
var state_114603__$1 = state_114603;
if(cljs.core.truth_(inst_114498)){
var statearr_114729_114885 = state_114603__$1;
(statearr_114729_114885[(1)] = (93));

} else {
var statearr_114730_114886 = state_114603__$1;
(statearr_114730_114886[(1)] = (94));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_114604 === (14))){
var inst_114297 = opts_STAR_.cljs$lang$protocol_mask$partition0$;
var inst_114298 = (inst_114297 & (64));
var inst_114299 = opts_STAR_.cljs$core$ISeq$;
var inst_114300 = (cljs.core.PROTOCOL_SENTINEL === inst_114299);
var inst_114301 = ((inst_114298) || (inst_114300));
var state_114603__$1 = state_114603;
if(cljs.core.truth_(inst_114301)){
var statearr_114731_114887 = state_114603__$1;
(statearr_114731_114887[(1)] = (17));

} else {
var statearr_114732_114888 = state_114603__$1;
(statearr_114732_114888[(1)] = (18));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_114604 === (45))){
var inst_114379 = (state_114603[(2)]);
var inst_114380 = fluree.db.util.async.throw_err(inst_114379);
var state_114603__$1 = state_114603;
var statearr_114733_114889 = state_114603__$1;
(statearr_114733_114889[(2)] = inst_114380);

(statearr_114733_114889[(1)] = (40));


return cljs.core.cst$kw$recur;
} else {
if((state_val_114604 === (53))){
var inst_114388 = (state_114603[(35)]);
var state_114603__$1 = state_114603;
var statearr_114734_114890 = state_114603__$1;
(statearr_114734_114890[(2)] = inst_114388);

(statearr_114734_114890[(1)] = (54));


return cljs.core.cst$kw$recur;
} else {
if((state_val_114604 === (78))){
var inst_114315 = (state_114603[(8)]);
var inst_114317 = (state_114603[(9)]);
var inst_114455 = [cljs.core.cst$kw$limit,cljs.core.cst$kw$offset];
var inst_114456 = [inst_114315,inst_114317];
var inst_114457 = cljs.core.PersistentHashMap.fromArrays(inst_114455,inst_114456);
var state_114603__$1 = state_114603;
var statearr_114735_114891 = state_114603__$1;
(statearr_114735_114891[(2)] = inst_114457);

(statearr_114735_114891[(1)] = (79));


return cljs.core.cst$kw$recur;
} else {
if((state_val_114604 === (26))){
var inst_114314 = (state_114603[(10)]);
var inst_114329 = cljs.core.vector_QMARK_(inst_114314);
var state_114603__$1 = state_114603;
if(inst_114329){
var statearr_114736_114892 = state_114603__$1;
(statearr_114736_114892[(1)] = (29));

} else {
var statearr_114737_114893 = state_114603__$1;
(statearr_114737_114893[(1)] = (30));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_114604 === (123))){
var inst_114594 = (state_114603[(2)]);
var state_114603__$1 = state_114603;
if(cljs.core.truth_(inst_114594)){
var statearr_114738_114894 = state_114603__$1;
(statearr_114738_114894[(1)] = (124));

} else {
var statearr_114739_114895 = state_114603__$1;
(statearr_114739_114895[(1)] = (125));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_114604 === (16))){
var inst_114308 = (state_114603[(2)]);
var state_114603__$1 = state_114603;
if(cljs.core.truth_(inst_114308)){
var statearr_114740_114896 = state_114603__$1;
(statearr_114740_114896[(1)] = (20));

} else {
var statearr_114741_114897 = state_114603__$1;
(statearr_114741_114897[(1)] = (21));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_114604 === (81))){
var inst_114466 = (state_114603[(2)]);
var inst_114467 = fluree.db.util.async.throw_err(inst_114466);
var state_114603__$1 = state_114603;
var statearr_114742_114898 = state_114603__$1;
(statearr_114742_114898[(2)] = inst_114467);

(statearr_114742_114898[(1)] = (76));


return cljs.core.cst$kw$recur;
} else {
if((state_val_114604 === (120))){
var inst_114586 = (state_114603[(2)]);
var state_114603__$1 = (function (){var statearr_114743 = state_114603;
(statearr_114743[(7)] = inst_114586);

return statearr_114743;
})();
if(cljs.core.truth_(selectOne)){
var statearr_114744_114899 = state_114603__$1;
(statearr_114744_114899[(1)] = (121));

} else {
var statearr_114745_114900 = state_114603__$1;
(statearr_114745_114900[(1)] = (122));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_114604 === (79))){
var inst_114459 = (state_114603[(2)]);
var inst_114460 = fluree.db.query.range.collection.cljs$core$IFn$_invoke$arity$3(db,from,inst_114459);
var state_114603__$1 = state_114603;
return cljs.core.async.impl.ioc_helpers.take_BANG_(state_114603__$1,(80),inst_114460);
} else {
if((state_val_114604 === (38))){
var inst_114364 = typeof from === 'string';
var state_114603__$1 = state_114603;
if(cljs.core.truth_(inst_114364)){
var statearr_114746_114901 = state_114603__$1;
(statearr_114746_114901[(1)] = (41));

} else {
var statearr_114747_114902 = state_114603__$1;
(statearr_114747_114902[(1)] = (42));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_114604 === (126))){
var inst_114599 = (state_114603[(2)]);
var state_114603__$1 = state_114603;
var statearr_114748_114903 = state_114603__$1;
(statearr_114748_114903[(2)] = inst_114599);


cljs.core.async.impl.ioc_helpers.process_exception(state_114603__$1);

return cljs.core.cst$kw$recur;
} else {
if((state_val_114604 === (98))){
var inst_114512 = (state_114603[(12)]);
var state_114603__$1 = state_114603;
var statearr_114749_114904 = state_114603__$1;
(statearr_114749_114904[(2)] = inst_114512);

(statearr_114749_114904[(1)] = (100));


return cljs.core.cst$kw$recur;
} else {
if((state_val_114604 === (124))){
var inst_114586 = (state_114603[(7)]);
var inst_114596 = cljs.core.first(inst_114586);
var state_114603__$1 = state_114603;
var statearr_114750_114905 = state_114603__$1;
(statearr_114750_114905[(2)] = inst_114596);

(statearr_114750_114905[(1)] = (126));


return cljs.core.cst$kw$recur;
} else {
if((state_val_114604 === (87))){
var inst_114475 = (state_114603[(20)]);
var inst_114479 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_114480 = [inst_114475];
var inst_114481 = (new cljs.core.PersistentVector(null,1,(5),inst_114479,inst_114480,null));
var state_114603__$1 = state_114603;
var statearr_114751_114906 = state_114603__$1;
(statearr_114751_114906[(2)] = inst_114481);

(statearr_114751_114906[(1)] = (88));


return cljs.core.cst$kw$recur;
} else {
if((state_val_114604 === (30))){
var inst_114314 = (state_114603[(10)]);
var inst_114337 = typeof inst_114314 === 'string';
var state_114603__$1 = state_114603;
if(cljs.core.truth_(inst_114337)){
var statearr_114752_114907 = state_114603__$1;
(statearr_114752_114907[(1)] = (32));

} else {
var statearr_114753_114908 = state_114603__$1;
(statearr_114753_114908[(1)] = (33));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_114604 === (73))){
var inst_114447 = (state_114603[(2)]);
var inst_114448 = fluree.db.util.async.throw_err(inst_114447);
var state_114603__$1 = state_114603;
var statearr_114754_114909 = state_114603__$1;
(statearr_114754_114909[(2)] = inst_114448);

(statearr_114754_114909[(1)] = (68));


return cljs.core.cst$kw$recur;
} else {
if((state_val_114604 === (96))){
var inst_114511 = (state_114603[(13)]);
var inst_114518 = (state_114603[(17)]);
var inst_114517 = cljs.core.seq(inst_114511);
var inst_114518__$1 = cljs.core.first(inst_114517);
var inst_114519 = cljs.core.next(inst_114517);
var inst_114520 = cljs.core.not(inst_114518__$1);
var state_114603__$1 = (function (){var statearr_114755 = state_114603;
(statearr_114755[(11)] = inst_114519);

(statearr_114755[(17)] = inst_114518__$1);

return statearr_114755;
})();
if(inst_114520){
var statearr_114756_114910 = state_114603__$1;
(statearr_114756_114910[(1)] = (98));

} else {
var statearr_114757_114911 = state_114603__$1;
(statearr_114757_114911[(1)] = (99));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_114604 === (10))){
var inst_114290 = (state_114603[(2)]);
var state_114603__$1 = state_114603;
var statearr_114758_114912 = state_114603__$1;
(statearr_114758_114912[(2)] = inst_114290);

(statearr_114758_114912[(1)] = (7));


return cljs.core.cst$kw$recur;
} else {
if((state_val_114604 === (18))){
var state_114603__$1 = state_114603;
var statearr_114759_114913 = state_114603__$1;
(statearr_114759_114913[(2)] = false);

(statearr_114759_114913[(1)] = (19));


return cljs.core.cst$kw$recur;
} else {
if((state_val_114604 === (105))){
var state_114603__$1 = state_114603;
var statearr_114760_114914 = state_114603__$1;
(statearr_114760_114914[(2)] = null);

(statearr_114760_114914[(1)] = (106));


return cljs.core.cst$kw$recur;
} else {
if((state_val_114604 === (52))){
var inst_114388 = (state_114603[(35)]);
var inst_114390 = fluree.db.query.fql.fuel_flake_transducer(fuel,max_fuel);
var inst_114391 = cljs.core.comp.cljs$core$IFn$_invoke$arity$2(inst_114388,inst_114390);
var state_114603__$1 = state_114603;
var statearr_114761_114915 = state_114603__$1;
(statearr_114761_114915[(2)] = inst_114391);

(statearr_114761_114915[(1)] = (54));


return cljs.core.cst$kw$recur;
} else {
if((state_val_114604 === (114))){
var inst_114325 = (state_114603[(15)]);
var inst_114327 = (state_114603[(16)]);
var inst_114550 = (state_114603[(34)]);
var inst_114317 = (state_114603[(9)]);
var inst_114554 = (state_114603[(2)]);
var inst_114555 = fluree.db.query.fql.subject_select.cljs$core$IFn$_invoke$arity$8(db,inst_114327,fuel,max_fuel,inst_114325,inst_114550,inst_114554,inst_114317);
var state_114603__$1 = state_114603;
return cljs.core.async.impl.ioc_helpers.take_BANG_(state_114603__$1,(111),inst_114555);
} else {
if((state_val_114604 === (67))){
var inst_114450 = typeof from === 'string';
var state_114603__$1 = state_114603;
if(cljs.core.truth_(inst_114450)){
var statearr_114762_114916 = state_114603__$1;
(statearr_114762_114916[(1)] = (74));

} else {
var statearr_114763_114917 = state_114603__$1;
(statearr_114763_114917[(1)] = (75));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_114604 === (71))){
var inst_114440 = (state_114603[(2)]);
var inst_114441 = fluree.db.query.range._block_or_tx_collection(db,inst_114440);
var state_114603__$1 = state_114603;
return cljs.core.async.impl.ioc_helpers.take_BANG_(state_114603__$1,(72),inst_114441);
} else {
if((state_val_114604 === (42))){
var state_114603__$1 = state_114603;
var statearr_114764_114918 = state_114603__$1;
(statearr_114764_114918[(2)] = null);

(statearr_114764_114918[(1)] = (43));


return cljs.core.cst$kw$recur;
} else {
if((state_val_114604 === (80))){
var inst_114325 = (state_114603[(15)]);
var inst_114327 = (state_114603[(16)]);
var inst_114462 = (state_114603[(2)]);
var inst_114463 = fluree.db.util.async.throw_err(inst_114462);
var inst_114464 = fluree.db.query.fql.flake_select.cljs$core$IFn$_invoke$arity$6(db,inst_114327,fuel,max_fuel,inst_114325,inst_114463);
var state_114603__$1 = state_114603;
return cljs.core.async.impl.ioc_helpers.take_BANG_(state_114603__$1,(81),inst_114464);
} else {
if((state_val_114604 === (37))){
var inst_114349 = (state_114603[(2)]);
var state_114603__$1 = state_114603;
var statearr_114765_114919 = state_114603__$1;
(statearr_114765_114919[(2)] = inst_114349);

(statearr_114765_114919[(1)] = (34));


return cljs.core.cst$kw$recur;
} else {
if((state_val_114604 === (63))){
var inst_114425 = ["_tx",null,"_block",null];
var inst_114426 = (new cljs.core.PersistentArrayMap(null,2,inst_114425,null));
var inst_114427 = (new cljs.core.PersistentHashSet(null,inst_114426,null));
var inst_114428 = (inst_114427.cljs$core$IFn$_invoke$arity$1 ? inst_114427.cljs$core$IFn$_invoke$arity$1(from) : inst_114427.call(null,from));
var state_114603__$1 = state_114603;
var statearr_114766_114920 = state_114603__$1;
(statearr_114766_114920[(2)] = inst_114428);

(statearr_114766_114920[(1)] = (65));


return cljs.core.cst$kw$recur;
} else {
if((state_val_114604 === (94))){
var state_114603__$1 = state_114603;
var statearr_114767_114921 = state_114603__$1;
(statearr_114767_114921[(1)] = (115));



return cljs.core.cst$kw$recur;
} else {
if((state_val_114604 === (8))){
var state_114603__$1 = state_114603;
var statearr_114769_114922 = state_114603__$1;
(statearr_114769_114922[(2)] = selectOne);

(statearr_114769_114922[(1)] = (10));


return cljs.core.cst$kw$recur;
} else {
if((state_val_114604 === (49))){
var inst_114388 = cljs.core.map.cljs$core$IFn$_invoke$arity$1(fluree.db.query.fql.s);
var state_114603__$1 = (function (){var statearr_114770 = state_114603;
(statearr_114770[(35)] = inst_114388);

return statearr_114770;
})();
if(cljs.core.truth_(fuel)){
var statearr_114771_114923 = state_114603__$1;
(statearr_114771_114923[(1)] = (52));

} else {
var statearr_114772_114924 = state_114603__$1;
(statearr_114772_114924[(1)] = (53));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_114604 === (84))){
var inst_114573 = (state_114603[(2)]);
var state_114603__$1 = state_114603;
var statearr_114773_114925 = state_114603__$1;
(statearr_114773_114925[(2)] = inst_114573);

(statearr_114773_114925[(1)] = (76));


return cljs.core.cst$kw$recur;
} else {
return null;
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
});})(c__99809__auto__,max_fuel,fuel,map__114262,map__114262__$1,select,orderBy,where,limit,offset,component,selectDistinct,prettyPrint,selectOne,from,groupBy,opts_SINGLEQUOTE_,opts_SINGLEQUOTE__SINGLEQUOTE_,opts_STAR_))
;
return ((function (switch__99702__auto__,c__99809__auto__,max_fuel,fuel,map__114262,map__114262__$1,select,orderBy,where,limit,offset,component,selectDistinct,prettyPrint,selectOne,from,groupBy,opts_SINGLEQUOTE_,opts_SINGLEQUOTE__SINGLEQUOTE_,opts_STAR_){
return (function() {
var fluree$db$query$fql$state_machine__99703__auto__ = null;
var fluree$db$query$fql$state_machine__99703__auto____0 = (function (){
var statearr_114774 = [null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null];
(statearr_114774[(0)] = fluree$db$query$fql$state_machine__99703__auto__);

(statearr_114774[(1)] = (1));

return statearr_114774;
});
var fluree$db$query$fql$state_machine__99703__auto____1 = (function (state_114603){
while(true){
var ret_value__99704__auto__ = (function (){try{while(true){
var result__99705__auto__ = switch__99702__auto__(state_114603);
if(cljs.core.keyword_identical_QMARK_(result__99705__auto__,cljs.core.cst$kw$recur)){
continue;
} else {
return result__99705__auto__;
}
break;
}
}catch (e114775){if((e114775 instanceof Object)){
var ex__99706__auto__ = e114775;
var statearr_114776_114926 = state_114603;
(statearr_114776_114926[(5)] = ex__99706__auto__);


cljs.core.async.impl.ioc_helpers.process_exception(state_114603);

return cljs.core.cst$kw$recur;
} else {
throw e114775;

}
}})();
if(cljs.core.keyword_identical_QMARK_(ret_value__99704__auto__,cljs.core.cst$kw$recur)){
var G__114927 = state_114603;
state_114603 = G__114927;
continue;
} else {
return ret_value__99704__auto__;
}
break;
}
});
fluree$db$query$fql$state_machine__99703__auto__ = function(state_114603){
switch(arguments.length){
case 0:
return fluree$db$query$fql$state_machine__99703__auto____0.call(this);
case 1:
return fluree$db$query$fql$state_machine__99703__auto____1.call(this,state_114603);
}
throw(new Error('Invalid arity: ' + arguments.length));
};
fluree$db$query$fql$state_machine__99703__auto__.cljs$core$IFn$_invoke$arity$0 = fluree$db$query$fql$state_machine__99703__auto____0;
fluree$db$query$fql$state_machine__99703__auto__.cljs$core$IFn$_invoke$arity$1 = fluree$db$query$fql$state_machine__99703__auto____1;
return fluree$db$query$fql$state_machine__99703__auto__;
})()
;})(switch__99702__auto__,c__99809__auto__,max_fuel,fuel,map__114262,map__114262__$1,select,orderBy,where,limit,offset,component,selectDistinct,prettyPrint,selectOne,from,groupBy,opts_SINGLEQUOTE_,opts_SINGLEQUOTE__SINGLEQUOTE_,opts_STAR_))
})();
var state__99811__auto__ = (function (){var statearr_114777 = (f__99810__auto__.cljs$core$IFn$_invoke$arity$0 ? f__99810__auto__.cljs$core$IFn$_invoke$arity$0() : f__99810__auto__.call(null));
(statearr_114777[(6)] = c__99809__auto__);

return statearr_114777;
})();
return cljs.core.async.impl.ioc_helpers.run_state_machine_wrapped(state__99811__auto__);
});})(c__99809__auto__,max_fuel,fuel,map__114262,map__114262__$1,select,orderBy,where,limit,offset,component,selectDistinct,prettyPrint,selectOne,from,groupBy,opts_SINGLEQUOTE_,opts_SINGLEQUOTE__SINGLEQUOTE_,opts_STAR_))
);

return c__99809__auto__;
}
}
});

fluree.db.query.fql.query.cljs$lang$maxFixedArity = 3;

