// Compiled by ClojureScript 1.10.520 {:static-fns true, :optimize-constants true}
goog.provide('fluree.db.query.range');
goog.require('cljs.core');
goog.require('cljs.core.constants');
goog.require('fluree.db.dbproto');
goog.require('fluree.db.constants');
goog.require('fluree.db.util.core');
goog.require('fluree.db.util.log');
goog.require('fluree.db.util.json');
goog.require('fluree.db.flake');
goog.require('cljs.core.async');
goog.require('fluree.db.util.async');
/**
 * Checks whether an index range is :spot, starts with [s1 -1 o1] and ends with [s1 int/max p1]
 */
fluree.db.query.range.value_with_nil_pred = (function fluree$db$query$range$value_with_nil_pred(idx,start_flake,end_flake){
return ((cljs.core._EQ_.cljs$core$IFn$_invoke$arity$2(cljs.core.cst$kw$spot,idx)) && ((!((start_flake.o == null)))) && (cljs.core._EQ_.cljs$core$IFn$_invoke$arity$2(start_flake.o,end_flake.o)) && (cljs.core._EQ_.cljs$core$IFn$_invoke$arity$2((-1),start_flake.p)) && (cljs.core._EQ_.cljs$core$IFn$_invoke$arity$2(fluree.db.flake.MAX_PREDICATE_ID,end_flake.p)));
});
/**
 * Will throw if predicate doesn't exist.
 */
fluree.db.query.range.pred_id_strict = (function fluree$db$query$range$pred_id_strict(db,p){
if(cljs.core.truth_(p)){
var or__4131__auto__ = fluree.db.dbproto._p_prop(db,cljs.core.cst$kw$id,p);
if(cljs.core.truth_(or__4131__auto__)){
return or__4131__auto__;
} else {
throw cljs.core.ex_info.cljs$core$IFn$_invoke$arity$2(["Invalid predicate, does not exist: ",cljs.core.str.cljs$core$IFn$_invoke$arity$1(p)].join(''),new cljs.core.PersistentArrayMap(null, 2, [cljs.core.cst$kw$status,(400),cljs.core.cst$kw$error,cljs.core.cst$kw$db_SLASH_invalid_DASH_predicate], null));
}
} else {
return null;
}
});
/**
 * Takes a match from index-range, and based on the index
 *   returns flake-ordered components of [s p o t op m].
 *   Coerces idents and string predicate names.
 */
fluree.db.query.range.match__GT_flake_parts = (function fluree$db$query$range$match__GT_flake_parts(db,idx,match){
var vec__102296 = match;
var p1 = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(vec__102296,(0),null);
var p2 = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(vec__102296,(1),null);
var p3 = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(vec__102296,(2),null);
var t = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(vec__102296,(3),null);
var op = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(vec__102296,(4),null);
var m = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(vec__102296,(5),null);
var G__102299 = idx;
var G__102299__$1 = (((G__102299 instanceof cljs.core.Keyword))?G__102299.fqn:null);
switch (G__102299__$1) {
case "spot":
return new cljs.core.PersistentVector(null, 6, 5, cljs.core.PersistentVector.EMPTY_NODE, [p1,fluree.db.dbproto._p_prop(db,cljs.core.cst$kw$id,p2),p3,t,op,m], null);

break;
case "psot":
return new cljs.core.PersistentVector(null, 6, 5, cljs.core.PersistentVector.EMPTY_NODE, [p2,fluree.db.dbproto._p_prop(db,cljs.core.cst$kw$id,p1),p3,t,op,m], null);

break;
case "post":
return new cljs.core.PersistentVector(null, 6, 5, cljs.core.PersistentVector.EMPTY_NODE, [p3,fluree.db.dbproto._p_prop(db,cljs.core.cst$kw$id,p1),p2,t,op,m], null);

break;
case "opst":
return new cljs.core.PersistentVector(null, 6, 5, cljs.core.PersistentVector.EMPTY_NODE, [p3,fluree.db.dbproto._p_prop(db,cljs.core.cst$kw$id,p2),p1,t,op,m], null);

break;
default:
throw (new Error(["No matching clause: ",cljs.core.str.cljs$core$IFn$_invoke$arity$1(G__102299__$1)].join('')));

}
});
fluree.db.query.range.subject_min_match = new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [fluree.db.util.core.max_long], null);
fluree.db.query.range.subject_max_match = new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [fluree.db.util.core.min_long], null);
fluree.db.query.range.pred_min_match = new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [(0)], null);
fluree.db.query.range.pred_max_match = new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [fluree.db.flake.MAX_PREDICATE_ID], null);
/**
 * Smallest index flake part match by index
 */
fluree.db.query.range.min_match = (function fluree$db$query$range$min_match(idx){
var G__102301 = idx;
var G__102301__$1 = (((G__102301 instanceof cljs.core.Keyword))?G__102301.fqn:null);
switch (G__102301__$1) {
case "spot":
return fluree.db.query.range.subject_min_match;

break;
case "psot":
return new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [(0)], null);

break;
case "post":
return new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [(0)], null);

break;
case "opst":
return fluree.db.query.range.subject_min_match;

break;
default:
throw (new Error(["No matching clause: ",cljs.core.str.cljs$core$IFn$_invoke$arity$1(G__102301__$1)].join('')));

}
});
/**
 * Smallest index flake part match by index
 */
fluree.db.query.range.max_match = (function fluree$db$query$range$max_match(idx){
var G__102303 = idx;
var G__102303__$1 = (((G__102303 instanceof cljs.core.Keyword))?G__102303.fqn:null);
switch (G__102303__$1) {
case "spot":
return fluree.db.query.range.subject_max_match;

break;
case "psot":
return fluree.db.query.range.pred_max_match;

break;
case "post":
return fluree.db.query.range.pred_max_match;

break;
case "opst":
return fluree.db.query.range.subject_max_match;

break;
default:
throw (new Error(["No matching clause: ",cljs.core.str.cljs$core$IFn$_invoke$arity$1(G__102303__$1)].join('')));

}
});
/**
 * Range query across an index.
 * 
 *   Uses a DB, but in the future support supplying a connection and db name, as we don't need a 't'
 * 
 *   Ranges take the natural numeric sort orders, but all results will
 *   return in reverse order (newest subjects and predicates first).
 * 
 *   Returns core async channel.
 * 
 *   opts:
 *   :from-t - start transaction (transaction 't' is negative, so smallest number is most recent). Defaults to db's t
 *   :to-t - stop transaction - can be null, which pulls full history
 *   :xform - xform applied to each result individually. This is not used when :chan is supplied.
 *   :limit - max number of flakes to return
 */
fluree.db.query.range.time_range = (function fluree$db$query$range$time_range(var_args){
var G__102306 = arguments.length;
switch (G__102306) {
case 2:
return fluree.db.query.range.time_range.cljs$core$IFn$_invoke$arity$2((arguments[(0)]),(arguments[(1)]));

break;
case 3:
return fluree.db.query.range.time_range.cljs$core$IFn$_invoke$arity$3((arguments[(0)]),(arguments[(1)]),(arguments[(2)]));

break;
case 4:
return fluree.db.query.range.time_range.cljs$core$IFn$_invoke$arity$4((arguments[(0)]),(arguments[(1)]),(arguments[(2)]),(arguments[(3)]));

break;
case 5:
return fluree.db.query.range.time_range.cljs$core$IFn$_invoke$arity$5((arguments[(0)]),(arguments[(1)]),(arguments[(2)]),(arguments[(3)]),(arguments[(4)]));

break;
case 6:
return fluree.db.query.range.time_range.cljs$core$IFn$_invoke$arity$6((arguments[(0)]),(arguments[(1)]),(arguments[(2)]),(arguments[(3)]),(arguments[(4)]),(arguments[(5)]));

break;
case 7:
return fluree.db.query.range.time_range.cljs$core$IFn$_invoke$arity$7((arguments[(0)]),(arguments[(1)]),(arguments[(2)]),(arguments[(3)]),(arguments[(4)]),(arguments[(5)]),(arguments[(6)]));

break;
default:
throw (new Error(["Invalid arity: ",cljs.core.str.cljs$core$IFn$_invoke$arity$1(arguments.length)].join('')));

}
});

fluree.db.query.range.time_range.cljs$core$IFn$_invoke$arity$2 = (function (db,idx){
return fluree.db.query.range.time_range.cljs$core$IFn$_invoke$arity$3(db,idx,cljs.core.PersistentArrayMap.EMPTY);
});

fluree.db.query.range.time_range.cljs$core$IFn$_invoke$arity$3 = (function (db,idx,opts){
return fluree.db.query.range.time_range.cljs$core$IFn$_invoke$arity$7(db,idx,cljs.core._GT__EQ_,fluree.db.query.range.min_match(idx),cljs.core._LT__EQ_,fluree.db.query.range.max_match(idx),opts);
});

fluree.db.query.range.time_range.cljs$core$IFn$_invoke$arity$4 = (function (db,idx,test,match){
return fluree.db.query.range.time_range.cljs$core$IFn$_invoke$arity$5(db,idx,test,match,cljs.core.PersistentArrayMap.EMPTY);
});

fluree.db.query.range.time_range.cljs$core$IFn$_invoke$arity$5 = (function (db,idx,test,match,opts){
var vec__102307 = (function (){var pred__102310 = cljs.core.identical_QMARK_;
var expr__102311 = test;
if(cljs.core.truth_((pred__102310.cljs$core$IFn$_invoke$arity$2 ? pred__102310.cljs$core$IFn$_invoke$arity$2(cljs.core._EQ_,expr__102311) : pred__102310.call(null,cljs.core._EQ_,expr__102311)))){
return new cljs.core.PersistentVector(null, 4, 5, cljs.core.PersistentVector.EMPTY_NODE, [cljs.core._GT__EQ_,match,cljs.core._LT__EQ_,match], null);
} else {
if(cljs.core.truth_((pred__102310.cljs$core$IFn$_invoke$arity$2 ? pred__102310.cljs$core$IFn$_invoke$arity$2(cljs.core._LT_,expr__102311) : pred__102310.call(null,cljs.core._LT_,expr__102311)))){
return new cljs.core.PersistentVector(null, 4, 5, cljs.core.PersistentVector.EMPTY_NODE, [cljs.core._GT_,fluree.db.query.range.min_match(idx),cljs.core._LT_,match], null);
} else {
if(cljs.core.truth_((pred__102310.cljs$core$IFn$_invoke$arity$2 ? pred__102310.cljs$core$IFn$_invoke$arity$2(cljs.core._LT__EQ_,expr__102311) : pred__102310.call(null,cljs.core._LT__EQ_,expr__102311)))){
return new cljs.core.PersistentVector(null, 4, 5, cljs.core.PersistentVector.EMPTY_NODE, [cljs.core._GT_,fluree.db.query.range.min_match(idx),cljs.core._LT__EQ_,match], null);
} else {
if(cljs.core.truth_((pred__102310.cljs$core$IFn$_invoke$arity$2 ? pred__102310.cljs$core$IFn$_invoke$arity$2(cljs.core._GT_,expr__102311) : pred__102310.call(null,cljs.core._GT_,expr__102311)))){
return new cljs.core.PersistentVector(null, 4, 5, cljs.core.PersistentVector.EMPTY_NODE, [cljs.core._GT_,match,cljs.core._LT__EQ_,fluree.db.query.range.max_match(idx)], null);
} else {
if(cljs.core.truth_((pred__102310.cljs$core$IFn$_invoke$arity$2 ? pred__102310.cljs$core$IFn$_invoke$arity$2(cljs.core._GT__EQ_,expr__102311) : pred__102310.call(null,cljs.core._GT__EQ_,expr__102311)))){
return new cljs.core.PersistentVector(null, 4, 5, cljs.core.PersistentVector.EMPTY_NODE, [cljs.core._GT__EQ_,match,cljs.core._LT_,fluree.db.query.range.max_match(idx)], null);
} else {
throw (new Error(["No matching clause: ",cljs.core.str.cljs$core$IFn$_invoke$arity$1(expr__102311)].join('')));
}
}
}
}
}
})();
var start_test = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(vec__102307,(0),null);
var start_match = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(vec__102307,(1),null);
var end_test = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(vec__102307,(2),null);
var end_match = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(vec__102307,(3),null);
return fluree.db.query.range.time_range.cljs$core$IFn$_invoke$arity$7(db,idx,start_test,start_match,end_test,end_match,opts);
});

fluree.db.query.range.time_range.cljs$core$IFn$_invoke$arity$6 = (function (db,idx,start_test,start_match,end_test,end_match){
return fluree.db.query.range.time_range.cljs$core$IFn$_invoke$arity$7(db,idx,start_test,start_match,end_test,end_match,cljs.core.PersistentArrayMap.EMPTY);
});

fluree.db.query.range.time_range.cljs$core$IFn$_invoke$arity$7 = (function (db,idx,start_test,start_match,end_test,end_match,opts){
var c__99809__auto__ = cljs.core.async.chan.cljs$core$IFn$_invoke$arity$1((1));
cljs.core.async.impl.dispatch.run(((function (c__99809__auto__){
return (function (){
var f__99810__auto__ = (function (){var switch__99702__auto__ = ((function (c__99809__auto__){
return (function (state_102521){
var state_val_102522 = (state_102521[(1)]);
if((state_val_102522 === (65))){
var inst_102482 = (state_102521[(7)]);
var inst_102475 = (state_102521[(8)]);
var inst_102474 = (state_102521[(9)]);
var inst_102489 = (inst_102474 + (1));
var tmp102523 = inst_102475;
var inst_102473 = inst_102482;
var inst_102474__$1 = inst_102489;
var inst_102475__$1 = tmp102523;
var state_102521__$1 = (function (){var statearr_102524 = state_102521;
(statearr_102524[(8)] = inst_102475__$1);

(statearr_102524[(9)] = inst_102474__$1);

(statearr_102524[(10)] = inst_102473);

return statearr_102524;
})();
var statearr_102525_102632 = state_102521__$1;
(statearr_102525_102632[(2)] = null);

(statearr_102525_102632[(1)] = (62));


return cljs.core.cst$kw$recur;
} else {
if((state_val_102522 === (70))){
var inst_102496 = (state_102521[(11)]);
var state_102521__$1 = state_102521;
var statearr_102526_102633 = state_102521__$1;
(statearr_102526_102633[(2)] = inst_102496);

(statearr_102526_102633[(1)] = (72));


return cljs.core.cst$kw$recur;
} else {
if((state_val_102522 === (62))){
var inst_102415 = (state_102521[(12)]);
var inst_102474 = (state_102521[(9)]);
var inst_102473 = (state_102521[(10)]);
var inst_102480 = cljs.core.seq(inst_102473);
var inst_102481 = cljs.core.first(inst_102480);
var inst_102482 = cljs.core.next(inst_102480);
var inst_102483 = (inst_102481 == null);
var inst_102484 = (inst_102474 > inst_102415);
var inst_102485 = ((inst_102483) || (inst_102484));
var state_102521__$1 = (function (){var statearr_102527 = state_102521;
(statearr_102527[(7)] = inst_102482);

return statearr_102527;
})();
if(cljs.core.truth_(inst_102485)){
var statearr_102528_102634 = state_102521__$1;
(statearr_102528_102634[(1)] = (64));

} else {
var statearr_102529_102635 = state_102521__$1;
(statearr_102529_102635[(1)] = (65));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_102522 === (7))){
var inst_102331 = (state_102521[(13)]);
var inst_102345 = (state_102521[(2)]);
var inst_102346 = fluree.db.util.core.pred_ident_QMARK_(inst_102331);
var state_102521__$1 = (function (){var statearr_102530 = state_102521;
(statearr_102530[(14)] = inst_102345);

return statearr_102530;
})();
if(inst_102346){
var statearr_102531_102636 = state_102521__$1;
(statearr_102531_102636[(1)] = (9));

} else {
var statearr_102532_102637 = state_102521__$1;
(statearr_102532_102637[(1)] = (10));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_102522 === (59))){
var inst_102415 = (state_102521[(12)]);
var inst_102443 = (state_102521[(15)]);
var inst_102442 = (state_102521[(16)]);
var inst_102456 = (state_102521[(17)]);
var inst_102459 = (inst_102415 - inst_102442);
var inst_102460 = fluree.db.flake.take(inst_102459,inst_102456);
var inst_102461 = cljs.core.into.cljs$core$IFn$_invoke$arity$2(inst_102460,inst_102443);
var state_102521__$1 = state_102521;
var statearr_102533_102638 = state_102521__$1;
(statearr_102533_102638[(2)] = inst_102461);

(statearr_102533_102638[(1)] = (61));


return cljs.core.cst$kw$recur;
} else {
if((state_val_102522 === (20))){
var inst_102368 = (state_102521[(2)]);
var inst_102369 = fluree.db.util.async.throw_err(inst_102368);
var state_102521__$1 = state_102521;
var statearr_102534_102639 = state_102521__$1;
(statearr_102534_102639[(2)] = inst_102369);

(statearr_102534_102639[(1)] = (19));


return cljs.core.cst$kw$recur;
} else {
if((state_val_102522 === (72))){
var inst_102515 = (state_102521[(2)]);
var state_102521__$1 = state_102521;
var statearr_102535_102640 = state_102521__$1;
(statearr_102535_102640[(2)] = inst_102515);

(statearr_102535_102640[(1)] = (54));


return cljs.core.cst$kw$recur;
} else {
if((state_val_102522 === (58))){
var inst_102441 = (state_102521[(18)]);
var inst_102456 = (state_102521[(2)]);
var inst_102457 = fluree.db.dbproto._rhs(inst_102441);
var state_102521__$1 = (function (){var statearr_102536 = state_102521;
(statearr_102536[(19)] = inst_102457);

(statearr_102536[(17)] = inst_102456);

return statearr_102536;
})();
var statearr_102537_102641 = state_102521__$1;
(statearr_102537_102641[(1)] = (59));



return cljs.core.cst$kw$recur;
} else {
if((state_val_102522 === (60))){
var inst_102442 = (state_102521[(16)]);
var inst_102456 = (state_102521[(17)]);
var inst_102470 = cljs.core.seq(inst_102456);
var inst_102471 = cljs.core.first(inst_102470);
var inst_102472 = cljs.core.next(inst_102470);
var inst_102473 = inst_102456;
var inst_102474 = inst_102442;
var inst_102475 = inst_102456;
var state_102521__$1 = (function (){var statearr_102539 = state_102521;
(statearr_102539[(20)] = inst_102471);

(statearr_102539[(8)] = inst_102475);

(statearr_102539[(21)] = inst_102472);

(statearr_102539[(9)] = inst_102474);

(statearr_102539[(10)] = inst_102473);

return statearr_102539;
})();
var statearr_102540_102642 = state_102521__$1;
(statearr_102540_102642[(2)] = null);

(statearr_102540_102642[(1)] = (62));


return cljs.core.cst$kw$recur;
} else {
if((state_val_102522 === (27))){
var inst_102372 = (state_102521[(22)]);
var state_102521__$1 = state_102521;
var statearr_102541_102643 = state_102521__$1;
(statearr_102541_102643[(2)] = inst_102372);

(statearr_102541_102643[(1)] = (29));


return cljs.core.cst$kw$recur;
} else {
if((state_val_102522 === (1))){
var state_102521__$1 = state_102521;
var statearr_102542_102644 = state_102521__$1;
(statearr_102542_102644[(2)] = null);

(statearr_102542_102644[(1)] = (4));


return cljs.core.cst$kw$recur;
} else {
if((state_val_102522 === (69))){
var inst_102505 = (state_102521[(2)]);
var inst_102506 = cljs.core.not(inst_102505);
var state_102521__$1 = state_102521;
if(inst_102506){
var statearr_102543_102645 = state_102521__$1;
(statearr_102543_102645[(1)] = (70));

} else {
var statearr_102544_102646 = state_102521__$1;
(statearr_102544_102646[(1)] = (71));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_102522 === (24))){
var state_102521__$1 = state_102521;
var statearr_102545_102647 = state_102521__$1;
(statearr_102545_102647[(2)] = (-1));

(statearr_102545_102647[(1)] = (26));


return cljs.core.cst$kw$recur;
} else {
if((state_val_102522 === (55))){
var inst_102448 = (state_102521[(23)]);
var inst_102409 = (state_102521[(24)]);
var inst_102410 = (state_102521[(25)]);
var inst_102447 = (state_102521[(2)]);
var inst_102448__$1 = fluree.db.util.async.throw_err(inst_102447);
var inst_102449 = fluree.db.flake.subrange(inst_102448__$1,start_test,inst_102409,end_test,inst_102410);
var inst_102450 = fluree.db.query.range.value_with_nil_pred(idx,inst_102409,inst_102410);
var state_102521__$1 = (function (){var statearr_102546 = state_102521;
(statearr_102546[(23)] = inst_102448__$1);

(statearr_102546[(26)] = inst_102449);

return statearr_102546;
})();
if(inst_102450){
var statearr_102547_102648 = state_102521__$1;
(statearr_102547_102648[(1)] = (56));

} else {
var statearr_102548_102649 = state_102521__$1;
(statearr_102548_102649[(1)] = (57));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_102522 === (39))){
var inst_102336 = (state_102521[(27)]);
var state_102521__$1 = state_102521;
var statearr_102549_102650 = state_102521__$1;
(statearr_102549_102650[(2)] = inst_102336);

(statearr_102549_102650[(1)] = (41));


return cljs.core.cst$kw$recur;
} else {
if((state_val_102522 === (46))){
var state_102521__$1 = state_102521;
var statearr_102550_102651 = state_102521__$1;
(statearr_102550_102651[(2)] = fluree.db.util.core.max_long);

(statearr_102550_102651[(1)] = (47));


return cljs.core.cst$kw$recur;
} else {
if((state_val_102522 === (4))){
var inst_102324 = (state_102521[(28)]);
var inst_102323 = (state_102521[(29)]);
var inst_102330 = (state_102521[(30)]);
var _ = cljs.core.async.impl.ioc_helpers.add_exception_frame(state_102521,(3),Error,null,(2));
var inst_102323__$1 = fluree.db.query.range.match__GT_flake_parts(db,idx,start_match);
var inst_102324__$1 = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(inst_102323__$1,(0),null);
var inst_102325 = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(inst_102323__$1,(1),null);
var inst_102326 = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(inst_102323__$1,(2),null);
var inst_102327 = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(inst_102323__$1,(3),null);
var inst_102328 = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(inst_102323__$1,(4),null);
var inst_102329 = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(inst_102323__$1,(5),null);
var inst_102330__$1 = fluree.db.query.range.match__GT_flake_parts(db,idx,end_match);
var inst_102331 = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(inst_102330__$1,(0),null);
var inst_102332 = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(inst_102330__$1,(1),null);
var inst_102333 = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(inst_102330__$1,(2),null);
var inst_102334 = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(inst_102330__$1,(3),null);
var inst_102335 = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(inst_102330__$1,(4),null);
var inst_102336 = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(inst_102330__$1,(5),null);
var inst_102337 = fluree.db.util.core.pred_ident_QMARK_(inst_102324__$1);
var state_102521__$1 = (function (){var statearr_102551 = state_102521;
(statearr_102551[(27)] = inst_102336);

(statearr_102551[(13)] = inst_102331);

(statearr_102551[(31)] = inst_102329);

(statearr_102551[(32)] = inst_102333);

(statearr_102551[(28)] = inst_102324__$1);

(statearr_102551[(33)] = inst_102328);

(statearr_102551[(34)] = inst_102325);

(statearr_102551[(35)] = inst_102335);

(statearr_102551[(36)] = inst_102326);

(statearr_102551[(37)] = inst_102332);

(statearr_102551[(38)] = inst_102334);

(statearr_102551[(29)] = inst_102323__$1);

(statearr_102551[(39)] = inst_102327);

(statearr_102551[(30)] = inst_102330__$1);

return statearr_102551;
})();
if(inst_102337){
var statearr_102552_102652 = state_102521__$1;
(statearr_102552_102652[(1)] = (5));

} else {
var statearr_102553_102653 = state_102521__$1;
(statearr_102553_102653[(1)] = (6));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_102522 === (54))){
var inst_102517 = (state_102521[(2)]);
var state_102521__$1 = state_102521;
var statearr_102554_102654 = state_102521__$1;
(statearr_102554_102654[(2)] = inst_102517);


cljs.core.async.impl.ioc_helpers.process_exception(state_102521__$1);

return cljs.core.cst$kw$recur;
} else {
if((state_val_102522 === (15))){
var inst_102333 = (state_102521[(32)]);
var inst_102363 = (state_102521[(2)]);
var inst_102364 = fluree.db.util.core.pred_ident_QMARK_(inst_102333);
var state_102521__$1 = (function (){var statearr_102555 = state_102521;
(statearr_102555[(40)] = inst_102363);

return statearr_102555;
})();
if(inst_102364){
var statearr_102556_102655 = state_102521__$1;
(statearr_102556_102655[(1)] = (17));

} else {
var statearr_102557_102656 = state_102521__$1;
(statearr_102557_102656[(1)] = (18));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_102522 === (48))){
var inst_102421 = (state_102521[(41)]);
var state_102521__$1 = state_102521;
var statearr_102558_102657 = state_102521__$1;
(statearr_102558_102657[(2)] = inst_102421);

(statearr_102558_102657[(1)] = (50));


return cljs.core.cst$kw$recur;
} else {
if((state_val_102522 === (50))){
var inst_102426 = (state_102521[(2)]);
var inst_102427 = cljs.core.cst$kw$to_DASH_t.cljs$core$IFn$_invoke$arity$1(opts);
var inst_102428 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_102429 = [cljs.core.cst$kw$novelty,idx];
var inst_102430 = (new cljs.core.PersistentVector(null,2,(5),inst_102428,inst_102429,null));
var inst_102431 = cljs.core.get_in.cljs$core$IFn$_invoke$arity$2(db,inst_102430);
var inst_102432 = cljs.core.get.cljs$core$IFn$_invoke$arity$2(db,idx);
var inst_102433 = fluree.db.dbproto._resolve(inst_102432);
var state_102521__$1 = (function (){var statearr_102559 = state_102521;
(statearr_102559[(42)] = inst_102426);

(statearr_102559[(43)] = inst_102431);

(statearr_102559[(44)] = inst_102427);

return statearr_102559;
})();
return cljs.core.async.impl.ioc_helpers.take_BANG_(state_102521__$1,(51),inst_102433);
} else {
if((state_val_102522 === (21))){
var inst_102363 = (state_102521[(40)]);
var state_102521__$1 = state_102521;
var statearr_102560_102658 = state_102521__$1;
(statearr_102560_102658[(2)] = inst_102363);

(statearr_102560_102658[(1)] = (23));


return cljs.core.cst$kw$recur;
} else {
if((state_val_102522 === (31))){
var inst_102332 = (state_102521[(37)]);
var state_102521__$1 = state_102521;
var statearr_102561_102659 = state_102521__$1;
(statearr_102561_102659[(2)] = inst_102332);

(statearr_102561_102659[(1)] = (32));


return cljs.core.cst$kw$recur;
} else {
if((state_val_102522 === (32))){
var inst_102329 = (state_102521[(31)]);
var inst_102390 = (state_102521[(2)]);
var state_102521__$1 = (function (){var statearr_102562 = state_102521;
(statearr_102562[(45)] = inst_102390);

return statearr_102562;
})();
if(cljs.core.truth_(inst_102329)){
var statearr_102563_102660 = state_102521__$1;
(statearr_102563_102660[(1)] = (33));

} else {
var statearr_102564_102661 = state_102521__$1;
(statearr_102564_102661[(1)] = (34));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_102522 === (40))){
var inst_102402 = (cljs.core._LT__EQ_ === end_test);
var state_102521__$1 = state_102521;
if(cljs.core.truth_(inst_102402)){
var statearr_102565_102662 = state_102521__$1;
(statearr_102565_102662[(1)] = (42));

} else {
var statearr_102566_102663 = state_102521__$1;
(statearr_102566_102663[(1)] = (43));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_102522 === (56))){
var inst_102448 = (state_102521[(23)]);
var inst_102372 = (state_102521[(22)]);
var inst_102354 = (state_102521[(46)]);
var inst_102328 = (state_102521[(33)]);
var inst_102449 = (state_102521[(26)]);
var inst_102335 = (state_102521[(35)]);
var inst_102441 = (state_102521[(18)]);
var inst_102334 = (state_102521[(38)]);
var inst_102363 = (state_102521[(40)]);
var inst_102323 = (state_102521[(29)]);
var inst_102327 = (state_102521[(39)]);
var inst_102426 = (state_102521[(42)]);
var inst_102409 = (state_102521[(24)]);
var inst_102415 = (state_102521[(12)]);
var inst_102390 = (state_102521[(45)]);
var inst_102345 = (state_102521[(14)]);
var inst_102443 = (state_102521[(15)]);
var inst_102399 = (state_102521[(47)]);
var inst_102330 = (state_102521[(30)]);
var inst_102431 = (state_102521[(43)]);
var inst_102442 = (state_102521[(16)]);
var inst_102420 = (state_102521[(48)]);
var inst_102410 = (state_102521[(25)]);
var inst_102427 = (state_102521[(44)]);
var inst_102381 = (state_102521[(49)]);
var inst_102436 = (state_102521[(50)]);
var inst_102416 = (state_102521[(51)]);
var inst_102408 = (state_102521[(52)]);
var inst_102452 = (function (){var no_filter_QMARK_ = true;
var next_node = inst_102441;
var flakes = inst_102448;
var s1 = inst_102345;
var o2 = inst_102372;
var t1 = inst_102327;
var i = inst_102442;
var m1 = inst_102399;
var root_node = inst_102436;
var to_t = inst_102427;
var s2 = inst_102354;
var p2 = inst_102390;
var permissions = inst_102416;
var limit = inst_102415;
var start_flake = inst_102409;
var acc = inst_102443;
var t2 = inst_102334;
var vec__102317 = inst_102323;
var op1 = inst_102328;
var o1 = inst_102363;
var end_flake = inst_102410;
var base_result = inst_102449;
var p1 = inst_102381;
var idx_compare = inst_102420;
var vec__102320 = inst_102330;
var op2 = inst_102335;
var from_t = inst_102426;
var m2 = inst_102408;
var novelty = inst_102431;
return ((function (no_filter_QMARK_,next_node,flakes,s1,o2,t1,i,m1,root_node,to_t,s2,p2,permissions,limit,start_flake,acc,t2,vec__102317,op1,o1,end_flake,base_result,p1,idx_compare,vec__102320,op2,from_t,m2,novelty,inst_102448,inst_102372,inst_102354,inst_102328,inst_102449,inst_102335,inst_102441,inst_102334,inst_102363,inst_102323,inst_102327,inst_102426,inst_102409,inst_102415,inst_102390,inst_102345,inst_102443,inst_102399,inst_102330,inst_102431,inst_102442,inst_102420,inst_102410,inst_102427,inst_102381,inst_102436,inst_102416,inst_102408,state_val_102522,c__99809__auto__){
return (function (filtered_result,f){
if(cljs.core._EQ_.cljs$core$IFn$_invoke$arity$2(f.o,start_flake.o)){
return filtered_result;
} else {
return cljs.core.disj.cljs$core$IFn$_invoke$arity$2(filtered_result,f);
}
});
;})(no_filter_QMARK_,next_node,flakes,s1,o2,t1,i,m1,root_node,to_t,s2,p2,permissions,limit,start_flake,acc,t2,vec__102317,op1,o1,end_flake,base_result,p1,idx_compare,vec__102320,op2,from_t,m2,novelty,inst_102448,inst_102372,inst_102354,inst_102328,inst_102449,inst_102335,inst_102441,inst_102334,inst_102363,inst_102323,inst_102327,inst_102426,inst_102409,inst_102415,inst_102390,inst_102345,inst_102443,inst_102399,inst_102330,inst_102431,inst_102442,inst_102420,inst_102410,inst_102427,inst_102381,inst_102436,inst_102416,inst_102408,state_val_102522,c__99809__auto__))
})();
var inst_102453 = cljs.core.reduce.cljs$core$IFn$_invoke$arity$3(inst_102452,inst_102449,inst_102449);
var state_102521__$1 = state_102521;
var statearr_102567_102664 = state_102521__$1;
(statearr_102567_102664[(2)] = inst_102453);

(statearr_102567_102664[(1)] = (58));


return cljs.core.cst$kw$recur;
} else {
if((state_val_102522 === (33))){
var inst_102329 = (state_102521[(31)]);
var state_102521__$1 = state_102521;
var statearr_102568_102665 = state_102521__$1;
(statearr_102568_102665[(2)] = inst_102329);

(statearr_102568_102665[(1)] = (35));


return cljs.core.cst$kw$recur;
} else {
if((state_val_102522 === (13))){
var inst_102326 = (state_102521[(36)]);
var inst_102357 = fluree.db.dbproto._subid.cljs$core$IFn$_invoke$arity$2(db,inst_102326);
var state_102521__$1 = state_102521;
return cljs.core.async.impl.ioc_helpers.take_BANG_(state_102521__$1,(16),inst_102357);
} else {
if((state_val_102522 === (22))){
var inst_102373 = (state_102521[(53)]);
var state_102521__$1 = state_102521;
var statearr_102569_102666 = state_102521__$1;
(statearr_102569_102666[(2)] = inst_102373);

(statearr_102569_102666[(1)] = (23));


return cljs.core.cst$kw$recur;
} else {
if((state_val_102522 === (36))){
var state_102521__$1 = state_102521;
var statearr_102570_102667 = state_102521__$1;
(statearr_102570_102667[(2)] = fluree.db.util.core.min_integer);

(statearr_102570_102667[(1)] = (38));


return cljs.core.cst$kw$recur;
} else {
if((state_val_102522 === (41))){
var inst_102372 = (state_102521[(22)]);
var inst_102354 = (state_102521[(46)]);
var inst_102411 = (state_102521[(54)]);
var inst_102328 = (state_102521[(33)]);
var inst_102335 = (state_102521[(35)]);
var inst_102334 = (state_102521[(38)]);
var inst_102363 = (state_102521[(40)]);
var inst_102327 = (state_102521[(39)]);
var inst_102390 = (state_102521[(45)]);
var inst_102345 = (state_102521[(14)]);
var inst_102399 = (state_102521[(47)]);
var inst_102381 = (state_102521[(49)]);
var inst_102408 = (state_102521[(52)]);
var inst_102408__$1 = (state_102521[(2)]);
var inst_102409 = fluree.db.flake.__GT_Flake(inst_102345,inst_102381,inst_102363,inst_102327,inst_102328,inst_102399);
var inst_102410 = fluree.db.flake.__GT_Flake(inst_102354,inst_102390,inst_102372,inst_102334,inst_102335,inst_102408__$1);
var inst_102411__$1 = cljs.core.cst$kw$limit.cljs$core$IFn$_invoke$arity$1(opts);
var state_102521__$1 = (function (){var statearr_102571 = state_102521;
(statearr_102571[(54)] = inst_102411__$1);

(statearr_102571[(24)] = inst_102409);

(statearr_102571[(25)] = inst_102410);

(statearr_102571[(52)] = inst_102408__$1);

return statearr_102571;
})();
if(cljs.core.truth_(inst_102411__$1)){
var statearr_102572_102668 = state_102521__$1;
(statearr_102572_102668[(1)] = (45));

} else {
var statearr_102573_102669 = state_102521__$1;
(statearr_102573_102669[(1)] = (46));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_102522 === (43))){
var state_102521__$1 = state_102521;
var statearr_102574_102670 = state_102521__$1;
(statearr_102574_102670[(2)] = fluree.db.util.core.min_integer);

(statearr_102574_102670[(1)] = (44));


return cljs.core.cst$kw$recur;
} else {
if((state_val_102522 === (61))){
var inst_102457 = (state_102521[(19)]);
var inst_102496 = (state_102521[(11)]);
var inst_102496__$1 = (state_102521[(2)]);
var inst_102497 = cljs.core.count(inst_102496__$1);
var state_102521__$1 = (function (){var statearr_102575 = state_102521;
(statearr_102575[(55)] = inst_102497);

(statearr_102575[(11)] = inst_102496__$1);

return statearr_102575;
})();
if(cljs.core.truth_(inst_102457)){
var statearr_102576_102671 = state_102521__$1;
(statearr_102576_102671[(1)] = (67));

} else {
var statearr_102577_102672 = state_102521__$1;
(statearr_102577_102672[(1)] = (68));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_102522 === (29))){
var inst_102386 = (state_102521[(2)]);
var state_102521__$1 = state_102521;
if(cljs.core.truth_(inst_102386)){
var statearr_102578_102673 = state_102521__$1;
(statearr_102578_102673[(1)] = (30));

} else {
var statearr_102579_102674 = state_102521__$1;
(statearr_102579_102674[(1)] = (31));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_102522 === (44))){
var inst_102406 = (state_102521[(2)]);
var state_102521__$1 = state_102521;
var statearr_102580_102675 = state_102521__$1;
(statearr_102580_102675[(2)] = inst_102406);

(statearr_102580_102675[(1)] = (41));


return cljs.core.cst$kw$recur;
} else {
if((state_val_102522 === (6))){
var inst_102324 = (state_102521[(28)]);
var state_102521__$1 = state_102521;
var statearr_102581_102676 = state_102521__$1;
(statearr_102581_102676[(2)] = inst_102324);

(statearr_102581_102676[(1)] = (7));


return cljs.core.cst$kw$recur;
} else {
if((state_val_102522 === (28))){
var inst_102382 = (state_102521[(56)]);
var state_102521__$1 = state_102521;
var statearr_102582_102677 = state_102521__$1;
(statearr_102582_102677[(2)] = inst_102382);

(statearr_102582_102677[(1)] = (29));


return cljs.core.cst$kw$recur;
} else {
if((state_val_102522 === (64))){
var inst_102475 = (state_102521[(8)]);
var inst_102443 = (state_102521[(15)]);
var inst_102487 = cljs.core.into.cljs$core$IFn$_invoke$arity$2(inst_102475,inst_102443);
var state_102521__$1 = state_102521;
var statearr_102583_102678 = state_102521__$1;
(statearr_102583_102678[(2)] = inst_102487);

(statearr_102583_102678[(1)] = (66));


return cljs.core.cst$kw$recur;
} else {
if((state_val_102522 === (51))){
var inst_102409 = (state_102521[(24)]);
var inst_102436 = (state_102521[(50)]);
var inst_102435 = (state_102521[(2)]);
var inst_102436__$1 = fluree.db.util.async.throw_err(inst_102435);
var inst_102437 = fluree.db.dbproto._lookup_leaf(inst_102436__$1,inst_102409);
var state_102521__$1 = (function (){var statearr_102584 = state_102521;
(statearr_102584[(50)] = inst_102436__$1);

return statearr_102584;
})();
return cljs.core.async.impl.ioc_helpers.take_BANG_(state_102521__$1,(52),inst_102437);
} else {
if((state_val_102522 === (25))){
var inst_102325 = (state_102521[(34)]);
var state_102521__$1 = state_102521;
var statearr_102585_102679 = state_102521__$1;
(statearr_102585_102679[(2)] = inst_102325);

(statearr_102585_102679[(1)] = (26));


return cljs.core.cst$kw$recur;
} else {
if((state_val_102522 === (34))){
var inst_102393 = (cljs.core._GT__EQ_ === start_test);
var state_102521__$1 = state_102521;
if(cljs.core.truth_(inst_102393)){
var statearr_102586_102680 = state_102521__$1;
(statearr_102586_102680[(1)] = (36));

} else {
var statearr_102587_102681 = state_102521__$1;
(statearr_102587_102681[(1)] = (37));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_102522 === (17))){
var inst_102333 = (state_102521[(32)]);
var inst_102366 = fluree.db.dbproto._subid.cljs$core$IFn$_invoke$arity$2(db,inst_102333);
var state_102521__$1 = state_102521;
return cljs.core.async.impl.ioc_helpers.take_BANG_(state_102521__$1,(20),inst_102366);
} else {
if((state_val_102522 === (3))){
var inst_102313 = (state_102521[(2)]);
var state_102521__$1 = state_102521;
var statearr_102588_102682 = state_102521__$1;
(statearr_102588_102682[(2)] = inst_102313);


cljs.core.async.impl.ioc_helpers.process_exception(state_102521__$1);

return cljs.core.cst$kw$recur;
} else {
if((state_val_102522 === (12))){
var inst_102350 = (state_102521[(2)]);
var inst_102351 = fluree.db.util.async.throw_err(inst_102350);
var state_102521__$1 = state_102521;
var statearr_102589_102683 = state_102521__$1;
(statearr_102589_102683[(2)] = inst_102351);

(statearr_102589_102683[(1)] = (11));


return cljs.core.cst$kw$recur;
} else {
if((state_val_102522 === (2))){
var inst_102519 = (state_102521[(2)]);
var state_102521__$1 = state_102521;
return cljs.core.async.impl.ioc_helpers.return_chan(state_102521__$1,inst_102519);
} else {
if((state_val_102522 === (66))){
var inst_102492 = (state_102521[(2)]);
var state_102521__$1 = state_102521;
var statearr_102590_102684 = state_102521__$1;
(statearr_102590_102684[(2)] = inst_102492);

(statearr_102590_102684[(1)] = (63));


return cljs.core.cst$kw$recur;
} else {
if((state_val_102522 === (23))){
var inst_102377 = (state_102521[(2)]);
var state_102521__$1 = state_102521;
if(cljs.core.truth_(inst_102377)){
var statearr_102591_102685 = state_102521__$1;
(statearr_102591_102685[(1)] = (24));

} else {
var statearr_102592_102686 = state_102521__$1;
(statearr_102592_102686[(1)] = (25));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_102522 === (47))){
var inst_102421 = (state_102521[(41)]);
var inst_102415 = (state_102521[(2)]);
var inst_102416 = cljs.core.cst$kw$permissions.cljs$core$IFn$_invoke$arity$1(db);
var inst_102417 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_102418 = [cljs.core.cst$kw$index_DASH_configs,idx,cljs.core.cst$kw$comparator];
var inst_102419 = (new cljs.core.PersistentVector(null,3,(5),inst_102417,inst_102418,null));
var inst_102420 = cljs.core.get_in.cljs$core$IFn$_invoke$arity$2(db,inst_102419);
var inst_102421__$1 = cljs.core.cst$kw$from_DASH_t.cljs$core$IFn$_invoke$arity$1(opts);
var state_102521__$1 = (function (){var statearr_102593 = state_102521;
(statearr_102593[(41)] = inst_102421__$1);

(statearr_102593[(12)] = inst_102415);

(statearr_102593[(48)] = inst_102420);

(statearr_102593[(51)] = inst_102416);

return statearr_102593;
})();
if(cljs.core.truth_(inst_102421__$1)){
var statearr_102594_102687 = state_102521__$1;
(statearr_102594_102687[(1)] = (48));

} else {
var statearr_102595_102688 = state_102521__$1;
(statearr_102595_102688[(1)] = (49));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_102522 === (35))){
var inst_102336 = (state_102521[(27)]);
var inst_102399 = (state_102521[(2)]);
var state_102521__$1 = (function (){var statearr_102596 = state_102521;
(statearr_102596[(47)] = inst_102399);

return statearr_102596;
})();
if(cljs.core.truth_(inst_102336)){
var statearr_102597_102689 = state_102521__$1;
(statearr_102597_102689[(1)] = (39));

} else {
var statearr_102598_102690 = state_102521__$1;
(statearr_102598_102690[(1)] = (40));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_102522 === (19))){
var inst_102325 = (state_102521[(34)]);
var inst_102373 = (state_102521[(53)]);
var inst_102372 = (state_102521[(2)]);
var inst_102373__$1 = (inst_102325 == null);
var state_102521__$1 = (function (){var statearr_102599 = state_102521;
(statearr_102599[(22)] = inst_102372);

(statearr_102599[(53)] = inst_102373__$1);

return statearr_102599;
})();
if(cljs.core.truth_(inst_102373__$1)){
var statearr_102600_102691 = state_102521__$1;
(statearr_102600_102691[(1)] = (21));

} else {
var statearr_102601_102692 = state_102521__$1;
(statearr_102601_102692[(1)] = (22));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_102522 === (57))){
var inst_102449 = (state_102521[(26)]);
var state_102521__$1 = state_102521;
var statearr_102602_102693 = state_102521__$1;
(statearr_102602_102693[(2)] = inst_102449);

(statearr_102602_102693[(1)] = (58));


return cljs.core.cst$kw$recur;
} else {
if((state_val_102522 === (68))){
var inst_102457 = (state_102521[(19)]);
var state_102521__$1 = state_102521;
var statearr_102603_102694 = state_102521__$1;
(statearr_102603_102694[(2)] = inst_102457);

(statearr_102603_102694[(1)] = (69));


return cljs.core.cst$kw$recur;
} else {
if((state_val_102522 === (11))){
var inst_102326 = (state_102521[(36)]);
var inst_102354 = (state_102521[(2)]);
var inst_102355 = fluree.db.util.core.pred_ident_QMARK_(inst_102326);
var state_102521__$1 = (function (){var statearr_102604 = state_102521;
(statearr_102604[(46)] = inst_102354);

return statearr_102604;
})();
if(inst_102355){
var statearr_102605_102695 = state_102521__$1;
(statearr_102605_102695[(1)] = (13));

} else {
var statearr_102606_102696 = state_102521__$1;
(statearr_102606_102696[(1)] = (14));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_102522 === (9))){
var inst_102331 = (state_102521[(13)]);
var inst_102348 = fluree.db.dbproto._subid.cljs$core$IFn$_invoke$arity$2(db,inst_102331);
var state_102521__$1 = state_102521;
return cljs.core.async.impl.ioc_helpers.take_BANG_(state_102521__$1,(12),inst_102348);
} else {
if((state_val_102522 === (5))){
var inst_102324 = (state_102521[(28)]);
var inst_102339 = fluree.db.dbproto._subid.cljs$core$IFn$_invoke$arity$2(db,inst_102324);
var state_102521__$1 = state_102521;
return cljs.core.async.impl.ioc_helpers.take_BANG_(state_102521__$1,(8),inst_102339);
} else {
if((state_val_102522 === (14))){
var inst_102326 = (state_102521[(36)]);
var state_102521__$1 = state_102521;
var statearr_102607_102697 = state_102521__$1;
(statearr_102607_102697[(2)] = inst_102326);

(statearr_102607_102697[(1)] = (15));


return cljs.core.cst$kw$recur;
} else {
if((state_val_102522 === (45))){
var inst_102411 = (state_102521[(54)]);
var state_102521__$1 = state_102521;
var statearr_102608_102698 = state_102521__$1;
(statearr_102608_102698[(2)] = inst_102411);

(statearr_102608_102698[(1)] = (47));


return cljs.core.cst$kw$recur;
} else {
if((state_val_102522 === (53))){
var inst_102441 = (state_102521[(18)]);
var inst_102426 = (state_102521[(42)]);
var inst_102431 = (state_102521[(43)]);
var inst_102427 = (state_102521[(44)]);
var inst_102445 = fluree.db.dbproto._resolve_history_range.cljs$core$IFn$_invoke$arity$4(inst_102441,inst_102426,inst_102427,inst_102431);
var state_102521__$1 = state_102521;
return cljs.core.async.impl.ioc_helpers.take_BANG_(state_102521__$1,(55),inst_102445);
} else {
if((state_val_102522 === (26))){
var inst_102332 = (state_102521[(37)]);
var inst_102382 = (state_102521[(56)]);
var inst_102381 = (state_102521[(2)]);
var inst_102382__$1 = (inst_102332 == null);
var state_102521__$1 = (function (){var statearr_102609 = state_102521;
(statearr_102609[(56)] = inst_102382__$1);

(statearr_102609[(49)] = inst_102381);

return statearr_102609;
})();
if(cljs.core.truth_(inst_102382__$1)){
var statearr_102610_102699 = state_102521__$1;
(statearr_102610_102699[(1)] = (27));

} else {
var statearr_102611_102700 = state_102521__$1;
(statearr_102611_102700[(1)] = (28));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_102522 === (16))){
var inst_102359 = (state_102521[(2)]);
var inst_102360 = fluree.db.util.async.throw_err(inst_102359);
var state_102521__$1 = state_102521;
var statearr_102612_102701 = state_102521__$1;
(statearr_102612_102701[(2)] = inst_102360);

(statearr_102612_102701[(1)] = (15));


return cljs.core.cst$kw$recur;
} else {
if((state_val_102522 === (38))){
var inst_102397 = (state_102521[(2)]);
var state_102521__$1 = state_102521;
var statearr_102613_102702 = state_102521__$1;
(statearr_102613_102702[(2)] = inst_102397);

(statearr_102613_102702[(1)] = (35));


return cljs.core.cst$kw$recur;
} else {
if((state_val_102522 === (30))){
var state_102521__$1 = state_102521;
var statearr_102614_102703 = state_102521__$1;
(statearr_102614_102703[(2)] = fluree.db.flake.MAX_PREDICATE_ID);

(statearr_102614_102703[(1)] = (32));


return cljs.core.cst$kw$recur;
} else {
if((state_val_102522 === (73))){
var inst_102497 = (state_102521[(55)]);
var inst_102496 = (state_102521[(11)]);
var inst_102511 = (state_102521[(2)]);
var inst_102512 = fluree.db.util.async.throw_err(inst_102511);
var inst_102441 = inst_102512;
var inst_102442 = inst_102497;
var inst_102443 = inst_102496;
var state_102521__$1 = (function (){var statearr_102615 = state_102521;
(statearr_102615[(18)] = inst_102441);

(statearr_102615[(15)] = inst_102443);

(statearr_102615[(16)] = inst_102442);

return statearr_102615;
})();
var statearr_102616_102704 = state_102521__$1;
(statearr_102616_102704[(2)] = null);

(statearr_102616_102704[(1)] = (53));


return cljs.core.cst$kw$recur;
} else {
if((state_val_102522 === (10))){
var inst_102331 = (state_102521[(13)]);
var state_102521__$1 = state_102521;
var statearr_102617_102705 = state_102521__$1;
(statearr_102617_102705[(2)] = inst_102331);

(statearr_102617_102705[(1)] = (11));


return cljs.core.cst$kw$recur;
} else {
if((state_val_102522 === (18))){
var inst_102333 = (state_102521[(32)]);
var state_102521__$1 = state_102521;
var statearr_102618_102706 = state_102521__$1;
(statearr_102618_102706[(2)] = inst_102333);

(statearr_102618_102706[(1)] = (19));


return cljs.core.cst$kw$recur;
} else {
if((state_val_102522 === (52))){
var inst_102439 = (state_102521[(2)]);
var inst_102440 = fluree.db.util.async.throw_err(inst_102439);
var inst_102441 = inst_102440;
var inst_102442 = (0);
var inst_102443 = null;
var state_102521__$1 = (function (){var statearr_102619 = state_102521;
(statearr_102619[(18)] = inst_102441);

(statearr_102619[(15)] = inst_102443);

(statearr_102619[(16)] = inst_102442);

return statearr_102619;
})();
var statearr_102620_102707 = state_102521__$1;
(statearr_102620_102707[(2)] = null);

(statearr_102620_102707[(1)] = (53));


return cljs.core.cst$kw$recur;
} else {
if((state_val_102522 === (67))){
var inst_102497 = (state_102521[(55)]);
var inst_102457 = (state_102521[(19)]);
var inst_102415 = (state_102521[(12)]);
var inst_102420 = (state_102521[(48)]);
var inst_102410 = (state_102521[(25)]);
var inst_102499 = (inst_102420.cljs$core$IFn$_invoke$arity$2 ? inst_102420.cljs$core$IFn$_invoke$arity$2(inst_102457,inst_102410) : inst_102420.call(null,inst_102457,inst_102410));
var inst_102500 = (inst_102499 < (0));
var inst_102501 = (inst_102497 < inst_102415);
var inst_102502 = ((inst_102500) && (inst_102501));
var state_102521__$1 = state_102521;
var statearr_102621_102708 = state_102521__$1;
(statearr_102621_102708[(2)] = inst_102502);

(statearr_102621_102708[(1)] = (69));


return cljs.core.cst$kw$recur;
} else {
if((state_val_102522 === (71))){
var inst_102457 = (state_102521[(19)]);
var inst_102436 = (state_102521[(50)]);
var inst_102509 = fluree.db.dbproto._lookup_leaf(inst_102436,inst_102457);
var state_102521__$1 = state_102521;
return cljs.core.async.impl.ioc_helpers.take_BANG_(state_102521__$1,(73),inst_102509);
} else {
if((state_val_102522 === (42))){
var state_102521__$1 = state_102521;
var statearr_102622_102709 = state_102521__$1;
(statearr_102622_102709[(2)] = (2147483647));

(statearr_102622_102709[(1)] = (44));


return cljs.core.cst$kw$recur;
} else {
if((state_val_102522 === (37))){
var state_102521__$1 = state_102521;
var statearr_102623_102710 = state_102521__$1;
(statearr_102623_102710[(2)] = (2147483647));

(statearr_102623_102710[(1)] = (38));


return cljs.core.cst$kw$recur;
} else {
if((state_val_102522 === (63))){
var inst_102494 = (state_102521[(2)]);
var state_102521__$1 = state_102521;
var statearr_102624_102711 = state_102521__$1;
(statearr_102624_102711[(2)] = inst_102494);

(statearr_102624_102711[(1)] = (61));


return cljs.core.cst$kw$recur;
} else {
if((state_val_102522 === (8))){
var inst_102341 = (state_102521[(2)]);
var inst_102342 = fluree.db.util.async.throw_err(inst_102341);
var state_102521__$1 = state_102521;
var statearr_102625_102712 = state_102521__$1;
(statearr_102625_102712[(2)] = inst_102342);

(statearr_102625_102712[(1)] = (7));


return cljs.core.cst$kw$recur;
} else {
if((state_val_102522 === (49))){
var inst_102424 = cljs.core.cst$kw$t.cljs$core$IFn$_invoke$arity$1(db);
var state_102521__$1 = state_102521;
var statearr_102626_102713 = state_102521__$1;
(statearr_102626_102713[(2)] = inst_102424);

(statearr_102626_102713[(1)] = (50));


return cljs.core.cst$kw$recur;
} else {
return null;
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
});})(c__99809__auto__))
;
return ((function (switch__99702__auto__,c__99809__auto__){
return (function() {
var fluree$db$query$range$state_machine__99703__auto__ = null;
var fluree$db$query$range$state_machine__99703__auto____0 = (function (){
var statearr_102627 = [null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null];
(statearr_102627[(0)] = fluree$db$query$range$state_machine__99703__auto__);

(statearr_102627[(1)] = (1));

return statearr_102627;
});
var fluree$db$query$range$state_machine__99703__auto____1 = (function (state_102521){
while(true){
var ret_value__99704__auto__ = (function (){try{while(true){
var result__99705__auto__ = switch__99702__auto__(state_102521);
if(cljs.core.keyword_identical_QMARK_(result__99705__auto__,cljs.core.cst$kw$recur)){
continue;
} else {
return result__99705__auto__;
}
break;
}
}catch (e102628){if((e102628 instanceof Object)){
var ex__99706__auto__ = e102628;
var statearr_102629_102714 = state_102521;
(statearr_102629_102714[(5)] = ex__99706__auto__);


cljs.core.async.impl.ioc_helpers.process_exception(state_102521);

return cljs.core.cst$kw$recur;
} else {
throw e102628;

}
}})();
if(cljs.core.keyword_identical_QMARK_(ret_value__99704__auto__,cljs.core.cst$kw$recur)){
var G__102715 = state_102521;
state_102521 = G__102715;
continue;
} else {
return ret_value__99704__auto__;
}
break;
}
});
fluree$db$query$range$state_machine__99703__auto__ = function(state_102521){
switch(arguments.length){
case 0:
return fluree$db$query$range$state_machine__99703__auto____0.call(this);
case 1:
return fluree$db$query$range$state_machine__99703__auto____1.call(this,state_102521);
}
throw(new Error('Invalid arity: ' + arguments.length));
};
fluree$db$query$range$state_machine__99703__auto__.cljs$core$IFn$_invoke$arity$0 = fluree$db$query$range$state_machine__99703__auto____0;
fluree$db$query$range$state_machine__99703__auto__.cljs$core$IFn$_invoke$arity$1 = fluree$db$query$range$state_machine__99703__auto____1;
return fluree$db$query$range$state_machine__99703__auto__;
})()
;})(switch__99702__auto__,c__99809__auto__))
})();
var state__99811__auto__ = (function (){var statearr_102630 = (f__99810__auto__.cljs$core$IFn$_invoke$arity$0 ? f__99810__auto__.cljs$core$IFn$_invoke$arity$0() : f__99810__auto__.call(null));
(statearr_102630[(6)] = c__99809__auto__);

return statearr_102630;
})();
return cljs.core.async.impl.ioc_helpers.run_state_machine_wrapped(state__99811__auto__);
});})(c__99809__auto__))
);

return c__99809__auto__;
});

fluree.db.query.range.time_range.cljs$lang$maxFixedArity = 7;

/**
 * Starting with flakes grouped by subject id, filters the flakes until
 *   either flake-limit or subject-limit reached.
 */
fluree.db.query.range.subject_groups__GT_allow_flakes = (function fluree$db$query$range$subject_groups__GT_allow_flakes(db,subject_groups,flake_start,subject_start,flake_limit,subject_limit){
var c__99809__auto__ = cljs.core.async.chan.cljs$core$IFn$_invoke$arity$1((1));
cljs.core.async.impl.dispatch.run(((function (c__99809__auto__){
return (function (){
var f__99810__auto__ = (function (){var switch__99702__auto__ = ((function (c__99809__auto__){
return (function (state_102762){
var state_val_102763 = (state_102762[(1)]);
if((state_val_102763 === (7))){
var state_102762__$1 = state_102762;
var statearr_102764_102782 = state_102762__$1;
(statearr_102764_102782[(2)] = (0));

(statearr_102764_102782[(1)] = (9));


return cljs.core.cst$kw$recur;
} else {
if((state_val_102763 === (1))){
var inst_102723 = cljs.core.seq(subject_groups);
var inst_102724 = cljs.core.first(inst_102723);
var inst_102725 = cljs.core.next(inst_102723);
var inst_102726 = cljs.core.PersistentVector.EMPTY;
var inst_102727 = subject_groups;
var inst_102728 = flake_start;
var inst_102729 = subject_start;
var inst_102730 = inst_102726;
var state_102762__$1 = (function (){var statearr_102765 = state_102762;
(statearr_102765[(7)] = inst_102727);

(statearr_102765[(8)] = inst_102729);

(statearr_102765[(9)] = inst_102725);

(statearr_102765[(10)] = inst_102728);

(statearr_102765[(11)] = inst_102730);

(statearr_102765[(12)] = inst_102724);

return statearr_102765;
})();
var statearr_102766_102783 = state_102762__$1;
(statearr_102766_102783[(2)] = null);

(statearr_102766_102783[(1)] = (2));


return cljs.core.cst$kw$recur;
} else {
if((state_val_102763 === (4))){
var inst_102729 = (state_102762[(8)]);
var inst_102728 = (state_102762[(10)]);
var inst_102730 = (state_102762[(11)]);
var inst_102743 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_102744 = [inst_102728,inst_102729,inst_102730];
var inst_102745 = (new cljs.core.PersistentVector(null,3,(5),inst_102743,inst_102744,null));
var state_102762__$1 = state_102762;
var statearr_102767_102784 = state_102762__$1;
(statearr_102767_102784[(2)] = inst_102745);

(statearr_102767_102784[(1)] = (6));


return cljs.core.cst$kw$recur;
} else {
if((state_val_102763 === (6))){
var inst_102758 = (state_102762[(2)]);
var state_102762__$1 = state_102762;
var statearr_102768_102785 = state_102762__$1;
(statearr_102768_102785[(2)] = inst_102758);

(statearr_102768_102785[(1)] = (3));


return cljs.core.cst$kw$recur;
} else {
if((state_val_102763 === (3))){
var inst_102760 = (state_102762[(2)]);
var state_102762__$1 = state_102762;
return cljs.core.async.impl.ioc_helpers.return_chan(state_102762__$1,inst_102760);
} else {
if((state_val_102763 === (2))){
var inst_102727 = (state_102762[(7)]);
var inst_102729 = (state_102762[(8)]);
var inst_102728 = (state_102762[(10)]);
var inst_102736 = (state_102762[(13)]);
var inst_102735 = cljs.core.seq(inst_102727);
var inst_102736__$1 = cljs.core.first(inst_102735);
var inst_102737 = cljs.core.next(inst_102735);
var inst_102738 = (inst_102736__$1 == null);
var inst_102739 = (inst_102728 >= flake_limit);
var inst_102740 = (inst_102729 >= subject_limit);
var inst_102741 = ((inst_102738) || (inst_102739) || (inst_102740));
var state_102762__$1 = (function (){var statearr_102769 = state_102762;
(statearr_102769[(13)] = inst_102736__$1);

(statearr_102769[(14)] = inst_102737);

return statearr_102769;
})();
if(cljs.core.truth_(inst_102741)){
var statearr_102770_102786 = state_102762__$1;
(statearr_102770_102786[(1)] = (4));

} else {
var statearr_102771_102787 = state_102762__$1;
(statearr_102771_102787[(1)] = (5));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_102763 === (9))){
var inst_102729 = (state_102762[(8)]);
var inst_102747 = (state_102762[(15)]);
var inst_102728 = (state_102762[(10)]);
var inst_102736 = (state_102762[(13)]);
var inst_102737 = (state_102762[(14)]);
var inst_102730 = (state_102762[(11)]);
var inst_102752 = (state_102762[(2)]);
var inst_102753 = (inst_102728 + inst_102747);
var inst_102754 = (inst_102729 + inst_102752);
var inst_102755 = cljs.core.into.cljs$core$IFn$_invoke$arity$2(inst_102730,inst_102736);
var inst_102727 = inst_102737;
var inst_102728__$1 = inst_102753;
var inst_102729__$1 = inst_102754;
var inst_102730__$1 = inst_102755;
var state_102762__$1 = (function (){var statearr_102772 = state_102762;
(statearr_102772[(7)] = inst_102727);

(statearr_102772[(8)] = inst_102729__$1);

(statearr_102772[(10)] = inst_102728__$1);

(statearr_102772[(11)] = inst_102730__$1);

return statearr_102772;
})();
var statearr_102773_102788 = state_102762__$1;
(statearr_102773_102788[(2)] = null);

(statearr_102773_102788[(1)] = (2));


return cljs.core.cst$kw$recur;
} else {
if((state_val_102763 === (5))){
var inst_102747 = (state_102762[(15)]);
var inst_102736 = (state_102762[(13)]);
var inst_102747__$1 = cljs.core.count(inst_102736);
var inst_102748 = cljs.core._EQ_.cljs$core$IFn$_invoke$arity$2((0),inst_102747__$1);
var state_102762__$1 = (function (){var statearr_102774 = state_102762;
(statearr_102774[(15)] = inst_102747__$1);

return statearr_102774;
})();
if(inst_102748){
var statearr_102775_102789 = state_102762__$1;
(statearr_102775_102789[(1)] = (7));

} else {
var statearr_102776_102790 = state_102762__$1;
(statearr_102776_102790[(1)] = (8));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_102763 === (8))){
var state_102762__$1 = state_102762;
var statearr_102777_102791 = state_102762__$1;
(statearr_102777_102791[(2)] = (1));

(statearr_102777_102791[(1)] = (9));


return cljs.core.cst$kw$recur;
} else {
return null;
}
}
}
}
}
}
}
}
}
});})(c__99809__auto__))
;
return ((function (switch__99702__auto__,c__99809__auto__){
return (function() {
var fluree$db$query$range$subject_groups__GT_allow_flakes_$_state_machine__99703__auto__ = null;
var fluree$db$query$range$subject_groups__GT_allow_flakes_$_state_machine__99703__auto____0 = (function (){
var statearr_102778 = [null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null];
(statearr_102778[(0)] = fluree$db$query$range$subject_groups__GT_allow_flakes_$_state_machine__99703__auto__);

(statearr_102778[(1)] = (1));

return statearr_102778;
});
var fluree$db$query$range$subject_groups__GT_allow_flakes_$_state_machine__99703__auto____1 = (function (state_102762){
while(true){
var ret_value__99704__auto__ = (function (){try{while(true){
var result__99705__auto__ = switch__99702__auto__(state_102762);
if(cljs.core.keyword_identical_QMARK_(result__99705__auto__,cljs.core.cst$kw$recur)){
continue;
} else {
return result__99705__auto__;
}
break;
}
}catch (e102779){if((e102779 instanceof Object)){
var ex__99706__auto__ = e102779;
var statearr_102780_102792 = state_102762;
(statearr_102780_102792[(5)] = ex__99706__auto__);


cljs.core.async.impl.ioc_helpers.process_exception(state_102762);

return cljs.core.cst$kw$recur;
} else {
throw e102779;

}
}})();
if(cljs.core.keyword_identical_QMARK_(ret_value__99704__auto__,cljs.core.cst$kw$recur)){
var G__102793 = state_102762;
state_102762 = G__102793;
continue;
} else {
return ret_value__99704__auto__;
}
break;
}
});
fluree$db$query$range$subject_groups__GT_allow_flakes_$_state_machine__99703__auto__ = function(state_102762){
switch(arguments.length){
case 0:
return fluree$db$query$range$subject_groups__GT_allow_flakes_$_state_machine__99703__auto____0.call(this);
case 1:
return fluree$db$query$range$subject_groups__GT_allow_flakes_$_state_machine__99703__auto____1.call(this,state_102762);
}
throw(new Error('Invalid arity: ' + arguments.length));
};
fluree$db$query$range$subject_groups__GT_allow_flakes_$_state_machine__99703__auto__.cljs$core$IFn$_invoke$arity$0 = fluree$db$query$range$subject_groups__GT_allow_flakes_$_state_machine__99703__auto____0;
fluree$db$query$range$subject_groups__GT_allow_flakes_$_state_machine__99703__auto__.cljs$core$IFn$_invoke$arity$1 = fluree$db$query$range$subject_groups__GT_allow_flakes_$_state_machine__99703__auto____1;
return fluree$db$query$range$subject_groups__GT_allow_flakes_$_state_machine__99703__auto__;
})()
;})(switch__99702__auto__,c__99809__auto__))
})();
var state__99811__auto__ = (function (){var statearr_102781 = (f__99810__auto__.cljs$core$IFn$_invoke$arity$0 ? f__99810__auto__.cljs$core$IFn$_invoke$arity$0() : f__99810__auto__.call(null));
(statearr_102781[(6)] = c__99809__auto__);

return statearr_102781;
})();
return cljs.core.async.impl.ioc_helpers.run_state_machine_wrapped(state__99811__auto__);
});})(c__99809__auto__))
);

return c__99809__auto__;
});
fluree.db.query.range.find_next_valid_node = (function fluree$db$query$range$find_next_valid_node(root_node,rhs,t,novelty,fast_forward_db_QMARK_){
var c__99809__auto__ = cljs.core.async.chan.cljs$core$IFn$_invoke$arity$1((1));
cljs.core.async.impl.dispatch.run(((function (c__99809__auto__){
return (function (){
var f__99810__auto__ = (function (){var switch__99702__auto__ = ((function (c__99809__auto__){
return (function (state_102833){
var state_val_102834 = (state_102833[(1)]);
if((state_val_102834 === (7))){
var inst_102829 = (state_102833[(2)]);
var state_102833__$1 = state_102833;
var statearr_102835_102860 = state_102833__$1;
(statearr_102835_102860[(2)] = inst_102829);


cljs.core.async.impl.ioc_helpers.process_exception(state_102833__$1);

return cljs.core.cst$kw$recur;
} else {
if((state_val_102834 === (1))){
var state_102833__$1 = state_102833;
var statearr_102836_102861 = state_102833__$1;
(statearr_102836_102861[(2)] = null);

(statearr_102836_102861[(1)] = (4));


return cljs.core.cst$kw$recur;
} else {
if((state_val_102834 === (4))){
var _ = cljs.core.async.impl.ioc_helpers.add_exception_frame(state_102833,(3),Error,null,(2));
var inst_102798 = fluree.db.dbproto._lookup_leaf(root_node,rhs);
var state_102833__$1 = state_102833;
return cljs.core.async.impl.ioc_helpers.take_BANG_(state_102833__$1,(5),inst_102798);
} else {
if((state_val_102834 === (15))){
var inst_102816 = (state_102833[(7)]);
var inst_102818 = fluree.db.dbproto._lookup_leaf(root_node,inst_102816);
var state_102833__$1 = state_102833;
return cljs.core.async.impl.ioc_helpers.take_BANG_(state_102833__$1,(18),inst_102818);
} else {
if((state_val_102834 === (13))){
var inst_102816 = (state_102833[(7)]);
var inst_102802 = (state_102833[(8)]);
var inst_102816__$1 = cljs.core.cst$kw$rhs.cljs$core$IFn$_invoke$arity$1(inst_102802);
var state_102833__$1 = (function (){var statearr_102837 = state_102833;
(statearr_102837[(7)] = inst_102816__$1);

return statearr_102837;
})();
if(cljs.core.truth_(inst_102816__$1)){
var statearr_102838_102862 = state_102833__$1;
(statearr_102838_102862[(1)] = (15));

} else {
var statearr_102839_102863 = state_102833__$1;
(statearr_102839_102863[(1)] = (16));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_102834 === (6))){
var state_102833__$1 = state_102833;
var statearr_102840_102864 = state_102833__$1;
(statearr_102840_102864[(2)] = null);

(statearr_102840_102864[(1)] = (10));


return cljs.core.cst$kw$recur;
} else {
if((state_val_102834 === (17))){
var inst_102825 = (state_102833[(2)]);
var state_102833__$1 = state_102833;
var statearr_102841_102865 = state_102833__$1;
(statearr_102841_102865[(2)] = inst_102825);

(statearr_102841_102865[(1)] = (14));


return cljs.core.cst$kw$recur;
} else {
if((state_val_102834 === (3))){
var inst_102794 = (state_102833[(2)]);
var state_102833__$1 = state_102833;
var statearr_102842_102866 = state_102833__$1;
(statearr_102842_102866[(2)] = inst_102794);


cljs.core.async.impl.ioc_helpers.process_exception(state_102833__$1);

return cljs.core.cst$kw$recur;
} else {
if((state_val_102834 === (12))){
var inst_102813 = (state_102833[(9)]);
var state_102833__$1 = state_102833;
var statearr_102843_102867 = state_102833__$1;
(statearr_102843_102867[(2)] = inst_102813);

(statearr_102843_102867[(1)] = (14));


return cljs.core.cst$kw$recur;
} else {
if((state_val_102834 === (2))){
var inst_102831 = (state_102833[(2)]);
var state_102833__$1 = state_102833;
return cljs.core.async.impl.ioc_helpers.return_chan(state_102833__$1,inst_102831);
} else {
if((state_val_102834 === (11))){
var inst_102810 = (state_102833[(2)]);
var inst_102811 = fluree.db.util.async.throw_err(inst_102810);
var state_102833__$1 = state_102833;
var statearr_102844_102868 = state_102833__$1;
(statearr_102844_102868[(2)] = inst_102811);


cljs.core.async.impl.ioc_helpers.process_exception(state_102833__$1);

return cljs.core.cst$kw$recur;
} else {
if((state_val_102834 === (9))){
var inst_102804 = (state_102833[(2)]);
var state_102833__$1 = (function (){var statearr_102845 = state_102833;
(statearr_102845[(10)] = inst_102804);

return statearr_102845;
})();
var statearr_102846_102869 = state_102833__$1;
(statearr_102846_102869[(2)] = null);


cljs.core.async.impl.ioc_helpers.process_exception(state_102833__$1);

return cljs.core.cst$kw$recur;
} else {
if((state_val_102834 === (5))){
var inst_102800 = (state_102833[(2)]);
var inst_102801 = fluree.db.util.async.throw_err(inst_102800);
var inst_102802 = inst_102801;
var state_102833__$1 = (function (){var statearr_102847 = state_102833;
(statearr_102847[(8)] = inst_102802);

return statearr_102847;
})();
var statearr_102848_102870 = state_102833__$1;
(statearr_102848_102870[(2)] = null);

(statearr_102848_102870[(1)] = (6));


return cljs.core.cst$kw$recur;
} else {
if((state_val_102834 === (14))){
var inst_102827 = (state_102833[(2)]);
var state_102833__$1 = state_102833;
var statearr_102849_102871 = state_102833__$1;
(statearr_102849_102871[(2)] = inst_102827);

(statearr_102849_102871[(1)] = (7));


return cljs.core.cst$kw$recur;
} else {
if((state_val_102834 === (16))){
var state_102833__$1 = state_102833;
var statearr_102850_102872 = state_102833__$1;
(statearr_102850_102872[(2)] = null);

(statearr_102850_102872[(1)] = (17));


return cljs.core.cst$kw$recur;
} else {
if((state_val_102834 === (10))){
var inst_102802 = (state_102833[(8)]);
var _ = cljs.core.async.impl.ioc_helpers.add_exception_frame(state_102833,(9),cljs.core.cst$kw$default,null,(8));
var inst_102808 = fluree.db.dbproto._resolve_to_t.cljs$core$IFn$_invoke$arity$4(inst_102802,t,novelty,fast_forward_db_QMARK_);
var state_102833__$1 = state_102833;
return cljs.core.async.impl.ioc_helpers.take_BANG_(state_102833__$1,(11),inst_102808);
} else {
if((state_val_102834 === (18))){
var inst_102820 = (state_102833[(2)]);
var inst_102821 = fluree.db.util.async.throw_err(inst_102820);
var inst_102802 = inst_102821;
var state_102833__$1 = (function (){var statearr_102851 = state_102833;
(statearr_102851[(8)] = inst_102802);

return statearr_102851;
})();
var statearr_102852_102873 = state_102833__$1;
(statearr_102852_102873[(2)] = null);

(statearr_102852_102873[(1)] = (6));


return cljs.core.cst$kw$recur;
} else {
if((state_val_102834 === (8))){
var inst_102813 = (state_102833[(9)]);
var inst_102813__$1 = (state_102833[(2)]);
var state_102833__$1 = (function (){var statearr_102853 = state_102833;
(statearr_102853[(9)] = inst_102813__$1);

return statearr_102853;
})();
if(cljs.core.truth_(inst_102813__$1)){
var statearr_102854_102874 = state_102833__$1;
(statearr_102854_102874[(1)] = (12));

} else {
var statearr_102855_102875 = state_102833__$1;
(statearr_102855_102875[(1)] = (13));

}

return cljs.core.cst$kw$recur;
} else {
return null;
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
});})(c__99809__auto__))
;
return ((function (switch__99702__auto__,c__99809__auto__){
return (function() {
var fluree$db$query$range$find_next_valid_node_$_state_machine__99703__auto__ = null;
var fluree$db$query$range$find_next_valid_node_$_state_machine__99703__auto____0 = (function (){
var statearr_102856 = [null,null,null,null,null,null,null,null,null,null,null];
(statearr_102856[(0)] = fluree$db$query$range$find_next_valid_node_$_state_machine__99703__auto__);

(statearr_102856[(1)] = (1));

return statearr_102856;
});
var fluree$db$query$range$find_next_valid_node_$_state_machine__99703__auto____1 = (function (state_102833){
while(true){
var ret_value__99704__auto__ = (function (){try{while(true){
var result__99705__auto__ = switch__99702__auto__(state_102833);
if(cljs.core.keyword_identical_QMARK_(result__99705__auto__,cljs.core.cst$kw$recur)){
continue;
} else {
return result__99705__auto__;
}
break;
}
}catch (e102857){if((e102857 instanceof Object)){
var ex__99706__auto__ = e102857;
var statearr_102858_102876 = state_102833;
(statearr_102858_102876[(5)] = ex__99706__auto__);


cljs.core.async.impl.ioc_helpers.process_exception(state_102833);

return cljs.core.cst$kw$recur;
} else {
throw e102857;

}
}})();
if(cljs.core.keyword_identical_QMARK_(ret_value__99704__auto__,cljs.core.cst$kw$recur)){
var G__102877 = state_102833;
state_102833 = G__102877;
continue;
} else {
return ret_value__99704__auto__;
}
break;
}
});
fluree$db$query$range$find_next_valid_node_$_state_machine__99703__auto__ = function(state_102833){
switch(arguments.length){
case 0:
return fluree$db$query$range$find_next_valid_node_$_state_machine__99703__auto____0.call(this);
case 1:
return fluree$db$query$range$find_next_valid_node_$_state_machine__99703__auto____1.call(this,state_102833);
}
throw(new Error('Invalid arity: ' + arguments.length));
};
fluree$db$query$range$find_next_valid_node_$_state_machine__99703__auto__.cljs$core$IFn$_invoke$arity$0 = fluree$db$query$range$find_next_valid_node_$_state_machine__99703__auto____0;
fluree$db$query$range$find_next_valid_node_$_state_machine__99703__auto__.cljs$core$IFn$_invoke$arity$1 = fluree$db$query$range$find_next_valid_node_$_state_machine__99703__auto____1;
return fluree$db$query$range$find_next_valid_node_$_state_machine__99703__auto__;
})()
;})(switch__99702__auto__,c__99809__auto__))
})();
var state__99811__auto__ = (function (){var statearr_102859 = (f__99810__auto__.cljs$core$IFn$_invoke$arity$0 ? f__99810__auto__.cljs$core$IFn$_invoke$arity$0() : f__99810__auto__.call(null));
(statearr_102859[(6)] = c__99809__auto__);

return statearr_102859;
})();
return cljs.core.async.impl.ioc_helpers.run_state_machine_wrapped(state__99811__auto__);
});})(c__99809__auto__))
);

return c__99809__auto__;
});
/**
 * Range query across an index as of a 't' defined by the db.
 * 
 *   Ranges take the natural numeric sort orders, but all results will
 *   return in reverse order (newest subjects and predicates first).
 * 
 *   Returns core async channel.
 * 
 *   opts:
 *   :xform - xform applied to each result individually. This is not used when :chan is supplied.
 *   :limit - max number of flakes to return
 */
fluree.db.query.range.index_range = (function fluree$db$query$range$index_range(var_args){
var G__102884 = arguments.length;
switch (G__102884) {
case 2:
return fluree.db.query.range.index_range.cljs$core$IFn$_invoke$arity$2((arguments[(0)]),(arguments[(1)]));

break;
case 3:
return fluree.db.query.range.index_range.cljs$core$IFn$_invoke$arity$3((arguments[(0)]),(arguments[(1)]),(arguments[(2)]));

break;
case 4:
return fluree.db.query.range.index_range.cljs$core$IFn$_invoke$arity$4((arguments[(0)]),(arguments[(1)]),(arguments[(2)]),(arguments[(3)]));

break;
case 5:
return fluree.db.query.range.index_range.cljs$core$IFn$_invoke$arity$5((arguments[(0)]),(arguments[(1)]),(arguments[(2)]),(arguments[(3)]),(arguments[(4)]));

break;
case 6:
return fluree.db.query.range.index_range.cljs$core$IFn$_invoke$arity$6((arguments[(0)]),(arguments[(1)]),(arguments[(2)]),(arguments[(3)]),(arguments[(4)]),(arguments[(5)]));

break;
case 7:
return fluree.db.query.range.index_range.cljs$core$IFn$_invoke$arity$7((arguments[(0)]),(arguments[(1)]),(arguments[(2)]),(arguments[(3)]),(arguments[(4)]),(arguments[(5)]),(arguments[(6)]));

break;
default:
throw (new Error(["Invalid arity: ",cljs.core.str.cljs$core$IFn$_invoke$arity$1(arguments.length)].join('')));

}
});

fluree.db.query.range.index_range.cljs$core$IFn$_invoke$arity$2 = (function (db,idx){
return fluree.db.query.range.index_range.cljs$core$IFn$_invoke$arity$3(db,idx,cljs.core.PersistentArrayMap.EMPTY);
});

fluree.db.query.range.index_range.cljs$core$IFn$_invoke$arity$3 = (function (db,idx,opts){
return fluree.db.query.range.index_range.cljs$core$IFn$_invoke$arity$7(db,idx,cljs.core._GT__EQ_,fluree.db.query.range.min_match(idx),cljs.core._LT__EQ_,fluree.db.query.range.max_match(idx),opts);
});

fluree.db.query.range.index_range.cljs$core$IFn$_invoke$arity$4 = (function (db,idx,test,match){
return fluree.db.query.range.index_range.cljs$core$IFn$_invoke$arity$5(db,idx,test,match,cljs.core.PersistentArrayMap.EMPTY);
});

fluree.db.query.range.index_range.cljs$core$IFn$_invoke$arity$5 = (function (db,idx,test,match,opts){
var vec__102885 = (function (){var pred__102888 = cljs.core.identical_QMARK_;
var expr__102889 = test;
if(cljs.core.truth_((pred__102888.cljs$core$IFn$_invoke$arity$2 ? pred__102888.cljs$core$IFn$_invoke$arity$2(cljs.core._EQ_,expr__102889) : pred__102888.call(null,cljs.core._EQ_,expr__102889)))){
return new cljs.core.PersistentVector(null, 4, 5, cljs.core.PersistentVector.EMPTY_NODE, [cljs.core._GT__EQ_,match,cljs.core._LT__EQ_,match], null);
} else {
if(cljs.core.truth_((pred__102888.cljs$core$IFn$_invoke$arity$2 ? pred__102888.cljs$core$IFn$_invoke$arity$2(cljs.core._LT_,expr__102889) : pred__102888.call(null,cljs.core._LT_,expr__102889)))){
return new cljs.core.PersistentVector(null, 4, 5, cljs.core.PersistentVector.EMPTY_NODE, [cljs.core._GT_,fluree.db.query.range.min_match(idx),cljs.core._LT_,match], null);
} else {
if(cljs.core.truth_((pred__102888.cljs$core$IFn$_invoke$arity$2 ? pred__102888.cljs$core$IFn$_invoke$arity$2(cljs.core._LT__EQ_,expr__102889) : pred__102888.call(null,cljs.core._LT__EQ_,expr__102889)))){
return new cljs.core.PersistentVector(null, 4, 5, cljs.core.PersistentVector.EMPTY_NODE, [cljs.core._GT_,fluree.db.query.range.min_match(idx),cljs.core._LT__EQ_,match], null);
} else {
if(cljs.core.truth_((pred__102888.cljs$core$IFn$_invoke$arity$2 ? pred__102888.cljs$core$IFn$_invoke$arity$2(cljs.core._GT_,expr__102889) : pred__102888.call(null,cljs.core._GT_,expr__102889)))){
return new cljs.core.PersistentVector(null, 4, 5, cljs.core.PersistentVector.EMPTY_NODE, [cljs.core._GT_,match,cljs.core._LT__EQ_,fluree.db.query.range.max_match(idx)], null);
} else {
if(cljs.core.truth_((pred__102888.cljs$core$IFn$_invoke$arity$2 ? pred__102888.cljs$core$IFn$_invoke$arity$2(cljs.core._GT__EQ_,expr__102889) : pred__102888.call(null,cljs.core._GT__EQ_,expr__102889)))){
return new cljs.core.PersistentVector(null, 4, 5, cljs.core.PersistentVector.EMPTY_NODE, [cljs.core._GT__EQ_,match,cljs.core._LT_,fluree.db.query.range.max_match(idx)], null);
} else {
throw (new Error(["No matching clause: ",cljs.core.str.cljs$core$IFn$_invoke$arity$1(expr__102889)].join('')));
}
}
}
}
}
})();
var start_test = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(vec__102885,(0),null);
var start_match = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(vec__102885,(1),null);
var end_test = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(vec__102885,(2),null);
var end_match = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(vec__102885,(3),null);
return fluree.db.query.range.index_range.cljs$core$IFn$_invoke$arity$7(db,idx,start_test,start_match,end_test,end_match,opts);
});

fluree.db.query.range.index_range.cljs$core$IFn$_invoke$arity$6 = (function (db,idx,start_test,start_match,end_test,end_match){
return fluree.db.query.range.index_range.cljs$core$IFn$_invoke$arity$7(db,idx,start_test,start_match,end_test,end_match,cljs.core.PersistentArrayMap.EMPTY);
});

fluree.db.query.range.index_range.cljs$core$IFn$_invoke$arity$7 = (function (db,idx,start_test,start_match,end_test,end_match,opts){
var c__99809__auto__ = cljs.core.async.chan.cljs$core$IFn$_invoke$arity$1((1));
cljs.core.async.impl.dispatch.run(((function (c__99809__auto__){
return (function (){
var f__99810__auto__ = (function (){var switch__99702__auto__ = ((function (c__99809__auto__){
return (function (state_103282){
var state_val_103283 = (state_103282[(1)]);
if((state_val_103283 === (121))){
var inst_103255 = (state_103282[(7)]);
var inst_103255__$1 = (state_103282[(2)]);
var state_103282__$1 = (function (){var statearr_103284 = state_103282;
(statearr_103284[(7)] = inst_103255__$1);

return statearr_103284;
})();
if(cljs.core.truth_(inst_103255__$1)){
var statearr_103285_103484 = state_103282__$1;
(statearr_103285_103484[(1)] = (122));

} else {
var statearr_103286_103485 = state_103282__$1;
(statearr_103286_103485[(1)] = (123));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (65))){
var inst_103051 = (state_103282[(2)]);
var state_103282__$1 = state_103282;
var statearr_103287_103486 = state_103282__$1;
(statearr_103287_103486[(2)] = inst_103051);

(statearr_103287_103486[(1)] = (62));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (70))){
var state_103282__$1 = state_103282;
var statearr_103288_103487 = state_103282__$1;
(statearr_103288_103487[(2)] = false);

(statearr_103288_103487[(1)] = (71));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (62))){
var inst_102955 = (state_103282[(8)]);
var inst_102964 = (state_103282[(9)]);
var inst_103008 = (state_103282[(10)]);
var inst_102921 = (state_103282[(11)]);
var inst_103017 = (state_103282[(12)]);
var inst_103053 = (state_103282[(13)]);
var inst_102920 = (state_103282[(14)]);
var inst_102914 = (state_103282[(15)]);
var inst_103035 = (state_103282[(16)]);
var inst_103044 = (state_103282[(17)]);
var inst_103026 = (state_103282[(18)]);
var inst_102913 = (state_103282[(19)]);
var inst_103053__$1 = (state_103282[(2)]);
var inst_103054 = fluree.db.flake.__GT_Flake(inst_102955,inst_103026,inst_103008,inst_102913,inst_102914,inst_103044);
var inst_103055 = fluree.db.flake.__GT_Flake(inst_102964,inst_103035,inst_103017,inst_102920,inst_102921,inst_103053__$1);
var inst_103057 = (opts == null);
var inst_103058 = cljs.core.not(inst_103057);
var state_103282__$1 = (function (){var statearr_103289 = state_103282;
(statearr_103289[(13)] = inst_103053__$1);

(statearr_103289[(20)] = inst_103055);

(statearr_103289[(21)] = inst_103054);

return statearr_103289;
})();
if(inst_103058){
var statearr_103290_103488 = state_103282__$1;
(statearr_103290_103488[(1)] = (66));

} else {
var statearr_103291_103489 = state_103282__$1;
(statearr_103291_103489[(1)] = (67));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (74))){
var inst_103078 = (state_103282[(22)]);
var inst_103076 = (state_103282[(23)]);
var inst_103076__$1 = (state_103282[(2)]);
var inst_103077 = cljs.core.get.cljs$core$IFn$_invoke$arity$3(inst_103076__$1,cljs.core.cst$kw$flake_DASH_limit,fluree.db.util.core.max_long);
var inst_103078__$1 = cljs.core.get.cljs$core$IFn$_invoke$arity$2(inst_103076__$1,cljs.core.cst$kw$limit);
var inst_103079 = cljs.core.get.cljs$core$IFn$_invoke$arity$3(inst_103076__$1,cljs.core.cst$kw$offset,(0));
var state_103282__$1 = (function (){var statearr_103292 = state_103282;
(statearr_103292[(22)] = inst_103078__$1);

(statearr_103292[(23)] = inst_103076__$1);

(statearr_103292[(24)] = inst_103079);

(statearr_103292[(25)] = inst_103077);

return statearr_103292;
})();
if(cljs.core.truth_(inst_103078__$1)){
var statearr_103293_103490 = state_103282__$1;
(statearr_103293_103490[(1)] = (75));

} else {
var statearr_103294_103491 = state_103282__$1;
(statearr_103294_103491[(1)] = (76));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (110))){
var inst_103110 = (state_103282[(26)]);
var inst_103177 = (state_103282[(27)]);
var inst_103109 = (state_103282[(28)]);
var inst_103083 = (state_103282[(29)]);
var inst_103077 = (state_103282[(25)]);
var inst_103226 = fluree.db.query.range.subject_groups__GT_allow_flakes(db,inst_103177,inst_103109,inst_103110,inst_103077,inst_103083);
var state_103282__$1 = state_103282;
return cljs.core.async.impl.ioc_helpers.take_BANG_(state_103282__$1,(118),inst_103226);
} else {
if((state_val_103283 === (130))){
var inst_103245 = (state_103282[(30)]);
var inst_103244 = (state_103282[(31)]);
var inst_103243 = (state_103282[(32)]);
var inst_103246 = (state_103282[(33)]);
var inst_103263 = (state_103282[(34)]);
var inst_103107 = inst_103263;
var inst_103108 = inst_103243;
var inst_103109 = inst_103244;
var inst_103110 = inst_103245;
var inst_103111 = inst_103246;
var state_103282__$1 = (function (){var statearr_103295 = state_103282;
(statearr_103295[(26)] = inst_103110);

(statearr_103295[(35)] = inst_103107);

(statearr_103295[(36)] = inst_103108);

(statearr_103295[(28)] = inst_103109);

(statearr_103295[(37)] = inst_103111);

return statearr_103295;
})();
var statearr_103296_103492 = state_103282__$1;
(statearr_103296_103492[(2)] = null);

(statearr_103296_103492[(1)] = (83));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (128))){
var inst_103267 = (state_103282[(2)]);
var inst_103268 = cljs.core.not(inst_103267);
var state_103282__$1 = state_103282;
if(inst_103268){
var statearr_103297_103493 = state_103282__$1;
(statearr_103297_103493[(1)] = (129));

} else {
var statearr_103298_103494 = state_103282__$1;
(statearr_103298_103494[(1)] = (130));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (7))){
var inst_102938 = (state_103282[(2)]);
var state_103282__$1 = state_103282;
if(cljs.core.truth_(inst_102938)){
var statearr_103299_103495 = state_103282__$1;
(statearr_103299_103495[(1)] = (11));

} else {
var statearr_103300_103496 = state_103282__$1;
(statearr_103300_103496[(1)] = (12));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (59))){
var inst_103042 = (state_103282[(2)]);
var state_103282__$1 = state_103282;
var statearr_103301_103497 = state_103282__$1;
(statearr_103301_103497[(2)] = inst_103042);

(statearr_103301_103497[(1)] = (56));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (86))){
var inst_103117 = (state_103282[(38)]);
var state_103282__$1 = state_103282;
var statearr_103302_103498 = state_103282__$1;
(statearr_103302_103498[(2)] = inst_103117);

(statearr_103302_103498[(1)] = (87));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (20))){
var inst_102912 = (state_103282[(39)]);
var inst_102964 = (state_103282[(2)]);
var inst_102965 = cljs.core.boolean_QMARK_(inst_102912);
var state_103282__$1 = (function (){var statearr_103303 = state_103282;
(statearr_103303[(9)] = inst_102964);

return statearr_103303;
})();
if(inst_102965){
var statearr_103304_103499 = state_103282__$1;
(statearr_103304_103499[(1)] = (22));

} else {
var statearr_103305_103500 = state_103282__$1;
(statearr_103305_103500[(1)] = (23));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (72))){
var inst_103073 = cljs.core.apply.cljs$core$IFn$_invoke$arity$2(cljs.core.hash_map,opts);
var state_103282__$1 = state_103282;
var statearr_103306_103501 = state_103282__$1;
(statearr_103306_103501[(2)] = inst_103073);

(statearr_103306_103501[(1)] = (74));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (58))){
var state_103282__$1 = state_103282;
var statearr_103307_103502 = state_103282__$1;
(statearr_103307_103502[(2)] = (2147483647));

(statearr_103307_103502[(1)] = (59));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (60))){
var inst_102922 = (state_103282[(40)]);
var state_103282__$1 = state_103282;
var statearr_103308_103503 = state_103282__$1;
(statearr_103308_103503[(2)] = inst_102922);

(statearr_103308_103503[(1)] = (62));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (27))){
var inst_102976 = (state_103282[(2)]);
var state_103282__$1 = state_103282;
var statearr_103309_103504 = state_103282__$1;
(statearr_103309_103504[(2)] = inst_102976);

(statearr_103309_103504[(1)] = (24));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (1))){
var state_103282__$1 = state_103282;
var statearr_103310_103505 = state_103282__$1;
(statearr_103310_103505[(2)] = null);

(statearr_103310_103505[(1)] = (4));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (69))){
var state_103282__$1 = state_103282;
var statearr_103311_103506 = state_103282__$1;
(statearr_103311_103506[(2)] = true);

(statearr_103311_103506[(1)] = (71));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (101))){
var inst_103146 = (state_103282[(41)]);
var state_103282__$1 = state_103282;
var statearr_103312_103507 = state_103282__$1;
(statearr_103312_103507[(2)] = inst_103146);

(statearr_103312_103507[(1)] = (102));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (24))){
var inst_102978 = (state_103282[(42)]);
var inst_102978__$1 = (state_103282[(2)]);
var state_103282__$1 = (function (){var statearr_103313 = state_103282;
(statearr_103313[(42)] = inst_102978__$1);

return statearr_103313;
})();
if(cljs.core.truth_(inst_102978__$1)){
var statearr_103314_103508 = state_103282__$1;
(statearr_103314_103508[(1)] = (31));

} else {
var statearr_103315_103509 = state_103282__$1;
(statearr_103315_103509[(1)] = (32));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (102))){
var inst_103150 = (state_103282[(2)]);
var state_103282__$1 = state_103282;
var statearr_103316_103510 = state_103282__$1;
(statearr_103316_103510[(2)] = inst_103150);

(statearr_103316_103510[(1)] = (99));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (55))){
var inst_103038 = (cljs.core._GT__EQ_ === start_test);
var state_103282__$1 = state_103282;
if(cljs.core.truth_(inst_103038)){
var statearr_103317_103511 = state_103282__$1;
(statearr_103317_103511[(1)] = (57));

} else {
var statearr_103318_103512 = state_103282__$1;
(statearr_103318_103512[(1)] = (58));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (85))){
var inst_103085 = (state_103282[(43)]);
var inst_103076 = (state_103282[(23)]);
var inst_102955 = (state_103282[(8)]);
var inst_102995 = (state_103282[(44)]);
var inst_102964 = (state_103282[(9)]);
var inst_102999 = (state_103282[(45)]);
var inst_103008 = (state_103282[(10)]);
var inst_102945 = (state_103282[(46)]);
var inst_103110 = (state_103282[(26)]);
var inst_102921 = (state_103282[(11)]);
var inst_103107 = (state_103282[(35)]);
var inst_103017 = (state_103282[(12)]);
var inst_102996 = (state_103282[(47)]);
var inst_103053 = (state_103282[(13)]);
var inst_103055 = (state_103282[(20)]);
var inst_102920 = (state_103282[(14)]);
var inst_103100 = (state_103282[(48)]);
var inst_103090 = (state_103282[(49)]);
var inst_103095 = (state_103282[(50)]);
var inst_103089 = (state_103282[(51)]);
var inst_103054 = (state_103282[(21)]);
var inst_102943 = (state_103282[(52)]);
var inst_103104 = (state_103282[(53)]);
var inst_103108 = (state_103282[(36)]);
var inst_103084 = (state_103282[(54)]);
var inst_102944 = (state_103282[(55)]);
var inst_103109 = (state_103282[(28)]);
var inst_102914 = (state_103282[(15)]);
var inst_103035 = (state_103282[(16)]);
var inst_103083 = (state_103282[(29)]);
var inst_103111 = (state_103282[(37)]);
var inst_102909 = (state_103282[(56)]);
var inst_103044 = (state_103282[(17)]);
var inst_103026 = (state_103282[(18)]);
var inst_103077 = (state_103282[(25)]);
var inst_103117 = (state_103282[(38)]);
var inst_102913 = (state_103282[(19)]);
var inst_103094 = (state_103282[(57)]);
var inst_102916 = (state_103282[(58)]);
var inst_103121 = (function (){var no_filter_QMARK_ = true;
var t = inst_103090;
var max_limit_QMARK_ = inst_103084;
var next_node = inst_103107;
var fast_forward_db_QMARK_ = inst_103095;
var s1 = inst_102955;
var o2 = inst_103017;
var t1 = inst_102913;
var predicate_fn = inst_102945;
var i = inst_103109;
var m1 = inst_103044;
var root_node = inst_103100;
var G__103118 = inst_103117;
var s2 = inst_102964;
var map__102908 = inst_103076;
var vec__102905 = inst_102996;
var p2 = inst_103035;
var permissions = inst_103085;
var map__102901 = inst_102943;
var limit = inst_103083;
var start_flake = inst_103054;
var vec__102895 = inst_102909;
var flake_limit = inst_103077;
var offset = inst_103108;
var acc = inst_103111;
var t2 = inst_102920;
var op1 = inst_102914;
var o1 = inst_103008;
var end_flake = inst_103055;
var base_result = inst_103117;
var s = inst_103110;
var node_start = inst_103104;
var p1 = inst_103026;
var subject_fn = inst_102944;
var object_fn = inst_102999;
var idx_compare = inst_103089;
var vec__102898 = inst_102916;
var vec__102902 = inst_102995;
var op2 = inst_102921;
var m2 = inst_103053;
var novelty = inst_103094;
return ((function (no_filter_QMARK_,t,max_limit_QMARK_,next_node,fast_forward_db_QMARK_,s1,o2,t1,predicate_fn,i,m1,root_node,G__103118,s2,map__102908,vec__102905,p2,permissions,map__102901,limit,start_flake,vec__102895,flake_limit,offset,acc,t2,op1,o1,end_flake,base_result,s,node_start,p1,subject_fn,object_fn,idx_compare,vec__102898,vec__102902,op2,m2,novelty,inst_103085,inst_103076,inst_102955,inst_102995,inst_102964,inst_102999,inst_103008,inst_102945,inst_103110,inst_102921,inst_103107,inst_103017,inst_102996,inst_103053,inst_103055,inst_102920,inst_103100,inst_103090,inst_103095,inst_103089,inst_103054,inst_102943,inst_103104,inst_103108,inst_103084,inst_102944,inst_103109,inst_102914,inst_103035,inst_103083,inst_103111,inst_102909,inst_103044,inst_103026,inst_103077,inst_103117,inst_102913,inst_103094,inst_102916,state_val_103283,c__99809__auto__){
return (function (p1__102878_SHARP_){
return cljs.core._EQ_.cljs$core$IFn$_invoke$arity$2(p1__102878_SHARP_.o,start_flake.o);
});
;})(no_filter_QMARK_,t,max_limit_QMARK_,next_node,fast_forward_db_QMARK_,s1,o2,t1,predicate_fn,i,m1,root_node,G__103118,s2,map__102908,vec__102905,p2,permissions,map__102901,limit,start_flake,vec__102895,flake_limit,offset,acc,t2,op1,o1,end_flake,base_result,s,node_start,p1,subject_fn,object_fn,idx_compare,vec__102898,vec__102902,op2,m2,novelty,inst_103085,inst_103076,inst_102955,inst_102995,inst_102964,inst_102999,inst_103008,inst_102945,inst_103110,inst_102921,inst_103107,inst_103017,inst_102996,inst_103053,inst_103055,inst_102920,inst_103100,inst_103090,inst_103095,inst_103089,inst_103054,inst_102943,inst_103104,inst_103108,inst_103084,inst_102944,inst_103109,inst_102914,inst_103035,inst_103083,inst_103111,inst_102909,inst_103044,inst_103026,inst_103077,inst_103117,inst_102913,inst_103094,inst_102916,state_val_103283,c__99809__auto__))
})();
var inst_103122 = cljs.core.filter.cljs$core$IFn$_invoke$arity$2(inst_103121,inst_103117);
var state_103282__$1 = state_103282;
var statearr_103319_103513 = state_103282__$1;
(statearr_103319_103513[(2)] = inst_103122);

(statearr_103319_103513[(1)] = (87));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (39))){
var inst_102998 = (state_103282[(59)]);
var state_103282__$1 = state_103282;
var statearr_103320_103514 = state_103282__$1;
(statearr_103320_103514[(2)] = inst_102998);

(statearr_103320_103514[(1)] = (40));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (88))){
var inst_103085 = (state_103282[(43)]);
var inst_103076 = (state_103282[(23)]);
var inst_102955 = (state_103282[(8)]);
var inst_102995 = (state_103282[(44)]);
var inst_102964 = (state_103282[(9)]);
var inst_102999 = (state_103282[(45)]);
var inst_103008 = (state_103282[(10)]);
var inst_102945 = (state_103282[(46)]);
var inst_103110 = (state_103282[(26)]);
var inst_102921 = (state_103282[(11)]);
var inst_103107 = (state_103282[(35)]);
var inst_103125 = (state_103282[(60)]);
var inst_103017 = (state_103282[(12)]);
var inst_102996 = (state_103282[(47)]);
var inst_103053 = (state_103282[(13)]);
var inst_103055 = (state_103282[(20)]);
var inst_102920 = (state_103282[(14)]);
var inst_103100 = (state_103282[(48)]);
var inst_103090 = (state_103282[(49)]);
var inst_103095 = (state_103282[(50)]);
var inst_103089 = (state_103282[(51)]);
var inst_103054 = (state_103282[(21)]);
var inst_102943 = (state_103282[(52)]);
var inst_103104 = (state_103282[(53)]);
var inst_103108 = (state_103282[(36)]);
var inst_103084 = (state_103282[(54)]);
var inst_102944 = (state_103282[(55)]);
var inst_103109 = (state_103282[(28)]);
var inst_102914 = (state_103282[(15)]);
var inst_103035 = (state_103282[(16)]);
var inst_103083 = (state_103282[(29)]);
var inst_103111 = (state_103282[(37)]);
var inst_102909 = (state_103282[(56)]);
var inst_103044 = (state_103282[(17)]);
var inst_103026 = (state_103282[(18)]);
var inst_103077 = (state_103282[(25)]);
var inst_103117 = (state_103282[(38)]);
var inst_102913 = (state_103282[(19)]);
var inst_103094 = (state_103282[(57)]);
var inst_102916 = (state_103282[(58)]);
var inst_103127 = (function (){var no_filter_QMARK_ = true;
var t = inst_103090;
var max_limit_QMARK_ = inst_103084;
var next_node = inst_103107;
var fast_forward_db_QMARK_ = inst_103095;
var s1 = inst_102955;
var o2 = inst_103017;
var t1 = inst_102913;
var predicate_fn = inst_102945;
var i = inst_103109;
var m1 = inst_103044;
var root_node = inst_103100;
var G__103118 = inst_103125;
var s2 = inst_102964;
var map__102908 = inst_103076;
var vec__102905 = inst_102996;
var p2 = inst_103035;
var permissions = inst_103085;
var map__102901 = inst_102943;
var limit = inst_103083;
var start_flake = inst_103054;
var vec__102895 = inst_102909;
var flake_limit = inst_103077;
var offset = inst_103108;
var acc = inst_103111;
var t2 = inst_102920;
var op1 = inst_102914;
var o1 = inst_103008;
var end_flake = inst_103055;
var base_result = inst_103117;
var s = inst_103110;
var node_start = inst_103104;
var p1 = inst_103026;
var subject_fn = inst_102944;
var object_fn = inst_102999;
var idx_compare = inst_103089;
var vec__102898 = inst_102916;
var vec__102902 = inst_102995;
var op2 = inst_102921;
var m2 = inst_103053;
var novelty = inst_103094;
return ((function (no_filter_QMARK_,t,max_limit_QMARK_,next_node,fast_forward_db_QMARK_,s1,o2,t1,predicate_fn,i,m1,root_node,G__103118,s2,map__102908,vec__102905,p2,permissions,map__102901,limit,start_flake,vec__102895,flake_limit,offset,acc,t2,op1,o1,end_flake,base_result,s,node_start,p1,subject_fn,object_fn,idx_compare,vec__102898,vec__102902,op2,m2,novelty,inst_103085,inst_103076,inst_102955,inst_102995,inst_102964,inst_102999,inst_103008,inst_102945,inst_103110,inst_102921,inst_103107,inst_103125,inst_103017,inst_102996,inst_103053,inst_103055,inst_102920,inst_103100,inst_103090,inst_103095,inst_103089,inst_103054,inst_102943,inst_103104,inst_103108,inst_103084,inst_102944,inst_103109,inst_102914,inst_103035,inst_103083,inst_103111,inst_102909,inst_103044,inst_103026,inst_103077,inst_103117,inst_102913,inst_103094,inst_102916,state_val_103283,c__99809__auto__){
return (function (p1__102879_SHARP_){
var G__103321 = p1__102879_SHARP_.s;
return (subject_fn.cljs$core$IFn$_invoke$arity$1 ? subject_fn.cljs$core$IFn$_invoke$arity$1(G__103321) : subject_fn.call(null,G__103321));
});
;})(no_filter_QMARK_,t,max_limit_QMARK_,next_node,fast_forward_db_QMARK_,s1,o2,t1,predicate_fn,i,m1,root_node,G__103118,s2,map__102908,vec__102905,p2,permissions,map__102901,limit,start_flake,vec__102895,flake_limit,offset,acc,t2,op1,o1,end_flake,base_result,s,node_start,p1,subject_fn,object_fn,idx_compare,vec__102898,vec__102902,op2,m2,novelty,inst_103085,inst_103076,inst_102955,inst_102995,inst_102964,inst_102999,inst_103008,inst_102945,inst_103110,inst_102921,inst_103107,inst_103125,inst_103017,inst_102996,inst_103053,inst_103055,inst_102920,inst_103100,inst_103090,inst_103095,inst_103089,inst_103054,inst_102943,inst_103104,inst_103108,inst_103084,inst_102944,inst_103109,inst_102914,inst_103035,inst_103083,inst_103111,inst_102909,inst_103044,inst_103026,inst_103077,inst_103117,inst_102913,inst_103094,inst_102916,state_val_103283,c__99809__auto__))
})();
var inst_103128 = cljs.core.filter.cljs$core$IFn$_invoke$arity$2(inst_103127,inst_103125);
var state_103282__$1 = state_103282;
var statearr_103322_103515 = state_103282__$1;
(statearr_103322_103515[(2)] = inst_103128);

(statearr_103322_103515[(1)] = (90));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (46))){
var inst_102911 = (state_103282[(61)]);
var state_103282__$1 = state_103282;
var statearr_103323_103516 = state_103282__$1;
(statearr_103323_103516[(2)] = inst_102911);

(statearr_103323_103516[(1)] = (47));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (4))){
var inst_102909 = (state_103282[(56)]);
var inst_102916 = (state_103282[(58)]);
var _ = cljs.core.async.impl.ioc_helpers.add_exception_frame(state_103282,(3),Error,null,(2));
var inst_102909__$1 = fluree.db.query.range.match__GT_flake_parts(db,idx,start_match);
var inst_102910 = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(inst_102909__$1,(0),null);
var inst_102911 = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(inst_102909__$1,(1),null);
var inst_102912 = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(inst_102909__$1,(2),null);
var inst_102913 = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(inst_102909__$1,(3),null);
var inst_102914 = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(inst_102909__$1,(4),null);
var inst_102915 = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(inst_102909__$1,(5),null);
var inst_102916__$1 = fluree.db.query.range.match__GT_flake_parts(db,idx,end_match);
var inst_102917 = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(inst_102916__$1,(0),null);
var inst_102918 = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(inst_102916__$1,(1),null);
var inst_102919 = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(inst_102916__$1,(2),null);
var inst_102920 = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(inst_102916__$1,(3),null);
var inst_102921 = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(inst_102916__$1,(4),null);
var inst_102922 = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(inst_102916__$1,(5),null);
var inst_102924 = (opts == null);
var inst_102925 = cljs.core.not(inst_102924);
var state_103282__$1 = (function (){var statearr_103324 = state_103282;
(statearr_103324[(62)] = inst_102919);

(statearr_103324[(63)] = inst_102918);

(statearr_103324[(11)] = inst_102921);

(statearr_103324[(14)] = inst_102920);

(statearr_103324[(40)] = inst_102922);

(statearr_103324[(39)] = inst_102912);

(statearr_103324[(64)] = inst_102910);

(statearr_103324[(65)] = inst_102917);

(statearr_103324[(66)] = inst_102915);

(statearr_103324[(15)] = inst_102914);

(statearr_103324[(61)] = inst_102911);

(statearr_103324[(56)] = inst_102909__$1);

(statearr_103324[(19)] = inst_102913);

(statearr_103324[(58)] = inst_102916__$1);

return statearr_103324;
})();
if(inst_102925){
var statearr_103325_103517 = state_103282__$1;
(statearr_103325_103517[(1)] = (5));

} else {
var statearr_103326_103518 = state_103282__$1;
(statearr_103326_103518[(1)] = (6));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (77))){
var inst_103083 = (state_103282[(29)]);
var inst_103083__$1 = (state_103282[(2)]);
var inst_103084 = cljs.core._EQ_.cljs$core$IFn$_invoke$arity$2(inst_103083__$1,fluree.db.util.core.max_long);
var inst_103085 = cljs.core.cst$kw$permissions.cljs$core$IFn$_invoke$arity$1(db);
var inst_103086 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_103087 = [cljs.core.cst$kw$index_DASH_configs,idx,cljs.core.cst$kw$comparator];
var inst_103088 = (new cljs.core.PersistentVector(null,3,(5),inst_103086,inst_103087,null));
var inst_103089 = cljs.core.get_in.cljs$core$IFn$_invoke$arity$2(db,inst_103088);
var inst_103090 = cljs.core.cst$kw$t.cljs$core$IFn$_invoke$arity$1(db);
var inst_103091 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_103092 = [cljs.core.cst$kw$novelty,idx];
var inst_103093 = (new cljs.core.PersistentVector(null,2,(5),inst_103091,inst_103092,null));
var inst_103094 = cljs.core.get_in.cljs$core$IFn$_invoke$arity$2(db,inst_103093);
var inst_103095 = cljs.core.cst$kw$tt_DASH_id.cljs$core$IFn$_invoke$arity$1(db);
var inst_103096 = cljs.core.get.cljs$core$IFn$_invoke$arity$2(db,idx);
var inst_103097 = fluree.db.dbproto._resolve(inst_103096);
var state_103282__$1 = (function (){var statearr_103327 = state_103282;
(statearr_103327[(43)] = inst_103085);

(statearr_103327[(49)] = inst_103090);

(statearr_103327[(50)] = inst_103095);

(statearr_103327[(51)] = inst_103089);

(statearr_103327[(54)] = inst_103084);

(statearr_103327[(29)] = inst_103083__$1);

(statearr_103327[(57)] = inst_103094);

return statearr_103327;
})();
return cljs.core.async.impl.ioc_helpers.take_BANG_(state_103282__$1,(78),inst_103097);
} else {
if((state_val_103283 === (106))){
var inst_103110 = (state_103282[(26)]);
var inst_103166 = (state_103282[(67)]);
var inst_103108 = (state_103282[(36)]);
var inst_103109 = (state_103282[(28)]);
var inst_103111 = (state_103282[(37)]);
var inst_103169 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_103170 = (inst_103108 - inst_103166);
var inst_103171 = [inst_103170,inst_103109,inst_103110,inst_103111];
var inst_103172 = (new cljs.core.PersistentVector(null,4,(5),inst_103169,inst_103171,null));
var state_103282__$1 = state_103282;
var statearr_103328_103519 = state_103282__$1;
(statearr_103328_103519[(2)] = inst_103172);

(statearr_103328_103519[(1)] = (108));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (119))){
var inst_103245 = (state_103282[(30)]);
var inst_103244 = (state_103282[(31)]);
var inst_103055 = (state_103282[(20)]);
var inst_103089 = (state_103282[(51)]);
var inst_103083 = (state_103282[(29)]);
var inst_103144 = (state_103282[(68)]);
var inst_103077 = (state_103282[(25)]);
var inst_103248 = (inst_103089.cljs$core$IFn$_invoke$arity$2 ? inst_103089.cljs$core$IFn$_invoke$arity$2(inst_103144,inst_103055) : inst_103089.call(null,inst_103144,inst_103055));
var inst_103249 = (inst_103248 < (0));
var inst_103250 = (inst_103244 < inst_103077);
var inst_103251 = (inst_103245 < inst_103083);
var inst_103252 = ((inst_103249) && (inst_103250) && (inst_103251));
var state_103282__$1 = state_103282;
var statearr_103329_103520 = state_103282__$1;
(statearr_103329_103520[(2)] = inst_103252);

(statearr_103329_103520[(1)] = (121));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (95))){
var inst_103137 = (state_103282[(69)]);
var state_103282__$1 = state_103282;
var statearr_103330_103521 = state_103282__$1;
(statearr_103330_103521[(2)] = inst_103137);

(statearr_103330_103521[(1)] = (96));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (54))){
var inst_102915 = (state_103282[(66)]);
var state_103282__$1 = state_103282;
var statearr_103331_103522 = state_103282__$1;
(statearr_103331_103522[(2)] = inst_102915);

(statearr_103331_103522[(1)] = (56));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (92))){
var inst_103131 = (state_103282[(70)]);
var state_103282__$1 = state_103282;
var statearr_103332_103523 = state_103282__$1;
(statearr_103332_103523[(2)] = inst_103131);

(statearr_103332_103523[(1)] = (93));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (104))){
var inst_103085 = (state_103282[(43)]);
var inst_103076 = (state_103282[(23)]);
var inst_102955 = (state_103282[(8)]);
var inst_102995 = (state_103282[(44)]);
var inst_102964 = (state_103282[(9)]);
var inst_102999 = (state_103282[(45)]);
var inst_103008 = (state_103282[(10)]);
var inst_102945 = (state_103282[(46)]);
var inst_103110 = (state_103282[(26)]);
var inst_102921 = (state_103282[(11)]);
var inst_103107 = (state_103282[(35)]);
var inst_103166 = (state_103282[(67)]);
var inst_103017 = (state_103282[(12)]);
var inst_102996 = (state_103282[(47)]);
var inst_103053 = (state_103282[(13)]);
var inst_103055 = (state_103282[(20)]);
var inst_102920 = (state_103282[(14)]);
var inst_103100 = (state_103282[(48)]);
var inst_103090 = (state_103282[(49)]);
var inst_103095 = (state_103282[(50)]);
var inst_103089 = (state_103282[(51)]);
var inst_103054 = (state_103282[(21)]);
var inst_102943 = (state_103282[(52)]);
var inst_103104 = (state_103282[(53)]);
var inst_103108 = (state_103282[(36)]);
var inst_103084 = (state_103282[(54)]);
var inst_103165 = (state_103282[(71)]);
var inst_102944 = (state_103282[(55)]);
var inst_103143 = (state_103282[(72)]);
var inst_103109 = (state_103282[(28)]);
var inst_102914 = (state_103282[(15)]);
var inst_103035 = (state_103282[(16)]);
var inst_103083 = (state_103282[(29)]);
var inst_103111 = (state_103282[(37)]);
var inst_102909 = (state_103282[(56)]);
var inst_103144 = (state_103282[(68)]);
var inst_103044 = (state_103282[(17)]);
var inst_103026 = (state_103282[(18)]);
var inst_103077 = (state_103282[(25)]);
var inst_103117 = (state_103282[(38)]);
var inst_102913 = (state_103282[(19)]);
var inst_103094 = (state_103282[(57)]);
var inst_102916 = (state_103282[(58)]);
var inst_103164 = (function (){var no_filter_QMARK_ = true;
var base_result_SINGLEQUOTE_ = inst_103143;
var t = inst_103090;
var max_limit_QMARK_ = inst_103084;
var next_node = inst_103107;
var fast_forward_db_QMARK_ = inst_103095;
var s1 = inst_102955;
var o2 = inst_103017;
var t1 = inst_102913;
var predicate_fn = inst_102945;
var i = inst_103109;
var rhs = inst_103144;
var m1 = inst_103044;
var root_node = inst_103100;
var s2 = inst_102964;
var map__102908 = inst_103076;
var vec__102905 = inst_102996;
var p2 = inst_103035;
var permissions = inst_103085;
var map__102901 = inst_102943;
var limit = inst_103083;
var start_flake = inst_103054;
var vec__102895 = inst_102909;
var flake_limit = inst_103077;
var offset = inst_103108;
var acc = inst_103111;
var t2 = inst_102920;
var op1 = inst_102914;
var o1 = inst_103008;
var end_flake = inst_103055;
var base_result = inst_103117;
var s = inst_103110;
var node_start = inst_103104;
var p1 = inst_103026;
var subject_fn = inst_102944;
var object_fn = inst_102999;
var idx_compare = inst_103089;
var vec__102898 = inst_102916;
var vec__102902 = inst_102995;
var op2 = inst_102921;
var m2 = inst_103053;
var novelty = inst_103094;
return ((function (no_filter_QMARK_,base_result_SINGLEQUOTE_,t,max_limit_QMARK_,next_node,fast_forward_db_QMARK_,s1,o2,t1,predicate_fn,i,rhs,m1,root_node,s2,map__102908,vec__102905,p2,permissions,map__102901,limit,start_flake,vec__102895,flake_limit,offset,acc,t2,op1,o1,end_flake,base_result,s,node_start,p1,subject_fn,object_fn,idx_compare,vec__102898,vec__102902,op2,m2,novelty,inst_103085,inst_103076,inst_102955,inst_102995,inst_102964,inst_102999,inst_103008,inst_102945,inst_103110,inst_102921,inst_103107,inst_103166,inst_103017,inst_102996,inst_103053,inst_103055,inst_102920,inst_103100,inst_103090,inst_103095,inst_103089,inst_103054,inst_102943,inst_103104,inst_103108,inst_103084,inst_103165,inst_102944,inst_103143,inst_103109,inst_102914,inst_103035,inst_103083,inst_103111,inst_102909,inst_103144,inst_103044,inst_103026,inst_103077,inst_103117,inst_102913,inst_103094,inst_102916,state_val_103283,c__99809__auto__){
return (function (p1__102882_SHARP_){
return p1__102882_SHARP_.s;
});
;})(no_filter_QMARK_,base_result_SINGLEQUOTE_,t,max_limit_QMARK_,next_node,fast_forward_db_QMARK_,s1,o2,t1,predicate_fn,i,rhs,m1,root_node,s2,map__102908,vec__102905,p2,permissions,map__102901,limit,start_flake,vec__102895,flake_limit,offset,acc,t2,op1,o1,end_flake,base_result,s,node_start,p1,subject_fn,object_fn,idx_compare,vec__102898,vec__102902,op2,m2,novelty,inst_103085,inst_103076,inst_102955,inst_102995,inst_102964,inst_102999,inst_103008,inst_102945,inst_103110,inst_102921,inst_103107,inst_103166,inst_103017,inst_102996,inst_103053,inst_103055,inst_102920,inst_103100,inst_103090,inst_103095,inst_103089,inst_103054,inst_102943,inst_103104,inst_103108,inst_103084,inst_103165,inst_102944,inst_103143,inst_103109,inst_102914,inst_103035,inst_103083,inst_103111,inst_102909,inst_103144,inst_103044,inst_103026,inst_103077,inst_103117,inst_102913,inst_103094,inst_102916,state_val_103283,c__99809__auto__))
})();
var inst_103165__$1 = cljs.core.partition_by.cljs$core$IFn$_invoke$arity$2(inst_103164,inst_103143);
var inst_103166__$1 = cljs.core.count(inst_103165__$1);
var inst_103167 = (inst_103108 > inst_103166__$1);
var state_103282__$1 = (function (){var statearr_103333 = state_103282;
(statearr_103333[(67)] = inst_103166__$1);

(statearr_103333[(71)] = inst_103165__$1);

return statearr_103333;
})();
if(cljs.core.truth_(inst_103167)){
var statearr_103334_103524 = state_103282__$1;
(statearr_103334_103524[(1)] = (106));

} else {
var statearr_103335_103525 = state_103282__$1;
(statearr_103335_103525[(1)] = (107));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (15))){
var inst_102910 = (state_103282[(64)]);
var state_103282__$1 = state_103282;
var statearr_103336_103526 = state_103282__$1;
(statearr_103336_103526[(2)] = inst_102910);

(statearr_103336_103526[(1)] = (16));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (48))){
var inst_103017 = (state_103282[(12)]);
var state_103282__$1 = state_103282;
var statearr_103337_103527 = state_103282__$1;
(statearr_103337_103527[(2)] = inst_103017);

(statearr_103337_103527[(1)] = (50));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (50))){
var inst_103031 = (state_103282[(2)]);
var state_103282__$1 = state_103282;
if(cljs.core.truth_(inst_103031)){
var statearr_103338_103528 = state_103282__$1;
(statearr_103338_103528[(1)] = (51));

} else {
var statearr_103339_103529 = state_103282__$1;
(statearr_103339_103529[(1)] = (52));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (116))){
var inst_103205 = (state_103282[(73)]);
var inst_103203 = (state_103282[(74)]);
var inst_103215 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_103216 = [inst_103205,inst_103203];
var inst_103217 = (new cljs.core.PersistentVector(null,2,(5),inst_103215,inst_103216,null));
var state_103282__$1 = state_103282;
var statearr_103340_103530 = state_103282__$1;
(statearr_103340_103530[(2)] = inst_103217);

(statearr_103340_103530[(1)] = (117));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (75))){
var inst_103078 = (state_103282[(22)]);
var state_103282__$1 = state_103282;
var statearr_103341_103531 = state_103282__$1;
(statearr_103341_103531[(2)] = inst_103078);

(statearr_103341_103531[(1)] = (77));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (99))){
var inst_103153 = (state_103282[(2)]);
var state_103282__$1 = state_103282;
if(cljs.core.truth_(inst_103153)){
var statearr_103342_103532 = state_103282__$1;
(statearr_103342_103532[(1)] = (103));

} else {
var statearr_103343_103533 = state_103282__$1;
(statearr_103343_103533[(1)] = (104));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (21))){
var inst_102960 = (state_103282[(2)]);
var inst_102961 = fluree.db.util.async.throw_err(inst_102960);
var state_103282__$1 = state_103282;
var statearr_103344_103534 = state_103282__$1;
(statearr_103344_103534[(2)] = inst_102961);

(statearr_103344_103534[(1)] = (20));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (31))){
var inst_102919 = (state_103282[(62)]);
var inst_102918 = (state_103282[(63)]);
var inst_102946 = (state_103282[(75)]);
var inst_102955 = (state_103282[(8)]);
var inst_102964 = (state_103282[(9)]);
var inst_102945 = (state_103282[(46)]);
var inst_102921 = (state_103282[(11)]);
var inst_102920 = (state_103282[(14)]);
var inst_102943 = (state_103282[(52)]);
var inst_102922 = (state_103282[(40)]);
var inst_102912 = (state_103282[(39)]);
var inst_102978 = (state_103282[(42)]);
var inst_102944 = (state_103282[(55)]);
var inst_102915 = (state_103282[(66)]);
var inst_102914 = (state_103282[(15)]);
var inst_102911 = (state_103282[(61)]);
var inst_102909 = (state_103282[(56)]);
var inst_102913 = (state_103282[(19)]);
var inst_102916 = (state_103282[(58)]);
var inst_102980 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_102981 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_102982 = [null,null];
var inst_102983 = (new cljs.core.PersistentVector(null,2,(5),inst_102981,inst_102982,null));
var inst_102984 = (function (){var bool = inst_102978;
var temp__5733__auto__ = inst_102978;
var s1 = inst_102955;
var o2 = inst_102919;
var t1 = inst_102913;
var predicate_fn = inst_102945;
var m1 = inst_102915;
var s2 = inst_102964;
var p2 = inst_102918;
var map__102901 = inst_102943;
var vec__102895 = inst_102909;
var t2 = inst_102920;
var op1 = inst_102914;
var o1 = inst_102912;
var p1 = inst_102911;
var subject_fn = inst_102944;
var object_fn = inst_102946;
var vec__102898 = inst_102916;
var op2 = inst_102921;
var m2 = inst_102922;
return ((function (bool,temp__5733__auto__,s1,o2,t1,predicate_fn,m1,s2,p2,map__102901,vec__102895,t2,op1,o1,p1,subject_fn,object_fn,vec__102898,op2,m2,inst_102919,inst_102918,inst_102946,inst_102955,inst_102964,inst_102945,inst_102921,inst_102920,inst_102943,inst_102922,inst_102912,inst_102978,inst_102944,inst_102915,inst_102914,inst_102911,inst_102909,inst_102913,inst_102916,inst_102980,inst_102981,inst_102982,inst_102983,state_val_103283,c__99809__auto__){
return (function (o){
return cljs.core._EQ_.cljs$core$IFn$_invoke$arity$2(o,bool);
});
;})(bool,temp__5733__auto__,s1,o2,t1,predicate_fn,m1,s2,p2,map__102901,vec__102895,t2,op1,o1,p1,subject_fn,object_fn,vec__102898,op2,m2,inst_102919,inst_102918,inst_102946,inst_102955,inst_102964,inst_102945,inst_102921,inst_102920,inst_102943,inst_102922,inst_102912,inst_102978,inst_102944,inst_102915,inst_102914,inst_102911,inst_102909,inst_102913,inst_102916,inst_102980,inst_102981,inst_102982,inst_102983,state_val_103283,c__99809__auto__))
})();
var inst_102985 = [inst_102983,inst_102984];
var inst_102986 = (new cljs.core.PersistentVector(null,2,(5),inst_102980,inst_102985,null));
var state_103282__$1 = state_103282;
var statearr_103345_103535 = state_103282__$1;
(statearr_103345_103535[(2)] = inst_102986);

(statearr_103345_103535[(1)] = (33));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (113))){
var inst_103186 = (state_103282[(76)]);
var inst_103195 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_103196 = [inst_103186,inst_103186];
var inst_103197 = (new cljs.core.PersistentVector(null,2,(5),inst_103195,inst_103196,null));
var state_103282__$1 = state_103282;
var statearr_103346_103536 = state_103282__$1;
(statearr_103346_103536[(2)] = inst_103197);

(statearr_103346_103536[(1)] = (114));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (32))){
var inst_102919 = (state_103282[(62)]);
var inst_102946 = (state_103282[(75)]);
var inst_102912 = (state_103282[(39)]);
var inst_102988 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_102989 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_102990 = [inst_102912,inst_102919];
var inst_102991 = (new cljs.core.PersistentVector(null,2,(5),inst_102989,inst_102990,null));
var inst_102992 = [inst_102991,inst_102946];
var inst_102993 = (new cljs.core.PersistentVector(null,2,(5),inst_102988,inst_102992,null));
var state_103282__$1 = state_103282;
var statearr_103347_103537 = state_103282__$1;
(statearr_103347_103537[(2)] = inst_102993);

(statearr_103347_103537[(1)] = (33));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (40))){
var inst_102911 = (state_103282[(61)]);
var inst_103018 = (state_103282[(77)]);
var inst_103017 = (state_103282[(2)]);
var inst_103018__$1 = (inst_102911 == null);
var state_103282__$1 = (function (){var statearr_103348 = state_103282;
(statearr_103348[(12)] = inst_103017);

(statearr_103348[(77)] = inst_103018__$1);

return statearr_103348;
})();
if(cljs.core.truth_(inst_103018__$1)){
var statearr_103349_103538 = state_103282__$1;
(statearr_103349_103538[(1)] = (42));

} else {
var statearr_103350_103539 = state_103282__$1;
(statearr_103350_103539[(1)] = (43));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (129))){
var inst_103246 = (state_103282[(33)]);
var state_103282__$1 = state_103282;
var statearr_103351_103540 = state_103282__$1;
(statearr_103351_103540[(2)] = inst_103246);

(statearr_103351_103540[(1)] = (131));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (91))){
var inst_103085 = (state_103282[(43)]);
var inst_103131 = (state_103282[(70)]);
var inst_103076 = (state_103282[(23)]);
var inst_102955 = (state_103282[(8)]);
var inst_102995 = (state_103282[(44)]);
var inst_102964 = (state_103282[(9)]);
var inst_102999 = (state_103282[(45)]);
var inst_103008 = (state_103282[(10)]);
var inst_102945 = (state_103282[(46)]);
var inst_103110 = (state_103282[(26)]);
var inst_102921 = (state_103282[(11)]);
var inst_103107 = (state_103282[(35)]);
var inst_103017 = (state_103282[(12)]);
var inst_102996 = (state_103282[(47)]);
var inst_103053 = (state_103282[(13)]);
var inst_103055 = (state_103282[(20)]);
var inst_102920 = (state_103282[(14)]);
var inst_103100 = (state_103282[(48)]);
var inst_103090 = (state_103282[(49)]);
var inst_103095 = (state_103282[(50)]);
var inst_103089 = (state_103282[(51)]);
var inst_103054 = (state_103282[(21)]);
var inst_102943 = (state_103282[(52)]);
var inst_103104 = (state_103282[(53)]);
var inst_103108 = (state_103282[(36)]);
var inst_103084 = (state_103282[(54)]);
var inst_102944 = (state_103282[(55)]);
var inst_103109 = (state_103282[(28)]);
var inst_102914 = (state_103282[(15)]);
var inst_103035 = (state_103282[(16)]);
var inst_103083 = (state_103282[(29)]);
var inst_103111 = (state_103282[(37)]);
var inst_102909 = (state_103282[(56)]);
var inst_103044 = (state_103282[(17)]);
var inst_103026 = (state_103282[(18)]);
var inst_103077 = (state_103282[(25)]);
var inst_103117 = (state_103282[(38)]);
var inst_102913 = (state_103282[(19)]);
var inst_103094 = (state_103282[(57)]);
var inst_102916 = (state_103282[(58)]);
var inst_103133 = (function (){var no_filter_QMARK_ = true;
var t = inst_103090;
var max_limit_QMARK_ = inst_103084;
var next_node = inst_103107;
var fast_forward_db_QMARK_ = inst_103095;
var s1 = inst_102955;
var o2 = inst_103017;
var t1 = inst_102913;
var predicate_fn = inst_102945;
var i = inst_103109;
var m1 = inst_103044;
var root_node = inst_103100;
var G__103118 = inst_103131;
var s2 = inst_102964;
var map__102908 = inst_103076;
var vec__102905 = inst_102996;
var p2 = inst_103035;
var permissions = inst_103085;
var map__102901 = inst_102943;
var limit = inst_103083;
var start_flake = inst_103054;
var vec__102895 = inst_102909;
var flake_limit = inst_103077;
var offset = inst_103108;
var acc = inst_103111;
var t2 = inst_102920;
var op1 = inst_102914;
var o1 = inst_103008;
var end_flake = inst_103055;
var base_result = inst_103117;
var s = inst_103110;
var node_start = inst_103104;
var p1 = inst_103026;
var subject_fn = inst_102944;
var object_fn = inst_102999;
var idx_compare = inst_103089;
var vec__102898 = inst_102916;
var vec__102902 = inst_102995;
var op2 = inst_102921;
var m2 = inst_103053;
var novelty = inst_103094;
return ((function (no_filter_QMARK_,t,max_limit_QMARK_,next_node,fast_forward_db_QMARK_,s1,o2,t1,predicate_fn,i,m1,root_node,G__103118,s2,map__102908,vec__102905,p2,permissions,map__102901,limit,start_flake,vec__102895,flake_limit,offset,acc,t2,op1,o1,end_flake,base_result,s,node_start,p1,subject_fn,object_fn,idx_compare,vec__102898,vec__102902,op2,m2,novelty,inst_103085,inst_103131,inst_103076,inst_102955,inst_102995,inst_102964,inst_102999,inst_103008,inst_102945,inst_103110,inst_102921,inst_103107,inst_103017,inst_102996,inst_103053,inst_103055,inst_102920,inst_103100,inst_103090,inst_103095,inst_103089,inst_103054,inst_102943,inst_103104,inst_103108,inst_103084,inst_102944,inst_103109,inst_102914,inst_103035,inst_103083,inst_103111,inst_102909,inst_103044,inst_103026,inst_103077,inst_103117,inst_102913,inst_103094,inst_102916,state_val_103283,c__99809__auto__){
return (function (p1__102880_SHARP_){
var G__103352 = p1__102880_SHARP_.p;
return (predicate_fn.cljs$core$IFn$_invoke$arity$1 ? predicate_fn.cljs$core$IFn$_invoke$arity$1(G__103352) : predicate_fn.call(null,G__103352));
});
;})(no_filter_QMARK_,t,max_limit_QMARK_,next_node,fast_forward_db_QMARK_,s1,o2,t1,predicate_fn,i,m1,root_node,G__103118,s2,map__102908,vec__102905,p2,permissions,map__102901,limit,start_flake,vec__102895,flake_limit,offset,acc,t2,op1,o1,end_flake,base_result,s,node_start,p1,subject_fn,object_fn,idx_compare,vec__102898,vec__102902,op2,m2,novelty,inst_103085,inst_103131,inst_103076,inst_102955,inst_102995,inst_102964,inst_102999,inst_103008,inst_102945,inst_103110,inst_102921,inst_103107,inst_103017,inst_102996,inst_103053,inst_103055,inst_102920,inst_103100,inst_103090,inst_103095,inst_103089,inst_103054,inst_102943,inst_103104,inst_103108,inst_103084,inst_102944,inst_103109,inst_102914,inst_103035,inst_103083,inst_103111,inst_102909,inst_103044,inst_103026,inst_103077,inst_103117,inst_102913,inst_103094,inst_102916,state_val_103283,c__99809__auto__))
})();
var inst_103134 = cljs.core.filter.cljs$core$IFn$_invoke$arity$2(inst_103133,inst_103131);
var state_103282__$1 = state_103282;
var statearr_103353_103541 = state_103282__$1;
(statearr_103353_103541[(2)] = inst_103134);

(statearr_103353_103541[(1)] = (93));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (117))){
var inst_103200 = (state_103282[(78)]);
var inst_103219 = (state_103282[(2)]);
var inst_103220 = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(inst_103219,(0),null);
var inst_103221 = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(inst_103219,(1),null);
var inst_103222 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_103223 = [inst_103220,inst_103200,inst_103221];
var inst_103224 = (new cljs.core.PersistentVector(null,3,(5),inst_103222,inst_103223,null));
var state_103282__$1 = state_103282;
var statearr_103354_103542 = state_103282__$1;
(statearr_103354_103542[(2)] = inst_103224);

(statearr_103354_103542[(1)] = (111));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (108))){
var inst_103240 = (state_103282[(2)]);
var state_103282__$1 = state_103282;
var statearr_103355_103543 = state_103282__$1;
(statearr_103355_103543[(2)] = inst_103240);

(statearr_103355_103543[(1)] = (105));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (56))){
var inst_102922 = (state_103282[(40)]);
var inst_103044 = (state_103282[(2)]);
var state_103282__$1 = (function (){var statearr_103356 = state_103282;
(statearr_103356[(17)] = inst_103044);

return statearr_103356;
})();
if(cljs.core.truth_(inst_102922)){
var statearr_103357_103544 = state_103282__$1;
(statearr_103357_103544[(1)] = (60));

} else {
var statearr_103358_103545 = state_103282__$1;
(statearr_103358_103545[(1)] = (61));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (33))){
var inst_102997 = (state_103282[(79)]);
var inst_102995 = (state_103282[(44)]);
var inst_102996 = (state_103282[(47)]);
var inst_102995__$1 = (state_103282[(2)]);
var inst_102996__$1 = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(inst_102995__$1,(0),null);
var inst_102997__$1 = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(inst_102996__$1,(0),null);
var inst_102998 = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(inst_102996__$1,(1),null);
var inst_102999 = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(inst_102995__$1,(1),null);
var inst_103000 = fluree.db.util.core.pred_ident_QMARK_(inst_102997__$1);
var state_103282__$1 = (function (){var statearr_103359 = state_103282;
(statearr_103359[(79)] = inst_102997__$1);

(statearr_103359[(44)] = inst_102995__$1);

(statearr_103359[(45)] = inst_102999);

(statearr_103359[(47)] = inst_102996__$1);

(statearr_103359[(59)] = inst_102998);

return statearr_103359;
})();
if(inst_103000){
var statearr_103360_103546 = state_103282__$1;
(statearr_103360_103546[(1)] = (34));

} else {
var statearr_103361_103547 = state_103282__$1;
(statearr_103361_103547[(1)] = (35));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (13))){
var inst_102943 = (state_103282[(52)]);
var inst_102910 = (state_103282[(64)]);
var inst_102943__$1 = (state_103282[(2)]);
var inst_102944 = cljs.core.get.cljs$core$IFn$_invoke$arity$2(inst_102943__$1,cljs.core.cst$kw$subject_DASH_fn);
var inst_102945 = cljs.core.get.cljs$core$IFn$_invoke$arity$2(inst_102943__$1,cljs.core.cst$kw$predicate_DASH_fn);
var inst_102946 = cljs.core.get.cljs$core$IFn$_invoke$arity$2(inst_102943__$1,cljs.core.cst$kw$object_DASH_fn);
var inst_102947 = fluree.db.util.core.pred_ident_QMARK_(inst_102910);
var state_103282__$1 = (function (){var statearr_103362 = state_103282;
(statearr_103362[(75)] = inst_102946);

(statearr_103362[(46)] = inst_102945);

(statearr_103362[(52)] = inst_102943__$1);

(statearr_103362[(55)] = inst_102944);

return statearr_103362;
})();
if(inst_102947){
var statearr_103363_103548 = state_103282__$1;
(statearr_103363_103548[(1)] = (14));

} else {
var statearr_103364_103549 = state_103282__$1;
(statearr_103364_103549[(1)] = (15));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (22))){
var inst_102912 = (state_103282[(39)]);
var state_103282__$1 = state_103282;
var statearr_103365_103550 = state_103282__$1;
(statearr_103365_103550[(2)] = inst_102912);

(statearr_103365_103550[(1)] = (24));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (90))){
var inst_102945 = (state_103282[(46)]);
var inst_103131 = (state_103282[(2)]);
var state_103282__$1 = (function (){var statearr_103366 = state_103282;
(statearr_103366[(70)] = inst_103131);

return statearr_103366;
})();
if(cljs.core.truth_(inst_102945)){
var statearr_103367_103551 = state_103282__$1;
(statearr_103367_103551[(1)] = (91));

} else {
var statearr_103368_103552 = state_103282__$1;
(statearr_103368_103552[(1)] = (92));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (109))){
var inst_103110 = (state_103282[(26)]);
var inst_103186 = (state_103282[(76)]);
var inst_103185 = (state_103282[(80)]);
var inst_103177 = (state_103282[(27)]);
var inst_103187 = (state_103282[(81)]);
var inst_103083 = (state_103282[(29)]);
var inst_103185__$1 = cljs.core.count(inst_103177);
var inst_103186__$1 = (inst_103110 + inst_103185__$1);
var inst_103187__$1 = (inst_103186__$1 - inst_103083);
var inst_103188 = cljs.core.pos_int_QMARK_(inst_103187__$1);
var state_103282__$1 = (function (){var statearr_103369 = state_103282;
(statearr_103369[(76)] = inst_103186__$1);

(statearr_103369[(80)] = inst_103185__$1);

(statearr_103369[(81)] = inst_103187__$1);

return statearr_103369;
})();
if(inst_103188){
var statearr_103370_103553 = state_103282__$1;
(statearr_103370_103553[(1)] = (112));

} else {
var statearr_103371_103554 = state_103282__$1;
(statearr_103371_103554[(1)] = (113));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (36))){
var inst_102998 = (state_103282[(59)]);
var inst_103008 = (state_103282[(2)]);
var inst_103009 = fluree.db.util.core.pred_ident_QMARK_(inst_102998);
var state_103282__$1 = (function (){var statearr_103372 = state_103282;
(statearr_103372[(10)] = inst_103008);

return statearr_103372;
})();
if(inst_103009){
var statearr_103373_103555 = state_103282__$1;
(statearr_103373_103555[(1)] = (38));

} else {
var statearr_103374_103556 = state_103282__$1;
(statearr_103374_103556[(1)] = (39));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (41))){
var inst_103013 = (state_103282[(2)]);
var inst_103014 = fluree.db.util.async.throw_err(inst_103013);
var state_103282__$1 = state_103282;
var statearr_103375_103557 = state_103282__$1;
(statearr_103375_103557[(2)] = inst_103014);

(statearr_103375_103557[(1)] = (40));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (118))){
var inst_103228 = (state_103282[(2)]);
var inst_103229 = fluree.db.util.async.throw_err(inst_103228);
var state_103282__$1 = state_103282;
var statearr_103376_103558 = state_103282__$1;
(statearr_103376_103558[(2)] = inst_103229);

(statearr_103376_103558[(1)] = (111));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (89))){
var inst_103125 = (state_103282[(60)]);
var state_103282__$1 = state_103282;
var statearr_103377_103559 = state_103282__$1;
(statearr_103377_103559[(2)] = inst_103125);

(statearr_103377_103559[(1)] = (90));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (100))){
var state_103282__$1 = state_103282;
var statearr_103378_103560 = state_103282__$1;
(statearr_103378_103560[(2)] = true);

(statearr_103378_103560[(1)] = (102));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (131))){
var inst_103273 = (state_103282[(2)]);
var state_103282__$1 = state_103282;
var statearr_103379_103561 = state_103282__$1;
(statearr_103379_103561[(2)] = inst_103273);

(statearr_103379_103561[(1)] = (84));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (122))){
var inst_103100 = (state_103282[(48)]);
var inst_103090 = (state_103282[(49)]);
var inst_103095 = (state_103282[(50)]);
var inst_103144 = (state_103282[(68)]);
var inst_103094 = (state_103282[(57)]);
var inst_103257 = fluree.db.query.range.find_next_valid_node(inst_103100,inst_103144,inst_103090,inst_103094,inst_103095);
var state_103282__$1 = state_103282;
return cljs.core.async.impl.ioc_helpers.take_BANG_(state_103282__$1,(125),inst_103257);
} else {
if((state_val_103283 === (43))){
var inst_103018 = (state_103282[(77)]);
var state_103282__$1 = state_103282;
var statearr_103380_103562 = state_103282__$1;
(statearr_103380_103562[(2)] = inst_103018);

(statearr_103380_103562[(1)] = (44));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (61))){
var inst_103047 = (cljs.core._LT__EQ_ === end_test);
var state_103282__$1 = state_103282;
if(cljs.core.truth_(inst_103047)){
var statearr_103381_103563 = state_103282__$1;
(statearr_103381_103563[(1)] = (63));

} else {
var statearr_103382_103564 = state_103282__$1;
(statearr_103382_103564[(1)] = (64));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (29))){
var state_103282__$1 = state_103282;
var statearr_103383_103565 = state_103282__$1;
(statearr_103383_103565[(2)] = null);

(statearr_103383_103565[(1)] = (30));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (44))){
var inst_103022 = (state_103282[(2)]);
var state_103282__$1 = state_103282;
if(cljs.core.truth_(inst_103022)){
var statearr_103384_103566 = state_103282__$1;
(statearr_103384_103566[(1)] = (45));

} else {
var statearr_103385_103567 = state_103282__$1;
(statearr_103385_103567[(1)] = (46));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (93))){
var inst_102999 = (state_103282[(45)]);
var inst_103137 = (state_103282[(2)]);
var state_103282__$1 = (function (){var statearr_103386 = state_103282;
(statearr_103386[(69)] = inst_103137);

return statearr_103386;
})();
if(cljs.core.truth_(inst_102999)){
var statearr_103387_103568 = state_103282__$1;
(statearr_103387_103568[(1)] = (94));

} else {
var statearr_103388_103569 = state_103282__$1;
(statearr_103388_103569[(1)] = (95));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (6))){
var state_103282__$1 = state_103282;
var statearr_103389_103570 = state_103282__$1;
(statearr_103389_103570[(2)] = false);

(statearr_103389_103570[(1)] = (7));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (111))){
var inst_103111 = (state_103282[(37)]);
var inst_103231 = (state_103282[(2)]);
var inst_103232 = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(inst_103231,(0),null);
var inst_103233 = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(inst_103231,(1),null);
var inst_103234 = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(inst_103231,(2),null);
var inst_103235 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_103236 = cljs.core.into.cljs$core$IFn$_invoke$arity$2(inst_103111,inst_103234);
var inst_103237 = [(0),inst_103232,inst_103233,inst_103236];
var inst_103238 = (new cljs.core.PersistentVector(null,4,(5),inst_103235,inst_103237,null));
var state_103282__$1 = state_103282;
var statearr_103390_103571 = state_103282__$1;
(statearr_103390_103571[(2)] = inst_103238);

(statearr_103390_103571[(1)] = (108));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (28))){
var state_103282__$1 = state_103282;
var statearr_103391_103572 = state_103282__$1;
(statearr_103391_103572[(2)] = null);

(statearr_103391_103572[(1)] = (30));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (64))){
var state_103282__$1 = state_103282;
var statearr_103392_103573 = state_103282__$1;
(statearr_103392_103573[(2)] = fluree.db.util.core.min_integer);

(statearr_103392_103573[(1)] = (65));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (103))){
var inst_103110 = (state_103282[(26)]);
var inst_103143 = (state_103282[(72)]);
var inst_103109 = (state_103282[(28)]);
var inst_103111 = (state_103282[(37)]);
var inst_103077 = (state_103282[(25)]);
var inst_103155 = cljs.core.count(inst_103143);
var inst_103156 = (inst_103077 - inst_103109);
var inst_103157 = cljs.core.take.cljs$core$IFn$_invoke$arity$2(inst_103156,inst_103143);
var inst_103158 = cljs.core.into.cljs$core$IFn$_invoke$arity$2(inst_103111,inst_103157);
var inst_103159 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_103160 = (inst_103109 + inst_103155);
var inst_103161 = [(0),inst_103160,inst_103110,inst_103158];
var inst_103162 = (new cljs.core.PersistentVector(null,4,(5),inst_103159,inst_103161,null));
var state_103282__$1 = state_103282;
var statearr_103393_103574 = state_103282__$1;
(statearr_103393_103574[(2)] = inst_103162);

(statearr_103393_103574[(1)] = (105));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (51))){
var state_103282__$1 = state_103282;
var statearr_103394_103575 = state_103282__$1;
(statearr_103394_103575[(2)] = fluree.db.flake.MAX_PREDICATE_ID);

(statearr_103394_103575[(1)] = (53));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (25))){
var inst_102919 = (state_103282[(62)]);
var state_103282__$1 = state_103282;
var statearr_103395_103576 = state_103282__$1;
(statearr_103395_103576[(2)] = inst_102919);

(statearr_103395_103576[(1)] = (27));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (34))){
var inst_102997 = (state_103282[(79)]);
var inst_103002 = fluree.db.dbproto._subid.cljs$core$IFn$_invoke$arity$2(db,inst_102997);
var state_103282__$1 = state_103282;
return cljs.core.async.impl.ioc_helpers.take_BANG_(state_103282__$1,(37),inst_103002);
} else {
if((state_val_103283 === (125))){
var inst_103259 = (state_103282[(2)]);
var inst_103260 = fluree.db.util.async.throw_err(inst_103259);
var state_103282__$1 = state_103282;
var statearr_103396_103577 = state_103282__$1;
(statearr_103396_103577[(2)] = inst_103260);

(statearr_103396_103577[(1)] = (124));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (17))){
var inst_102951 = (state_103282[(2)]);
var inst_102952 = fluree.db.util.async.throw_err(inst_102951);
var state_103282__$1 = state_103282;
var statearr_103397_103578 = state_103282__$1;
(statearr_103397_103578[(2)] = inst_102952);

(statearr_103397_103578[(1)] = (16));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (3))){
var inst_102891 = (state_103282[(2)]);
var state_103282__$1 = state_103282;
var statearr_103398_103579 = state_103282__$1;
(statearr_103398_103579[(2)] = inst_102891);


cljs.core.async.impl.ioc_helpers.process_exception(state_103282__$1);

return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (12))){
var state_103282__$1 = state_103282;
var statearr_103399_103580 = state_103282__$1;
(statearr_103399_103580[(2)] = opts);

(statearr_103399_103580[(1)] = (13));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (2))){
var inst_103280 = (state_103282[(2)]);
var state_103282__$1 = state_103282;
return cljs.core.async.impl.ioc_helpers.return_chan(state_103282__$1,inst_103280);
} else {
if((state_val_103283 === (66))){
var inst_103060 = opts.cljs$lang$protocol_mask$partition0$;
var inst_103061 = (inst_103060 & (64));
var inst_103062 = opts.cljs$core$ISeq$;
var inst_103063 = (cljs.core.PROTOCOL_SENTINEL === inst_103062);
var inst_103064 = ((inst_103061) || (inst_103063));
var state_103282__$1 = state_103282;
if(cljs.core.truth_(inst_103064)){
var statearr_103400_103581 = state_103282__$1;
(statearr_103400_103581[(1)] = (69));

} else {
var statearr_103401_103582 = state_103282__$1;
(statearr_103401_103582[(1)] = (70));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (107))){
var inst_103108 = (state_103282[(36)]);
var inst_103165 = (state_103282[(71)]);
var inst_103177 = cljs.core.drop.cljs$core$IFn$_invoke$arity$2(inst_103108,inst_103165);
var state_103282__$1 = (function (){var statearr_103402 = state_103282;
(statearr_103402[(27)] = inst_103177);

return statearr_103402;
})();
var statearr_103403_103583 = state_103282__$1;
(statearr_103403_103583[(1)] = (109));



return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (23))){
var inst_102919 = (state_103282[(62)]);
var inst_102968 = cljs.core.boolean_QMARK_(inst_102919);
var state_103282__$1 = state_103282;
if(inst_102968){
var statearr_103405_103584 = state_103282__$1;
(statearr_103405_103584[(1)] = (25));

} else {
var statearr_103406_103585 = state_103282__$1;
(statearr_103406_103585[(1)] = (26));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (47))){
var inst_102918 = (state_103282[(63)]);
var inst_103027 = (state_103282[(82)]);
var inst_103026 = (state_103282[(2)]);
var inst_103027__$1 = (inst_102918 == null);
var state_103282__$1 = (function (){var statearr_103407 = state_103282;
(statearr_103407[(82)] = inst_103027__$1);

(statearr_103407[(18)] = inst_103026);

return statearr_103407;
})();
if(cljs.core.truth_(inst_103027__$1)){
var statearr_103408_103586 = state_103282__$1;
(statearr_103408_103586[(1)] = (48));

} else {
var statearr_103409_103587 = state_103282__$1;
(statearr_103409_103587[(1)] = (49));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (35))){
var inst_102997 = (state_103282[(79)]);
var state_103282__$1 = state_103282;
var statearr_103410_103588 = state_103282__$1;
(statearr_103410_103588[(2)] = inst_102997);

(statearr_103410_103588[(1)] = (36));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (127))){
var inst_103255 = (state_103282[(7)]);
var state_103282__$1 = state_103282;
var statearr_103411_103589 = state_103282__$1;
(statearr_103411_103589[(2)] = inst_103255);

(statearr_103411_103589[(1)] = (128));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (82))){
var inst_103278 = (state_103282[(2)]);
var state_103282__$1 = state_103282;
var statearr_103412_103590 = state_103282__$1;
(statearr_103412_103590[(2)] = inst_103278);


cljs.core.async.impl.ioc_helpers.process_exception(state_103282__$1);

return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (76))){
var state_103282__$1 = state_103282;
var statearr_103413_103591 = state_103282__$1;
(statearr_103413_103591[(2)] = fluree.db.util.core.max_long);

(statearr_103413_103591[(1)] = (77));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (97))){
var inst_103108 = (state_103282[(36)]);
var inst_103146 = (state_103282[(41)]);
var inst_103146__$1 = cljs.core._EQ_.cljs$core$IFn$_invoke$arity$2((0),inst_103108);
var state_103282__$1 = (function (){var statearr_103414 = state_103282;
(statearr_103414[(41)] = inst_103146__$1);

return statearr_103414;
})();
if(inst_103146__$1){
var statearr_103415_103592 = state_103282__$1;
(statearr_103415_103592[(1)] = (100));

} else {
var statearr_103416_103593 = state_103282__$1;
(statearr_103416_103593[(1)] = (101));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (19))){
var inst_102917 = (state_103282[(65)]);
var state_103282__$1 = state_103282;
var statearr_103417_103594 = state_103282__$1;
(statearr_103417_103594[(2)] = inst_102917);

(statearr_103417_103594[(1)] = (20));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (57))){
var state_103282__$1 = state_103282;
var statearr_103418_103595 = state_103282__$1;
(statearr_103418_103595[(2)] = fluree.db.util.core.min_integer);

(statearr_103418_103595[(1)] = (59));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (68))){
var inst_103071 = (state_103282[(2)]);
var state_103282__$1 = state_103282;
if(cljs.core.truth_(inst_103071)){
var statearr_103419_103596 = state_103282__$1;
(statearr_103419_103596[(1)] = (72));

} else {
var statearr_103420_103597 = state_103282__$1;
(statearr_103420_103597[(1)] = (73));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (11))){
var inst_102940 = cljs.core.apply.cljs$core$IFn$_invoke$arity$2(cljs.core.hash_map,opts);
var state_103282__$1 = state_103282;
var statearr_103421_103598 = state_103282__$1;
(statearr_103421_103598[(2)] = inst_102940);

(statearr_103421_103598[(1)] = (13));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (115))){
var inst_103205 = (state_103282[(73)]);
var inst_103204 = (state_103282[(83)]);
var inst_103203 = (state_103282[(74)]);
var inst_103077 = (state_103282[(25)]);
var inst_103208 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_103209 = (inst_103205 - inst_103077);
var inst_103210 = (inst_103204 - inst_103209);
var inst_103211 = cljs.core.take.cljs$core$IFn$_invoke$arity$2(inst_103210,inst_103203);
var inst_103212 = [inst_103077,inst_103211];
var inst_103213 = (new cljs.core.PersistentVector(null,2,(5),inst_103208,inst_103212,null));
var state_103282__$1 = state_103282;
var statearr_103422_103599 = state_103282__$1;
(statearr_103422_103599[(2)] = inst_103213);

(statearr_103422_103599[(1)] = (117));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (9))){
var state_103282__$1 = state_103282;
var statearr_103423_103600 = state_103282__$1;
(statearr_103423_103600[(2)] = false);

(statearr_103423_103600[(1)] = (10));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (5))){
var inst_102927 = opts.cljs$lang$protocol_mask$partition0$;
var inst_102928 = (inst_102927 & (64));
var inst_102929 = opts.cljs$core$ISeq$;
var inst_102930 = (cljs.core.PROTOCOL_SENTINEL === inst_102929);
var inst_102931 = ((inst_102928) || (inst_102930));
var state_103282__$1 = state_103282;
if(cljs.core.truth_(inst_102931)){
var statearr_103424_103601 = state_103282__$1;
(statearr_103424_103601[(1)] = (8));

} else {
var statearr_103425_103602 = state_103282__$1;
(statearr_103425_103602[(1)] = (9));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (112))){
var inst_103185 = (state_103282[(80)]);
var inst_103187 = (state_103282[(81)]);
var inst_103083 = (state_103282[(29)]);
var inst_103190 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_103191 = (inst_103185 - inst_103187);
var inst_103192 = [inst_103083,inst_103191];
var inst_103193 = (new cljs.core.PersistentVector(null,2,(5),inst_103190,inst_103192,null));
var state_103282__$1 = state_103282;
var statearr_103426_103603 = state_103282__$1;
(statearr_103426_103603[(2)] = inst_103193);

(statearr_103426_103603[(1)] = (114));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (83))){
var inst_103107 = (state_103282[(35)]);
var inst_103055 = (state_103282[(20)]);
var inst_103054 = (state_103282[(21)]);
var inst_103116 = cljs.core.cst$kw$flakes.cljs$core$IFn$_invoke$arity$1(inst_103107);
var inst_103117 = fluree.db.flake.subrange(inst_103116,start_test,inst_103054,end_test,inst_103055);
var inst_103119 = fluree.db.query.range.value_with_nil_pred(idx,inst_103054,inst_103055);
var state_103282__$1 = (function (){var statearr_103427 = state_103282;
(statearr_103427[(38)] = inst_103117);

return statearr_103427;
})();
if(inst_103119){
var statearr_103428_103604 = state_103282__$1;
(statearr_103428_103604[(1)] = (85));

} else {
var statearr_103429_103605 = state_103282__$1;
(statearr_103429_103605[(1)] = (86));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (14))){
var inst_102910 = (state_103282[(64)]);
var inst_102949 = fluree.db.dbproto._subid.cljs$core$IFn$_invoke$arity$2(db,inst_102910);
var state_103282__$1 = state_103282;
return cljs.core.async.impl.ioc_helpers.take_BANG_(state_103282__$1,(17),inst_102949);
} else {
if((state_val_103283 === (45))){
var state_103282__$1 = state_103282;
var statearr_103430_103606 = state_103282__$1;
(statearr_103430_103606[(2)] = (-1));

(statearr_103430_103606[(1)] = (47));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (53))){
var inst_102915 = (state_103282[(66)]);
var inst_103035 = (state_103282[(2)]);
var state_103282__$1 = (function (){var statearr_103431 = state_103282;
(statearr_103431[(16)] = inst_103035);

return statearr_103431;
})();
if(cljs.core.truth_(inst_102915)){
var statearr_103432_103607 = state_103282__$1;
(statearr_103432_103607[(1)] = (54));

} else {
var statearr_103433_103608 = state_103282__$1;
(statearr_103433_103608[(1)] = (55));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (78))){
var inst_103100 = (state_103282[(48)]);
var inst_103090 = (state_103282[(49)]);
var inst_103095 = (state_103282[(50)]);
var inst_103054 = (state_103282[(21)]);
var inst_103094 = (state_103282[(57)]);
var inst_103099 = (state_103282[(2)]);
var inst_103100__$1 = fluree.db.util.async.throw_err(inst_103099);
var inst_103101 = fluree.db.query.range.find_next_valid_node(inst_103100__$1,inst_103054,inst_103090,inst_103094,inst_103095);
var state_103282__$1 = (function (){var statearr_103434 = state_103282;
(statearr_103434[(48)] = inst_103100__$1);

return statearr_103434;
})();
return cljs.core.async.impl.ioc_helpers.take_BANG_(state_103282__$1,(79),inst_103101);
} else {
if((state_val_103283 === (26))){
var state_103282__$1 = state_103282;
var statearr_103435_103609 = state_103282__$1;
(statearr_103435_103609[(1)] = (28));



return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (123))){
var state_103282__$1 = state_103282;
var statearr_103437_103610 = state_103282__$1;
(statearr_103437_103610[(2)] = null);

(statearr_103437_103610[(1)] = (124));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (16))){
var inst_102917 = (state_103282[(65)]);
var inst_102955 = (state_103282[(2)]);
var inst_102956 = fluree.db.util.core.pred_ident_QMARK_(inst_102917);
var state_103282__$1 = (function (){var statearr_103438 = state_103282;
(statearr_103438[(8)] = inst_102955);

return statearr_103438;
})();
if(inst_102956){
var statearr_103439_103611 = state_103282__$1;
(statearr_103439_103611[(1)] = (18));

} else {
var statearr_103440_103612 = state_103282__$1;
(statearr_103440_103612[(1)] = (19));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (81))){
var state_103282__$1 = state_103282;
var statearr_103441_103613 = state_103282__$1;
(statearr_103441_103613[(2)] = null);

(statearr_103441_103613[(1)] = (82));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (120))){
var inst_103144 = (state_103282[(68)]);
var state_103282__$1 = state_103282;
var statearr_103442_103614 = state_103282__$1;
(statearr_103442_103614[(2)] = inst_103144);

(statearr_103442_103614[(1)] = (121));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (79))){
var inst_103104 = (state_103282[(53)]);
var inst_103103 = (state_103282[(2)]);
var inst_103104__$1 = fluree.db.util.async.throw_err(inst_103103);
var state_103282__$1 = (function (){var statearr_103443 = state_103282;
(statearr_103443[(53)] = inst_103104__$1);

return statearr_103443;
})();
if(cljs.core.truth_(inst_103104__$1)){
var statearr_103444_103615 = state_103282__$1;
(statearr_103444_103615[(1)] = (80));

} else {
var statearr_103445_103616 = state_103282__$1;
(statearr_103445_103616[(1)] = (81));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (38))){
var inst_102998 = (state_103282[(59)]);
var inst_103011 = fluree.db.dbproto._subid.cljs$core$IFn$_invoke$arity$2(db,inst_102998);
var state_103282__$1 = state_103282;
return cljs.core.async.impl.ioc_helpers.take_BANG_(state_103282__$1,(41),inst_103011);
} else {
if((state_val_103283 === (126))){
var inst_103263 = (state_103282[(34)]);
var state_103282__$1 = state_103282;
var statearr_103446_103617 = state_103282__$1;
(statearr_103446_103617[(2)] = inst_103263);

(statearr_103446_103617[(1)] = (128));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (98))){
var inst_103084 = (state_103282[(54)]);
var state_103282__$1 = state_103282;
var statearr_103447_103618 = state_103282__$1;
(statearr_103447_103618[(2)] = inst_103084);

(statearr_103447_103618[(1)] = (99));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (124))){
var inst_103255 = (state_103282[(7)]);
var inst_103263 = (state_103282[(2)]);
var state_103282__$1 = (function (){var statearr_103448 = state_103282;
(statearr_103448[(34)] = inst_103263);

return statearr_103448;
})();
if(cljs.core.truth_(inst_103255)){
var statearr_103449_103619 = state_103282__$1;
(statearr_103449_103619[(1)] = (126));

} else {
var statearr_103450_103620 = state_103282__$1;
(statearr_103450_103620[(1)] = (127));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (87))){
var inst_102944 = (state_103282[(55)]);
var inst_103125 = (state_103282[(2)]);
var state_103282__$1 = (function (){var statearr_103451 = state_103282;
(statearr_103451[(60)] = inst_103125);

return statearr_103451;
})();
if(cljs.core.truth_(inst_102944)){
var statearr_103452_103621 = state_103282__$1;
(statearr_103452_103621[(1)] = (88));

} else {
var statearr_103453_103622 = state_103282__$1;
(statearr_103453_103622[(1)] = (89));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (30))){
var inst_102974 = (state_103282[(2)]);
var state_103282__$1 = state_103282;
var statearr_103454_103623 = state_103282__$1;
(statearr_103454_103623[(2)] = inst_102974);

(statearr_103454_103623[(1)] = (27));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (73))){
var state_103282__$1 = state_103282;
var statearr_103455_103624 = state_103282__$1;
(statearr_103455_103624[(2)] = opts);

(statearr_103455_103624[(1)] = (74));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (96))){
var inst_103107 = (state_103282[(35)]);
var inst_103084 = (state_103282[(54)]);
var inst_103143 = (state_103282[(2)]);
var inst_103144 = fluree.db.dbproto._rhs(inst_103107);
var state_103282__$1 = (function (){var statearr_103456 = state_103282;
(statearr_103456[(72)] = inst_103143);

(statearr_103456[(68)] = inst_103144);

return statearr_103456;
})();
if(cljs.core.truth_(inst_103084)){
var statearr_103457_103625 = state_103282__$1;
(statearr_103457_103625[(1)] = (97));

} else {
var statearr_103458_103626 = state_103282__$1;
(statearr_103458_103626[(1)] = (98));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (10))){
var inst_102935 = (state_103282[(2)]);
var state_103282__$1 = state_103282;
var statearr_103459_103627 = state_103282__$1;
(statearr_103459_103627[(2)] = inst_102935);

(statearr_103459_103627[(1)] = (7));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (18))){
var inst_102917 = (state_103282[(65)]);
var inst_102958 = fluree.db.dbproto._subid.cljs$core$IFn$_invoke$arity$2(db,inst_102917);
var state_103282__$1 = state_103282;
return cljs.core.async.impl.ioc_helpers.take_BANG_(state_103282__$1,(21),inst_102958);
} else {
if((state_val_103283 === (105))){
var inst_103144 = (state_103282[(68)]);
var inst_103242 = (state_103282[(2)]);
var inst_103243 = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(inst_103242,(0),null);
var inst_103244 = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(inst_103242,(1),null);
var inst_103245 = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(inst_103242,(2),null);
var inst_103246 = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(inst_103242,(3),null);
var state_103282__$1 = (function (){var statearr_103460 = state_103282;
(statearr_103460[(30)] = inst_103245);

(statearr_103460[(31)] = inst_103244);

(statearr_103460[(32)] = inst_103243);

(statearr_103460[(33)] = inst_103246);

return statearr_103460;
})();
if(cljs.core.truth_(inst_103144)){
var statearr_103461_103628 = state_103282__$1;
(statearr_103461_103628[(1)] = (119));

} else {
var statearr_103462_103629 = state_103282__$1;
(statearr_103462_103629[(1)] = (120));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (52))){
var inst_102918 = (state_103282[(63)]);
var state_103282__$1 = state_103282;
var statearr_103463_103630 = state_103282__$1;
(statearr_103463_103630[(2)] = inst_102918);

(statearr_103463_103630[(1)] = (53));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (114))){
var inst_103205 = (state_103282[(73)]);
var inst_103204 = (state_103282[(83)]);
var inst_103177 = (state_103282[(27)]);
var inst_103109 = (state_103282[(28)]);
var inst_103203 = (state_103282[(74)]);
var inst_103077 = (state_103282[(25)]);
var inst_103199 = (state_103282[(2)]);
var inst_103200 = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(inst_103199,(0),null);
var inst_103201 = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(inst_103199,(1),null);
var inst_103202 = cljs.core.take.cljs$core$IFn$_invoke$arity$2(inst_103201,inst_103177);
var inst_103203__$1 = cljs.core.apply.cljs$core$IFn$_invoke$arity$2(cljs.core.concat,inst_103202);
var inst_103204__$1 = cljs.core.count(inst_103203__$1);
var inst_103205__$1 = (inst_103109 + inst_103204__$1);
var inst_103206 = (inst_103205__$1 > inst_103077);
var state_103282__$1 = (function (){var statearr_103464 = state_103282;
(statearr_103464[(73)] = inst_103205__$1);

(statearr_103464[(83)] = inst_103204__$1);

(statearr_103464[(78)] = inst_103200);

(statearr_103464[(74)] = inst_103203__$1);

return statearr_103464;
})();
if(cljs.core.truth_(inst_103206)){
var statearr_103465_103631 = state_103282__$1;
(statearr_103465_103631[(1)] = (115));

} else {
var statearr_103466_103632 = state_103282__$1;
(statearr_103466_103632[(1)] = (116));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (67))){
var state_103282__$1 = state_103282;
var statearr_103467_103633 = state_103282__$1;
(statearr_103467_103633[(2)] = false);

(statearr_103467_103633[(1)] = (68));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (71))){
var inst_103068 = (state_103282[(2)]);
var state_103282__$1 = state_103282;
var statearr_103468_103634 = state_103282__$1;
(statearr_103468_103634[(2)] = inst_103068);

(statearr_103468_103634[(1)] = (68));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (42))){
var inst_103008 = (state_103282[(10)]);
var state_103282__$1 = state_103282;
var statearr_103469_103635 = state_103282__$1;
(statearr_103469_103635[(2)] = inst_103008);

(statearr_103469_103635[(1)] = (44));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (80))){
var inst_103104 = (state_103282[(53)]);
var inst_103079 = (state_103282[(24)]);
var inst_103106 = cljs.core.PersistentVector.EMPTY;
var inst_103107 = inst_103104;
var inst_103108 = inst_103079;
var inst_103109 = (0);
var inst_103110 = (0);
var inst_103111 = inst_103106;
var state_103282__$1 = (function (){var statearr_103470 = state_103282;
(statearr_103470[(26)] = inst_103110);

(statearr_103470[(35)] = inst_103107);

(statearr_103470[(36)] = inst_103108);

(statearr_103470[(28)] = inst_103109);

(statearr_103470[(37)] = inst_103111);

return statearr_103470;
})();
var statearr_103471_103636 = state_103282__$1;
(statearr_103471_103636[(2)] = null);

(statearr_103471_103636[(1)] = (83));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (37))){
var inst_103004 = (state_103282[(2)]);
var inst_103005 = fluree.db.util.async.throw_err(inst_103004);
var state_103282__$1 = state_103282;
var statearr_103472_103637 = state_103282__$1;
(statearr_103472_103637[(2)] = inst_103005);

(statearr_103472_103637[(1)] = (36));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (63))){
var state_103282__$1 = state_103282;
var statearr_103473_103638 = state_103282__$1;
(statearr_103473_103638[(2)] = (2147483647));

(statearr_103473_103638[(1)] = (65));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (94))){
var inst_103085 = (state_103282[(43)]);
var inst_103076 = (state_103282[(23)]);
var inst_102955 = (state_103282[(8)]);
var inst_102995 = (state_103282[(44)]);
var inst_102964 = (state_103282[(9)]);
var inst_102999 = (state_103282[(45)]);
var inst_103008 = (state_103282[(10)]);
var inst_102945 = (state_103282[(46)]);
var inst_103110 = (state_103282[(26)]);
var inst_102921 = (state_103282[(11)]);
var inst_103107 = (state_103282[(35)]);
var inst_103017 = (state_103282[(12)]);
var inst_102996 = (state_103282[(47)]);
var inst_103053 = (state_103282[(13)]);
var inst_103055 = (state_103282[(20)]);
var inst_102920 = (state_103282[(14)]);
var inst_103100 = (state_103282[(48)]);
var inst_103090 = (state_103282[(49)]);
var inst_103137 = (state_103282[(69)]);
var inst_103095 = (state_103282[(50)]);
var inst_103089 = (state_103282[(51)]);
var inst_103054 = (state_103282[(21)]);
var inst_102943 = (state_103282[(52)]);
var inst_103104 = (state_103282[(53)]);
var inst_103108 = (state_103282[(36)]);
var inst_103084 = (state_103282[(54)]);
var inst_102944 = (state_103282[(55)]);
var inst_103109 = (state_103282[(28)]);
var inst_102914 = (state_103282[(15)]);
var inst_103035 = (state_103282[(16)]);
var inst_103083 = (state_103282[(29)]);
var inst_103111 = (state_103282[(37)]);
var inst_102909 = (state_103282[(56)]);
var inst_103044 = (state_103282[(17)]);
var inst_103026 = (state_103282[(18)]);
var inst_103077 = (state_103282[(25)]);
var inst_103117 = (state_103282[(38)]);
var inst_102913 = (state_103282[(19)]);
var inst_103094 = (state_103282[(57)]);
var inst_102916 = (state_103282[(58)]);
var inst_103139 = (function (){var no_filter_QMARK_ = true;
var t = inst_103090;
var max_limit_QMARK_ = inst_103084;
var next_node = inst_103107;
var fast_forward_db_QMARK_ = inst_103095;
var s1 = inst_102955;
var o2 = inst_103017;
var t1 = inst_102913;
var predicate_fn = inst_102945;
var i = inst_103109;
var m1 = inst_103044;
var root_node = inst_103100;
var G__103118 = inst_103137;
var s2 = inst_102964;
var map__102908 = inst_103076;
var vec__102905 = inst_102996;
var p2 = inst_103035;
var permissions = inst_103085;
var map__102901 = inst_102943;
var limit = inst_103083;
var start_flake = inst_103054;
var vec__102895 = inst_102909;
var flake_limit = inst_103077;
var offset = inst_103108;
var acc = inst_103111;
var t2 = inst_102920;
var op1 = inst_102914;
var o1 = inst_103008;
var end_flake = inst_103055;
var base_result = inst_103117;
var s = inst_103110;
var node_start = inst_103104;
var p1 = inst_103026;
var subject_fn = inst_102944;
var object_fn = inst_102999;
var idx_compare = inst_103089;
var vec__102898 = inst_102916;
var vec__102902 = inst_102995;
var op2 = inst_102921;
var m2 = inst_103053;
var novelty = inst_103094;
return ((function (no_filter_QMARK_,t,max_limit_QMARK_,next_node,fast_forward_db_QMARK_,s1,o2,t1,predicate_fn,i,m1,root_node,G__103118,s2,map__102908,vec__102905,p2,permissions,map__102901,limit,start_flake,vec__102895,flake_limit,offset,acc,t2,op1,o1,end_flake,base_result,s,node_start,p1,subject_fn,object_fn,idx_compare,vec__102898,vec__102902,op2,m2,novelty,inst_103085,inst_103076,inst_102955,inst_102995,inst_102964,inst_102999,inst_103008,inst_102945,inst_103110,inst_102921,inst_103107,inst_103017,inst_102996,inst_103053,inst_103055,inst_102920,inst_103100,inst_103090,inst_103137,inst_103095,inst_103089,inst_103054,inst_102943,inst_103104,inst_103108,inst_103084,inst_102944,inst_103109,inst_102914,inst_103035,inst_103083,inst_103111,inst_102909,inst_103044,inst_103026,inst_103077,inst_103117,inst_102913,inst_103094,inst_102916,state_val_103283,c__99809__auto__){
return (function (p1__102881_SHARP_){
var G__103474 = p1__102881_SHARP_.o;
return (object_fn.cljs$core$IFn$_invoke$arity$1 ? object_fn.cljs$core$IFn$_invoke$arity$1(G__103474) : object_fn.call(null,G__103474));
});
;})(no_filter_QMARK_,t,max_limit_QMARK_,next_node,fast_forward_db_QMARK_,s1,o2,t1,predicate_fn,i,m1,root_node,G__103118,s2,map__102908,vec__102905,p2,permissions,map__102901,limit,start_flake,vec__102895,flake_limit,offset,acc,t2,op1,o1,end_flake,base_result,s,node_start,p1,subject_fn,object_fn,idx_compare,vec__102898,vec__102902,op2,m2,novelty,inst_103085,inst_103076,inst_102955,inst_102995,inst_102964,inst_102999,inst_103008,inst_102945,inst_103110,inst_102921,inst_103107,inst_103017,inst_102996,inst_103053,inst_103055,inst_102920,inst_103100,inst_103090,inst_103137,inst_103095,inst_103089,inst_103054,inst_102943,inst_103104,inst_103108,inst_103084,inst_102944,inst_103109,inst_102914,inst_103035,inst_103083,inst_103111,inst_102909,inst_103044,inst_103026,inst_103077,inst_103117,inst_102913,inst_103094,inst_102916,state_val_103283,c__99809__auto__))
})();
var inst_103140 = cljs.core.filter.cljs$core$IFn$_invoke$arity$2(inst_103139,inst_103137);
var state_103282__$1 = state_103282;
var statearr_103475_103639 = state_103282__$1;
(statearr_103475_103639[(2)] = inst_103140);

(statearr_103475_103639[(1)] = (96));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (8))){
var state_103282__$1 = state_103282;
var statearr_103476_103640 = state_103282__$1;
(statearr_103476_103640[(2)] = true);

(statearr_103476_103640[(1)] = (10));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (49))){
var inst_103027 = (state_103282[(82)]);
var state_103282__$1 = state_103282;
var statearr_103477_103641 = state_103282__$1;
(statearr_103477_103641[(2)] = inst_103027);

(statearr_103477_103641[(1)] = (50));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103283 === (84))){
var inst_103275 = (state_103282[(2)]);
var state_103282__$1 = state_103282;
var statearr_103478_103642 = state_103282__$1;
(statearr_103478_103642[(2)] = inst_103275);

(statearr_103478_103642[(1)] = (82));


return cljs.core.cst$kw$recur;
} else {
return null;
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
});})(c__99809__auto__))
;
return ((function (switch__99702__auto__,c__99809__auto__){
return (function() {
var fluree$db$query$range$state_machine__99703__auto__ = null;
var fluree$db$query$range$state_machine__99703__auto____0 = (function (){
var statearr_103479 = [null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null];
(statearr_103479[(0)] = fluree$db$query$range$state_machine__99703__auto__);

(statearr_103479[(1)] = (1));

return statearr_103479;
});
var fluree$db$query$range$state_machine__99703__auto____1 = (function (state_103282){
while(true){
var ret_value__99704__auto__ = (function (){try{while(true){
var result__99705__auto__ = switch__99702__auto__(state_103282);
if(cljs.core.keyword_identical_QMARK_(result__99705__auto__,cljs.core.cst$kw$recur)){
continue;
} else {
return result__99705__auto__;
}
break;
}
}catch (e103480){if((e103480 instanceof Object)){
var ex__99706__auto__ = e103480;
var statearr_103481_103643 = state_103282;
(statearr_103481_103643[(5)] = ex__99706__auto__);


cljs.core.async.impl.ioc_helpers.process_exception(state_103282);

return cljs.core.cst$kw$recur;
} else {
throw e103480;

}
}})();
if(cljs.core.keyword_identical_QMARK_(ret_value__99704__auto__,cljs.core.cst$kw$recur)){
var G__103644 = state_103282;
state_103282 = G__103644;
continue;
} else {
return ret_value__99704__auto__;
}
break;
}
});
fluree$db$query$range$state_machine__99703__auto__ = function(state_103282){
switch(arguments.length){
case 0:
return fluree$db$query$range$state_machine__99703__auto____0.call(this);
case 1:
return fluree$db$query$range$state_machine__99703__auto____1.call(this,state_103282);
}
throw(new Error('Invalid arity: ' + arguments.length));
};
fluree$db$query$range$state_machine__99703__auto__.cljs$core$IFn$_invoke$arity$0 = fluree$db$query$range$state_machine__99703__auto____0;
fluree$db$query$range$state_machine__99703__auto__.cljs$core$IFn$_invoke$arity$1 = fluree$db$query$range$state_machine__99703__auto____1;
return fluree$db$query$range$state_machine__99703__auto__;
})()
;})(switch__99702__auto__,c__99809__auto__))
})();
var state__99811__auto__ = (function (){var statearr_103482 = (f__99810__auto__.cljs$core$IFn$_invoke$arity$0 ? f__99810__auto__.cljs$core$IFn$_invoke$arity$0() : f__99810__auto__.call(null));
(statearr_103482[(6)] = c__99809__auto__);

return statearr_103482;
})();
return cljs.core.async.impl.ioc_helpers.run_state_machine_wrapped(state__99811__auto__);
});})(c__99809__auto__))
);

return c__99809__auto__;
});

fluree.db.query.range.index_range.cljs$lang$maxFixedArity = 7;

fluree.db.query.range.non_nil_non_boolean_QMARK_ = (function fluree$db$query$range$non_nil_non_boolean_QMARK_(o){
return (((!((o == null)))) && ((!(cljs.core.boolean_QMARK_(o)))));
});
fluree.db.query.range.tag_string_QMARK_ = (function fluree$db$query$range$tag_string_QMARK_(possible_tag){
return cljs.core.re_find(/^[a-zA-Z0-9-_]*\/[a-zA-Z0-9-_]*:[a-zA-Z0-9-]*$/,possible_tag);
});
fluree.db.query.range.tag_sid_start = fluree.db.flake.min_subject_id((3));
fluree.db.query.range.tag_sid_end = fluree.db.flake.max_subject_id((3));
/**
 * Returns true if flake is a root setting flake.
 */
fluree.db.query.range.is_tag_flake_QMARK_ = (function fluree$db$query$range$is_tag_flake_QMARK_(f){
return (((fluree.db.query.range.tag_sid_start <= f.o)) && ((f.o <= fluree.db.query.range.tag_sid_end)));
});
fluree.db.query.range.coerce_tag_flakes = (function fluree$db$query$range$coerce_tag_flakes(db,flakes){
var c__99809__auto__ = cljs.core.async.chan.cljs$core$IFn$_invoke$arity$1((1));
cljs.core.async.impl.dispatch.run(((function (c__99809__auto__){
return (function (){
var f__99810__auto__ = (function (){var switch__99702__auto__ = ((function (c__99809__auto__){
return (function (state_103699){
var state_val_103700 = (state_103699[(1)]);
if((state_val_103700 === (7))){
var inst_103673 = (state_103699[(7)]);
var inst_103663 = (state_103699[(8)]);
var inst_103671 = fluree.db.flake.Flake__GT_parts(inst_103663);
var inst_103672 = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(inst_103671,(0),null);
var inst_103673__$1 = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(inst_103671,(1),null);
var inst_103674 = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(inst_103671,(2),null);
var inst_103675 = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(inst_103671,(3),null);
var inst_103676 = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(inst_103671,(4),null);
var inst_103677 = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(inst_103671,(5),null);
var inst_103678 = fluree.db.dbproto._tag.cljs$core$IFn$_invoke$arity$3(db,inst_103674,inst_103673__$1);
var state_103699__$1 = (function (){var statearr_103701 = state_103699;
(statearr_103701[(9)] = inst_103675);

(statearr_103701[(10)] = inst_103677);

(statearr_103701[(11)] = inst_103676);

(statearr_103701[(7)] = inst_103673__$1);

(statearr_103701[(12)] = inst_103672);

return statearr_103701;
})();
return cljs.core.async.impl.ioc_helpers.take_BANG_(state_103699__$1,(10),inst_103678);
} else {
if((state_val_103700 === (1))){
var inst_103652 = cljs.core.seq(flakes);
var inst_103653 = cljs.core.first(inst_103652);
var inst_103654 = cljs.core.next(inst_103652);
var inst_103655 = cljs.core.PersistentVector.EMPTY;
var inst_103656 = flakes;
var inst_103657 = inst_103655;
var state_103699__$1 = (function (){var statearr_103702 = state_103699;
(statearr_103702[(13)] = inst_103653);

(statearr_103702[(14)] = inst_103654);

(statearr_103702[(15)] = inst_103657);

(statearr_103702[(16)] = inst_103656);

return statearr_103702;
})();
var statearr_103703_103720 = state_103699__$1;
(statearr_103703_103720[(2)] = null);

(statearr_103703_103720[(1)] = (2));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103700 === (4))){
var inst_103663 = (state_103699[(8)]);
var inst_103666 = fluree.db.query.range.is_tag_flake_QMARK_(inst_103663);
var state_103699__$1 = state_103699;
if(inst_103666){
var statearr_103704_103721 = state_103699__$1;
(statearr_103704_103721[(1)] = (7));

} else {
var statearr_103705_103722 = state_103699__$1;
(statearr_103705_103722[(1)] = (8));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_103700 === (6))){
var inst_103695 = (state_103699[(2)]);
var state_103699__$1 = state_103699;
var statearr_103706_103723 = state_103699__$1;
(statearr_103706_103723[(2)] = inst_103695);

(statearr_103706_103723[(1)] = (3));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103700 === (3))){
var inst_103697 = (state_103699[(2)]);
var state_103699__$1 = state_103699;
return cljs.core.async.impl.ioc_helpers.return_chan(state_103699__$1,inst_103697);
} else {
if((state_val_103700 === (2))){
var inst_103663 = (state_103699[(8)]);
var inst_103656 = (state_103699[(16)]);
var inst_103662 = cljs.core.seq(inst_103656);
var inst_103663__$1 = cljs.core.first(inst_103662);
var inst_103664 = cljs.core.next(inst_103662);
var state_103699__$1 = (function (){var statearr_103707 = state_103699;
(statearr_103707[(17)] = inst_103664);

(statearr_103707[(8)] = inst_103663__$1);

return statearr_103707;
})();
if(cljs.core.truth_(inst_103663__$1)){
var statearr_103708_103724 = state_103699__$1;
(statearr_103708_103724[(1)] = (4));

} else {
var statearr_103709_103725 = state_103699__$1;
(statearr_103709_103725[(1)] = (5));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_103700 === (9))){
var inst_103692 = (state_103699[(2)]);
var state_103699__$1 = state_103699;
var statearr_103710_103726 = state_103699__$1;
(statearr_103710_103726[(2)] = inst_103692);

(statearr_103710_103726[(1)] = (6));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103700 === (5))){
var inst_103657 = (state_103699[(15)]);
var state_103699__$1 = state_103699;
var statearr_103711_103727 = state_103699__$1;
(statearr_103711_103727[(2)] = inst_103657);

(statearr_103711_103727[(1)] = (6));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103700 === (10))){
var inst_103675 = (state_103699[(9)]);
var inst_103677 = (state_103699[(10)]);
var inst_103676 = (state_103699[(11)]);
var inst_103657 = (state_103699[(15)]);
var inst_103664 = (state_103699[(17)]);
var inst_103673 = (state_103699[(7)]);
var inst_103672 = (state_103699[(12)]);
var inst_103680 = (state_103699[(2)]);
var inst_103681 = fluree.db.util.async.throw_err(inst_103680);
var inst_103682 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_103683 = [inst_103672,inst_103673,inst_103681,inst_103675,inst_103676,inst_103677];
var inst_103684 = (new cljs.core.PersistentVector(null,6,(5),inst_103682,inst_103683,null));
var inst_103685 = fluree.db.flake.parts__GT_Flake.cljs$core$IFn$_invoke$arity$1(inst_103684);
var inst_103686 = cljs.core.conj.cljs$core$IFn$_invoke$arity$2(inst_103657,inst_103685);
var inst_103656 = inst_103664;
var inst_103657__$1 = inst_103686;
var state_103699__$1 = (function (){var statearr_103712 = state_103699;
(statearr_103712[(15)] = inst_103657__$1);

(statearr_103712[(16)] = inst_103656);

return statearr_103712;
})();
var statearr_103713_103728 = state_103699__$1;
(statearr_103713_103728[(2)] = null);

(statearr_103713_103728[(1)] = (2));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103700 === (8))){
var inst_103657 = (state_103699[(15)]);
var inst_103664 = (state_103699[(17)]);
var inst_103663 = (state_103699[(8)]);
var inst_103689 = cljs.core.conj.cljs$core$IFn$_invoke$arity$2(inst_103657,inst_103663);
var inst_103656 = inst_103664;
var inst_103657__$1 = inst_103689;
var state_103699__$1 = (function (){var statearr_103714 = state_103699;
(statearr_103714[(15)] = inst_103657__$1);

(statearr_103714[(16)] = inst_103656);

return statearr_103714;
})();
var statearr_103715_103729 = state_103699__$1;
(statearr_103715_103729[(2)] = null);

(statearr_103715_103729[(1)] = (2));


return cljs.core.cst$kw$recur;
} else {
return null;
}
}
}
}
}
}
}
}
}
}
});})(c__99809__auto__))
;
return ((function (switch__99702__auto__,c__99809__auto__){
return (function() {
var fluree$db$query$range$coerce_tag_flakes_$_state_machine__99703__auto__ = null;
var fluree$db$query$range$coerce_tag_flakes_$_state_machine__99703__auto____0 = (function (){
var statearr_103716 = [null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null];
(statearr_103716[(0)] = fluree$db$query$range$coerce_tag_flakes_$_state_machine__99703__auto__);

(statearr_103716[(1)] = (1));

return statearr_103716;
});
var fluree$db$query$range$coerce_tag_flakes_$_state_machine__99703__auto____1 = (function (state_103699){
while(true){
var ret_value__99704__auto__ = (function (){try{while(true){
var result__99705__auto__ = switch__99702__auto__(state_103699);
if(cljs.core.keyword_identical_QMARK_(result__99705__auto__,cljs.core.cst$kw$recur)){
continue;
} else {
return result__99705__auto__;
}
break;
}
}catch (e103717){if((e103717 instanceof Object)){
var ex__99706__auto__ = e103717;
var statearr_103718_103730 = state_103699;
(statearr_103718_103730[(5)] = ex__99706__auto__);


cljs.core.async.impl.ioc_helpers.process_exception(state_103699);

return cljs.core.cst$kw$recur;
} else {
throw e103717;

}
}})();
if(cljs.core.keyword_identical_QMARK_(ret_value__99704__auto__,cljs.core.cst$kw$recur)){
var G__103731 = state_103699;
state_103699 = G__103731;
continue;
} else {
return ret_value__99704__auto__;
}
break;
}
});
fluree$db$query$range$coerce_tag_flakes_$_state_machine__99703__auto__ = function(state_103699){
switch(arguments.length){
case 0:
return fluree$db$query$range$coerce_tag_flakes_$_state_machine__99703__auto____0.call(this);
case 1:
return fluree$db$query$range$coerce_tag_flakes_$_state_machine__99703__auto____1.call(this,state_103699);
}
throw(new Error('Invalid arity: ' + arguments.length));
};
fluree$db$query$range$coerce_tag_flakes_$_state_machine__99703__auto__.cljs$core$IFn$_invoke$arity$0 = fluree$db$query$range$coerce_tag_flakes_$_state_machine__99703__auto____0;
fluree$db$query$range$coerce_tag_flakes_$_state_machine__99703__auto__.cljs$core$IFn$_invoke$arity$1 = fluree$db$query$range$coerce_tag_flakes_$_state_machine__99703__auto____1;
return fluree$db$query$range$coerce_tag_flakes_$_state_machine__99703__auto__;
})()
;})(switch__99702__auto__,c__99809__auto__))
})();
var state__99811__auto__ = (function (){var statearr_103719 = (f__99810__auto__.cljs$core$IFn$_invoke$arity$0 ? f__99810__auto__.cljs$core$IFn$_invoke$arity$0() : f__99810__auto__.call(null));
(statearr_103719[(6)] = c__99809__auto__);

return statearr_103719;
})();
return cljs.core.async.impl.ioc_helpers.run_state_machine_wrapped(state__99811__auto__);
});})(c__99809__auto__))
);

return c__99809__auto__;
});
fluree.db.query.range.search = (function fluree$db$query$range$search(var_args){
var G__103733 = arguments.length;
switch (G__103733) {
case 2:
return fluree.db.query.range.search.cljs$core$IFn$_invoke$arity$2((arguments[(0)]),(arguments[(1)]));

break;
case 3:
return fluree.db.query.range.search.cljs$core$IFn$_invoke$arity$3((arguments[(0)]),(arguments[(1)]),(arguments[(2)]));

break;
default:
throw (new Error(["Invalid arity: ",cljs.core.str.cljs$core$IFn$_invoke$arity$1(arguments.length)].join('')));

}
});

fluree.db.query.range.search.cljs$core$IFn$_invoke$arity$2 = (function (db,fparts){
return fluree.db.query.range.search.cljs$core$IFn$_invoke$arity$3(db,fparts,cljs.core.PersistentArrayMap.EMPTY);
});

fluree.db.query.range.search.cljs$core$IFn$_invoke$arity$3 = (function (db,fparts,opts){
var c__99809__auto__ = cljs.core.async.chan.cljs$core$IFn$_invoke$arity$1((1));
cljs.core.async.impl.dispatch.run(((function (c__99809__auto__){
return (function (){
var f__99810__auto__ = (function (){var switch__99702__auto__ = ((function (c__99809__auto__){
return (function (state_103880){
var state_val_103881 = (state_103880[(1)]);
if((state_val_103881 === (62))){
var inst_103876 = (state_103880[(2)]);
var state_103880__$1 = state_103880;
var statearr_103882_103966 = state_103880__$1;
(statearr_103882_103966[(2)] = inst_103876);


cljs.core.async.impl.ioc_helpers.process_exception(state_103880__$1);

return cljs.core.cst$kw$recur;
} else {
if((state_val_103881 === (7))){
var inst_103751 = (state_103880[(7)]);
var inst_103751__$1 = (state_103880[(2)]);
var state_103880__$1 = (function (){var statearr_103883 = state_103880;
(statearr_103883[(7)] = inst_103751__$1);

return statearr_103883;
})();
if(cljs.core.truth_(inst_103751__$1)){
var statearr_103884_103967 = state_103880__$1;
(statearr_103884_103967[(1)] = (8));

} else {
var statearr_103885_103968 = state_103880__$1;
(statearr_103885_103968[(1)] = (9));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_103881 === (59))){
var inst_103856 = (state_103880[(2)]);
var inst_103857 = fluree.db.util.async.throw_err(inst_103856);
var state_103880__$1 = state_103880;
var statearr_103886_103969 = state_103880__$1;
(statearr_103886_103969[(2)] = inst_103857);

(statearr_103886_103969[(1)] = (58));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103881 === (20))){
var inst_103777 = (state_103880[(2)]);
var state_103880__$1 = state_103880;
var statearr_103887_103970 = state_103880__$1;
(statearr_103887_103970[(2)] = inst_103777);

(statearr_103887_103970[(1)] = (16));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103881 === (58))){
var inst_103860 = (state_103880[(2)]);
var state_103880__$1 = state_103880;
var statearr_103888_103971 = state_103880__$1;
(statearr_103888_103971[(2)] = inst_103860);

(statearr_103888_103971[(1)] = (54));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103881 === (60))){
var inst_103868 = (state_103880[(8)]);
var inst_103870 = fluree.db.query.range.coerce_tag_flakes(db,inst_103868);
var state_103880__$1 = state_103880;
return cljs.core.async.impl.ioc_helpers.take_BANG_(state_103880__$1,(63),inst_103870);
} else {
if((state_val_103881 === (27))){
var inst_103742 = (state_103880[(9)]);
var state_103880__$1 = state_103880;
var statearr_103889_103972 = state_103880__$1;
(statearr_103889_103972[(2)] = inst_103742);

(statearr_103889_103972[(1)] = (28));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103881 === (1))){
var state_103880__$1 = state_103880;
var statearr_103890_103973 = state_103880__$1;
(statearr_103890_103973[(2)] = null);

(statearr_103890_103973[(1)] = (4));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103881 === (24))){
var inst_103751 = (state_103880[(7)]);
var inst_103868 = (state_103880[(2)]);
var state_103880__$1 = (function (){var statearr_103891 = state_103880;
(statearr_103891[(8)] = inst_103868);

return statearr_103891;
})();
if(cljs.core.truth_(inst_103751)){
var statearr_103892_103974 = state_103880__$1;
(statearr_103892_103974[(1)] = (60));

} else {
var statearr_103893_103975 = state_103880__$1;
(statearr_103893_103975[(1)] = (61));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_103881 === (55))){
var inst_103847 = (state_103880[(2)]);
var inst_103848 = fluree.db.util.async.throw_err(inst_103847);
var state_103880__$1 = state_103880;
var statearr_103894_103976 = state_103880__$1;
(statearr_103894_103976[(2)] = inst_103848);

(statearr_103894_103976[(1)] = (54));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103881 === (39))){
var inst_103745 = (state_103880[(10)]);
var inst_103816 = (state_103880[(11)]);
var inst_103816__$1 = cljs.core.not(inst_103745);
var state_103880__$1 = (function (){var statearr_103895 = state_103880;
(statearr_103895[(11)] = inst_103816__$1);

return statearr_103895;
})();
if(inst_103816__$1){
var statearr_103896_103977 = state_103880__$1;
(statearr_103896_103977[(1)] = (42));

} else {
var statearr_103897_103978 = state_103880__$1;
(statearr_103897_103978[(1)] = (43));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_103881 === (46))){
var inst_103742 = (state_103880[(9)]);
var state_103880__$1 = state_103880;
if(cljs.core.truth_(inst_103742)){
var statearr_103898_103979 = state_103880__$1;
(statearr_103898_103979[(1)] = (52));

} else {
var statearr_103899_103980 = state_103880__$1;
(statearr_103899_103980[(1)] = (53));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_103881 === (4))){
var inst_103742 = (state_103880[(9)]);
var _ = cljs.core.async.impl.ioc_helpers.add_exception_frame(state_103880,(3),Error,null,(2));
var inst_103741 = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(fparts,(0),null);
var inst_103742__$1 = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(fparts,(1),null);
var inst_103743 = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(fparts,(2),null);
var inst_103744 = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(fparts,(3),null);
var inst_103745 = fluree.db.dbproto._p_prop(db,cljs.core.cst$kw$idx_QMARK_,inst_103742__$1);
var state_103880__$1 = (function (){var statearr_103900 = state_103880;
(statearr_103900[(12)] = inst_103741);

(statearr_103900[(13)] = inst_103744);

(statearr_103900[(10)] = inst_103745);

(statearr_103900[(9)] = inst_103742__$1);

(statearr_103900[(14)] = inst_103743);

return statearr_103900;
})();
if(cljs.core.truth_(inst_103742__$1)){
var statearr_103901_103981 = state_103880__$1;
(statearr_103901_103981[(1)] = (5));

} else {
var statearr_103902_103982 = state_103880__$1;
(statearr_103902_103982[(1)] = (6));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_103881 === (54))){
var inst_103862 = (state_103880[(2)]);
var state_103880__$1 = state_103880;
var statearr_103903_103983 = state_103880__$1;
(statearr_103903_103983[(2)] = inst_103862);

(statearr_103903_103983[(1)] = (47));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103881 === (15))){
var inst_103743 = (state_103880[(14)]);
var inst_103767 = typeof inst_103743 === 'string';
var state_103880__$1 = state_103880;
if(cljs.core.truth_(inst_103767)){
var statearr_103904_103984 = state_103880__$1;
(statearr_103904_103984[(1)] = (18));

} else {
var statearr_103905_103985 = state_103880__$1;
(statearr_103905_103985[(1)] = (19));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_103881 === (48))){
var inst_103741 = (state_103880[(12)]);
var inst_103751 = (state_103880[(7)]);
var inst_103744 = (state_103880[(13)]);
var inst_103781 = (state_103880[(15)]);
var inst_103745 = (state_103880[(10)]);
var inst_103756 = (state_103880[(16)]);
var inst_103825 = (state_103880[(17)]);
var inst_103742 = (state_103880[(9)]);
var inst_103827 = (function (){var obj_fn = inst_103825;
var t = inst_103744;
var temp__5733__auto__ = inst_103825;
var vec__103738 = fparts;
var p = inst_103742;
var idx_predicate_QMARK_ = inst_103745;
var o = inst_103781;
var tag_predicate_QMARK_ = inst_103751;
var s = inst_103741;
var o_coerce_QMARK_ = inst_103756;
return ((function (obj_fn,t,temp__5733__auto__,vec__103738,p,idx_predicate_QMARK_,o,tag_predicate_QMARK_,s,o_coerce_QMARK_,inst_103741,inst_103751,inst_103744,inst_103781,inst_103745,inst_103756,inst_103825,inst_103742,state_val_103881,c__99809__auto__){
return (function (x){
var and__4120__auto__ = (obj_fn.cljs$core$IFn$_invoke$arity$1 ? obj_fn.cljs$core$IFn$_invoke$arity$1(x) : obj_fn.call(null,x));
if(cljs.core.truth_(and__4120__auto__)){
return cljs.core._EQ_.cljs$core$IFn$_invoke$arity$2(x,o);
} else {
return and__4120__auto__;
}
});
;})(obj_fn,t,temp__5733__auto__,vec__103738,p,idx_predicate_QMARK_,o,tag_predicate_QMARK_,s,o_coerce_QMARK_,inst_103741,inst_103751,inst_103744,inst_103781,inst_103745,inst_103756,inst_103825,inst_103742,state_val_103881,c__99809__auto__))
})();
var state_103880__$1 = state_103880;
var statearr_103906_103986 = state_103880__$1;
(statearr_103906_103986[(2)] = inst_103827);

(statearr_103906_103986[(1)] = (50));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103881 === (50))){
var inst_103741 = (state_103880[(12)]);
var inst_103744 = (state_103880[(13)]);
var inst_103742 = (state_103880[(9)]);
var inst_103831 = (state_103880[(2)]);
var inst_103832 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_103833 = [inst_103742,inst_103741,null,inst_103744];
var inst_103834 = (new cljs.core.PersistentVector(null,4,(5),inst_103832,inst_103833,null));
var inst_103835 = cljs.core.assoc.cljs$core$IFn$_invoke$arity$3(opts,cljs.core.cst$kw$object_DASH_fn,inst_103831);
var inst_103836 = fluree.db.query.range.index_range.cljs$core$IFn$_invoke$arity$5(db,cljs.core.cst$kw$psot,cljs.core._EQ_,inst_103834,inst_103835);
var state_103880__$1 = state_103880;
return cljs.core.async.impl.ioc_helpers.take_BANG_(state_103880__$1,(51),inst_103836);
} else {
if((state_val_103881 === (21))){
var inst_103773 = (state_103880[(2)]);
var inst_103774 = fluree.db.util.async.throw_err(inst_103773);
var state_103880__$1 = state_103880;
var statearr_103907_103987 = state_103880__$1;
(statearr_103907_103987[(2)] = inst_103774);

(statearr_103907_103987[(1)] = (20));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103881 === (31))){
var inst_103802 = (state_103880[(2)]);
var state_103880__$1 = state_103880;
var statearr_103908_103988 = state_103880__$1;
(statearr_103908_103988[(2)] = inst_103802);

(statearr_103908_103988[(1)] = (28));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103881 === (32))){
var inst_103781 = (state_103880[(15)]);
var inst_103795 = cljs.core.fn_QMARK_(inst_103781);
var inst_103796 = (!(inst_103795));
var state_103880__$1 = state_103880;
var statearr_103909_103989 = state_103880__$1;
(statearr_103909_103989[(2)] = inst_103796);

(statearr_103909_103989[(1)] = (34));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103881 === (40))){
var inst_103742 = (state_103880[(9)]);
var state_103880__$1 = state_103880;
var statearr_103910_103990 = state_103880__$1;
(statearr_103910_103990[(2)] = inst_103742);

(statearr_103910_103990[(1)] = (41));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103881 === (56))){
var inst_103741 = (state_103880[(12)]);
var inst_103744 = (state_103880[(13)]);
var inst_103781 = (state_103880[(15)]);
var inst_103742 = (state_103880[(9)]);
var inst_103851 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_103852 = [inst_103781,inst_103742,inst_103741,inst_103744];
var inst_103853 = (new cljs.core.PersistentVector(null,4,(5),inst_103851,inst_103852,null));
var inst_103854 = fluree.db.query.range.index_range.cljs$core$IFn$_invoke$arity$5(db,cljs.core.cst$kw$opst,cljs.core._EQ_,inst_103853,opts);
var state_103880__$1 = state_103880;
return cljs.core.async.impl.ioc_helpers.take_BANG_(state_103880__$1,(59),inst_103854);
} else {
if((state_val_103881 === (33))){
var inst_103745 = (state_103880[(10)]);
var state_103880__$1 = state_103880;
var statearr_103911_103991 = state_103880__$1;
(statearr_103911_103991[(2)] = inst_103745);

(statearr_103911_103991[(1)] = (34));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103881 === (13))){
var inst_103741 = (state_103880[(12)]);
var inst_103781 = (state_103880[(2)]);
var state_103880__$1 = (function (){var statearr_103912 = state_103880;
(statearr_103912[(15)] = inst_103781);

return statearr_103912;
})();
if(cljs.core.truth_(inst_103741)){
var statearr_103913_103992 = state_103880__$1;
(statearr_103913_103992[(1)] = (22));

} else {
var statearr_103914_103993 = state_103880__$1;
(statearr_103914_103993[(1)] = (23));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_103881 === (22))){
var inst_103741 = (state_103880[(12)]);
var inst_103744 = (state_103880[(13)]);
var inst_103781 = (state_103880[(15)]);
var inst_103742 = (state_103880[(9)]);
var inst_103783 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_103784 = [inst_103741,inst_103742,inst_103781,inst_103744];
var inst_103785 = (new cljs.core.PersistentVector(null,4,(5),inst_103783,inst_103784,null));
var inst_103786 = fluree.db.query.range.index_range.cljs$core$IFn$_invoke$arity$5(db,cljs.core.cst$kw$spot,cljs.core._EQ_,inst_103785,opts);
var state_103880__$1 = state_103880;
return cljs.core.async.impl.ioc_helpers.take_BANG_(state_103880__$1,(25),inst_103786);
} else {
if((state_val_103881 === (36))){
var inst_103742 = (state_103880[(9)]);
var state_103880__$1 = state_103880;
if(cljs.core.truth_(inst_103742)){
var statearr_103915_103994 = state_103880__$1;
(statearr_103915_103994[(1)] = (39));

} else {
var statearr_103916_103995 = state_103880__$1;
(statearr_103916_103995[(1)] = (40));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_103881 === (41))){
var inst_103823 = (state_103880[(2)]);
var state_103880__$1 = state_103880;
if(cljs.core.truth_(inst_103823)){
var statearr_103917_103996 = state_103880__$1;
(statearr_103917_103996[(1)] = (45));

} else {
var statearr_103918_103997 = state_103880__$1;
(statearr_103918_103997[(1)] = (46));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_103881 === (43))){
var inst_103816 = (state_103880[(11)]);
var state_103880__$1 = state_103880;
var statearr_103919_103998 = state_103880__$1;
(statearr_103919_103998[(2)] = inst_103816);

(statearr_103919_103998[(1)] = (44));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103881 === (61))){
var inst_103868 = (state_103880[(8)]);
var state_103880__$1 = state_103880;
var statearr_103920_103999 = state_103880__$1;
(statearr_103920_103999[(2)] = inst_103868);

(statearr_103920_103999[(1)] = (62));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103881 === (29))){
var inst_103745 = (state_103880[(10)]);
var state_103880__$1 = state_103880;
if(cljs.core.truth_(inst_103745)){
var statearr_103921_104000 = state_103880__$1;
(statearr_103921_104000[(1)] = (32));

} else {
var statearr_103922_104001 = state_103880__$1;
(statearr_103922_104001[(1)] = (33));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_103881 === (44))){
var inst_103820 = (state_103880[(2)]);
var state_103880__$1 = state_103880;
var statearr_103923_104002 = state_103880__$1;
(statearr_103923_104002[(2)] = inst_103820);

(statearr_103923_104002[(1)] = (41));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103881 === (6))){
var state_103880__$1 = state_103880;
var statearr_103924_104003 = state_103880__$1;
(statearr_103924_104003[(2)] = false);

(statearr_103924_104003[(1)] = (7));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103881 === (28))){
var inst_103805 = (state_103880[(2)]);
var state_103880__$1 = state_103880;
if(cljs.core.truth_(inst_103805)){
var statearr_103925_104004 = state_103880__$1;
(statearr_103925_104004[(1)] = (35));

} else {
var statearr_103926_104005 = state_103880__$1;
(statearr_103926_104005[(1)] = (36));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_103881 === (51))){
var inst_103838 = (state_103880[(2)]);
var inst_103839 = fluree.db.util.async.throw_err(inst_103838);
var state_103880__$1 = state_103880;
var statearr_103927_104006 = state_103880__$1;
(statearr_103927_104006[(2)] = inst_103839);

(statearr_103927_104006[(1)] = (47));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103881 === (25))){
var inst_103788 = (state_103880[(2)]);
var inst_103789 = fluree.db.util.async.throw_err(inst_103788);
var state_103880__$1 = state_103880;
var statearr_103928_104007 = state_103880__$1;
(statearr_103928_104007[(2)] = inst_103789);

(statearr_103928_104007[(1)] = (24));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103881 === (34))){
var inst_103799 = (state_103880[(2)]);
var state_103880__$1 = state_103880;
var statearr_103929_104008 = state_103880__$1;
(statearr_103929_104008[(2)] = inst_103799);

(statearr_103929_104008[(1)] = (31));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103881 === (17))){
var inst_103764 = (state_103880[(2)]);
var inst_103765 = fluree.db.util.async.throw_err(inst_103764);
var state_103880__$1 = state_103880;
var statearr_103930_104009 = state_103880__$1;
(statearr_103930_104009[(2)] = inst_103765);

(statearr_103930_104009[(1)] = (16));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103881 === (3))){
var inst_103734 = (state_103880[(2)]);
var state_103880__$1 = state_103880;
var statearr_103931_104010 = state_103880__$1;
(statearr_103931_104010[(2)] = inst_103734);


cljs.core.async.impl.ioc_helpers.process_exception(state_103880__$1);

return cljs.core.cst$kw$recur;
} else {
if((state_val_103881 === (12))){
var inst_103743 = (state_103880[(14)]);
var inst_103760 = fluree.db.query.range.tag_string_QMARK_(inst_103743);
var state_103880__$1 = state_103880;
if(cljs.core.truth_(inst_103760)){
var statearr_103932_104011 = state_103880__$1;
(statearr_103932_104011[(1)] = (14));

} else {
var statearr_103933_104012 = state_103880__$1;
(statearr_103933_104012[(1)] = (15));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_103881 === (2))){
var inst_103878 = (state_103880[(2)]);
var state_103880__$1 = state_103880;
return cljs.core.async.impl.ioc_helpers.return_chan(state_103880__$1,inst_103878);
} else {
if((state_val_103881 === (23))){
var inst_103742 = (state_103880[(9)]);
var state_103880__$1 = state_103880;
if(cljs.core.truth_(inst_103742)){
var statearr_103934_104013 = state_103880__$1;
(statearr_103934_104013[(1)] = (26));

} else {
var statearr_103935_104014 = state_103880__$1;
(statearr_103935_104014[(1)] = (27));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_103881 === (47))){
var inst_103864 = (state_103880[(2)]);
var state_103880__$1 = state_103880;
var statearr_103936_104015 = state_103880__$1;
(statearr_103936_104015[(2)] = inst_103864);

(statearr_103936_104015[(1)] = (37));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103881 === (35))){
var inst_103741 = (state_103880[(12)]);
var inst_103744 = (state_103880[(13)]);
var inst_103781 = (state_103880[(15)]);
var inst_103742 = (state_103880[(9)]);
var inst_103807 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_103808 = [inst_103742,inst_103781,inst_103741,inst_103744];
var inst_103809 = (new cljs.core.PersistentVector(null,4,(5),inst_103807,inst_103808,null));
var inst_103810 = fluree.db.query.range.index_range.cljs$core$IFn$_invoke$arity$5(db,cljs.core.cst$kw$post,cljs.core._EQ_,inst_103809,opts);
var state_103880__$1 = state_103880;
return cljs.core.async.impl.ioc_helpers.take_BANG_(state_103880__$1,(38),inst_103810);
} else {
if((state_val_103881 === (19))){
var state_103880__$1 = state_103880;
var statearr_103937_104016 = state_103880__$1;
(statearr_103937_104016[(2)] = null);

(statearr_103937_104016[(1)] = (20));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103881 === (57))){
var state_103880__$1 = state_103880;
var statearr_103938_104017 = state_103880__$1;
(statearr_103938_104017[(2)] = null);

(statearr_103938_104017[(1)] = (58));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103881 === (11))){
var inst_103743 = (state_103880[(14)]);
var state_103880__$1 = state_103880;
var statearr_103939_104018 = state_103880__$1;
(statearr_103939_104018[(2)] = inst_103743);

(statearr_103939_104018[(1)] = (13));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103881 === (9))){
var inst_103751 = (state_103880[(7)]);
var state_103880__$1 = state_103880;
var statearr_103940_104019 = state_103880__$1;
(statearr_103940_104019[(2)] = inst_103751);

(statearr_103940_104019[(1)] = (10));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103881 === (5))){
var inst_103742 = (state_103880[(9)]);
var inst_103747 = fluree.db.dbproto._p_prop(db,cljs.core.cst$kw$type,inst_103742);
var inst_103748 = cljs.core._EQ_.cljs$core$IFn$_invoke$arity$2(cljs.core.cst$kw$tag,inst_103747);
var state_103880__$1 = state_103880;
var statearr_103941_104020 = state_103880__$1;
(statearr_103941_104020[(2)] = inst_103748);

(statearr_103941_104020[(1)] = (7));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103881 === (14))){
var inst_103743 = (state_103880[(14)]);
var inst_103762 = fluree.db.dbproto._tag_id.cljs$core$IFn$_invoke$arity$2(db,inst_103743);
var state_103880__$1 = state_103880;
return cljs.core.async.impl.ioc_helpers.take_BANG_(state_103880__$1,(17),inst_103762);
} else {
if((state_val_103881 === (45))){
var inst_103825 = (state_103880[(17)]);
var inst_103825__$1 = cljs.core.cst$kw$object_DASH_fn.cljs$core$IFn$_invoke$arity$1(opts);
var state_103880__$1 = (function (){var statearr_103942 = state_103880;
(statearr_103942[(17)] = inst_103825__$1);

return statearr_103942;
})();
if(cljs.core.truth_(inst_103825__$1)){
var statearr_103943_104021 = state_103880__$1;
(statearr_103943_104021[(1)] = (48));

} else {
var statearr_103944_104022 = state_103880__$1;
(statearr_103944_104022[(1)] = (49));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_103881 === (53))){
var inst_103781 = (state_103880[(15)]);
var state_103880__$1 = state_103880;
if(cljs.core.truth_(inst_103781)){
var statearr_103945_104023 = state_103880__$1;
(statearr_103945_104023[(1)] = (56));

} else {
var statearr_103946_104024 = state_103880__$1;
(statearr_103946_104024[(1)] = (57));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_103881 === (26))){
var inst_103781 = (state_103880[(15)]);
var inst_103792 = (state_103880[(18)]);
var inst_103792__$1 = fluree.db.query.range.non_nil_non_boolean_QMARK_(inst_103781);
var state_103880__$1 = (function (){var statearr_103947 = state_103880;
(statearr_103947[(18)] = inst_103792__$1);

return statearr_103947;
})();
if(inst_103792__$1){
var statearr_103948_104025 = state_103880__$1;
(statearr_103948_104025[(1)] = (29));

} else {
var statearr_103949_104026 = state_103880__$1;
(statearr_103949_104026[(1)] = (30));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_103881 === (16))){
var inst_103779 = (state_103880[(2)]);
var state_103880__$1 = state_103880;
var statearr_103950_104027 = state_103880__$1;
(statearr_103950_104027[(2)] = inst_103779);

(statearr_103950_104027[(1)] = (13));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103881 === (38))){
var inst_103812 = (state_103880[(2)]);
var inst_103813 = fluree.db.util.async.throw_err(inst_103812);
var state_103880__$1 = state_103880;
var statearr_103951_104028 = state_103880__$1;
(statearr_103951_104028[(2)] = inst_103813);

(statearr_103951_104028[(1)] = (37));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103881 === (30))){
var inst_103792 = (state_103880[(18)]);
var state_103880__$1 = state_103880;
var statearr_103952_104029 = state_103880__$1;
(statearr_103952_104029[(2)] = inst_103792);

(statearr_103952_104029[(1)] = (31));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103881 === (10))){
var inst_103756 = (state_103880[(16)]);
var inst_103756__$1 = (state_103880[(2)]);
var inst_103757 = cljs.core.not(inst_103756__$1);
var state_103880__$1 = (function (){var statearr_103953 = state_103880;
(statearr_103953[(16)] = inst_103756__$1);

return statearr_103953;
})();
if(inst_103757){
var statearr_103954_104030 = state_103880__$1;
(statearr_103954_104030[(1)] = (11));

} else {
var statearr_103955_104031 = state_103880__$1;
(statearr_103955_104031[(1)] = (12));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_103881 === (18))){
var inst_103742 = (state_103880[(9)]);
var inst_103743 = (state_103880[(14)]);
var inst_103769 = fluree.db.dbproto._p_prop(db,cljs.core.cst$kw$name,inst_103742);
var inst_103770 = [cljs.core.str.cljs$core$IFn$_invoke$arity$1(inst_103769),":",cljs.core.str.cljs$core$IFn$_invoke$arity$1(inst_103743)].join('');
var inst_103771 = fluree.db.dbproto._tag_id.cljs$core$IFn$_invoke$arity$2(db,inst_103770);
var state_103880__$1 = state_103880;
return cljs.core.async.impl.ioc_helpers.take_BANG_(state_103880__$1,(21),inst_103771);
} else {
if((state_val_103881 === (52))){
var inst_103741 = (state_103880[(12)]);
var inst_103744 = (state_103880[(13)]);
var inst_103781 = (state_103880[(15)]);
var inst_103742 = (state_103880[(9)]);
var inst_103842 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_103843 = [inst_103742,inst_103741,inst_103781,inst_103744];
var inst_103844 = (new cljs.core.PersistentVector(null,4,(5),inst_103842,inst_103843,null));
var inst_103845 = fluree.db.query.range.index_range.cljs$core$IFn$_invoke$arity$5(db,cljs.core.cst$kw$psot,cljs.core._EQ_,inst_103844,opts);
var state_103880__$1 = state_103880;
return cljs.core.async.impl.ioc_helpers.take_BANG_(state_103880__$1,(55),inst_103845);
} else {
if((state_val_103881 === (42))){
var inst_103781 = (state_103880[(15)]);
var state_103880__$1 = state_103880;
var statearr_103956_104032 = state_103880__$1;
(statearr_103956_104032[(2)] = inst_103781);

(statearr_103956_104032[(1)] = (44));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103881 === (37))){
var inst_103866 = (state_103880[(2)]);
var state_103880__$1 = state_103880;
var statearr_103957_104033 = state_103880__$1;
(statearr_103957_104033[(2)] = inst_103866);

(statearr_103957_104033[(1)] = (24));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103881 === (63))){
var inst_103872 = (state_103880[(2)]);
var inst_103873 = fluree.db.util.async.throw_err(inst_103872);
var state_103880__$1 = state_103880;
var statearr_103958_104034 = state_103880__$1;
(statearr_103958_104034[(2)] = inst_103873);

(statearr_103958_104034[(1)] = (62));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103881 === (8))){
var inst_103743 = (state_103880[(14)]);
var inst_103753 = typeof inst_103743 === 'string';
var state_103880__$1 = state_103880;
var statearr_103959_104035 = state_103880__$1;
(statearr_103959_104035[(2)] = inst_103753);

(statearr_103959_104035[(1)] = (10));


return cljs.core.cst$kw$recur;
} else {
if((state_val_103881 === (49))){
var inst_103741 = (state_103880[(12)]);
var inst_103751 = (state_103880[(7)]);
var inst_103744 = (state_103880[(13)]);
var inst_103781 = (state_103880[(15)]);
var inst_103745 = (state_103880[(10)]);
var inst_103756 = (state_103880[(16)]);
var inst_103825 = (state_103880[(17)]);
var inst_103742 = (state_103880[(9)]);
var inst_103829 = (function (){var t = inst_103744;
var temp__5733__auto__ = inst_103825;
var vec__103738 = fparts;
var p = inst_103742;
var idx_predicate_QMARK_ = inst_103745;
var o = inst_103781;
var tag_predicate_QMARK_ = inst_103751;
var s = inst_103741;
var o_coerce_QMARK_ = inst_103756;
return ((function (t,temp__5733__auto__,vec__103738,p,idx_predicate_QMARK_,o,tag_predicate_QMARK_,s,o_coerce_QMARK_,inst_103741,inst_103751,inst_103744,inst_103781,inst_103745,inst_103756,inst_103825,inst_103742,state_val_103881,c__99809__auto__){
return (function (x){
return cljs.core._EQ_.cljs$core$IFn$_invoke$arity$2(x,o);
});
;})(t,temp__5733__auto__,vec__103738,p,idx_predicate_QMARK_,o,tag_predicate_QMARK_,s,o_coerce_QMARK_,inst_103741,inst_103751,inst_103744,inst_103781,inst_103745,inst_103756,inst_103825,inst_103742,state_val_103881,c__99809__auto__))
})();
var state_103880__$1 = state_103880;
var statearr_103960_104036 = state_103880__$1;
(statearr_103960_104036[(2)] = inst_103829);

(statearr_103960_104036[(1)] = (50));


return cljs.core.cst$kw$recur;
} else {
return null;
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
});})(c__99809__auto__))
;
return ((function (switch__99702__auto__,c__99809__auto__){
return (function() {
var fluree$db$query$range$state_machine__99703__auto__ = null;
var fluree$db$query$range$state_machine__99703__auto____0 = (function (){
var statearr_103961 = [null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null];
(statearr_103961[(0)] = fluree$db$query$range$state_machine__99703__auto__);

(statearr_103961[(1)] = (1));

return statearr_103961;
});
var fluree$db$query$range$state_machine__99703__auto____1 = (function (state_103880){
while(true){
var ret_value__99704__auto__ = (function (){try{while(true){
var result__99705__auto__ = switch__99702__auto__(state_103880);
if(cljs.core.keyword_identical_QMARK_(result__99705__auto__,cljs.core.cst$kw$recur)){
continue;
} else {
return result__99705__auto__;
}
break;
}
}catch (e103962){if((e103962 instanceof Object)){
var ex__99706__auto__ = e103962;
var statearr_103963_104037 = state_103880;
(statearr_103963_104037[(5)] = ex__99706__auto__);


cljs.core.async.impl.ioc_helpers.process_exception(state_103880);

return cljs.core.cst$kw$recur;
} else {
throw e103962;

}
}})();
if(cljs.core.keyword_identical_QMARK_(ret_value__99704__auto__,cljs.core.cst$kw$recur)){
var G__104038 = state_103880;
state_103880 = G__104038;
continue;
} else {
return ret_value__99704__auto__;
}
break;
}
});
fluree$db$query$range$state_machine__99703__auto__ = function(state_103880){
switch(arguments.length){
case 0:
return fluree$db$query$range$state_machine__99703__auto____0.call(this);
case 1:
return fluree$db$query$range$state_machine__99703__auto____1.call(this,state_103880);
}
throw(new Error('Invalid arity: ' + arguments.length));
};
fluree$db$query$range$state_machine__99703__auto__.cljs$core$IFn$_invoke$arity$0 = fluree$db$query$range$state_machine__99703__auto____0;
fluree$db$query$range$state_machine__99703__auto__.cljs$core$IFn$_invoke$arity$1 = fluree$db$query$range$state_machine__99703__auto____1;
return fluree$db$query$range$state_machine__99703__auto__;
})()
;})(switch__99702__auto__,c__99809__auto__))
})();
var state__99811__auto__ = (function (){var statearr_103964 = (f__99810__auto__.cljs$core$IFn$_invoke$arity$0 ? f__99810__auto__.cljs$core$IFn$_invoke$arity$0() : f__99810__auto__.call(null));
(statearr_103964[(6)] = c__99809__auto__);

return statearr_103964;
})();
return cljs.core.async.impl.ioc_helpers.run_state_machine_wrapped(state__99811__auto__);
});})(c__99809__auto__))
);

return c__99809__auto__;
});

fluree.db.query.range.search.cljs$lang$maxFixedArity = 3;

/**
 * Returns spot index range for only the requested collection.
 */
fluree.db.query.range.collection = (function fluree$db$query$range$collection(var_args){
var G__104040 = arguments.length;
switch (G__104040) {
case 2:
return fluree.db.query.range.collection.cljs$core$IFn$_invoke$arity$2((arguments[(0)]),(arguments[(1)]));

break;
case 3:
return fluree.db.query.range.collection.cljs$core$IFn$_invoke$arity$3((arguments[(0)]),(arguments[(1)]),(arguments[(2)]));

break;
default:
throw (new Error(["Invalid arity: ",cljs.core.str.cljs$core$IFn$_invoke$arity$1(arguments.length)].join('')));

}
});

fluree.db.query.range.collection.cljs$core$IFn$_invoke$arity$2 = (function (db,name){
return fluree.db.query.range.collection.cljs$core$IFn$_invoke$arity$3(db,name,null);
});

fluree.db.query.range.collection.cljs$core$IFn$_invoke$arity$3 = (function (db,name,opts){
var c__99809__auto__ = cljs.core.async.chan.cljs$core$IFn$_invoke$arity$1((1));
cljs.core.async.impl.dispatch.run(((function (c__99809__auto__){
return (function (){
var f__99810__auto__ = (function (){var switch__99702__auto__ = ((function (c__99809__auto__){
return (function (state_104072){
var state_val_104073 = (state_104072[(1)]);
if((state_val_104073 === (1))){
var state_104072__$1 = state_104072;
var statearr_104074_104087 = state_104072__$1;
(statearr_104074_104087[(2)] = null);

(statearr_104074_104087[(1)] = (4));


return cljs.core.cst$kw$recur;
} else {
if((state_val_104073 === (2))){
var inst_104070 = (state_104072[(2)]);
var state_104072__$1 = state_104072;
return cljs.core.async.impl.ioc_helpers.return_chan(state_104072__$1,inst_104070);
} else {
if((state_val_104073 === (3))){
var inst_104041 = (state_104072[(2)]);
var state_104072__$1 = state_104072;
var statearr_104075_104088 = state_104072__$1;
(statearr_104075_104088[(2)] = inst_104041);


cljs.core.async.impl.ioc_helpers.process_exception(state_104072__$1);

return cljs.core.cst$kw$recur;
} else {
if((state_val_104073 === (4))){
var inst_104045 = (state_104072[(7)]);
var _ = cljs.core.async.impl.ioc_helpers.add_exception_frame(state_104072,(3),cljs.core.cst$kw$default,null,(2));
var inst_104045__$1 = fluree.db.dbproto._c_prop(db,cljs.core.cst$kw$id,name);
var state_104072__$1 = (function (){var statearr_104076 = state_104072;
(statearr_104076[(7)] = inst_104045__$1);

return statearr_104076;
})();
if(cljs.core.truth_(inst_104045__$1)){
var statearr_104077_104089 = state_104072__$1;
(statearr_104077_104089[(1)] = (5));

} else {
var statearr_104078_104090 = state_104072__$1;
(statearr_104078_104090[(1)] = (6));

}

return cljs.core.cst$kw$recur;
} else {
if((state_val_104073 === (5))){
var inst_104045 = (state_104072[(7)]);
var inst_104047 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_104048 = fluree.db.flake.max_subject_id(inst_104045);
var inst_104049 = [inst_104048];
var inst_104050 = (new cljs.core.PersistentVector(null,1,(5),inst_104047,inst_104049,null));
var inst_104051 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_104052 = fluree.db.flake.min_subject_id(inst_104045);
var inst_104053 = [inst_104052];
var inst_104054 = (new cljs.core.PersistentVector(null,1,(5),inst_104051,inst_104053,null));
var inst_104055 = fluree.db.query.range.index_range.cljs$core$IFn$_invoke$arity$7(db,cljs.core.cst$kw$spot,cljs.core._GT__EQ_,inst_104050,cljs.core._LT__EQ_,inst_104054,opts);
var state_104072__$1 = state_104072;
return cljs.core.async.impl.ioc_helpers.take_BANG_(state_104072__$1,(8),inst_104055);
} else {
if((state_val_104073 === (6))){
var inst_104060 = cljs.core.pr_str.cljs$core$IFn$_invoke$arity$variadic(cljs.core.prim_seq.cljs$core$IFn$_invoke$arity$2([name], 0));
var inst_104061 = ["Invalid collection name: ",inst_104060].join('');
var inst_104062 = [cljs.core.cst$kw$status,cljs.core.cst$kw$error];
var inst_104063 = [(400),cljs.core.cst$kw$db_SLASH_invalid_DASH_collection];
var inst_104064 = cljs.core.PersistentHashMap.fromArrays(inst_104062,inst_104063);
var inst_104065 = cljs.core.ex_info.cljs$core$IFn$_invoke$arity$2(inst_104061,inst_104064);
var inst_104066 = (function(){throw inst_104065})();
var state_104072__$1 = state_104072;
var statearr_104079_104091 = state_104072__$1;
(statearr_104079_104091[(2)] = inst_104066);

(statearr_104079_104091[(1)] = (7));


return cljs.core.cst$kw$recur;
} else {
if((state_val_104073 === (7))){
var inst_104068 = (state_104072[(2)]);
var state_104072__$1 = state_104072;
var statearr_104080_104092 = state_104072__$1;
(statearr_104080_104092[(2)] = inst_104068);


cljs.core.async.impl.ioc_helpers.process_exception(state_104072__$1);

return cljs.core.cst$kw$recur;
} else {
if((state_val_104073 === (8))){
var inst_104057 = (state_104072[(2)]);
var inst_104058 = fluree.db.util.async.throw_err(inst_104057);
var state_104072__$1 = state_104072;
var statearr_104081_104093 = state_104072__$1;
(statearr_104081_104093[(2)] = inst_104058);

(statearr_104081_104093[(1)] = (7));


return cljs.core.cst$kw$recur;
} else {
return null;
}
}
}
}
}
}
}
}
});})(c__99809__auto__))
;
return ((function (switch__99702__auto__,c__99809__auto__){
return (function() {
var fluree$db$query$range$state_machine__99703__auto__ = null;
var fluree$db$query$range$state_machine__99703__auto____0 = (function (){
var statearr_104082 = [null,null,null,null,null,null,null,null];
(statearr_104082[(0)] = fluree$db$query$range$state_machine__99703__auto__);

(statearr_104082[(1)] = (1));

return statearr_104082;
});
var fluree$db$query$range$state_machine__99703__auto____1 = (function (state_104072){
while(true){
var ret_value__99704__auto__ = (function (){try{while(true){
var result__99705__auto__ = switch__99702__auto__(state_104072);
if(cljs.core.keyword_identical_QMARK_(result__99705__auto__,cljs.core.cst$kw$recur)){
continue;
} else {
return result__99705__auto__;
}
break;
}
}catch (e104083){if((e104083 instanceof Object)){
var ex__99706__auto__ = e104083;
var statearr_104084_104094 = state_104072;
(statearr_104084_104094[(5)] = ex__99706__auto__);


cljs.core.async.impl.ioc_helpers.process_exception(state_104072);

return cljs.core.cst$kw$recur;
} else {
throw e104083;

}
}})();
if(cljs.core.keyword_identical_QMARK_(ret_value__99704__auto__,cljs.core.cst$kw$recur)){
var G__104095 = state_104072;
state_104072 = G__104095;
continue;
} else {
return ret_value__99704__auto__;
}
break;
}
});
fluree$db$query$range$state_machine__99703__auto__ = function(state_104072){
switch(arguments.length){
case 0:
return fluree$db$query$range$state_machine__99703__auto____0.call(this);
case 1:
return fluree$db$query$range$state_machine__99703__auto____1.call(this,state_104072);
}
throw(new Error('Invalid arity: ' + arguments.length));
};
fluree$db$query$range$state_machine__99703__auto__.cljs$core$IFn$_invoke$arity$0 = fluree$db$query$range$state_machine__99703__auto____0;
fluree$db$query$range$state_machine__99703__auto__.cljs$core$IFn$_invoke$arity$1 = fluree$db$query$range$state_machine__99703__auto____1;
return fluree$db$query$range$state_machine__99703__auto__;
})()
;})(switch__99702__auto__,c__99809__auto__))
})();
var state__99811__auto__ = (function (){var statearr_104085 = (f__99810__auto__.cljs$core$IFn$_invoke$arity$0 ? f__99810__auto__.cljs$core$IFn$_invoke$arity$0() : f__99810__auto__.call(null));
(statearr_104085[(6)] = c__99809__auto__);

return statearr_104085;
})();
return cljs.core.async.impl.ioc_helpers.run_state_machine_wrapped(state__99811__auto__);
});})(c__99809__auto__))
);

return c__99809__auto__;
});

fluree.db.query.range.collection.cljs$lang$maxFixedArity = 3;

/**
 * Returns spot index range for only the requested collection.
 */
fluree.db.query.range._block_or_tx_collection = (function fluree$db$query$range$_block_or_tx_collection(db,opts){
return fluree.db.query.range.index_range.cljs$core$IFn$_invoke$arity$7(db,cljs.core.cst$kw$spot,cljs.core._GT_,new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [(0)], null),cljs.core._LT__EQ_,new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [fluree.db.util.core.min_long], null),opts);
});
/**
 * Returns vector of transactions from a set of flakes.
 * Each transaction is a map with the following keys:
 * 1. db - the associated ledger
 * 2. tx - a map containing all transaction data in the original cmd
 * 3. nonce - the nonce
 * 4. auth - the authority that submitted the transaction
 * 5. expire - expiration
 */
fluree.db.query.range.txn_from_flakes = (function fluree$db$query$range$txn_from_flakes(flakes){
var G__104099 = flakes;
var vec__104100 = G__104099;
var seq__104101 = cljs.core.seq(vec__104100);
var first__104102 = cljs.core.first(seq__104101);
var seq__104101__$1 = cljs.core.next(seq__104101);
var flake_SINGLEQUOTE_ = first__104102;
var r = seq__104101__$1;
var result_STAR_ = cljs.core.PersistentVector.EMPTY;
var G__104099__$1 = G__104099;
var result_STAR___$1 = result_STAR_;
while(true){
var vec__104109 = G__104099__$1;
var seq__104110 = cljs.core.seq(vec__104109);
var first__104111 = cljs.core.first(seq__104110);
var seq__104110__$1 = cljs.core.next(seq__104110);
var flake_SINGLEQUOTE___$1 = first__104111;
var r__$1 = seq__104110__$1;
var result_STAR___$2 = result_STAR___$1;
if((flake_SINGLEQUOTE___$1 == null)){
return result_STAR___$2;
} else {
var obj = flake_SINGLEQUOTE___$1.o;
var cmd_map = (function (){try{return fluree.db.util.json.parse(obj);
}catch (e104113){var e = e104113;
return null;
}})();
var map__104112 = cmd_map;
var map__104112__$1 = (((((!((map__104112 == null))))?(((((map__104112.cljs$lang$protocol_mask$partition0$ & (64))) || ((cljs.core.PROTOCOL_SENTINEL === map__104112.cljs$core$ISeq$))))?true:false):false))?cljs.core.apply.cljs$core$IFn$_invoke$arity$2(cljs.core.hash_map,map__104112):map__104112);
var type = cljs.core.get.cljs$core$IFn$_invoke$arity$2(map__104112__$1,cljs.core.cst$kw$type);
var db = cljs.core.get.cljs$core$IFn$_invoke$arity$2(map__104112__$1,cljs.core.cst$kw$db);
var tx = cljs.core.get.cljs$core$IFn$_invoke$arity$2(map__104112__$1,cljs.core.cst$kw$tx);
var nonce = cljs.core.get.cljs$core$IFn$_invoke$arity$2(map__104112__$1,cljs.core.cst$kw$nonce);
var auth = cljs.core.get.cljs$core$IFn$_invoke$arity$2(map__104112__$1,cljs.core.cst$kw$auth);
var expire = cljs.core.get.cljs$core$IFn$_invoke$arity$2(map__104112__$1,cljs.core.cst$kw$expire);
var G__104115 = r__$1;
var G__104116 = ((cljs.core._EQ_.cljs$core$IFn$_invoke$arity$2(type,"tx"))?cljs.core.conj.cljs$core$IFn$_invoke$arity$2(result_STAR___$2,new cljs.core.PersistentArrayMap(null, 5, [cljs.core.cst$kw$db,db,cljs.core.cst$kw$tx,tx,cljs.core.cst$kw$nonce,nonce,cljs.core.cst$kw$auth,auth,cljs.core.cst$kw$expire,expire], null)):result_STAR___$2);
G__104099__$1 = G__104115;
result_STAR___$1 = G__104116;
continue;
}
break;
}
});
/**
 * Returns block data as a map, with the following keys:
 *   1. block - block number
 *   2. t - fluree "time" since ledger creation
 *   3. sigs - List of transactor signatures that signed this block
 *   4. instant - instant this block was created, per the transactor.
 *   5. hash - hash of current block
 *   6. prev-hash - hash of previous block, if relevant
 *   7. flakes - list of flakes comprising block
 *   8. txn - list of transactions in block
 *   
 */
fluree.db.query.range.block_with_tx_data = (function fluree$db$query$range$block_with_tx_data(blocks){
var G__104125 = blocks;
var vec__104126 = G__104125;
var seq__104127 = cljs.core.seq(vec__104126);
var first__104128 = cljs.core.first(seq__104127);
var seq__104127__$1 = cljs.core.next(seq__104127);
var block_SINGLEQUOTE_ = first__104128;
var r = seq__104127__$1;
var result_STAR_ = cljs.core.PersistentVector.EMPTY;
var G__104125__$1 = G__104125;
var result_STAR___$1 = result_STAR_;
while(true){
var vec__104134 = G__104125__$1;
var seq__104135 = cljs.core.seq(vec__104134);
var first__104136 = cljs.core.first(seq__104135);
var seq__104135__$1 = cljs.core.next(seq__104135);
var block_SINGLEQUOTE___$1 = first__104136;
var r__$1 = seq__104135__$1;
var result_STAR___$2 = result_STAR___$1;
if((block_SINGLEQUOTE___$1 == null)){
return result_STAR___$2;
} else {
var map__104137 = block_SINGLEQUOTE___$1;
var map__104137__$1 = (((((!((map__104137 == null))))?(((((map__104137.cljs$lang$protocol_mask$partition0$ & (64))) || ((cljs.core.PROTOCOL_SENTINEL === map__104137.cljs$core$ISeq$))))?true:false):false))?cljs.core.apply.cljs$core$IFn$_invoke$arity$2(cljs.core.hash_map,map__104137):map__104137);
var block = cljs.core.get.cljs$core$IFn$_invoke$arity$2(map__104137__$1,cljs.core.cst$kw$block);
var t = cljs.core.get.cljs$core$IFn$_invoke$arity$2(map__104137__$1,cljs.core.cst$kw$t);
var flakes = cljs.core.get.cljs$core$IFn$_invoke$arity$2(map__104137__$1,cljs.core.cst$kw$flakes);
var prev_hash = cljs.core.some(((function (G__104125__$1,result_STAR___$1,map__104137,map__104137__$1,block,t,flakes,vec__104134,seq__104135,first__104136,seq__104135__$1,block_SINGLEQUOTE___$1,r__$1,result_STAR___$2,G__104125,vec__104126,seq__104127,first__104128,seq__104127__$1,block_SINGLEQUOTE_,r,result_STAR_){
return (function (p1__104117_SHARP_){
if(cljs.core._EQ_.cljs$core$IFn$_invoke$arity$2(p1__104117_SHARP_.p,(2))){
return p1__104117_SHARP_.o;
} else {
return null;
}
});})(G__104125__$1,result_STAR___$1,map__104137,map__104137__$1,block,t,flakes,vec__104134,seq__104135,first__104136,seq__104135__$1,block_SINGLEQUOTE___$1,r__$1,result_STAR___$2,G__104125,vec__104126,seq__104127,first__104128,seq__104127__$1,block_SINGLEQUOTE_,r,result_STAR_))
,flakes);
var hash = cljs.core.some(((function (G__104125__$1,result_STAR___$1,map__104137,map__104137__$1,block,t,flakes,prev_hash,vec__104134,seq__104135,first__104136,seq__104135__$1,block_SINGLEQUOTE___$1,r__$1,result_STAR___$2,G__104125,vec__104126,seq__104127,first__104128,seq__104127__$1,block_SINGLEQUOTE_,r,result_STAR_){
return (function (p1__104118_SHARP_){
if(cljs.core._EQ_.cljs$core$IFn$_invoke$arity$2(p1__104118_SHARP_.p,(1))){
return p1__104118_SHARP_.o;
} else {
return null;
}
});})(G__104125__$1,result_STAR___$1,map__104137,map__104137__$1,block,t,flakes,prev_hash,vec__104134,seq__104135,first__104136,seq__104135__$1,block_SINGLEQUOTE___$1,r__$1,result_STAR___$2,G__104125,vec__104126,seq__104127,first__104128,seq__104127__$1,block_SINGLEQUOTE_,r,result_STAR_))
,flakes);
var instant = cljs.core.some(((function (G__104125__$1,result_STAR___$1,map__104137,map__104137__$1,block,t,flakes,prev_hash,hash,vec__104134,seq__104135,first__104136,seq__104135__$1,block_SINGLEQUOTE___$1,r__$1,result_STAR___$2,G__104125,vec__104126,seq__104127,first__104128,seq__104127__$1,block_SINGLEQUOTE_,r,result_STAR_){
return (function (p1__104119_SHARP_){
if(cljs.core._EQ_.cljs$core$IFn$_invoke$arity$2(p1__104119_SHARP_.p,(5))){
return p1__104119_SHARP_.o;
} else {
return null;
}
});})(G__104125__$1,result_STAR___$1,map__104137,map__104137__$1,block,t,flakes,prev_hash,hash,vec__104134,seq__104135,first__104136,seq__104135__$1,block_SINGLEQUOTE___$1,r__$1,result_STAR___$2,G__104125,vec__104126,seq__104127,first__104128,seq__104127__$1,block_SINGLEQUOTE_,r,result_STAR_))
,flakes);
var sigs = cljs.core.some(((function (G__104125__$1,result_STAR___$1,map__104137,map__104137__$1,block,t,flakes,prev_hash,hash,instant,vec__104134,seq__104135,first__104136,seq__104135__$1,block_SINGLEQUOTE___$1,r__$1,result_STAR___$2,G__104125,vec__104126,seq__104127,first__104128,seq__104127__$1,block_SINGLEQUOTE_,r,result_STAR_){
return (function (p1__104120_SHARP_){
if(cljs.core._EQ_.cljs$core$IFn$_invoke$arity$2(p1__104120_SHARP_.p,(7))){
return p1__104120_SHARP_.o;
} else {
return null;
}
});})(G__104125__$1,result_STAR___$1,map__104137,map__104137__$1,block,t,flakes,prev_hash,hash,instant,vec__104134,seq__104135,first__104136,seq__104135__$1,block_SINGLEQUOTE___$1,r__$1,result_STAR___$2,G__104125,vec__104126,seq__104127,first__104128,seq__104127__$1,block_SINGLEQUOTE_,r,result_STAR_))
,flakes);
var txn_flakes = cljs.core.filter.cljs$core$IFn$_invoke$arity$2(((function (G__104125__$1,result_STAR___$1,map__104137,map__104137__$1,block,t,flakes,prev_hash,hash,instant,sigs,vec__104134,seq__104135,first__104136,seq__104135__$1,block_SINGLEQUOTE___$1,r__$1,result_STAR___$2,G__104125,vec__104126,seq__104127,first__104128,seq__104127__$1,block_SINGLEQUOTE_,r,result_STAR_){
return (function (p1__104121_SHARP_){
return cljs.core._EQ_.cljs$core$IFn$_invoke$arity$2(p1__104121_SHARP_.p,(106));
});})(G__104125__$1,result_STAR___$1,map__104137,map__104137__$1,block,t,flakes,prev_hash,hash,instant,sigs,vec__104134,seq__104135,first__104136,seq__104135__$1,block_SINGLEQUOTE___$1,r__$1,result_STAR___$2,G__104125,vec__104126,seq__104127,first__104128,seq__104127__$1,block_SINGLEQUOTE_,r,result_STAR_))
,flakes);
var txn_flakes_SINGLEQUOTE_ = fluree.db.query.range.txn_from_flakes(txn_flakes);
var G__104139 = r__$1;
var G__104140 = cljs.core.conj.cljs$core$IFn$_invoke$arity$2(result_STAR___$2,new cljs.core.PersistentArrayMap(null, 8, [cljs.core.cst$kw$block,block,cljs.core.cst$kw$t,t,cljs.core.cst$kw$hash,hash,cljs.core.cst$kw$prev_DASH_hash,prev_hash,cljs.core.cst$kw$instant,instant,cljs.core.cst$kw$sigs,sigs,cljs.core.cst$kw$flakes,flakes,cljs.core.cst$kw$txn,txn_flakes_SINGLEQUOTE_], null));
G__104125__$1 = G__104139;
result_STAR___$1 = G__104140;
continue;
}
break;
}
});
