// Compiled by ClojureScript 1.10.520 {:target :nodejs}
goog.provide('fluree.db.query.fql');
goog.require('cljs.core');
goog.require('fluree.db.query.fql_parser');
goog.require('fluree.db.dbproto');
goog.require('fluree.db.util.log');
goog.require('clojure.string');
goog.require('fluree.db.query.range');
goog.require('fluree.db.flake');
goog.require('fluree.db.util.core');
goog.require('clojure.set');
goog.require('fluree.db.query.analytical');
goog.require('fluree.db.query.schema');
goog.require('cljs.core.async');
goog.require('fluree.db.util.async');

/**
 * Can sit in a flake pipeline and accumulate a count of 1 for every flake pulled.
 * 
 *   Inputs are:
 *   - fuel - volatile! that holds fuel counter
 *   - max-fuel - throw exception if @fuel ever exceeds this number
 * 
 *   To get final count, just deref fuel volatile when when where is complete.
 */
fluree.db.query.fql.fuel_flake_transducer = (function fluree$db$query$fql$fuel_flake_transducer(fuel,max_fuel){
return (function (xf){
return (function() {
var G__96403 = null;
var G__96403__0 = (function (){
return xf.call(null);
});
var G__96403__1 = (function (result){
return xf.call(null,result);
});
var G__96403__2 = (function (result,flake){
cljs.core._vreset_BANG_.call(null,fuel,(cljs.core._deref.call(null,fuel) + (1)));

if(cljs.core.truth_((function (){var and__4120__auto__ = max_fuel;
if(cljs.core.truth_(and__4120__auto__)){
return (cljs.core.deref.call(null,fuel) > max_fuel);
} else {
return and__4120__auto__;
}
})())){
throw cljs.core.ex_info.call(null,["Maximum query cost of ",cljs.core.str.cljs$core$IFn$_invoke$arity$1(max_fuel)," exceeded."].join(''),new cljs.core.PersistentArrayMap(null, 2, [new cljs.core.Keyword(null,"status","status",-1997798413),(400),new cljs.core.Keyword(null,"error","error",-978969032),new cljs.core.Keyword("db","exceeded-cost","db/exceeded-cost",-915096223)], null));
} else {
}

return xf.call(null,result,flake);
});
G__96403 = function(result,flake){
switch(arguments.length){
case 0:
return G__96403__0.call(this);
case 1:
return G__96403__1.call(this,result);
case 2:
return G__96403__2.call(this,result,flake);
}
throw(new Error('Invalid arity: ' + arguments.length));
};
G__96403.cljs$core$IFn$_invoke$arity$0 = G__96403__0;
G__96403.cljs$core$IFn$_invoke$arity$1 = G__96403__1;
G__96403.cljs$core$IFn$_invoke$arity$2 = G__96403__2;
return G__96403;
})()
});
});
/**
 * Can sit in a flake group pipeline and accumulate a count of 1 for every flake pulled.
 * 
 *   Supply with a volatile!
 * 
 *   To get final count, just deref volatile when when where is complete.
 */
fluree.db.query.fql.fuel_flakes_transducer = (function fluree$db$query$fql$fuel_flakes_transducer(fuel,max_fuel){
return (function (xf){
return (function() {
var G__96404 = null;
var G__96404__0 = (function (){
return xf.call(null);
});
var G__96404__1 = (function (result){
return xf.call(null,result);
});
var G__96404__2 = (function (result,flakes){
cljs.core._vreset_BANG_.call(null,fuel,(cljs.core._deref.call(null,fuel) + cljs.core.count.call(null,flakes)));

return xf.call(null,result,flakes);
});
G__96404 = function(result,flakes){
switch(arguments.length){
case 0:
return G__96404__0.call(this);
case 1:
return G__96404__1.call(this,result);
case 2:
return G__96404__2.call(this,result,flakes);
}
throw(new Error('Invalid arity: ' + arguments.length));
};
G__96404.cljs$core$IFn$_invoke$arity$0 = G__96404__0;
G__96404.cljs$core$IFn$_invoke$arity$1 = G__96404__1;
G__96404.cljs$core$IFn$_invoke$arity$2 = G__96404__2;
return G__96404;
})()
});
});
/**
 * Adds a n amount of fuel and will throw if max fuel exceeded.
 */
fluree.db.query.fql.add_fuel = (function fluree$db$query$fql$add_fuel(fuel,n,max_fuel){
cljs.core._vreset_BANG_.call(null,fuel,(cljs.core._deref.call(null,fuel) + n));

if(cljs.core.truth_((function (){var and__4120__auto__ = max_fuel;
if(cljs.core.truth_(and__4120__auto__)){
return (cljs.core.deref.call(null,fuel) > max_fuel);
} else {
return and__4120__auto__;
}
})())){
throw cljs.core.ex_info.call(null,["Maximum query cost of ",cljs.core.str.cljs$core$IFn$_invoke$arity$1(max_fuel)," exceeded."].join(''),new cljs.core.PersistentArrayMap(null, 2, [new cljs.core.Keyword(null,"status","status",-1997798413),(400),new cljs.core.Keyword(null,"error","error",-978969032),new cljs.core.Keyword("db","exceeded-cost","db/exceeded-cost",-915096223)], null));
} else {
return null;
}
});
/**
 * Just uses query cache to avoid constant lookups.
 */
fluree.db.query.fql.wildcard_pred_spec = (function fluree$db$query$fql$wildcard_pred_spec(db,cache,p,compact_QMARK_){
var or__4131__auto__ = cljs.core.get_in.call(null,cljs.core.deref.call(null,cache),new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [p,compact_QMARK_], null));
if(cljs.core.truth_(or__4131__auto__)){
return or__4131__auto__;
} else {
var p_map = fluree.db.query.fql_parser.p__GT_pred_config.call(null,db,p,compact_QMARK_);
cljs.core._vreset_BANG_.call(null,cache,cljs.core.assoc_in.call(null,cljs.core._deref.call(null,cache),new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [p,compact_QMARK_], null),p_map));

return p_map;
}
});
fluree.db.query.fql.compare_fn = (function fluree$db$query$fql$compare_fn(a,b){
if(typeof a === 'string'){
var res = cljs.core.compare.call(null,clojure.string.upper_case.call(null,a),clojure.string.upper_case.call(null,b));
if(cljs.core._EQ_.call(null,res,(0))){
return ((-1) * cljs.core.compare.call(null,a,b));
} else {
return res;
}
} else {
return cljs.core.compare.call(null,a,b);
}
});
/**
 * We only need to do this if there is an orderBy, otherwise limit and offset
 *   were performed in index-range.
 */
fluree.db.query.fql.sort_offset_and_limit_res = (function fluree$db$query$fql$sort_offset_and_limit_res(sortPred,sortOrder,offset,limit,res){
if(cljs.core.vector_QMARK_.call(null,res)){
var G__96406 = res;
var G__96406__$1 = (cljs.core.truth_(sortPred)?cljs.core.sort_by.call(null,((function (G__96406){
return (function (p1__96405_SHARP_){
return cljs.core.get.call(null,p1__96405_SHARP_,sortPred);
});})(G__96406))
,fluree.db.query.fql.compare_fn,G__96406):G__96406);
var G__96406__$2 = ((cljs.core._EQ_.call(null,"DESC",sortOrder))?cljs.core.reverse.call(null,G__96406__$1):G__96406__$1);
var G__96406__$3 = (cljs.core.truth_(offset)?cljs.core.drop.call(null,offset,G__96406__$2):G__96406__$2);
if(cljs.core.truth_(limit)){
return cljs.core.take.call(null,limit,G__96406__$3);
} else {
return G__96406__$3;
}
} else {
return res;
}
});
fluree.db.query.fql.add_pred = (function fluree$db$query$fql$add_pred(var_args){
var G__96408 = arguments.length;
switch (G__96408) {
case 9:
return fluree.db.query.fql.add_pred.cljs$core$IFn$_invoke$arity$9((arguments[(0)]),(arguments[(1)]),(arguments[(2)]),(arguments[(3)]),(arguments[(4)]),(arguments[(5)]),(arguments[(6)]),(arguments[(7)]),(arguments[(8)]));

break;
case 10:
return fluree.db.query.fql.add_pred.cljs$core$IFn$_invoke$arity$10((arguments[(0)]),(arguments[(1)]),(arguments[(2)]),(arguments[(3)]),(arguments[(4)]),(arguments[(5)]),(arguments[(6)]),(arguments[(7)]),(arguments[(8)]),(arguments[(9)]));

break;
default:
throw (new Error(["Invalid arity: ",cljs.core.str.cljs$core$IFn$_invoke$arity$1(arguments.length)].join('')));

}
});

fluree.db.query.fql.add_pred.cljs$core$IFn$_invoke$arity$9 = (function (db,cache,fuel,max_fuel,acc,pred_spec,flake,componentFollow_QMARK_,recur_QMARK_){
return fluree.db.query.fql.add_pred.call(null,db,cache,fuel,max_fuel,acc,pred_spec,flake,componentFollow_QMARK_,recur_QMARK_,cljs.core.PersistentArrayMap.EMPTY);
});

fluree.db.query.fql.add_pred.cljs$core$IFn$_invoke$arity$10 = (function (db,cache,fuel,max_fuel,acc,pred_spec,flake,componentFollow_QMARK_,recur_QMARK_,offset_map){
var c__86675__auto__ = cljs.core.async.chan.call(null,(1));
cljs.core.async.impl.dispatch.run.call(null,((function (c__86675__auto__){
return (function (){
var f__86676__auto__ = (function (){var switch__86624__auto__ = ((function (c__86675__auto__){
return (function (state_96707){
var state_val_96708 = (state_96707[(1)]);
if((state_val_96708 === (65))){
var state_96707__$1 = state_96707;
if(cljs.core.truth_(componentFollow_QMARK_)){
var statearr_96709_96863 = state_96707__$1;
(statearr_96709_96863[(1)] = (71));

} else {
var statearr_96710_96864 = state_96707__$1;
(statearr_96710_96864[(1)] = (72));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_96708 === (70))){
var inst_96436 = (state_96707[(7)]);
var inst_96574 = (state_96707[(2)]);
var inst_96575 = fluree.db.util.async.throw_err.call(null,inst_96574);
var inst_96576 = cljs.core._deref.call(null,cache);
var inst_96577 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_96578 = flake.o;
var inst_96579 = new cljs.core.Keyword(null,"name","name",1843675177).cljs$core$IFn$_invoke$arity$1(inst_96436);
var inst_96580 = [inst_96578,inst_96579];
var inst_96581 = (new cljs.core.PersistentVector(null,2,(5),inst_96577,inst_96580,null));
var inst_96582 = cljs.core.assoc.call(null,inst_96576,inst_96581,inst_96575);
var inst_96583 = cljs.core._vreset_BANG_.call(null,cache,inst_96582);
var state_96707__$1 = (function (){var statearr_96711 = state_96707;
(statearr_96711[(8)] = inst_96583);

return statearr_96711;
})();
var statearr_96712_96865 = state_96707__$1;
(statearr_96712_96865[(2)] = inst_96575);

(statearr_96712_96865[(1)] = (69));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_96708 === (62))){
var inst_96545 = (state_96707[(9)]);
var state_96707__$1 = state_96707;
var statearr_96713_96866 = state_96707__$1;
(statearr_96713_96866[(2)] = inst_96545);

(statearr_96713_96866[(1)] = (63));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_96708 === (74))){
var inst_96436 = (state_96707[(7)]);
var inst_96595 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_96596 = flake.o;
var inst_96597 = [inst_96596];
var inst_96598 = (new cljs.core.PersistentVector(null,1,(5),inst_96595,inst_96597,null));
var inst_96599 = [new cljs.core.Keyword(null,"limit","limit",-1355822363)];
var inst_96600 = new cljs.core.Keyword(null,"limit","limit",-1355822363).cljs$core$IFn$_invoke$arity$1(inst_96436);
var inst_96601 = [inst_96600];
var inst_96602 = cljs.core.PersistentHashMap.fromArrays(inst_96599,inst_96601);
var inst_96603 = fluree.db.query.range.index_range.call(null,db,new cljs.core.Keyword(null,"spot","spot",-1706962147),cljs.core._EQ_,inst_96598,inst_96602);
var state_96707__$1 = state_96707;
return cljs.core.async.impl.ioc_helpers.take_BANG_.call(null,state_96707__$1,(77),inst_96603);
} else {
if((state_val_96708 === (7))){
var inst_96423 = (state_96707[(2)]);
var state_96707__$1 = state_96707;
if(cljs.core.truth_(inst_96423)){
var statearr_96714_96867 = state_96707__$1;
(statearr_96714_96867[(1)] = (8));

} else {
var statearr_96715_96868 = state_96707__$1;
(statearr_96715_96868[(1)] = (9));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_96708 === (59))){
var inst_96539 = (state_96707[(10)]);
var state_96707__$1 = state_96707;
var statearr_96716_96869 = state_96707__$1;
(statearr_96716_96869[(2)] = inst_96539);

(statearr_96716_96869[(1)] = (60));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_96708 === (86))){
var inst_96624 = (state_96707[(11)]);
var state_96707__$1 = state_96707;
var statearr_96717_96870 = state_96707__$1;
(statearr_96717_96870[(2)] = inst_96624);

(statearr_96717_96870[(1)] = (87));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_96708 === (20))){
var inst_96436 = (state_96707[(7)]);
var inst_96452 = inst_96436.cljs$lang$protocol_mask$partition0$;
var inst_96453 = (inst_96452 & (64));
var inst_96454 = inst_96436.cljs$core$ISeq$;
var inst_96455 = (cljs.core.PROTOCOL_SENTINEL === inst_96454);
var inst_96456 = ((inst_96453) || (inst_96455));
var state_96707__$1 = state_96707;
if(cljs.core.truth_(inst_96456)){
var statearr_96718_96871 = state_96707__$1;
(statearr_96718_96871[(1)] = (23));

} else {
var statearr_96719_96872 = state_96707__$1;
(statearr_96719_96872[(1)] = (24));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_96708 === (72))){
var state_96707__$1 = state_96707;
var statearr_96720_96873 = state_96707__$1;
(statearr_96720_96873[(2)] = componentFollow_QMARK_);

(statearr_96720_96873[(1)] = (73));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_96708 === (58))){
var inst_96539 = (state_96707[(10)]);
var inst_96541 = fluree.db.query.fql.fuel_flake_transducer.call(null,fuel,max_fuel);
var inst_96542 = cljs.core.sequence.call(null,inst_96541,inst_96539);
var state_96707__$1 = state_96707;
var statearr_96721_96874 = state_96707__$1;
(statearr_96721_96874[(2)] = inst_96542);

(statearr_96721_96874[(1)] = (60));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_96708 === (60))){
var inst_96545 = (state_96707[(2)]);
var state_96707__$1 = (function (){var statearr_96722 = state_96707;
(statearr_96722[(9)] = inst_96545);

return statearr_96722;
})();
var statearr_96723_96875 = state_96707__$1;
(statearr_96723_96875[(1)] = (61));



return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_96708 === (27))){
var inst_96436 = (state_96707[(7)]);
var state_96707__$1 = state_96707;
var statearr_96725_96876 = state_96707__$1;
(statearr_96725_96876[(2)] = inst_96436);

(statearr_96725_96876[(1)] = (28));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_96708 === (1))){
var state_96707__$1 = state_96707;
var statearr_96726_96877 = state_96707__$1;
(statearr_96726_96877[(2)] = null);

(statearr_96726_96877[(1)] = (4));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_96708 === (69))){
var inst_96560 = (state_96707[(12)]);
var inst_96585 = (state_96707[(2)]);
var inst_96586 = [inst_96585,offset_map];
var inst_96587 = (new cljs.core.PersistentVector(null,2,(5),inst_96560,inst_96586,null));
var state_96707__$1 = state_96707;
var statearr_96727_96878 = state_96707__$1;
(statearr_96727_96878[(2)] = inst_96587);

(statearr_96727_96878[(1)] = (66));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_96708 === (101))){
var state_96707__$1 = state_96707;
var statearr_96728_96879 = state_96707__$1;
(statearr_96728_96879[(1)] = (103));



return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_96708 === (24))){
var state_96707__$1 = state_96707;
var statearr_96730_96880 = state_96707__$1;
(statearr_96730_96880[(2)] = false);

(statearr_96730_96880[(1)] = (25));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_96708 === (102))){
var inst_96701 = (state_96707[(2)]);
var state_96707__$1 = state_96707;
var statearr_96731_96881 = state_96707__$1;
(statearr_96731_96881[(2)] = inst_96701);

(statearr_96731_96881[(1)] = (99));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_96708 === (55))){
var inst_96663 = (state_96707[(2)]);
var state_96707__$1 = state_96707;
var statearr_96732_96882 = state_96707__$1;
(statearr_96732_96882[(2)] = inst_96663);

(statearr_96732_96882[(1)] = (46));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_96708 === (85))){
var inst_96606 = (state_96707[(13)]);
var inst_96473 = (state_96707[(14)]);
var inst_96474 = (state_96707[(15)]);
var inst_96469 = (state_96707[(16)]);
var inst_96471 = (state_96707[(17)]);
var inst_96472 = (state_96707[(18)]);
var inst_96436 = (state_96707[(7)]);
var inst_96624 = (state_96707[(11)]);
var inst_96470 = (state_96707[(19)]);
var inst_96430 = (state_96707[(20)]);
var inst_96447 = (state_96707[(21)]);
var inst_96468 = (state_96707[(22)]);
var inst_96626 = (function (){var p = inst_96474;
var pred_spec__$1 = inst_96430;
var orderBy = inst_96472;
var children = inst_96606;
var multi_QMARK_ = inst_96469;
var limit = inst_96471;
var offset = inst_96473;
var k = inst_96447;
var pred_spec_SINGLEQUOTE_ = inst_96436;
var G__96618 = inst_96624;
var map__96413 = inst_96468;
var ref_QMARK_ = inst_96470;
return ((function (p,pred_spec__$1,orderBy,children,multi_QMARK_,limit,offset,k,pred_spec_SINGLEQUOTE_,G__96618,map__96413,ref_QMARK_,inst_96606,inst_96473,inst_96474,inst_96469,inst_96471,inst_96472,inst_96436,inst_96624,inst_96470,inst_96430,inst_96447,inst_96468,state_val_96708,c__86675__auto__){
return (function (n){
return fluree.db.query.fql.flakes__GT_res.call(null,db,cache,fuel,max_fuel,new cljs.core.PersistentArrayMap(null, 1, [new cljs.core.Keyword(null,"wildcard?","wildcard?",-686044101),true], null),n);
});
;})(p,pred_spec__$1,orderBy,children,multi_QMARK_,limit,offset,k,pred_spec_SINGLEQUOTE_,G__96618,map__96413,ref_QMARK_,inst_96606,inst_96473,inst_96474,inst_96469,inst_96471,inst_96472,inst_96436,inst_96624,inst_96470,inst_96430,inst_96447,inst_96468,state_val_96708,c__86675__auto__))
})();
var inst_96627 = inst_96626.call(null,inst_96624);
var state_96707__$1 = state_96707;
var statearr_96733_96883 = state_96707__$1;
(statearr_96733_96883[(2)] = inst_96627);

(statearr_96733_96883[(1)] = (87));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_96708 === (39))){
var inst_96473 = (state_96707[(14)]);
var inst_96474 = (state_96707[(15)]);
var inst_96493 = (inst_96473 - (1));
var inst_96494 = cljs.core.assoc.call(null,offset_map,inst_96474,inst_96493);
var state_96707__$1 = state_96707;
var statearr_96734_96884 = state_96707__$1;
(statearr_96734_96884[(2)] = inst_96494);

(statearr_96734_96884[(1)] = (40));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_96708 === (88))){
var inst_96640 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_96641 = ["_id"];
var inst_96642 = flake.o;
var inst_96643 = [inst_96642];
var inst_96644 = cljs.core.PersistentHashMap.fromArrays(inst_96641,inst_96643);
var inst_96645 = [inst_96644,offset_map];
var inst_96646 = (new cljs.core.PersistentVector(null,2,(5),inst_96640,inst_96645,null));
var state_96707__$1 = state_96707;
var statearr_96735_96885 = state_96707__$1;
(statearr_96735_96885[(2)] = inst_96646);

(statearr_96735_96885[(1)] = (90));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_96708 === (46))){
var inst_96665 = (state_96707[(2)]);
var state_96707__$1 = state_96707;
var statearr_96736_96886 = state_96707__$1;
(statearr_96736_96886[(2)] = inst_96665);

(statearr_96736_96886[(1)] = (37));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_96708 === (4))){
var inst_96417 = (state_96707[(23)]);
var _ = cljs.core.async.impl.ioc_helpers.add_exception_frame.call(null,state_96707,(3),Error,null,(2));
var inst_96417__$1 = new cljs.core.Keyword(null,"wildcard?","wildcard?",-686044101).cljs$core$IFn$_invoke$arity$1(pred_spec);
var state_96707__$1 = (function (){var statearr_96737 = state_96707;
(statearr_96737[(23)] = inst_96417__$1);

return statearr_96737;
})();
if(cljs.core.truth_(inst_96417__$1)){
var statearr_96738_96887 = state_96707__$1;
(statearr_96738_96887[(1)] = (5));

} else {
var statearr_96739_96888 = state_96707__$1;
(statearr_96739_96888[(1)] = (6));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_96708 === (77))){
var inst_96606 = (state_96707[(13)]);
var inst_96605 = (state_96707[(2)]);
var inst_96606__$1 = fluree.db.util.async.throw_err.call(null,inst_96605);
var inst_96607 = cljs.core.empty_QMARK_.call(null,inst_96606__$1);
var state_96707__$1 = (function (){var statearr_96740 = state_96707;
(statearr_96740[(13)] = inst_96606__$1);

return statearr_96740;
})();
if(inst_96607){
var statearr_96741_96889 = state_96707__$1;
(statearr_96741_96889[(1)] = (78));

} else {
var statearr_96742_96890 = state_96707__$1;
(statearr_96742_96890[(1)] = (79));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_96708 === (95))){
var inst_96671 = (state_96707[(24)]);
var state_96707__$1 = state_96707;
var statearr_96743_96891 = state_96707__$1;
(statearr_96743_96891[(2)] = inst_96671);

(statearr_96743_96891[(1)] = (96));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_96708 === (54))){
var inst_96436 = (state_96707[(7)]);
var inst_96558 = new cljs.core.Keyword(null,"tag?","tag?",1714008252).cljs$core$IFn$_invoke$arity$1(inst_96436);
var state_96707__$1 = state_96707;
if(cljs.core.truth_(inst_96558)){
var statearr_96744_96892 = state_96707__$1;
(statearr_96744_96892[(1)] = (64));

} else {
var statearr_96745_96893 = state_96707__$1;
(statearr_96745_96893[(1)] = (65));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_96708 === (92))){
var state_96707__$1 = state_96707;
var statearr_96746_96894 = state_96707__$1;
(statearr_96746_96894[(2)] = null);

(statearr_96746_96894[(1)] = (93));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_96708 === (104))){
var state_96707__$1 = state_96707;
var statearr_96747_96895 = state_96707__$1;
(statearr_96747_96895[(2)] = null);

(statearr_96747_96895[(1)] = (105));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_96708 === (15))){
var inst_96436 = (state_96707[(7)]);
var inst_96440 = (state_96707[(25)]);
var inst_96440__$1 = new cljs.core.Keyword(null,"name","name",1843675177).cljs$core$IFn$_invoke$arity$1(inst_96436);
var state_96707__$1 = (function (){var statearr_96748 = state_96707;
(statearr_96748[(25)] = inst_96440__$1);

return statearr_96748;
})();
if(cljs.core.truth_(inst_96440__$1)){
var statearr_96749_96896 = state_96707__$1;
(statearr_96749_96896[(1)] = (17));

} else {
var statearr_96750_96897 = state_96707__$1;
(statearr_96750_96897[(1)] = (18));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_96708 === (48))){
var inst_96514 = (state_96707[(26)]);
var state_96707__$1 = state_96707;
var statearr_96751_96898 = state_96707__$1;
(statearr_96751_96898[(2)] = inst_96514);

(statearr_96751_96898[(1)] = (49));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_96708 === (50))){
var inst_96516 = (state_96707[(27)]);
var state_96707__$1 = state_96707;
var statearr_96752_96899 = state_96707__$1;
(statearr_96752_96899[(2)] = inst_96516);

(statearr_96752_96899[(1)] = (52));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_96708 === (75))){
var inst_96470 = (state_96707[(19)]);
var state_96707__$1 = state_96707;
if(cljs.core.truth_(inst_96470)){
var statearr_96753_96900 = state_96707__$1;
(statearr_96753_96900[(1)] = (88));

} else {
var statearr_96754_96901 = state_96707__$1;
(statearr_96754_96901[(1)] = (89));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_96708 === (99))){
var inst_96703 = (state_96707[(2)]);
var state_96707__$1 = state_96707;
var statearr_96755_96902 = state_96707__$1;
(statearr_96755_96902[(2)] = inst_96703);


cljs.core.async.impl.ioc_helpers.process_exception.call(null,state_96707__$1);

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_96708 === (21))){
var state_96707__$1 = state_96707;
var statearr_96756_96903 = state_96707__$1;
(statearr_96756_96903[(2)] = false);

(statearr_96756_96903[(1)] = (22));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_96708 === (31))){
var inst_96486 = (state_96707[(2)]);
var state_96707__$1 = state_96707;
if(cljs.core.truth_(inst_96486)){
var statearr_96757_96904 = state_96707__$1;
(statearr_96757_96904[(1)] = (35));

} else {
var statearr_96758_96905 = state_96707__$1;
(statearr_96758_96905[(1)] = (36));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_96708 === (32))){
var inst_96473 = (state_96707[(14)]);
var inst_96474 = (state_96707[(15)]);
var inst_96477 = cljs.core.not_EQ_.call(null,(0),inst_96473);
var inst_96478 = cljs.core.get.call(null,offset_map,inst_96474);
var inst_96479 = cljs.core.not_EQ_.call(null,(0),inst_96478);
var inst_96480 = ((inst_96477) && (inst_96479));
var state_96707__$1 = state_96707;
var statearr_96759_96906 = state_96707__$1;
(statearr_96759_96906[(2)] = inst_96480);

(statearr_96759_96906[(1)] = (34));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_96708 === (40))){
var inst_96488 = (state_96707[(28)]);
var inst_96496 = (state_96707[(2)]);
var inst_96497 = [null,inst_96496];
var inst_96498 = (new cljs.core.PersistentVector(null,2,(5),inst_96488,inst_96497,null));
var state_96707__$1 = state_96707;
var statearr_96760_96907 = state_96707__$1;
(statearr_96760_96907[(2)] = inst_96498);

(statearr_96760_96907[(1)] = (37));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_96708 === (91))){
var inst_96649 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_96650 = flake.o;
var inst_96651 = [inst_96650,offset_map];
var inst_96652 = (new cljs.core.PersistentVector(null,2,(5),inst_96649,inst_96651,null));
var state_96707__$1 = state_96707;
var statearr_96761_96908 = state_96707__$1;
(statearr_96761_96908[(2)] = inst_96652);

(statearr_96761_96908[(1)] = (93));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_96708 === (56))){
var inst_96530 = (state_96707[(29)]);
var inst_96553 = (state_96707[(2)]);
var inst_96554 = fluree.db.util.async.throw_err.call(null,inst_96553);
var inst_96555 = [inst_96554,offset_map];
var inst_96556 = (new cljs.core.PersistentVector(null,2,(5),inst_96530,inst_96555,null));
var state_96707__$1 = state_96707;
var statearr_96762_96909 = state_96707__$1;
(statearr_96762_96909[(2)] = inst_96556);

(statearr_96762_96909[(1)] = (55));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_96708 === (33))){
var inst_96473 = (state_96707[(14)]);
var state_96707__$1 = state_96707;
var statearr_96763_96910 = state_96707__$1;
(statearr_96763_96910[(2)] = inst_96473);

(statearr_96763_96910[(1)] = (34));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_96708 === (13))){
var inst_96437 = (state_96707[(30)]);
var inst_96436 = (state_96707[(7)]);
var inst_96436__$1 = (state_96707[(2)]);
var inst_96437__$1 = new cljs.core.Keyword(null,"as","as",1148689641).cljs$core$IFn$_invoke$arity$1(inst_96436__$1);
var state_96707__$1 = (function (){var statearr_96764 = state_96707;
(statearr_96764[(30)] = inst_96437__$1);

(statearr_96764[(7)] = inst_96436__$1);

return statearr_96764;
})();
if(cljs.core.truth_(inst_96437__$1)){
var statearr_96765_96911 = state_96707__$1;
(statearr_96765_96911[(1)] = (14));

} else {
var statearr_96766_96912 = state_96707__$1;
(statearr_96766_96912[(1)] = (15));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_96708 === (22))){
var inst_96463 = (state_96707[(2)]);
var state_96707__$1 = state_96707;
if(cljs.core.truth_(inst_96463)){
var statearr_96767_96913 = state_96707__$1;
(statearr_96767_96913[(1)] = (26));

} else {
var statearr_96768_96914 = state_96707__$1;
(statearr_96768_96914[(1)] = (27));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_96708 === (90))){
var inst_96657 = (state_96707[(2)]);
var state_96707__$1 = state_96707;
var statearr_96769_96915 = state_96707__$1;
(statearr_96769_96915[(2)] = inst_96657);

(statearr_96769_96915[(1)] = (76));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_96708 === (36))){
var inst_96469 = (state_96707[(16)]);
var state_96707__$1 = state_96707;
if(cljs.core.truth_(inst_96469)){
var statearr_96770_96916 = state_96707__$1;
(statearr_96770_96916[(1)] = (41));

} else {
var statearr_96771_96917 = state_96707__$1;
(statearr_96771_96917[(1)] = (42));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_96708 === (41))){
var inst_96471 = (state_96707[(17)]);
var inst_96472 = (state_96707[(18)]);
var inst_96447 = (state_96707[(21)]);
var inst_96501 = cljs.core.not.call(null,inst_96472);
var inst_96502 = cljs.core.get.call(null,acc,inst_96447);
var inst_96503 = cljs.core.count.call(null,inst_96502);
var inst_96504 = (inst_96503 >= inst_96471);
var inst_96505 = ((inst_96501) && (inst_96504));
var state_96707__$1 = state_96707;
var statearr_96772_96918 = state_96707__$1;
(statearr_96772_96918[(2)] = inst_96505);

(statearr_96772_96918[(1)] = (43));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_96708 === (89))){
var state_96707__$1 = state_96707;
var statearr_96773_96919 = state_96707__$1;
(statearr_96773_96919[(1)] = (91));



return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_96708 === (100))){
var inst_96669 = (state_96707[(31)]);
var inst_96447 = (state_96707[(21)]);
var inst_96668 = (state_96707[(32)]);
var inst_96688 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_96689 = cljs.core.assoc.call(null,acc,inst_96447,inst_96668);
var inst_96690 = [inst_96689,inst_96669];
var inst_96691 = (new cljs.core.PersistentVector(null,2,(5),inst_96688,inst_96690,null));
var state_96707__$1 = state_96707;
var statearr_96775_96920 = state_96707__$1;
(statearr_96775_96920[(2)] = inst_96691);

(statearr_96775_96920[(1)] = (102));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_96708 === (43))){
var inst_96508 = (state_96707[(2)]);
var state_96707__$1 = state_96707;
if(cljs.core.truth_(inst_96508)){
var statearr_96776_96921 = state_96707__$1;
(statearr_96776_96921[(1)] = (44));

} else {
var statearr_96777_96922 = state_96707__$1;
(statearr_96777_96922[(1)] = (45));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_96708 === (61))){
var inst_96473 = (state_96707[(14)]);
var inst_96545 = (state_96707[(9)]);
var inst_96529 = (state_96707[(33)]);
var inst_96474 = (state_96707[(15)]);
var inst_96469 = (state_96707[(16)]);
var inst_96471 = (state_96707[(17)]);
var inst_96472 = (state_96707[(18)]);
var inst_96436 = (state_96707[(7)]);
var inst_96470 = (state_96707[(19)]);
var inst_96430 = (state_96707[(20)]);
var inst_96447 = (state_96707[(21)]);
var inst_96468 = (state_96707[(22)]);
var inst_96547 = (function (){var p = inst_96474;
var pred_spec__$1 = inst_96430;
var orderBy = inst_96472;
var nested_select_spec = inst_96529;
var multi_QMARK_ = inst_96469;
var limit = inst_96471;
var offset = inst_96473;
var G__96531 = inst_96545;
var k = inst_96447;
var pred_spec_SINGLEQUOTE_ = inst_96436;
var map__96413 = inst_96468;
var ref_QMARK_ = inst_96470;
return ((function (p,pred_spec__$1,orderBy,nested_select_spec,multi_QMARK_,limit,offset,G__96531,k,pred_spec_SINGLEQUOTE_,map__96413,ref_QMARK_,inst_96473,inst_96545,inst_96529,inst_96474,inst_96469,inst_96471,inst_96472,inst_96436,inst_96470,inst_96430,inst_96447,inst_96468,state_val_96708,c__86675__auto__){
return (function (n){
return fluree.db.query.fql.flakes__GT_res.call(null,db,cache,fuel,max_fuel,nested_select_spec,n);
});
;})(p,pred_spec__$1,orderBy,nested_select_spec,multi_QMARK_,limit,offset,G__96531,k,pred_spec_SINGLEQUOTE_,map__96413,ref_QMARK_,inst_96473,inst_96545,inst_96529,inst_96474,inst_96469,inst_96471,inst_96472,inst_96436,inst_96470,inst_96430,inst_96447,inst_96468,state_val_96708,c__86675__auto__))
})();
var inst_96548 = inst_96547.call(null,inst_96545);
var state_96707__$1 = state_96707;
var statearr_96778_96923 = state_96707__$1;
(statearr_96778_96923[(2)] = inst_96548);

(statearr_96778_96923[(1)] = (63));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_96708 === (29))){
var inst_96473 = (state_96707[(14)]);
var state_96707__$1 = state_96707;
if(cljs.core.truth_(inst_96473)){
var statearr_96779_96924 = state_96707__$1;
(statearr_96779_96924[(1)] = (32));

} else {
var statearr_96780_96925 = state_96707__$1;
(statearr_96780_96925[(1)] = (33));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_96708 === (44))){
var inst_96510 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_96511 = [null,offset_map];
var inst_96512 = (new cljs.core.PersistentVector(null,2,(5),inst_96510,inst_96511,null));
var state_96707__$1 = state_96707;
var statearr_96781_96926 = state_96707__$1;
(statearr_96781_96926[(2)] = inst_96512);

(statearr_96781_96926[(1)] = (46));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_96708 === (93))){
var inst_96655 = (state_96707[(2)]);
var state_96707__$1 = state_96707;
var statearr_96782_96927 = state_96707__$1;
(statearr_96782_96927[(2)] = inst_96655);

(statearr_96782_96927[(1)] = (90));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_96708 === (6))){
var inst_96417 = (state_96707[(23)]);
var state_96707__$1 = state_96707;
var statearr_96783_96928 = state_96707__$1;
(statearr_96783_96928[(2)] = inst_96417);

(statearr_96783_96928[(1)] = (7));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_96708 === (28))){
var inst_96469 = (state_96707[(16)]);
var inst_96468 = (state_96707[(22)]);
var inst_96468__$1 = (state_96707[(2)]);
var inst_96469__$1 = cljs.core.get.call(null,inst_96468__$1,new cljs.core.Keyword(null,"multi?","multi?",-749311069));
var inst_96470 = cljs.core.get.call(null,inst_96468__$1,new cljs.core.Keyword(null,"ref?","ref?",1932693720));
var inst_96471 = cljs.core.get.call(null,inst_96468__$1,new cljs.core.Keyword(null,"limit","limit",-1355822363));
var inst_96472 = cljs.core.get.call(null,inst_96468__$1,new cljs.core.Keyword(null,"orderBy","orderBy",-1329797793));
var inst_96473 = cljs.core.get.call(null,inst_96468__$1,new cljs.core.Keyword(null,"offset","offset",296498311));
var inst_96474 = cljs.core.get.call(null,inst_96468__$1,new cljs.core.Keyword(null,"p","p",151049309));
var state_96707__$1 = (function (){var statearr_96784 = state_96707;
(statearr_96784[(14)] = inst_96473);

(statearr_96784[(15)] = inst_96474);

(statearr_96784[(16)] = inst_96469__$1);

(statearr_96784[(17)] = inst_96471);

(statearr_96784[(18)] = inst_96472);

(statearr_96784[(19)] = inst_96470);

(statearr_96784[(22)] = inst_96468__$1);

return statearr_96784;
})();
if(cljs.core.truth_(inst_96469__$1)){
var statearr_96785_96929 = state_96707__$1;
(statearr_96785_96929[(1)] = (29));

} else {
var statearr_96786_96930 = state_96707__$1;
(statearr_96786_96930[(1)] = (30));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_96708 === (64))){
var inst_96436 = (state_96707[(7)]);
var inst_96567 = (state_96707[(34)]);
var inst_96560 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_96561 = cljs.core.deref.call(null,cache);
var inst_96562 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_96563 = flake.o;
var inst_96564 = new cljs.core.Keyword(null,"name","name",1843675177).cljs$core$IFn$_invoke$arity$1(inst_96436);
var inst_96565 = [inst_96563,inst_96564];
var inst_96566 = (new cljs.core.PersistentVector(null,2,(5),inst_96562,inst_96565,null));
var inst_96567__$1 = cljs.core.get.call(null,inst_96561,inst_96566);
var state_96707__$1 = (function (){var statearr_96787 = state_96707;
(statearr_96787[(34)] = inst_96567__$1);

(statearr_96787[(12)] = inst_96560);

return statearr_96787;
})();
if(cljs.core.truth_(inst_96567__$1)){
var statearr_96788_96931 = state_96707__$1;
(statearr_96788_96931[(1)] = (67));

} else {
var statearr_96789_96932 = state_96707__$1;
(statearr_96789_96932[(1)] = (68));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_96708 === (103))){
var inst_96669 = (state_96707[(31)]);
var inst_96694 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_96695 = [acc,inst_96669];
var inst_96696 = (new cljs.core.PersistentVector(null,2,(5),inst_96694,inst_96695,null));
var state_96707__$1 = state_96707;
var statearr_96790_96933 = state_96707__$1;
(statearr_96790_96933[(2)] = inst_96696);

(statearr_96790_96933[(1)] = (105));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_96708 === (51))){
var inst_96436 = (state_96707[(7)]);
var inst_96519 = new cljs.core.Keyword(null,"wildcard?","wildcard?",-686044101).cljs$core$IFn$_invoke$arity$1(inst_96436);
var state_96707__$1 = state_96707;
var statearr_96791_96934 = state_96707__$1;
(statearr_96791_96934[(2)] = inst_96519);

(statearr_96791_96934[(1)] = (52));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_96708 === (25))){
var inst_96460 = (state_96707[(2)]);
var state_96707__$1 = state_96707;
var statearr_96792_96935 = state_96707__$1;
(statearr_96792_96935[(2)] = inst_96460);

(statearr_96792_96935[(1)] = (22));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_96708 === (34))){
var inst_96483 = (state_96707[(2)]);
var state_96707__$1 = state_96707;
var statearr_96793_96936 = state_96707__$1;
(statearr_96793_96936[(2)] = inst_96483);

(statearr_96793_96936[(1)] = (31));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_96708 === (17))){
var inst_96440 = (state_96707[(25)]);
var state_96707__$1 = state_96707;
var statearr_96794_96937 = state_96707__$1;
(statearr_96794_96937[(2)] = inst_96440);

(statearr_96794_96937[(1)] = (19));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_96708 === (3))){
var inst_96409 = (state_96707[(2)]);
var state_96707__$1 = state_96707;
var statearr_96795_96938 = state_96707__$1;
(statearr_96795_96938[(2)] = inst_96409);


cljs.core.async.impl.ioc_helpers.process_exception.call(null,state_96707__$1);

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_96708 === (12))){
var inst_96430 = (state_96707[(20)]);
var inst_96434 = cljs.core.assoc.call(null,inst_96430,new cljs.core.Keyword(null,"componentFollow?","componentFollow?",-1486906651),componentFollow_QMARK_);
var state_96707__$1 = state_96707;
var statearr_96796_96939 = state_96707__$1;
(statearr_96796_96939[(2)] = inst_96434);

(statearr_96796_96939[(1)] = (13));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_96708 === (2))){
var inst_96705 = (state_96707[(2)]);
var state_96707__$1 = state_96707;
return cljs.core.async.impl.ioc_helpers.return_chan.call(null,state_96707__$1,inst_96705);
} else {
if((state_val_96708 === (66))){
var inst_96661 = (state_96707[(2)]);
var state_96707__$1 = state_96707;
var statearr_96797_96940 = state_96707__$1;
(statearr_96797_96940[(2)] = inst_96661);

(statearr_96797_96940[(1)] = (55));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_96708 === (23))){
var state_96707__$1 = state_96707;
var statearr_96798_96941 = state_96707__$1;
(statearr_96798_96941[(2)] = true);

(statearr_96798_96941[(1)] = (25));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_96708 === (47))){
var inst_96436 = (state_96707[(7)]);
var inst_96516 = (state_96707[(27)]);
var inst_96516__$1 = new cljs.core.Keyword(null,"select","select",1147833503).cljs$core$IFn$_invoke$arity$1(inst_96436);
var state_96707__$1 = (function (){var statearr_96799 = state_96707;
(statearr_96799[(27)] = inst_96516__$1);

return statearr_96799;
})();
if(cljs.core.truth_(inst_96516__$1)){
var statearr_96800_96942 = state_96707__$1;
(statearr_96800_96942[(1)] = (50));

} else {
var statearr_96801_96943 = state_96707__$1;
(statearr_96801_96943[(1)] = (51));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_96708 === (35))){
var inst_96474 = (state_96707[(15)]);
var inst_96488 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_96489 = cljs.core.get.call(null,offset_map,inst_96474);
var state_96707__$1 = (function (){var statearr_96802 = state_96707;
(statearr_96802[(28)] = inst_96488);

return statearr_96802;
})();
if(cljs.core.truth_(inst_96489)){
var statearr_96803_96944 = state_96707__$1;
(statearr_96803_96944[(1)] = (38));

} else {
var statearr_96804_96945 = state_96707__$1;
(statearr_96804_96945[(1)] = (39));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_96708 === (82))){
var inst_96606 = (state_96707[(13)]);
var inst_96620 = fluree.db.query.fql.fuel_flake_transducer.call(null,fuel,max_fuel);
var inst_96621 = cljs.core.sequence.call(null,inst_96620,inst_96606);
var state_96707__$1 = state_96707;
var statearr_96805_96946 = state_96707__$1;
(statearr_96805_96946[(2)] = inst_96621);

(statearr_96805_96946[(1)] = (84));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_96708 === (76))){
var inst_96659 = (state_96707[(2)]);
var state_96707__$1 = state_96707;
var statearr_96806_96947 = state_96707__$1;
(statearr_96806_96947[(2)] = inst_96659);

(statearr_96806_96947[(1)] = (66));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_96708 === (97))){
var inst_96669 = (state_96707[(31)]);
var inst_96447 = (state_96707[(21)]);
var inst_96668 = (state_96707[(32)]);
var inst_96677 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_96678 = cljs.core.PersistentVector.EMPTY;
var inst_96679 = cljs.core.get.call(null,acc,inst_96447,inst_96678);
var inst_96680 = cljs.core.conj.call(null,inst_96679,inst_96668);
var inst_96681 = cljs.core.assoc.call(null,acc,inst_96447,inst_96680);
var inst_96682 = [inst_96681,inst_96669];
var inst_96683 = (new cljs.core.PersistentVector(null,2,(5),inst_96677,inst_96682,null));
var state_96707__$1 = state_96707;
var statearr_96807_96948 = state_96707__$1;
(statearr_96807_96948[(2)] = inst_96683);

(statearr_96807_96948[(1)] = (99));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_96708 === (19))){
var inst_96445 = (state_96707[(2)]);
var state_96707__$1 = state_96707;
var statearr_96808_96949 = state_96707__$1;
(statearr_96808_96949[(2)] = inst_96445);

(statearr_96808_96949[(1)] = (16));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_96708 === (57))){
var inst_96538 = (state_96707[(2)]);
var inst_96539 = fluree.db.util.async.throw_err.call(null,inst_96538);
var state_96707__$1 = (function (){var statearr_96809 = state_96707;
(statearr_96809[(10)] = inst_96539);

return statearr_96809;
})();
if(cljs.core.truth_(fuel)){
var statearr_96810_96950 = state_96707__$1;
(statearr_96810_96950[(1)] = (58));

} else {
var statearr_96811_96951 = state_96707__$1;
(statearr_96811_96951[(1)] = (59));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_96708 === (68))){
var inst_96436 = (state_96707[(7)]);
var inst_96570 = flake.o;
var inst_96571 = new cljs.core.Keyword(null,"name","name",1843675177).cljs$core$IFn$_invoke$arity$1(inst_96436);
var inst_96572 = fluree.db.dbproto._tag.call(null,db,inst_96570,inst_96571);
var state_96707__$1 = state_96707;
return cljs.core.async.impl.ioc_helpers.take_BANG_.call(null,state_96707__$1,(70),inst_96572);
} else {
if((state_val_96708 === (11))){
var inst_96430 = (state_96707[(20)]);
var state_96707__$1 = state_96707;
var statearr_96812_96952 = state_96707__$1;
(statearr_96812_96952[(2)] = inst_96430);

(statearr_96812_96952[(1)] = (13));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_96708 === (9))){
var state_96707__$1 = state_96707;
var statearr_96813_96953 = state_96707__$1;
(statearr_96813_96953[(2)] = pred_spec);

(statearr_96813_96953[(1)] = (10));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_96708 === (5))){
var inst_96419 = new cljs.core.Keyword(null,"as","as",1148689641).cljs$core$IFn$_invoke$arity$1(pred_spec);
var inst_96420 = (inst_96419 == null);
var state_96707__$1 = state_96707;
var statearr_96814_96954 = state_96707__$1;
(statearr_96814_96954[(2)] = inst_96420);

(statearr_96814_96954[(1)] = (7));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_96708 === (83))){
var inst_96606 = (state_96707[(13)]);
var state_96707__$1 = state_96707;
var statearr_96815_96955 = state_96707__$1;
(statearr_96815_96955[(2)] = inst_96606);

(statearr_96815_96955[(1)] = (84));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_96708 === (14))){
var inst_96437 = (state_96707[(30)]);
var state_96707__$1 = state_96707;
var statearr_96816_96956 = state_96707__$1;
(statearr_96816_96956[(2)] = inst_96437);

(statearr_96816_96956[(1)] = (16));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_96708 === (45))){
var inst_96514 = (state_96707[(26)]);
var inst_96514__$1 = cljs.core.not.call(null,recur_QMARK_);
var state_96707__$1 = (function (){var statearr_96817 = state_96707;
(statearr_96817[(26)] = inst_96514__$1);

return statearr_96817;
})();
if(inst_96514__$1){
var statearr_96818_96957 = state_96707__$1;
(statearr_96818_96957[(1)] = (47));

} else {
var statearr_96819_96958 = state_96707__$1;
(statearr_96819_96958[(1)] = (48));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_96708 === (53))){
var inst_96436 = (state_96707[(7)]);
var inst_96526 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_96527 = [new cljs.core.Keyword(null,"wildcard?","wildcard?",-686044101),new cljs.core.Keyword(null,"compact?","compact?",1216893298),new cljs.core.Keyword(null,"select","select",1147833503)];
var inst_96528 = (new cljs.core.PersistentVector(null,3,(5),inst_96526,inst_96527,null));
var inst_96529 = cljs.core.select_keys.call(null,inst_96436,inst_96528);
var inst_96530 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_96532 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_96533 = flake.o;
var inst_96534 = [inst_96533];
var inst_96535 = (new cljs.core.PersistentVector(null,1,(5),inst_96532,inst_96534,null));
var inst_96536 = fluree.db.query.range.index_range.call(null,db,new cljs.core.Keyword(null,"spot","spot",-1706962147),cljs.core._EQ_,inst_96535);
var state_96707__$1 = (function (){var statearr_96820 = state_96707;
(statearr_96820[(33)] = inst_96529);

(statearr_96820[(29)] = inst_96530);

return statearr_96820;
})();
return cljs.core.async.impl.ioc_helpers.take_BANG_.call(null,state_96707__$1,(57),inst_96536);
} else {
if((state_val_96708 === (78))){
var inst_96609 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_96610 = ["_id"];
var inst_96611 = flake.o;
var inst_96612 = [inst_96611];
var inst_96613 = cljs.core.PersistentHashMap.fromArrays(inst_96610,inst_96612);
var inst_96614 = [inst_96613,offset_map];
var inst_96615 = (new cljs.core.PersistentVector(null,2,(5),inst_96609,inst_96614,null));
var state_96707__$1 = state_96707;
var statearr_96821_96959 = state_96707__$1;
(statearr_96821_96959[(2)] = inst_96615);

(statearr_96821_96959[(1)] = (80));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_96708 === (26))){
var inst_96436 = (state_96707[(7)]);
var inst_96465 = cljs.core.apply.call(null,cljs.core.hash_map,inst_96436);
var state_96707__$1 = state_96707;
var statearr_96822_96960 = state_96707__$1;
(statearr_96822_96960[(2)] = inst_96465);

(statearr_96822_96960[(1)] = (28));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_96708 === (16))){
var inst_96436 = (state_96707[(7)]);
var inst_96447 = (state_96707[(2)]);
var inst_96449 = (inst_96436 == null);
var inst_96450 = cljs.core.not.call(null,inst_96449);
var state_96707__$1 = (function (){var statearr_96823 = state_96707;
(statearr_96823[(21)] = inst_96447);

return statearr_96823;
})();
if(inst_96450){
var statearr_96824_96961 = state_96707__$1;
(statearr_96824_96961[(1)] = (20));

} else {
var statearr_96825_96962 = state_96707__$1;
(statearr_96825_96962[(1)] = (21));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_96708 === (81))){
var inst_96617 = (state_96707[(35)]);
var inst_96632 = (state_96707[(2)]);
var inst_96633 = fluree.db.util.async.throw_err.call(null,inst_96632);
var inst_96634 = [inst_96633,offset_map];
var inst_96635 = (new cljs.core.PersistentVector(null,2,(5),inst_96617,inst_96634,null));
var state_96707__$1 = state_96707;
var statearr_96826_96963 = state_96707__$1;
(statearr_96826_96963[(2)] = inst_96635);

(statearr_96826_96963[(1)] = (80));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_96708 === (79))){
var inst_96617 = cljs.core.PersistentVector.EMPTY_NODE;
var state_96707__$1 = (function (){var statearr_96827 = state_96707;
(statearr_96827[(35)] = inst_96617);

return statearr_96827;
})();
if(cljs.core.truth_(fuel)){
var statearr_96828_96964 = state_96707__$1;
(statearr_96828_96964[(1)] = (82));

} else {
var statearr_96829_96965 = state_96707__$1;
(statearr_96829_96965[(1)] = (83));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_96708 === (38))){
var inst_96474 = (state_96707[(15)]);
var inst_96491 = cljs.core.update.call(null,offset_map,inst_96474,cljs.core.dec);
var state_96707__$1 = state_96707;
var statearr_96830_96966 = state_96707__$1;
(statearr_96830_96966[(2)] = inst_96491);

(statearr_96830_96966[(1)] = (40));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_96708 === (98))){
var inst_96668 = (state_96707[(32)]);
var inst_96685 = (inst_96668 == null);
var inst_96686 = cljs.core.not.call(null,inst_96685);
var state_96707__$1 = state_96707;
if(inst_96686){
var statearr_96831_96967 = state_96707__$1;
(statearr_96831_96967[(1)] = (100));

} else {
var statearr_96832_96968 = state_96707__$1;
(statearr_96832_96968[(1)] = (101));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_96708 === (87))){
var inst_96630 = (state_96707[(2)]);
var state_96707__$1 = state_96707;
return cljs.core.async.impl.ioc_helpers.take_BANG_.call(null,state_96707__$1,(81),inst_96630);
} else {
if((state_val_96708 === (30))){
var inst_96469 = (state_96707[(16)]);
var state_96707__$1 = state_96707;
var statearr_96833_96969 = state_96707__$1;
(statearr_96833_96969[(2)] = inst_96469);

(statearr_96833_96969[(1)] = (31));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_96708 === (73))){
var inst_96593 = (state_96707[(2)]);
var state_96707__$1 = state_96707;
if(cljs.core.truth_(inst_96593)){
var statearr_96834_96970 = state_96707__$1;
(statearr_96834_96970[(1)] = (74));

} else {
var statearr_96835_96971 = state_96707__$1;
(statearr_96835_96971[(1)] = (75));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_96708 === (96))){
var inst_96675 = (state_96707[(2)]);
var state_96707__$1 = state_96707;
if(cljs.core.truth_(inst_96675)){
var statearr_96836_96972 = state_96707__$1;
(statearr_96836_96972[(1)] = (97));

} else {
var statearr_96837_96973 = state_96707__$1;
(statearr_96837_96973[(1)] = (98));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_96708 === (10))){
var inst_96430 = (state_96707[(20)]);
var inst_96430__$1 = (state_96707[(2)]);
var inst_96431 = cljs.core.contains_QMARK_.call(null,inst_96430__$1,new cljs.core.Keyword(null,"componentFollow?","componentFollow?",-1486906651));
var state_96707__$1 = (function (){var statearr_96838 = state_96707;
(statearr_96838[(20)] = inst_96430__$1);

return statearr_96838;
})();
if(inst_96431){
var statearr_96839_96974 = state_96707__$1;
(statearr_96839_96974[(1)] = (11));

} else {
var statearr_96840_96975 = state_96707__$1;
(statearr_96840_96975[(1)] = (12));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_96708 === (18))){
var inst_96436 = (state_96707[(7)]);
var inst_96443 = new cljs.core.Keyword(null,"p","p",151049309).cljs$core$IFn$_invoke$arity$1(inst_96436);
var state_96707__$1 = state_96707;
var statearr_96841_96976 = state_96707__$1;
(statearr_96841_96976[(2)] = inst_96443);

(statearr_96841_96976[(1)] = (19));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_96708 === (105))){
var inst_96699 = (state_96707[(2)]);
var state_96707__$1 = state_96707;
var statearr_96842_96977 = state_96707__$1;
(statearr_96842_96977[(2)] = inst_96699);

(statearr_96842_96977[(1)] = (102));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_96708 === (52))){
var inst_96521 = (state_96707[(2)]);
var state_96707__$1 = state_96707;
var statearr_96843_96978 = state_96707__$1;
(statearr_96843_96978[(2)] = inst_96521);

(statearr_96843_96978[(1)] = (49));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_96708 === (67))){
var inst_96567 = (state_96707[(34)]);
var state_96707__$1 = state_96707;
var statearr_96844_96979 = state_96707__$1;
(statearr_96844_96979[(2)] = inst_96567);

(statearr_96844_96979[(1)] = (69));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_96708 === (71))){
var inst_96436 = (state_96707[(7)]);
var inst_96590 = new cljs.core.Keyword(null,"component?","component?",407783990).cljs$core$IFn$_invoke$arity$1(inst_96436);
var state_96707__$1 = state_96707;
var statearr_96845_96980 = state_96707__$1;
(statearr_96845_96980[(2)] = inst_96590);

(statearr_96845_96980[(1)] = (73));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_96708 === (42))){
var inst_96469 = (state_96707[(16)]);
var state_96707__$1 = state_96707;
var statearr_96846_96981 = state_96707__$1;
(statearr_96846_96981[(2)] = inst_96469);

(statearr_96846_96981[(1)] = (43));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_96708 === (80))){
var inst_96637 = (state_96707[(2)]);
var state_96707__$1 = state_96707;
var statearr_96847_96982 = state_96707__$1;
(statearr_96847_96982[(2)] = inst_96637);

(statearr_96847_96982[(1)] = (76));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_96708 === (37))){
var inst_96671 = (state_96707[(24)]);
var inst_96668 = (state_96707[(32)]);
var inst_96667 = (state_96707[(2)]);
var inst_96668__$1 = cljs.core.nth.call(null,inst_96667,(0),null);
var inst_96669 = cljs.core.nth.call(null,inst_96667,(1),null);
var inst_96670 = (inst_96668__$1 == null);
var inst_96671__$1 = cljs.core.not.call(null,inst_96670);
var state_96707__$1 = (function (){var statearr_96848 = state_96707;
(statearr_96848[(24)] = inst_96671__$1);

(statearr_96848[(31)] = inst_96669);

(statearr_96848[(32)] = inst_96668__$1);

return statearr_96848;
})();
if(inst_96671__$1){
var statearr_96849_96983 = state_96707__$1;
(statearr_96849_96983[(1)] = (94));

} else {
var statearr_96850_96984 = state_96707__$1;
(statearr_96850_96984[(1)] = (95));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_96708 === (63))){
var inst_96551 = (state_96707[(2)]);
var state_96707__$1 = state_96707;
return cljs.core.async.impl.ioc_helpers.take_BANG_.call(null,state_96707__$1,(56),inst_96551);
} else {
if((state_val_96708 === (94))){
var inst_96469 = (state_96707[(16)]);
var state_96707__$1 = state_96707;
var statearr_96851_96985 = state_96707__$1;
(statearr_96851_96985[(2)] = inst_96469);

(statearr_96851_96985[(1)] = (96));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_96708 === (8))){
var inst_96425 = flake.p;
var inst_96426 = new cljs.core.Keyword(null,"compact?","compact?",1216893298).cljs$core$IFn$_invoke$arity$1(pred_spec);
var inst_96427 = fluree.db.query.fql.wildcard_pred_spec.call(null,db,cache,inst_96425,inst_96426);
var state_96707__$1 = state_96707;
var statearr_96852_96986 = state_96707__$1;
(statearr_96852_96986[(2)] = inst_96427);

(statearr_96852_96986[(1)] = (10));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_96708 === (49))){
var inst_96524 = (state_96707[(2)]);
var state_96707__$1 = state_96707;
if(cljs.core.truth_(inst_96524)){
var statearr_96853_96987 = state_96707__$1;
(statearr_96853_96987[(1)] = (53));

} else {
var statearr_96854_96988 = state_96707__$1;
(statearr_96854_96988[(1)] = (54));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_96708 === (84))){
var inst_96624 = (state_96707[(2)]);
var state_96707__$1 = (function (){var statearr_96855 = state_96707;
(statearr_96855[(11)] = inst_96624);

return statearr_96855;
})();
var statearr_96856_96989 = state_96707__$1;
(statearr_96856_96989[(1)] = (85));



return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
return null;
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
});})(c__86675__auto__))
;
return ((function (switch__86624__auto__,c__86675__auto__){
return (function() {
var fluree$db$query$fql$state_machine__86625__auto__ = null;
var fluree$db$query$fql$state_machine__86625__auto____0 = (function (){
var statearr_96858 = [null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null];
(statearr_96858[(0)] = fluree$db$query$fql$state_machine__86625__auto__);

(statearr_96858[(1)] = (1));

return statearr_96858;
});
var fluree$db$query$fql$state_machine__86625__auto____1 = (function (state_96707){
while(true){
var ret_value__86626__auto__ = (function (){try{while(true){
var result__86627__auto__ = switch__86624__auto__.call(null,state_96707);
if(cljs.core.keyword_identical_QMARK_.call(null,result__86627__auto__,new cljs.core.Keyword(null,"recur","recur",-437573268))){
continue;
} else {
return result__86627__auto__;
}
break;
}
}catch (e96859){if((e96859 instanceof Object)){
var ex__86628__auto__ = e96859;
var statearr_96860_96990 = state_96707;
(statearr_96860_96990[(5)] = ex__86628__auto__);


cljs.core.async.impl.ioc_helpers.process_exception.call(null,state_96707);

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
throw e96859;

}
}})();
if(cljs.core.keyword_identical_QMARK_.call(null,ret_value__86626__auto__,new cljs.core.Keyword(null,"recur","recur",-437573268))){
var G__96991 = state_96707;
state_96707 = G__96991;
continue;
} else {
return ret_value__86626__auto__;
}
break;
}
});
fluree$db$query$fql$state_machine__86625__auto__ = function(state_96707){
switch(arguments.length){
case 0:
return fluree$db$query$fql$state_machine__86625__auto____0.call(this);
case 1:
return fluree$db$query$fql$state_machine__86625__auto____1.call(this,state_96707);
}
throw(new Error('Invalid arity: ' + arguments.length));
};
fluree$db$query$fql$state_machine__86625__auto__.cljs$core$IFn$_invoke$arity$0 = fluree$db$query$fql$state_machine__86625__auto____0;
fluree$db$query$fql$state_machine__86625__auto__.cljs$core$IFn$_invoke$arity$1 = fluree$db$query$fql$state_machine__86625__auto____1;
return fluree$db$query$fql$state_machine__86625__auto__;
})()
;})(switch__86624__auto__,c__86675__auto__))
})();
var state__86677__auto__ = (function (){var statearr_96861 = f__86676__auto__.call(null);
(statearr_96861[(6)] = c__86675__auto__);

return statearr_96861;
})();
return cljs.core.async.impl.ioc_helpers.run_state_machine_wrapped.call(null,state__86677__auto__);
});})(c__86675__auto__))
);

return c__86675__auto__;
});

fluree.db.query.fql.add_pred.cljs$lang$maxFixedArity = 10;

/**
 * Resolves a full predicate select spec in case there are
 *   any namespace lookups (:ns-lookup) in the map that
 *   need to be resolved for this given subject.
 */
fluree.db.query.fql.full_select_spec = (function fluree$db$query$fql$full_select_spec(db,cache,base_pred_spec,subject_id){
var coll_id = fluree.db.flake.sid__GT_cid.call(null,subject_id);
var or__4131__auto__ = cljs.core.get.call(null,cljs.core.deref.call(null,cache),new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [coll_id,base_pred_spec], null));
if(cljs.core.truth_(or__4131__auto__)){
return or__4131__auto__;
} else {
var lookup_specs = fluree.db.query.fql_parser.ns_lookup_pred_spec.call(null,db,coll_id,cljs.core.get_in.call(null,base_pred_spec,new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"select","select",1147833503),new cljs.core.Keyword(null,"ns-lookup","ns-lookup",960704767)], null)));
var updated_spec = cljs.core.update.call(null,base_pred_spec,new cljs.core.Keyword(null,"select","select",1147833503),((function (lookup_specs,or__4131__auto__,coll_id){
return (function (sel){
return cljs.core.dissoc.call(null,cljs.core.assoc.call(null,sel,new cljs.core.Keyword(null,"pred-id","pred-id",-942630484),cljs.core.merge.call(null,lookup_specs,new cljs.core.Keyword(null,"pred-id","pred-id",-942630484).cljs$core$IFn$_invoke$arity$1(sel))),new cljs.core.Keyword(null,"ns-lookup","ns-lookup",960704767));
});})(lookup_specs,or__4131__auto__,coll_id))
);
cljs.core._vreset_BANG_.call(null,cache,cljs.core.assoc.call(null,cljs.core._deref.call(null,cache),new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [coll_id,base_pred_spec], null),updated_spec));

return updated_spec;
}
});
/**
 * Returns true if the predicate spec has a sub-selection that requires a namespace lookup.
 */
fluree.db.query.fql.has_ns_lookups_QMARK_ = (function fluree$db$query$fql$has_ns_lookups_QMARK_(select_spec){
return cljs.core.get_in.call(null,select_spec,new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"select","select",1147833503),new cljs.core.Keyword(null,"ns-lookup","ns-lookup",960704767)], null));
});
fluree.db.query.fql.s = (function fluree$db$query$fql$s(f){
return f.s;
});
fluree.db.query.fql.o = (function fluree$db$query$fql$o(f){
return f.o;
});
/**
 * Resolves all reverse references into a result map.
 */
fluree.db.query.fql.resolve_reverse_refs = (function fluree$db$query$fql$resolve_reverse_refs(db,cache,fuel,max_fuel,subject_id,reverse_refs_specs){
var c__86675__auto__ = cljs.core.async.chan.call(null,(1));
cljs.core.async.impl.dispatch.run.call(null,((function (c__86675__auto__){
return (function (){
var f__86676__auto__ = (function (){var switch__86624__auto__ = ((function (c__86675__auto__){
return (function (state_97167){
var state_val_97168 = (state_97167[(1)]);
if((state_val_97168 === (7))){
var inst_97007 = (state_97167[(7)]);
var state_97167__$1 = state_97167;
var statearr_97169_97258 = state_97167__$1;
(statearr_97169_97258[(2)] = inst_97007);

(statearr_97169_97258[(1)] = (9));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97168 === (59))){
var inst_97155 = (state_97167[(2)]);
var state_97167__$1 = state_97167;
var statearr_97170_97259 = state_97167__$1;
(statearr_97170_97259[(2)] = inst_97155);

(statearr_97170_97259[(1)] = (56));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97168 === (20))){
var state_97167__$1 = state_97167;
var statearr_97171_97260 = state_97167__$1;
(statearr_97171_97260[(2)] = fuel);

(statearr_97171_97260[(1)] = (22));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97168 === (58))){
var inst_97049 = (state_97167[(8)]);
var state_97167__$1 = state_97167;
var statearr_97172_97261 = state_97167__$1;
(statearr_97172_97261[(2)] = inst_97049);

(statearr_97172_97261[(1)] = (59));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97168 === (27))){
var inst_97047 = (state_97167[(9)]);
var inst_97149 = (state_97167[(2)]);
var state_97167__$1 = (function (){var statearr_97173 = state_97167;
(statearr_97173[(10)] = inst_97149);

return statearr_97173;
})();
if(cljs.core.truth_(inst_97047)){
var statearr_97174_97262 = state_97167__$1;
(statearr_97174_97262[(1)] = (54));

} else {
var statearr_97175_97263 = state_97167__$1;
(statearr_97175_97263[(1)] = (55));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97168 === (1))){
var state_97167__$1 = state_97167;
var statearr_97176_97264 = state_97167__$1;
(statearr_97176_97264[(2)] = null);

(statearr_97176_97264[(1)] = (4));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97168 === (24))){
var state_97167__$1 = state_97167;
var statearr_97177_97265 = state_97167__$1;
(statearr_97177_97265[(2)] = null);

(statearr_97177_97265[(1)] = (25));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97168 === (55))){
var inst_97048 = (state_97167[(11)]);
var state_97167__$1 = state_97167;
if(cljs.core.truth_(inst_97048)){
var statearr_97178_97266 = state_97167__$1;
(statearr_97178_97266[(1)] = (57));

} else {
var statearr_97179_97267 = state_97167__$1;
(statearr_97179_97267[(1)] = (58));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97168 === (39))){
var inst_97106 = (state_97167[(2)]);
var state_97167__$1 = state_97167;
if(cljs.core.truth_(inst_97106)){
var statearr_97180_97268 = state_97167__$1;
(statearr_97180_97268[(1)] = (40));

} else {
var statearr_97181_97269 = state_97167__$1;
(statearr_97181_97269[(1)] = (41));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97168 === (46))){
var inst_97023 = (state_97167[(12)]);
var inst_97118 = (state_97167[(13)]);
var inst_97117 = (state_97167[(2)]);
var inst_97118__$1 = fluree.db.util.async.throw_err.call(null,inst_97117);
var inst_97119 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_97120 = [new cljs.core.Keyword(null,"wildcard?","wildcard?",-686044101),new cljs.core.Keyword(null,"compact?","compact?",1216893298),new cljs.core.Keyword(null,"select","select",1147833503),new cljs.core.Keyword(null,"limit","limit",-1355822363)];
var inst_97121 = (new cljs.core.PersistentVector(null,4,(5),inst_97119,inst_97120,null));
var inst_97122 = cljs.core.select_keys.call(null,inst_97023,inst_97121);
var inst_97123 = cljs.core.empty_QMARK_.call(null,inst_97118__$1);
var state_97167__$1 = (function (){var statearr_97182 = state_97167;
(statearr_97182[(13)] = inst_97118__$1);

(statearr_97182[(14)] = inst_97122);

return statearr_97182;
})();
if(inst_97123){
var statearr_97183_97270 = state_97167__$1;
(statearr_97183_97270[(1)] = (47));

} else {
var statearr_97184_97271 = state_97167__$1;
(statearr_97184_97271[(1)] = (48));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97168 === (4))){
var _ = cljs.core.async.impl.ioc_helpers.add_exception_frame.call(null,state_97167,(3),Error,null,(2));
var inst_97003 = cljs.core.seq.call(null,reverse_refs_specs);
var inst_97004 = cljs.core.first.call(null,inst_97003);
var inst_97005 = cljs.core.next.call(null,inst_97003);
var inst_97006 = reverse_refs_specs;
var inst_97007 = null;
var state_97167__$1 = (function (){var statearr_97185 = state_97167;
(statearr_97185[(15)] = inst_97004);

(statearr_97185[(7)] = inst_97007);

(statearr_97185[(16)] = inst_97005);

(statearr_97185[(17)] = inst_97006);

return statearr_97185;
})();
var statearr_97186_97272 = state_97167__$1;
(statearr_97186_97272[(2)] = null);

(statearr_97186_97272[(1)] = (5));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97168 === (54))){
var inst_97047 = (state_97167[(9)]);
var state_97167__$1 = state_97167;
var statearr_97187_97273 = state_97167__$1;
(statearr_97187_97273[(2)] = inst_97047);

(statearr_97187_97273[(1)] = (56));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97168 === (15))){
var inst_97036 = (state_97167[(2)]);
var state_97167__$1 = state_97167;
var statearr_97188_97274 = state_97167__$1;
(statearr_97188_97274[(2)] = inst_97036);

(statearr_97188_97274[(1)] = (12));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97168 === (48))){
var state_97167__$1 = state_97167;
if(cljs.core.truth_(fuel)){
var statearr_97189_97275 = state_97167__$1;
(statearr_97189_97275[(1)] = (50));

} else {
var statearr_97190_97276 = state_97167__$1;
(statearr_97190_97276[(1)] = (51));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97168 === (50))){
var inst_97118 = (state_97167[(13)]);
var inst_97127 = cljs.core.count.call(null,inst_97118);
var inst_97128 = fluree.db.query.fql.add_fuel.call(null,fuel,inst_97127,max_fuel);
var state_97167__$1 = state_97167;
var statearr_97191_97277 = state_97167__$1;
(statearr_97191_97277[(2)] = inst_97128);

(statearr_97191_97277[(1)] = (52));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97168 === (21))){
var inst_97058 = (state_97167[(18)]);
var state_97167__$1 = state_97167;
var statearr_97192_97278 = state_97167__$1;
(statearr_97192_97278[(2)] = inst_97058);

(statearr_97192_97278[(1)] = (22));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97168 === (31))){
var inst_97046 = (state_97167[(19)]);
var inst_97081 = (state_97167[(20)]);
var inst_97094 = (inst_97081 >= inst_97046);
var state_97167__$1 = state_97167;
var statearr_97194_97279 = state_97167__$1;
(statearr_97194_97279[(2)] = inst_97094);

(statearr_97194_97279[(1)] = (33));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97168 === (32))){
var inst_97046 = (state_97167[(19)]);
var state_97167__$1 = state_97167;
var statearr_97195_97280 = state_97167__$1;
(statearr_97195_97280[(2)] = inst_97046);

(statearr_97195_97280[(1)] = (33));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97168 === (40))){
var inst_97089 = (state_97167[(21)]);
var inst_97082 = (state_97167[(22)]);
var inst_97081 = (state_97167[(20)]);
var inst_97108 = (inst_97081 + (1));
var tmp97193 = inst_97082;
var inst_97080 = inst_97089;
var inst_97081__$1 = inst_97108;
var inst_97082__$1 = tmp97193;
var state_97167__$1 = (function (){var statearr_97196 = state_97167;
(statearr_97196[(22)] = inst_97082__$1);

(statearr_97196[(23)] = inst_97080);

(statearr_97196[(20)] = inst_97081__$1);

return statearr_97196;
})();
var statearr_97197_97281 = state_97167__$1;
(statearr_97197_97281[(2)] = null);

(statearr_97197_97281[(1)] = (26));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97168 === (56))){
var inst_97007 = (state_97167[(7)]);
var inst_97014 = (state_97167[(24)]);
var inst_97149 = (state_97167[(10)]);
var inst_97157 = (state_97167[(2)]);
var inst_97158 = cljs.core.assoc.call(null,inst_97007,inst_97157,inst_97149);
var inst_97006 = inst_97014;
var inst_97007__$1 = inst_97158;
var state_97167__$1 = (function (){var statearr_97198 = state_97167;
(statearr_97198[(7)] = inst_97007__$1);

(statearr_97198[(17)] = inst_97006);

return statearr_97198;
})();
var statearr_97199_97282 = state_97167__$1;
(statearr_97199_97282[(2)] = null);

(statearr_97199_97282[(1)] = (5));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97168 === (33))){
var inst_97097 = (state_97167[(2)]);
var state_97167__$1 = state_97167;
var statearr_97200_97283 = state_97167__$1;
(statearr_97200_97283[(2)] = inst_97097);

(statearr_97200_97283[(1)] = (30));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97168 === (13))){
var state_97167__$1 = state_97167;
var statearr_97201_97284 = state_97167__$1;
(statearr_97201_97284[(2)] = true);

(statearr_97201_97284[(1)] = (15));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97168 === (22))){
var inst_97062 = (state_97167[(2)]);
var state_97167__$1 = state_97167;
if(cljs.core.truth_(inst_97062)){
var statearr_97202_97285 = state_97167__$1;
(statearr_97202_97285[(1)] = (23));

} else {
var statearr_97203_97286 = state_97167__$1;
(statearr_97203_97286[(1)] = (24));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97168 === (36))){
var inst_97147 = (state_97167[(2)]);
var state_97167__$1 = state_97167;
var statearr_97204_97287 = state_97167__$1;
(statearr_97204_97287[(2)] = inst_97147);

(statearr_97204_97287[(1)] = (27));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97168 === (41))){
var state_97167__$1 = state_97167;
var statearr_97205_97288 = state_97167__$1;
(statearr_97205_97288[(1)] = (43));



return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97168 === (43))){
var inst_97088 = (state_97167[(25)]);
var inst_97112 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_97113 = [inst_97088];
var inst_97114 = (new cljs.core.PersistentVector(null,1,(5),inst_97112,inst_97113,null));
var inst_97115 = fluree.db.query.range.index_range.call(null,db,new cljs.core.Keyword(null,"spot","spot",-1706962147),cljs.core._EQ_,inst_97114);
var state_97167__$1 = state_97167;
return cljs.core.async.impl.ioc_helpers.take_BANG_.call(null,state_97167__$1,(46),inst_97115);
} else {
if((state_val_97168 === (29))){
var inst_97046 = (state_97167[(19)]);
var state_97167__$1 = state_97167;
if(cljs.core.truth_(inst_97046)){
var statearr_97207_97289 = state_97167__$1;
(statearr_97207_97289[(1)] = (31));

} else {
var statearr_97208_97290 = state_97167__$1;
(statearr_97208_97290[(1)] = (32));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97168 === (44))){
var state_97167__$1 = state_97167;
var statearr_97209_97291 = state_97167__$1;
(statearr_97209_97291[(2)] = null);

(statearr_97209_97291[(1)] = (45));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97168 === (6))){
var inst_97163 = (state_97167[(2)]);
var state_97167__$1 = state_97167;
var statearr_97210_97292 = state_97167__$1;
(statearr_97210_97292[(2)] = inst_97163);


cljs.core.async.impl.ioc_helpers.process_exception.call(null,state_97167__$1);

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97168 === (28))){
var inst_97090 = (state_97167[(26)]);
var state_97167__$1 = state_97167;
var statearr_97211_97293 = state_97167__$1;
(statearr_97211_97293[(2)] = inst_97090);

(statearr_97211_97293[(1)] = (30));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97168 === (51))){
var state_97167__$1 = state_97167;
var statearr_97212_97294 = state_97167__$1;
(statearr_97212_97294[(2)] = null);

(statearr_97212_97294[(1)] = (52));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97168 === (25))){
var inst_97058 = (state_97167[(18)]);
var inst_97068 = (state_97167[(2)]);
var inst_97076 = cljs.core.seq.call(null,inst_97058);
var inst_97077 = cljs.core.first.call(null,inst_97076);
var inst_97078 = cljs.core.next.call(null,inst_97076);
var inst_97079 = cljs.core.PersistentVector.EMPTY;
var inst_97080 = inst_97058;
var inst_97081 = (0);
var inst_97082 = inst_97079;
var state_97167__$1 = (function (){var statearr_97213 = state_97167;
(statearr_97213[(27)] = inst_97068);

(statearr_97213[(28)] = inst_97078);

(statearr_97213[(22)] = inst_97082);

(statearr_97213[(23)] = inst_97080);

(statearr_97213[(20)] = inst_97081);

(statearr_97213[(29)] = inst_97077);

return statearr_97213;
})();
var statearr_97214_97295 = state_97167__$1;
(statearr_97214_97295[(2)] = null);

(statearr_97214_97295[(1)] = (26));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97168 === (34))){
var inst_97082 = (state_97167[(22)]);
var state_97167__$1 = state_97167;
var statearr_97215_97296 = state_97167__$1;
(statearr_97215_97296[(2)] = inst_97082);

(statearr_97215_97296[(1)] = (36));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97168 === (17))){
var inst_97023 = (state_97167[(12)]);
var state_97167__$1 = state_97167;
var statearr_97216_97297 = state_97167__$1;
(statearr_97216_97297[(2)] = inst_97023);

(statearr_97216_97297[(1)] = (18));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97168 === (3))){
var inst_96992 = (state_97167[(2)]);
var state_97167__$1 = state_97167;
var statearr_97217_97298 = state_97167__$1;
(statearr_97217_97298[(2)] = inst_96992);


cljs.core.async.impl.ioc_helpers.process_exception.call(null,state_97167__$1);

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97168 === (12))){
var inst_97039 = (state_97167[(2)]);
var state_97167__$1 = state_97167;
if(cljs.core.truth_(inst_97039)){
var statearr_97218_97299 = state_97167__$1;
(statearr_97218_97299[(1)] = (16));

} else {
var statearr_97219_97300 = state_97167__$1;
(statearr_97219_97300[(1)] = (17));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97168 === (2))){
var inst_97165 = (state_97167[(2)]);
var state_97167__$1 = state_97167;
return cljs.core.async.impl.ioc_helpers.return_chan.call(null,state_97167__$1,inst_97165);
} else {
if((state_val_97168 === (23))){
var inst_97058 = (state_97167[(18)]);
var inst_97064 = cljs.core.count.call(null,inst_97058);
var inst_97065 = fluree.db.query.fql.add_fuel.call(null,fuel,inst_97064,max_fuel);
var state_97167__$1 = state_97167;
var statearr_97220_97301 = state_97167__$1;
(statearr_97220_97301[(2)] = inst_97065);

(statearr_97220_97301[(1)] = (25));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97168 === (47))){
var inst_97082 = (state_97167[(22)]);
var state_97167__$1 = state_97167;
var statearr_97221_97302 = state_97167__$1;
(statearr_97221_97302[(2)] = inst_97082);

(statearr_97221_97302[(1)] = (49));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97168 === (35))){
var inst_97045 = (state_97167[(30)]);
var state_97167__$1 = state_97167;
if(cljs.core.truth_(inst_97045)){
var statearr_97222_97303 = state_97167__$1;
(statearr_97222_97303[(1)] = (37));

} else {
var statearr_97223_97304 = state_97167__$1;
(statearr_97223_97304[(1)] = (38));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97168 === (19))){
var inst_97058 = (state_97167[(18)]);
var inst_97055 = (state_97167[(2)]);
var inst_97056 = fluree.db.util.async.throw_err.call(null,inst_97055);
var inst_97057 = cljs.core.map.call(null,fluree.db.query.fql.s,inst_97056);
var inst_97058__$1 = cljs.core.not_empty.call(null,inst_97057);
var state_97167__$1 = (function (){var statearr_97224 = state_97167;
(statearr_97224[(18)] = inst_97058__$1);

return statearr_97224;
})();
if(cljs.core.truth_(inst_97058__$1)){
var statearr_97225_97305 = state_97167__$1;
(statearr_97225_97305[(1)] = (20));

} else {
var statearr_97226_97306 = state_97167__$1;
(statearr_97226_97306[(1)] = (21));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97168 === (57))){
var inst_97048 = (state_97167[(11)]);
var state_97167__$1 = state_97167;
var statearr_97227_97307 = state_97167__$1;
(statearr_97227_97307[(2)] = inst_97048);

(statearr_97227_97307[(1)] = (59));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97168 === (11))){
var state_97167__$1 = state_97167;
var statearr_97228_97308 = state_97167__$1;
(statearr_97228_97308[(2)] = false);

(statearr_97228_97308[(1)] = (12));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97168 === (9))){
var inst_97161 = (state_97167[(2)]);
var state_97167__$1 = state_97167;
var statearr_97229_97309 = state_97167__$1;
(statearr_97229_97309[(2)] = inst_97161);

(statearr_97229_97309[(1)] = (6));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97168 === (5))){
var inst_97013 = (state_97167[(31)]);
var inst_97006 = (state_97167[(17)]);
var inst_97012 = cljs.core.seq.call(null,inst_97006);
var inst_97013__$1 = cljs.core.first.call(null,inst_97012);
var inst_97014 = cljs.core.next.call(null,inst_97012);
var inst_97015 = cljs.core.not.call(null,inst_97013__$1);
var state_97167__$1 = (function (){var statearr_97230 = state_97167;
(statearr_97230[(31)] = inst_97013__$1);

(statearr_97230[(24)] = inst_97014);

return statearr_97230;
})();
if(inst_97015){
var statearr_97231_97310 = state_97167__$1;
(statearr_97231_97310[(1)] = (7));

} else {
var statearr_97232_97311 = state_97167__$1;
(statearr_97232_97311[(1)] = (8));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97168 === (14))){
var state_97167__$1 = state_97167;
var statearr_97233_97312 = state_97167__$1;
(statearr_97233_97312[(2)] = false);

(statearr_97233_97312[(1)] = (15));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97168 === (45))){
var inst_97143 = (state_97167[(2)]);
var state_97167__$1 = state_97167;
var statearr_97234_97313 = state_97167__$1;
(statearr_97234_97313[(2)] = inst_97143);

(statearr_97234_97313[(1)] = (42));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97168 === (53))){
var inst_97082 = (state_97167[(22)]);
var inst_97134 = (state_97167[(2)]);
var inst_97135 = fluree.db.util.async.throw_err.call(null,inst_97134);
var inst_97136 = cljs.core.conj.call(null,inst_97082,inst_97135);
var state_97167__$1 = state_97167;
var statearr_97235_97314 = state_97167__$1;
(statearr_97235_97314[(2)] = inst_97136);

(statearr_97235_97314[(1)] = (49));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97168 === (26))){
var inst_97090 = (state_97167[(26)]);
var inst_97080 = (state_97167[(23)]);
var inst_97088 = (state_97167[(25)]);
var inst_97087 = cljs.core.seq.call(null,inst_97080);
var inst_97088__$1 = cljs.core.first.call(null,inst_97087);
var inst_97089 = cljs.core.next.call(null,inst_97087);
var inst_97090__$1 = cljs.core.not.call(null,inst_97088__$1);
var state_97167__$1 = (function (){var statearr_97236 = state_97167;
(statearr_97236[(26)] = inst_97090__$1);

(statearr_97236[(21)] = inst_97089);

(statearr_97236[(25)] = inst_97088__$1);

return statearr_97236;
})();
if(inst_97090__$1){
var statearr_97237_97315 = state_97167__$1;
(statearr_97237_97315[(1)] = (28));

} else {
var statearr_97238_97316 = state_97167__$1;
(statearr_97238_97316[(1)] = (29));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97168 === (16))){
var inst_97023 = (state_97167[(12)]);
var inst_97041 = cljs.core.apply.call(null,cljs.core.hash_map,inst_97023);
var state_97167__$1 = state_97167;
var statearr_97239_97317 = state_97167__$1;
(statearr_97239_97317[(2)] = inst_97041);

(statearr_97239_97317[(1)] = (18));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97168 === (38))){
var inst_97045 = (state_97167[(30)]);
var state_97167__$1 = state_97167;
var statearr_97240_97318 = state_97167__$1;
(statearr_97240_97318[(2)] = inst_97045);

(statearr_97240_97318[(1)] = (39));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97168 === (30))){
var inst_97099 = (state_97167[(2)]);
var state_97167__$1 = state_97167;
if(cljs.core.truth_(inst_97099)){
var statearr_97241_97319 = state_97167__$1;
(statearr_97241_97319[(1)] = (34));

} else {
var statearr_97242_97320 = state_97167__$1;
(statearr_97242_97320[(1)] = (35));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97168 === (10))){
var inst_97023 = (state_97167[(12)]);
var inst_97028 = inst_97023.cljs$lang$protocol_mask$partition0$;
var inst_97029 = (inst_97028 & (64));
var inst_97030 = inst_97023.cljs$core$ISeq$;
var inst_97031 = (cljs.core.PROTOCOL_SENTINEL === inst_97030);
var inst_97032 = ((inst_97029) || (inst_97031));
var state_97167__$1 = state_97167;
if(cljs.core.truth_(inst_97032)){
var statearr_97243_97321 = state_97167__$1;
(statearr_97243_97321[(1)] = (13));

} else {
var statearr_97244_97322 = state_97167__$1;
(statearr_97244_97322[(1)] = (14));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97168 === (18))){
var inst_97022 = (state_97167[(32)]);
var inst_97044 = (state_97167[(2)]);
var inst_97045 = cljs.core.get.call(null,inst_97044,new cljs.core.Keyword(null,"offset","offset",296498311));
var inst_97046 = cljs.core.get.call(null,inst_97044,new cljs.core.Keyword(null,"limit","limit",-1355822363));
var inst_97047 = cljs.core.get.call(null,inst_97044,new cljs.core.Keyword(null,"as","as",1148689641));
var inst_97048 = cljs.core.get.call(null,inst_97044,new cljs.core.Keyword(null,"name","name",1843675177));
var inst_97049 = cljs.core.get.call(null,inst_97044,new cljs.core.Keyword(null,"p","p",151049309));
var inst_97050 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_97051 = [subject_id,inst_97022];
var inst_97052 = (new cljs.core.PersistentVector(null,2,(5),inst_97050,inst_97051,null));
var inst_97053 = fluree.db.query.range.index_range.call(null,db,new cljs.core.Keyword(null,"opst","opst",1213963058),cljs.core._EQ_,inst_97052);
var state_97167__$1 = (function (){var statearr_97245 = state_97167;
(statearr_97245[(19)] = inst_97046);

(statearr_97245[(30)] = inst_97045);

(statearr_97245[(11)] = inst_97048);

(statearr_97245[(8)] = inst_97049);

(statearr_97245[(9)] = inst_97047);

return statearr_97245;
})();
return cljs.core.async.impl.ioc_helpers.take_BANG_.call(null,state_97167__$1,(19),inst_97053);
} else {
if((state_val_97168 === (52))){
var inst_97118 = (state_97167[(13)]);
var inst_97122 = (state_97167[(14)]);
var inst_97131 = (state_97167[(2)]);
var inst_97132 = fluree.db.query.fql.flakes__GT_res.call(null,db,cache,fuel,max_fuel,inst_97122,inst_97118);
var state_97167__$1 = (function (){var statearr_97246 = state_97167;
(statearr_97246[(33)] = inst_97131);

return statearr_97246;
})();
return cljs.core.async.impl.ioc_helpers.take_BANG_.call(null,state_97167__$1,(53),inst_97132);
} else {
if((state_val_97168 === (42))){
var inst_97145 = (state_97167[(2)]);
var state_97167__$1 = state_97167;
var statearr_97247_97323 = state_97167__$1;
(statearr_97247_97323[(2)] = inst_97145);

(statearr_97247_97323[(1)] = (36));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97168 === (37))){
var inst_97045 = (state_97167[(30)]);
var inst_97081 = (state_97167[(20)]);
var inst_97103 = (inst_97081 < inst_97045);
var state_97167__$1 = state_97167;
var statearr_97248_97324 = state_97167__$1;
(statearr_97248_97324[(2)] = inst_97103);

(statearr_97248_97324[(1)] = (39));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97168 === (8))){
var inst_97023 = (state_97167[(12)]);
var inst_97013 = (state_97167[(31)]);
var inst_97022 = cljs.core.nth.call(null,inst_97013,(0),null);
var inst_97023__$1 = cljs.core.nth.call(null,inst_97013,(1),null);
var inst_97025 = (inst_97023__$1 == null);
var inst_97026 = cljs.core.not.call(null,inst_97025);
var state_97167__$1 = (function (){var statearr_97249 = state_97167;
(statearr_97249[(32)] = inst_97022);

(statearr_97249[(12)] = inst_97023__$1);

return statearr_97249;
})();
if(inst_97026){
var statearr_97250_97325 = state_97167__$1;
(statearr_97250_97325[(1)] = (10));

} else {
var statearr_97251_97326 = state_97167__$1;
(statearr_97251_97326[(1)] = (11));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97168 === (49))){
var inst_97089 = (state_97167[(21)]);
var inst_97081 = (state_97167[(20)]);
var inst_97138 = (state_97167[(2)]);
var inst_97139 = (inst_97081 + (1));
var inst_97080 = inst_97089;
var inst_97081__$1 = inst_97139;
var inst_97082 = inst_97138;
var state_97167__$1 = (function (){var statearr_97252 = state_97167;
(statearr_97252[(22)] = inst_97082);

(statearr_97252[(23)] = inst_97080);

(statearr_97252[(20)] = inst_97081__$1);

return statearr_97252;
})();
var statearr_97253_97327 = state_97167__$1;
(statearr_97253_97327[(2)] = null);

(statearr_97253_97327[(1)] = (26));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
return null;
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
});})(c__86675__auto__))
;
return ((function (switch__86624__auto__,c__86675__auto__){
return (function() {
var fluree$db$query$fql$resolve_reverse_refs_$_state_machine__86625__auto__ = null;
var fluree$db$query$fql$resolve_reverse_refs_$_state_machine__86625__auto____0 = (function (){
var statearr_97254 = [null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null];
(statearr_97254[(0)] = fluree$db$query$fql$resolve_reverse_refs_$_state_machine__86625__auto__);

(statearr_97254[(1)] = (1));

return statearr_97254;
});
var fluree$db$query$fql$resolve_reverse_refs_$_state_machine__86625__auto____1 = (function (state_97167){
while(true){
var ret_value__86626__auto__ = (function (){try{while(true){
var result__86627__auto__ = switch__86624__auto__.call(null,state_97167);
if(cljs.core.keyword_identical_QMARK_.call(null,result__86627__auto__,new cljs.core.Keyword(null,"recur","recur",-437573268))){
continue;
} else {
return result__86627__auto__;
}
break;
}
}catch (e97255){if((e97255 instanceof Object)){
var ex__86628__auto__ = e97255;
var statearr_97256_97328 = state_97167;
(statearr_97256_97328[(5)] = ex__86628__auto__);


cljs.core.async.impl.ioc_helpers.process_exception.call(null,state_97167);

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
throw e97255;

}
}})();
if(cljs.core.keyword_identical_QMARK_.call(null,ret_value__86626__auto__,new cljs.core.Keyword(null,"recur","recur",-437573268))){
var G__97329 = state_97167;
state_97167 = G__97329;
continue;
} else {
return ret_value__86626__auto__;
}
break;
}
});
fluree$db$query$fql$resolve_reverse_refs_$_state_machine__86625__auto__ = function(state_97167){
switch(arguments.length){
case 0:
return fluree$db$query$fql$resolve_reverse_refs_$_state_machine__86625__auto____0.call(this);
case 1:
return fluree$db$query$fql$resolve_reverse_refs_$_state_machine__86625__auto____1.call(this,state_97167);
}
throw(new Error('Invalid arity: ' + arguments.length));
};
fluree$db$query$fql$resolve_reverse_refs_$_state_machine__86625__auto__.cljs$core$IFn$_invoke$arity$0 = fluree$db$query$fql$resolve_reverse_refs_$_state_machine__86625__auto____0;
fluree$db$query$fql$resolve_reverse_refs_$_state_machine__86625__auto__.cljs$core$IFn$_invoke$arity$1 = fluree$db$query$fql$resolve_reverse_refs_$_state_machine__86625__auto____1;
return fluree$db$query$fql$resolve_reverse_refs_$_state_machine__86625__auto__;
})()
;})(switch__86624__auto__,c__86675__auto__))
})();
var state__86677__auto__ = (function (){var statearr_97257 = f__86676__auto__.call(null);
(statearr_97257[(6)] = c__86675__auto__);

return statearr_97257;
})();
return cljs.core.async.impl.ioc_helpers.run_state_machine_wrapped.call(null,state__86677__auto__);
});})(c__86675__auto__))
);

return c__86675__auto__;
});
fluree.db.query.fql.component_follow_QMARK_ = (function fluree$db$query$fql$component_follow_QMARK_(pred_spec,select_spec){
if(cljs.core.contains_QMARK_.call(null,pred_spec,new cljs.core.Keyword(null,"componentFollow?","componentFollow?",-1486906651))){
return new cljs.core.Keyword(null,"componentFollow?","componentFollow?",-1486906651).cljs$core$IFn$_invoke$arity$1(pred_spec);
} else {
if((!((new cljs.core.Keyword(null,"componentFollow?","componentFollow?",-1486906651).cljs$core$IFn$_invoke$arity$1(select_spec) == null)))){
return new cljs.core.Keyword(null,"componentFollow?","componentFollow?",-1486906651).cljs$core$IFn$_invoke$arity$1(select_spec);
} else {
if(cljs.core.truth_((function (){var or__4131__auto__ = new cljs.core.Keyword(null,"component?","component?",407783990).cljs$core$IFn$_invoke$arity$1(pred_spec);
if(cljs.core.truth_(or__4131__auto__)){
return or__4131__auto__;
} else {
return new cljs.core.Keyword(null,"wildcard?","wildcard?",-686044101).cljs$core$IFn$_invoke$arity$1(select_spec);
}
})())){
return true;
} else {
return null;
}
}
}
});
fluree.db.query.fql.select_spec__GT_reverse_pred_specs = (function fluree$db$query$fql$select_spec__GT_reverse_pred_specs(select_spec){
return cljs.core.reduce.call(null,(function (acc,spec){
var key_spec = cljs.core.key.call(null,spec);
var val_spec = (((new cljs.core.Keyword(null,"componentFollow?","componentFollow?",-1486906651).cljs$core$IFn$_invoke$arity$1(cljs.core.val.call(null,spec)) == null))?cljs.core.assoc.call(null,cljs.core.val.call(null,spec),new cljs.core.Keyword(null,"componentFollow?","componentFollow?",-1486906651),new cljs.core.Keyword(null,"componentFollow?","componentFollow?",-1486906651).cljs$core$IFn$_invoke$arity$1(select_spec)):cljs.core.val.call(null,spec));
return cljs.core.assoc.call(null,acc,key_spec,val_spec);
}),cljs.core.PersistentArrayMap.EMPTY,cljs.core.get_in.call(null,select_spec,new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"select","select",1147833503),new cljs.core.Keyword(null,"reverse","reverse",-888455266)], null)));
});
fluree.db.query.fql.get_recursion_map_multi = (function fluree$db$query$fql$get_recursion_map_multi(recursion_map,k,f,full_select_spec,seen_QMARK_){
return new cljs.core.PersistentVector(null, 3, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [fluree.db.query.fql.o.call(null,f)], null)], null),cljs.core.assoc_in.call(null,cljs.core.assoc_in.call(null,cljs.core.assoc_in.call(null,cljs.core.assoc_in.call(null,recursion_map,new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [k,fluree.db.query.fql.o.call(null,f)], null),new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [fluree.db.query.fql.o.call(null,f)], null)], null)),new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [k,new cljs.core.Keyword(null,"depth","depth",1768663640)], null),(0)),new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"pred-ids","pred-ids",-1902141555),k], null),f.p),new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"select-specs","select-specs",-681748023),f.p], null),full_select_spec),true], null);
});
fluree.db.query.fql.add_in_multi_flakes = (function fluree$db$query$fql$add_in_multi_flakes(acc,new_child_paths,k,f,db,cache,fuel,max_fuel,pred_spec,component_follow_QMARK_,parent_exists){
var c__86675__auto__ = cljs.core.async.chan.call(null,(1));
cljs.core.async.impl.dispatch.run.call(null,((function (c__86675__auto__){
return (function (){
var f__86676__auto__ = (function (){var switch__86624__auto__ = ((function (c__86675__auto__){
return (function (state_97443){
var state_val_97444 = (state_97443[(1)]);
if((state_val_97444 === (7))){
var inst_97346 = (state_97443[(7)]);
var state_97443__$1 = state_97443;
var statearr_97445_97494 = state_97443__$1;
(statearr_97445_97494[(2)] = inst_97346);

(statearr_97445_97494[(1)] = (9));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97444 === (20))){
var inst_97390 = (state_97443[(2)]);
var state_97443__$1 = state_97443;
var statearr_97446_97495 = state_97443__$1;
(statearr_97446_97495[(2)] = inst_97390);

(statearr_97446_97495[(1)] = (17));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97444 === (27))){
var inst_97413 = (state_97443[(2)]);
var inst_97414 = fluree.db.util.async.throw_err.call(null,inst_97413);
var state_97443__$1 = state_97443;
var statearr_97447_97496 = state_97443__$1;
(statearr_97447_97496[(2)] = inst_97414);

(statearr_97447_97496[(1)] = (26));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97444 === (1))){
var state_97443__$1 = state_97443;
var statearr_97448_97497 = state_97443__$1;
(statearr_97448_97497[(2)] = null);

(statearr_97448_97497[(1)] = (4));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97444 === (24))){
var inst_97346 = (state_97443[(7)]);
var inst_97411 = fluree.db.query.fql.add_pred.call(null,db,cache,fuel,max_fuel,inst_97346,pred_spec,f,component_follow_QMARK_,true);
var state_97443__$1 = state_97443;
return cljs.core.async.impl.ioc_helpers.take_BANG_.call(null,state_97443__$1,(27),inst_97411);
} else {
if((state_val_97444 === (4))){
var _ = cljs.core.async.impl.ioc_helpers.add_exception_frame.call(null,state_97443,(3),Error,null,(2));
var inst_97342 = cljs.core.seq.call(null,new_child_paths);
var inst_97343 = cljs.core.first.call(null,inst_97342);
var inst_97344 = cljs.core.next.call(null,inst_97342);
var inst_97345 = new_child_paths;
var inst_97346 = acc;
var state_97443__$1 = (function (){var statearr_97449 = state_97443;
(statearr_97449[(8)] = inst_97343);

(statearr_97449[(9)] = inst_97345);

(statearr_97449[(10)] = inst_97344);

(statearr_97449[(7)] = inst_97346);

return statearr_97449;
})();
var statearr_97450_97498 = state_97443__$1;
(statearr_97450_97498[(2)] = null);

(statearr_97450_97498[(1)] = (5));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97444 === (15))){
var inst_97395 = (state_97443[(11)]);
var inst_97395__$1 = (state_97443[(2)]);
var inst_97396 = cljs.core.count.call(null,inst_97395__$1);
var inst_97397 = (inst_97396 > (1));
var state_97443__$1 = (function (){var statearr_97451 = state_97443;
(statearr_97451[(11)] = inst_97395__$1);

return statearr_97451;
})();
if(cljs.core.truth_(inst_97397)){
var statearr_97452_97499 = state_97443__$1;
(statearr_97452_97499[(1)] = (21));

} else {
var statearr_97453_97500 = state_97443__$1;
(statearr_97453_97500[(1)] = (22));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97444 === (21))){
var inst_97395 = (state_97443[(11)]);
var inst_97399 = cljs.core.drop_last.call(null,inst_97395);
var state_97443__$1 = state_97443;
var statearr_97454_97501 = state_97443__$1;
(statearr_97454_97501[(2)] = inst_97399);

(statearr_97454_97501[(1)] = (23));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97444 === (31))){
var inst_97353 = (state_97443[(12)]);
var inst_97346 = (state_97443[(7)]);
var inst_97433 = (state_97443[(2)]);
var inst_97434 = cljs.core.conj.call(null,inst_97346,inst_97433);
var inst_97345 = inst_97353;
var inst_97346__$1 = inst_97434;
var state_97443__$1 = (function (){var statearr_97455 = state_97443;
(statearr_97455[(9)] = inst_97345);

(statearr_97455[(7)] = inst_97346__$1);

return statearr_97455;
})();
var statearr_97456_97502 = state_97443__$1;
(statearr_97456_97502[(2)] = null);

(statearr_97456_97502[(1)] = (5));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97444 === (13))){
var inst_97364 = (state_97443[(13)]);
var inst_97361 = (state_97443[(14)]);
var inst_97372 = inst_97361;
var inst_97373 = inst_97364;
var state_97443__$1 = (function (){var statearr_97457 = state_97443;
(statearr_97457[(15)] = inst_97372);

(statearr_97457[(16)] = inst_97373);

return statearr_97457;
})();
var statearr_97458_97503 = state_97443__$1;
(statearr_97458_97503[(2)] = null);

(statearr_97458_97503[(1)] = (16));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97444 === (22))){
var inst_97395 = (state_97443[(11)]);
var state_97443__$1 = state_97443;
var statearr_97459_97504 = state_97443__$1;
(statearr_97459_97504[(2)] = inst_97395);

(statearr_97459_97504[(1)] = (23));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97444 === (29))){
var inst_97422 = (state_97443[(17)]);
var state_97443__$1 = state_97443;
var statearr_97460_97505 = state_97443__$1;
(statearr_97460_97505[(2)] = inst_97422);

(statearr_97460_97505[(1)] = (31));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97444 === (6))){
var inst_97439 = (state_97443[(2)]);
var state_97443__$1 = state_97443;
var statearr_97461_97506 = state_97443__$1;
(statearr_97461_97506[(2)] = inst_97439);


cljs.core.async.impl.ioc_helpers.process_exception.call(null,state_97443__$1);

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97444 === (28))){
var inst_97418 = (state_97443[(2)]);
var inst_97419 = fluree.db.util.async.throw_err.call(null,inst_97418);
var state_97443__$1 = state_97443;
var statearr_97462_97507 = state_97443__$1;
(statearr_97462_97507[(2)] = inst_97419);

(statearr_97462_97507[(1)] = (26));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97444 === (25))){
var inst_97403 = (state_97443[(18)]);
var inst_97416 = fluree.db.query.fql.add_pred.call(null,db,cache,fuel,max_fuel,inst_97403,pred_spec,f,component_follow_QMARK_,true);
var state_97443__$1 = state_97443;
return cljs.core.async.impl.ioc_helpers.take_BANG_.call(null,state_97443__$1,(28),inst_97416);
} else {
if((state_val_97444 === (17))){
var inst_97392 = (state_97443[(2)]);
var state_97443__$1 = state_97443;
var statearr_97463_97508 = state_97443__$1;
(statearr_97463_97508[(2)] = inst_97392);

(statearr_97463_97508[(1)] = (15));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97444 === (3))){
var inst_97331 = (state_97443[(2)]);
var state_97443__$1 = state_97443;
var statearr_97464_97509 = state_97443__$1;
(statearr_97464_97509[(2)] = inst_97331);


cljs.core.async.impl.ioc_helpers.process_exception.call(null,state_97443__$1);

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97444 === (12))){
var inst_97361 = (state_97443[(14)]);
var inst_97346 = (state_97443[(7)]);
var inst_97361__$1 = (state_97443[(2)]);
var inst_97362 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_97363 = [k];
var inst_97364 = (new cljs.core.PersistentVector(null,1,(5),inst_97362,inst_97363,null));
var inst_97365 = new cljs.core.Keyword(null,"_id","_id",-789960287).cljs$core$IFn$_invoke$arity$1(inst_97346);
var inst_97366 = fluree.db.query.fql.s.call(null,f);
var inst_97367 = cljs.core.not_EQ_.call(null,inst_97365,inst_97366);
var inst_97368 = cljs.core.empty_QMARK_.call(null,inst_97361__$1);
var inst_97369 = (!(inst_97368));
var inst_97370 = ((inst_97367) && (inst_97369));
var state_97443__$1 = (function (){var statearr_97465 = state_97443;
(statearr_97465[(13)] = inst_97364);

(statearr_97465[(14)] = inst_97361__$1);

return statearr_97465;
})();
if(cljs.core.truth_(inst_97370)){
var statearr_97466_97510 = state_97443__$1;
(statearr_97466_97510[(1)] = (13));

} else {
var statearr_97467_97511 = state_97443__$1;
(statearr_97467_97511[(1)] = (14));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97444 === (2))){
var inst_97441 = (state_97443[(2)]);
var state_97443__$1 = state_97443;
return cljs.core.async.impl.ioc_helpers.return_chan.call(null,state_97443__$1,inst_97441);
} else {
if((state_val_97444 === (23))){
var inst_97402 = (state_97443[(19)]);
var inst_97346 = (state_97443[(7)]);
var inst_97402__$1 = (state_97443[(2)]);
var inst_97403 = cljs.core.get_in.call(null,inst_97346,inst_97402__$1);
var inst_97407 = new cljs.core.Keyword(null,"_id","_id",-789960287).cljs$core$IFn$_invoke$arity$1(inst_97346);
var inst_97408 = fluree.db.query.fql.s.call(null,f);
var inst_97409 = cljs.core._EQ_.call(null,inst_97407,inst_97408);
var state_97443__$1 = (function (){var statearr_97468 = state_97443;
(statearr_97468[(18)] = inst_97403);

(statearr_97468[(19)] = inst_97402__$1);

return statearr_97468;
})();
if(inst_97409){
var statearr_97469_97512 = state_97443__$1;
(statearr_97469_97512[(1)] = (24));

} else {
var statearr_97470_97513 = state_97443__$1;
(statearr_97470_97513[(1)] = (25));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97444 === (19))){
var inst_97381 = (state_97443[(20)]);
var state_97443__$1 = state_97443;
var statearr_97471_97514 = state_97443__$1;
(statearr_97471_97514[(2)] = inst_97381);

(statearr_97471_97514[(1)] = (20));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97444 === (11))){
var inst_97352 = (state_97443[(21)]);
var inst_97359 = cljs.core.drop_last.call(null,inst_97352);
var state_97443__$1 = state_97443;
var statearr_97472_97515 = state_97443__$1;
(statearr_97472_97515[(2)] = inst_97359);

(statearr_97472_97515[(1)] = (12));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97444 === (9))){
var inst_97437 = (state_97443[(2)]);
var state_97443__$1 = state_97443;
var statearr_97473_97516 = state_97443__$1;
(statearr_97473_97516[(2)] = inst_97437);

(statearr_97473_97516[(1)] = (6));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97444 === (5))){
var inst_97345 = (state_97443[(9)]);
var inst_97352 = (state_97443[(21)]);
var inst_97351 = cljs.core.seq.call(null,inst_97345);
var inst_97352__$1 = cljs.core.first.call(null,inst_97351);
var inst_97353 = cljs.core.next.call(null,inst_97351);
var inst_97354 = cljs.core.not.call(null,inst_97352__$1);
var state_97443__$1 = (function (){var statearr_97474 = state_97443;
(statearr_97474[(12)] = inst_97353);

(statearr_97474[(21)] = inst_97352__$1);

return statearr_97474;
})();
if(inst_97354){
var statearr_97475_97517 = state_97443__$1;
(statearr_97475_97517[(1)] = (7));

} else {
var statearr_97476_97518 = state_97443__$1;
(statearr_97476_97518[(1)] = (8));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97444 === (14))){
var inst_97364 = (state_97443[(13)]);
var state_97443__$1 = state_97443;
var statearr_97477_97519 = state_97443__$1;
(statearr_97477_97519[(2)] = inst_97364);

(statearr_97477_97519[(1)] = (15));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97444 === (26))){
var inst_97402 = (state_97443[(19)]);
var inst_97346 = (state_97443[(7)]);
var inst_97421 = (state_97443[(2)]);
var inst_97422 = cljs.core.nth.call(null,inst_97421,(0),null);
var inst_97423 = cljs.core.nth.call(null,inst_97421,(1),null);
var inst_97424 = new cljs.core.Keyword(null,"_id","_id",-789960287).cljs$core$IFn$_invoke$arity$1(inst_97346);
var inst_97425 = fluree.db.query.fql.s.call(null,f);
var inst_97426 = cljs.core._EQ_.call(null,inst_97424,inst_97425);
var inst_97427 = cljs.core.empty_QMARK_.call(null,inst_97402);
var inst_97428 = ((inst_97426) || (inst_97427));
var state_97443__$1 = (function (){var statearr_97478 = state_97443;
(statearr_97478[(22)] = inst_97423);

(statearr_97478[(17)] = inst_97422);

return statearr_97478;
})();
if(cljs.core.truth_(inst_97428)){
var statearr_97479_97520 = state_97443__$1;
(statearr_97479_97520[(1)] = (29));

} else {
var statearr_97480_97521 = state_97443__$1;
(statearr_97480_97521[(1)] = (30));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97444 === (16))){
var inst_97343 = (state_97443[(8)]);
var inst_97345 = (state_97443[(9)]);
var inst_97353 = (state_97443[(12)]);
var inst_97372 = (state_97443[(15)]);
var inst_97344 = (state_97443[(10)]);
var inst_97346 = (state_97443[(7)]);
var inst_97352 = (state_97443[(21)]);
var inst_97373 = (state_97443[(16)]);
var inst_97375 = cljs.core.get_in.call(null,inst_97346,inst_97373);
var inst_97376 = (function (){var keys_SINGLEQUOTE_ = inst_97373;
var first__97350 = inst_97352;
var G__97338 = inst_97345;
var r = inst_97353;
var vec__97339 = new_child_paths;
var vec__97348 = inst_97345;
var child_path = inst_97372;
var acc__$1 = inst_97346;
var value = inst_97375;
var first__97341 = inst_97343;
var seq__97349 = inst_97353;
var seq__97340 = inst_97344;
return ((function (keys_SINGLEQUOTE_,first__97350,G__97338,r,vec__97339,vec__97348,child_path,acc__$1,value,first__97341,seq__97349,seq__97340,inst_97343,inst_97345,inst_97353,inst_97372,inst_97344,inst_97346,inst_97352,inst_97373,inst_97375,state_val_97444,c__86675__auto__){
return (function (p1__97330_SHARP_){
return cljs.core._EQ_.call(null,new cljs.core.Keyword(null,"_id","_id",-789960287).cljs$core$IFn$_invoke$arity$1(p1__97330_SHARP_),cljs.core.first.call(null,child_path));
});
;})(keys_SINGLEQUOTE_,first__97350,G__97338,r,vec__97339,vec__97348,child_path,acc__$1,value,first__97341,seq__97349,seq__97340,inst_97343,inst_97345,inst_97353,inst_97372,inst_97344,inst_97346,inst_97352,inst_97373,inst_97375,state_val_97444,c__86675__auto__))
})();
var inst_97377 = cljs.core.filter.call(null,inst_97376,inst_97375);
var inst_97378 = cljs.core.first.call(null,inst_97377);
var inst_97379 = inst_97375.indexOf(inst_97378);
var inst_97380 = cljs.core.conj.call(null,inst_97373,inst_97379);
var inst_97381 = cljs.core.conj.call(null,inst_97380,k);
var inst_97382 = cljs.core.rest.call(null,inst_97372);
var inst_97383 = cljs.core.count.call(null,inst_97382);
var inst_97384 = (inst_97383 > (0));
var state_97443__$1 = (function (){var statearr_97481 = state_97443;
(statearr_97481[(20)] = inst_97381);

return statearr_97481;
})();
if(cljs.core.truth_(inst_97384)){
var statearr_97482_97522 = state_97443__$1;
(statearr_97482_97522[(1)] = (18));

} else {
var statearr_97483_97523 = state_97443__$1;
(statearr_97483_97523[(1)] = (19));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97444 === (30))){
var inst_97402 = (state_97443[(19)]);
var inst_97422 = (state_97443[(17)]);
var inst_97346 = (state_97443[(7)]);
var inst_97431 = cljs.core.assoc_in.call(null,inst_97346,inst_97402,inst_97422);
var state_97443__$1 = state_97443;
var statearr_97484_97524 = state_97443__$1;
(statearr_97484_97524[(2)] = inst_97431);

(statearr_97484_97524[(1)] = (31));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97444 === (10))){
var inst_97352 = (state_97443[(21)]);
var state_97443__$1 = state_97443;
var statearr_97485_97525 = state_97443__$1;
(statearr_97485_97525[(2)] = inst_97352);

(statearr_97485_97525[(1)] = (12));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97444 === (18))){
var inst_97372 = (state_97443[(15)]);
var inst_97381 = (state_97443[(20)]);
var inst_97386 = cljs.core.rest.call(null,inst_97372);
var inst_97372__$1 = inst_97386;
var inst_97373 = inst_97381;
var state_97443__$1 = (function (){var statearr_97486 = state_97443;
(statearr_97486[(15)] = inst_97372__$1);

(statearr_97486[(16)] = inst_97373);

return statearr_97486;
})();
var statearr_97487_97526 = state_97443__$1;
(statearr_97487_97526[(2)] = null);

(statearr_97487_97526[(1)] = (16));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97444 === (8))){
var state_97443__$1 = state_97443;
if(cljs.core.truth_(parent_exists)){
var statearr_97488_97527 = state_97443__$1;
(statearr_97488_97527[(1)] = (10));

} else {
var statearr_97489_97528 = state_97443__$1;
(statearr_97489_97528[(1)] = (11));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
return null;
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
});})(c__86675__auto__))
;
return ((function (switch__86624__auto__,c__86675__auto__){
return (function() {
var fluree$db$query$fql$add_in_multi_flakes_$_state_machine__86625__auto__ = null;
var fluree$db$query$fql$add_in_multi_flakes_$_state_machine__86625__auto____0 = (function (){
var statearr_97490 = [null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null];
(statearr_97490[(0)] = fluree$db$query$fql$add_in_multi_flakes_$_state_machine__86625__auto__);

(statearr_97490[(1)] = (1));

return statearr_97490;
});
var fluree$db$query$fql$add_in_multi_flakes_$_state_machine__86625__auto____1 = (function (state_97443){
while(true){
var ret_value__86626__auto__ = (function (){try{while(true){
var result__86627__auto__ = switch__86624__auto__.call(null,state_97443);
if(cljs.core.keyword_identical_QMARK_.call(null,result__86627__auto__,new cljs.core.Keyword(null,"recur","recur",-437573268))){
continue;
} else {
return result__86627__auto__;
}
break;
}
}catch (e97491){if((e97491 instanceof Object)){
var ex__86628__auto__ = e97491;
var statearr_97492_97529 = state_97443;
(statearr_97492_97529[(5)] = ex__86628__auto__);


cljs.core.async.impl.ioc_helpers.process_exception.call(null,state_97443);

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
throw e97491;

}
}})();
if(cljs.core.keyword_identical_QMARK_.call(null,ret_value__86626__auto__,new cljs.core.Keyword(null,"recur","recur",-437573268))){
var G__97530 = state_97443;
state_97443 = G__97530;
continue;
} else {
return ret_value__86626__auto__;
}
break;
}
});
fluree$db$query$fql$add_in_multi_flakes_$_state_machine__86625__auto__ = function(state_97443){
switch(arguments.length){
case 0:
return fluree$db$query$fql$add_in_multi_flakes_$_state_machine__86625__auto____0.call(this);
case 1:
return fluree$db$query$fql$add_in_multi_flakes_$_state_machine__86625__auto____1.call(this,state_97443);
}
throw(new Error('Invalid arity: ' + arguments.length));
};
fluree$db$query$fql$add_in_multi_flakes_$_state_machine__86625__auto__.cljs$core$IFn$_invoke$arity$0 = fluree$db$query$fql$add_in_multi_flakes_$_state_machine__86625__auto____0;
fluree$db$query$fql$add_in_multi_flakes_$_state_machine__86625__auto__.cljs$core$IFn$_invoke$arity$1 = fluree$db$query$fql$add_in_multi_flakes_$_state_machine__86625__auto____1;
return fluree$db$query$fql$add_in_multi_flakes_$_state_machine__86625__auto__;
})()
;})(switch__86624__auto__,c__86675__auto__))
})();
var state__86677__auto__ = (function (){var statearr_97493 = f__86676__auto__.call(null);
(statearr_97493[(6)] = c__86675__auto__);

return statearr_97493;
})();
return cljs.core.async.impl.ioc_helpers.run_state_machine_wrapped.call(null,state__86677__auto__);
});})(c__86675__auto__))
);

return c__86675__auto__;
});
fluree.db.query.fql.flake__GT_recur_multi = (function fluree$db$query$fql$flake__GT_recur_multi(db,f,pred_spec,recursion_map,flakes,acc,fuel,max_fuel,select_spec,cache,component_follow_QMARK_){
var c__86675__auto__ = cljs.core.async.chan.call(null,(1));
cljs.core.async.impl.dispatch.run.call(null,((function (c__86675__auto__){
return (function (){
var f__86676__auto__ = (function (){var switch__86624__auto__ = ((function (c__86675__auto__){
return (function (state_97640){
var state_val_97641 = (state_97640[(1)]);
if((state_val_97641 === (7))){
var inst_97540 = (state_97640[(7)]);
var inst_97555 = (state_97640[(8)]);
var inst_97551 = (state_97640[(9)]);
var inst_97551__$1 = (state_97640[(2)]);
var inst_97552 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_97553 = [inst_97551__$1,inst_97540];
var inst_97554 = (new cljs.core.PersistentVector(null,2,(5),inst_97552,inst_97553,null));
var inst_97555__$1 = cljs.core.get_in.call(null,recursion_map,inst_97554);
var state_97640__$1 = (function (){var statearr_97642 = state_97640;
(statearr_97642[(8)] = inst_97555__$1);

(statearr_97642[(9)] = inst_97551__$1);

return statearr_97642;
})();
if(cljs.core.truth_(inst_97555__$1)){
var statearr_97643_97702 = state_97640__$1;
(statearr_97643_97702[(1)] = (11));

} else {
var statearr_97644_97703 = state_97640__$1;
(statearr_97644_97703[(1)] = (12));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97641 === (20))){
var inst_97582 = (state_97640[(10)]);
var inst_97584 = f.o;
var inst_97585 = fluree.db.query.fql.resolve_reverse_refs.call(null,db,cache,fuel,max_fuel,inst_97584,inst_97582);
var state_97640__$1 = state_97640;
return cljs.core.async.impl.ioc_helpers.take_BANG_.call(null,state_97640__$1,(23),inst_97585);
} else {
if((state_val_97641 === (27))){
var inst_97602 = (state_97640[(2)]);
var state_97640__$1 = state_97640;
if(cljs.core.truth_(inst_97602)){
var statearr_97645_97704 = state_97640__$1;
(statearr_97645_97704[(1)] = (28));

} else {
var statearr_97646_97705 = state_97640__$1;
(statearr_97646_97705[(1)] = (29));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97641 === (1))){
var state_97640__$1 = state_97640;
var statearr_97647_97706 = state_97640__$1;
(statearr_97647_97706[(2)] = null);

(statearr_97647_97706[(1)] = (4));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97641 === (24))){
var inst_97569 = (state_97640[(11)]);
var inst_97596 = (state_97640[(2)]);
var inst_97597 = fluree.db.util.async.throw_err.call(null,inst_97596);
var state_97640__$1 = (function (){var statearr_97648 = state_97640;
(statearr_97648[(12)] = inst_97597);

return statearr_97648;
})();
if(cljs.core.truth_(inst_97569)){
var statearr_97649_97707 = state_97640__$1;
(statearr_97649_97707[(1)] = (25));

} else {
var statearr_97650_97708 = state_97640__$1;
(statearr_97650_97708[(1)] = (26));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97641 === (39))){
var inst_97619 = (state_97640[(13)]);
var state_97640__$1 = state_97640;
var statearr_97651_97709 = state_97640__$1;
(statearr_97651_97709[(2)] = inst_97619);

(statearr_97651_97709[(1)] = (40));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97641 === (4))){
var inst_97541 = (state_97640[(14)]);
var _ = cljs.core.async.impl.ioc_helpers.add_exception_frame.call(null,state_97640,(3),Error,null,(2));
var inst_97538 = fluree.db.query.fql.s.call(null,f);
var inst_97539 = cljs.core.assoc.call(null,acc,new cljs.core.Keyword(null,"_id","_id",-789960287),inst_97538);
var inst_97540 = fluree.db.query.fql.o.call(null,f);
var inst_97541__$1 = new cljs.core.Keyword(null,"as","as",1148689641).cljs$core$IFn$_invoke$arity$1(pred_spec);
var state_97640__$1 = (function (){var statearr_97652 = state_97640;
(statearr_97652[(7)] = inst_97540);

(statearr_97652[(14)] = inst_97541__$1);

(statearr_97652[(15)] = inst_97539);

return statearr_97652;
})();
if(cljs.core.truth_(inst_97541__$1)){
var statearr_97653_97710 = state_97640__$1;
(statearr_97653_97710[(1)] = (5));

} else {
var statearr_97654_97711 = state_97640__$1;
(statearr_97654_97711[(1)] = (6));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97641 === (15))){
var inst_97563 = (state_97640[(16)]);
var inst_97572 = cljs.core.not.call(null,inst_97563);
var state_97640__$1 = state_97640;
var statearr_97655_97712 = state_97640__$1;
(statearr_97655_97712[(2)] = inst_97572);

(statearr_97655_97712[(1)] = (16));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97641 === (21))){
var state_97640__$1 = state_97640;
var statearr_97656_97713 = state_97640__$1;
(statearr_97656_97713[(2)] = null);

(statearr_97656_97713[(1)] = (22));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97641 === (31))){
var inst_97593 = (state_97640[(17)]);
var inst_97607 = cljs.core.rest.call(null,flakes);
var inst_97608 = cljs.core.concat.call(null,inst_97607,inst_97593);
var state_97640__$1 = state_97640;
var statearr_97657_97714 = state_97640__$1;
(statearr_97657_97714[(2)] = inst_97608);

(statearr_97657_97714[(1)] = (33));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97641 === (32))){
var state_97640__$1 = state_97640;
var statearr_97658_97715 = state_97640__$1;
(statearr_97658_97715[(1)] = (34));



return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97641 === (40))){
var inst_97611 = (state_97640[(18)]);
var inst_97625 = (state_97640[(2)]);
var inst_97626 = cljs.core.concat.call(null,inst_97611,inst_97625);
var state_97640__$1 = state_97640;
var statearr_97660_97716 = state_97640__$1;
(statearr_97660_97716[(2)] = inst_97626);

(statearr_97660_97716[(1)] = (36));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97641 === (33))){
var inst_97631 = (state_97640[(2)]);
var state_97640__$1 = state_97640;
var statearr_97661_97717 = state_97640__$1;
(statearr_97661_97717[(2)] = inst_97631);

(statearr_97661_97717[(1)] = (30));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97641 === (13))){
var inst_97569 = (state_97640[(11)]);
var inst_97551 = (state_97640[(9)]);
var inst_97562 = (state_97640[(19)]);
var inst_97559 = (state_97640[(2)]);
var inst_97560 = fluree.db.query.fql.get_recursion_map_multi.call(null,recursion_map,inst_97551,f,select_spec,inst_97559);
var inst_97561 = cljs.core.nth.call(null,inst_97560,(0),null);
var inst_97562__$1 = cljs.core.nth.call(null,inst_97560,(1),null);
var inst_97563 = cljs.core.nth.call(null,inst_97560,(2),null);
var inst_97564 = new cljs.core.Keyword(null,"recur","recur",-437573268).cljs$core$IFn$_invoke$arity$1(pred_spec);
var inst_97565 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_97566 = [inst_97551,new cljs.core.Keyword(null,"depth","depth",1768663640)];
var inst_97567 = (new cljs.core.PersistentVector(null,2,(5),inst_97565,inst_97566,null));
var inst_97568 = cljs.core.get_in.call(null,inst_97562__$1,inst_97567);
var inst_97569__$1 = (inst_97564 < inst_97568);
var state_97640__$1 = (function (){var statearr_97662 = state_97640;
(statearr_97662[(11)] = inst_97569__$1);

(statearr_97662[(20)] = inst_97561);

(statearr_97662[(16)] = inst_97563);

(statearr_97662[(19)] = inst_97562__$1);

return statearr_97662;
})();
if(cljs.core.truth_(inst_97569__$1)){
var statearr_97663_97718 = state_97640__$1;
(statearr_97663_97718[(1)] = (14));

} else {
var statearr_97664_97719 = state_97640__$1;
(statearr_97664_97719[(1)] = (15));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97641 === (22))){
var inst_97591 = (state_97640[(2)]);
var state_97640__$1 = state_97640;
var statearr_97665_97720 = state_97640__$1;
(statearr_97665_97720[(2)] = inst_97591);

(statearr_97665_97720[(1)] = (19));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97641 === (36))){
var inst_97629 = (state_97640[(2)]);
var state_97640__$1 = state_97640;
var statearr_97666_97721 = state_97640__$1;
(statearr_97666_97721[(2)] = inst_97629);

(statearr_97666_97721[(1)] = (33));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97641 === (29))){
var inst_97593 = (state_97640[(17)]);
var state_97640__$1 = state_97640;
if(cljs.core.truth_(inst_97593)){
var statearr_97667_97722 = state_97640__$1;
(statearr_97667_97722[(1)] = (31));

} else {
var statearr_97668_97723 = state_97640__$1;
(statearr_97668_97723[(1)] = (32));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97641 === (6))){
var inst_97544 = (state_97640[(21)]);
var inst_97544__$1 = new cljs.core.Keyword(null,"name","name",1843675177).cljs$core$IFn$_invoke$arity$1(pred_spec);
var state_97640__$1 = (function (){var statearr_97669 = state_97640;
(statearr_97669[(21)] = inst_97544__$1);

return statearr_97669;
})();
if(cljs.core.truth_(inst_97544__$1)){
var statearr_97670_97724 = state_97640__$1;
(statearr_97670_97724[(1)] = (8));

} else {
var statearr_97671_97725 = state_97640__$1;
(statearr_97671_97725[(1)] = (9));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97641 === (28))){
var inst_97604 = cljs.core.rest.call(null,flakes);
var state_97640__$1 = state_97640;
var statearr_97672_97726 = state_97640__$1;
(statearr_97672_97726[(2)] = inst_97604);

(statearr_97672_97726[(1)] = (30));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97641 === (25))){
var inst_97569 = (state_97640[(11)]);
var state_97640__$1 = state_97640;
var statearr_97673_97727 = state_97640__$1;
(statearr_97673_97727[(2)] = inst_97569);

(statearr_97673_97727[(1)] = (27));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97641 === (34))){
var inst_97540 = (state_97640[(7)]);
var inst_97611 = cljs.core.rest.call(null,flakes);
var inst_97613 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_97614 = [inst_97540];
var inst_97615 = (new cljs.core.PersistentVector(null,1,(5),inst_97613,inst_97614,null));
var inst_97616 = fluree.db.query.range.index_range.call(null,db,new cljs.core.Keyword(null,"spot","spot",-1706962147),cljs.core._EQ_,inst_97615);
var state_97640__$1 = (function (){var statearr_97674 = state_97640;
(statearr_97674[(18)] = inst_97611);

return statearr_97674;
})();
return cljs.core.async.impl.ioc_helpers.take_BANG_.call(null,state_97640__$1,(37),inst_97616);
} else {
if((state_val_97641 === (17))){
var state_97640__$1 = state_97640;
var statearr_97675_97728 = state_97640__$1;
(statearr_97675_97728[(2)] = null);

(statearr_97675_97728[(1)] = (19));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97641 === (3))){
var inst_97531 = (state_97640[(2)]);
var state_97640__$1 = state_97640;
var statearr_97676_97729 = state_97640__$1;
(statearr_97676_97729[(2)] = inst_97531);


cljs.core.async.impl.ioc_helpers.process_exception.call(null,state_97640__$1);

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97641 === (12))){
var state_97640__$1 = state_97640;
var statearr_97677_97730 = state_97640__$1;
(statearr_97677_97730[(2)] = false);

(statearr_97677_97730[(1)] = (13));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97641 === (2))){
var inst_97638 = (state_97640[(2)]);
var state_97640__$1 = state_97640;
return cljs.core.async.impl.ioc_helpers.return_chan.call(null,state_97640__$1,inst_97638);
} else {
if((state_val_97641 === (23))){
var inst_97587 = (state_97640[(2)]);
var inst_97588 = fluree.db.util.async.throw_err.call(null,inst_97587);
var state_97640__$1 = state_97640;
var statearr_97678_97731 = state_97640__$1;
(statearr_97678_97731[(2)] = inst_97588);

(statearr_97678_97731[(1)] = (22));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97641 === (35))){
var state_97640__$1 = state_97640;
var statearr_97679_97732 = state_97640__$1;
(statearr_97679_97732[(2)] = null);

(statearr_97679_97732[(1)] = (36));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97641 === (19))){
var inst_97561 = (state_97640[(20)]);
var inst_97539 = (state_97640[(15)]);
var inst_97551 = (state_97640[(9)]);
var inst_97593 = (state_97640[(2)]);
var inst_97594 = fluree.db.query.fql.add_in_multi_flakes.call(null,inst_97539,inst_97561,inst_97551,f,db,cache,fuel,max_fuel,pred_spec,component_follow_QMARK_,false);
var state_97640__$1 = (function (){var statearr_97680 = state_97640;
(statearr_97680[(17)] = inst_97593);

return statearr_97680;
})();
return cljs.core.async.impl.ioc_helpers.take_BANG_.call(null,state_97640__$1,(24),inst_97594);
} else {
if((state_val_97641 === (11))){
var inst_97555 = (state_97640[(8)]);
var state_97640__$1 = state_97640;
var statearr_97681_97733 = state_97640__$1;
(statearr_97681_97733[(2)] = inst_97555);

(statearr_97681_97733[(1)] = (13));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97641 === (9))){
var inst_97547 = new cljs.core.Keyword(null,"p","p",151049309).cljs$core$IFn$_invoke$arity$1(pred_spec);
var state_97640__$1 = state_97640;
var statearr_97682_97734 = state_97640__$1;
(statearr_97682_97734[(2)] = inst_97547);

(statearr_97682_97734[(1)] = (10));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97641 === (5))){
var inst_97541 = (state_97640[(14)]);
var state_97640__$1 = state_97640;
var statearr_97683_97735 = state_97640__$1;
(statearr_97683_97735[(2)] = inst_97541);

(statearr_97683_97735[(1)] = (7));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97641 === (14))){
var inst_97569 = (state_97640[(11)]);
var state_97640__$1 = state_97640;
var statearr_97684_97736 = state_97640__$1;
(statearr_97684_97736[(2)] = inst_97569);

(statearr_97684_97736[(1)] = (16));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97641 === (26))){
var inst_97563 = (state_97640[(16)]);
var inst_97600 = cljs.core.not.call(null,inst_97563);
var state_97640__$1 = state_97640;
var statearr_97685_97737 = state_97640__$1;
(statearr_97685_97737[(2)] = inst_97600);

(statearr_97685_97737[(1)] = (27));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97641 === (16))){
var inst_97574 = (state_97640[(2)]);
var state_97640__$1 = state_97640;
if(cljs.core.truth_(inst_97574)){
var statearr_97686_97738 = state_97640__$1;
(statearr_97686_97738[(1)] = (17));

} else {
var statearr_97687_97739 = state_97640__$1;
(statearr_97687_97739[(1)] = (18));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97641 === (38))){
var inst_97619 = (state_97640[(13)]);
var inst_97621 = fluree.db.query.fql.fuel_flake_transducer.call(null,fuel,max_fuel);
var inst_97622 = cljs.core.sequence.call(null,inst_97621,inst_97619);
var state_97640__$1 = state_97640;
var statearr_97688_97740 = state_97640__$1;
(statearr_97688_97740[(2)] = inst_97622);

(statearr_97688_97740[(1)] = (40));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97641 === (30))){
var inst_97597 = (state_97640[(12)]);
var inst_97562 = (state_97640[(19)]);
var inst_97633 = (state_97640[(2)]);
var inst_97634 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_97635 = [inst_97597,inst_97633,inst_97562];
var inst_97636 = (new cljs.core.PersistentVector(null,3,(5),inst_97634,inst_97635,null));
var state_97640__$1 = state_97640;
var statearr_97689_97741 = state_97640__$1;
(statearr_97689_97741[(2)] = inst_97636);


cljs.core.async.impl.ioc_helpers.process_exception.call(null,state_97640__$1);

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97641 === (10))){
var inst_97549 = (state_97640[(2)]);
var state_97640__$1 = state_97640;
var statearr_97690_97742 = state_97640__$1;
(statearr_97690_97742[(2)] = inst_97549);

(statearr_97690_97742[(1)] = (7));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97641 === (18))){
var inst_97582 = (state_97640[(10)]);
var inst_97562 = (state_97640[(19)]);
var inst_97577 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_97578 = f.p;
var inst_97579 = [new cljs.core.Keyword(null,"select-specs","select-specs",-681748023),inst_97578];
var inst_97580 = (new cljs.core.PersistentVector(null,2,(5),inst_97577,inst_97579,null));
var inst_97581 = cljs.core.get_in.call(null,inst_97562,inst_97580);
var inst_97582__$1 = fluree.db.query.fql.select_spec__GT_reverse_pred_specs.call(null,inst_97581);
var state_97640__$1 = (function (){var statearr_97691 = state_97640;
(statearr_97691[(10)] = inst_97582__$1);

return statearr_97691;
})();
if(cljs.core.truth_(inst_97582__$1)){
var statearr_97692_97743 = state_97640__$1;
(statearr_97692_97743[(1)] = (20));

} else {
var statearr_97693_97744 = state_97640__$1;
(statearr_97693_97744[(1)] = (21));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97641 === (37))){
var inst_97618 = (state_97640[(2)]);
var inst_97619 = fluree.db.util.async.throw_err.call(null,inst_97618);
var state_97640__$1 = (function (){var statearr_97694 = state_97640;
(statearr_97694[(13)] = inst_97619);

return statearr_97694;
})();
if(cljs.core.truth_(fuel)){
var statearr_97695_97745 = state_97640__$1;
(statearr_97695_97745[(1)] = (38));

} else {
var statearr_97696_97746 = state_97640__$1;
(statearr_97696_97746[(1)] = (39));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97641 === (8))){
var inst_97544 = (state_97640[(21)]);
var state_97640__$1 = state_97640;
var statearr_97697_97747 = state_97640__$1;
(statearr_97697_97747[(2)] = inst_97544);

(statearr_97697_97747[(1)] = (10));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
return null;
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
});})(c__86675__auto__))
;
return ((function (switch__86624__auto__,c__86675__auto__){
return (function() {
var fluree$db$query$fql$flake__GT_recur_multi_$_state_machine__86625__auto__ = null;
var fluree$db$query$fql$flake__GT_recur_multi_$_state_machine__86625__auto____0 = (function (){
var statearr_97698 = [null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null];
(statearr_97698[(0)] = fluree$db$query$fql$flake__GT_recur_multi_$_state_machine__86625__auto__);

(statearr_97698[(1)] = (1));

return statearr_97698;
});
var fluree$db$query$fql$flake__GT_recur_multi_$_state_machine__86625__auto____1 = (function (state_97640){
while(true){
var ret_value__86626__auto__ = (function (){try{while(true){
var result__86627__auto__ = switch__86624__auto__.call(null,state_97640);
if(cljs.core.keyword_identical_QMARK_.call(null,result__86627__auto__,new cljs.core.Keyword(null,"recur","recur",-437573268))){
continue;
} else {
return result__86627__auto__;
}
break;
}
}catch (e97699){if((e97699 instanceof Object)){
var ex__86628__auto__ = e97699;
var statearr_97700_97748 = state_97640;
(statearr_97700_97748[(5)] = ex__86628__auto__);


cljs.core.async.impl.ioc_helpers.process_exception.call(null,state_97640);

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
throw e97699;

}
}})();
if(cljs.core.keyword_identical_QMARK_.call(null,ret_value__86626__auto__,new cljs.core.Keyword(null,"recur","recur",-437573268))){
var G__97749 = state_97640;
state_97640 = G__97749;
continue;
} else {
return ret_value__86626__auto__;
}
break;
}
});
fluree$db$query$fql$flake__GT_recur_multi_$_state_machine__86625__auto__ = function(state_97640){
switch(arguments.length){
case 0:
return fluree$db$query$fql$flake__GT_recur_multi_$_state_machine__86625__auto____0.call(this);
case 1:
return fluree$db$query$fql$flake__GT_recur_multi_$_state_machine__86625__auto____1.call(this,state_97640);
}
throw(new Error('Invalid arity: ' + arguments.length));
};
fluree$db$query$fql$flake__GT_recur_multi_$_state_machine__86625__auto__.cljs$core$IFn$_invoke$arity$0 = fluree$db$query$fql$flake__GT_recur_multi_$_state_machine__86625__auto____0;
fluree$db$query$fql$flake__GT_recur_multi_$_state_machine__86625__auto__.cljs$core$IFn$_invoke$arity$1 = fluree$db$query$fql$flake__GT_recur_multi_$_state_machine__86625__auto____1;
return fluree$db$query$fql$flake__GT_recur_multi_$_state_machine__86625__auto__;
})()
;})(switch__86624__auto__,c__86675__auto__))
})();
var state__86677__auto__ = (function (){var statearr_97701 = f__86676__auto__.call(null);
(statearr_97701[(6)] = c__86675__auto__);

return statearr_97701;
})();
return cljs.core.async.impl.ioc_helpers.run_state_machine_wrapped.call(null,state__86677__auto__);
});})(c__86675__auto__))
);

return c__86675__auto__;
});
fluree.db.query.fql.get_recursion_map = (function fluree$db$query$fql$get_recursion_map(db,recursion_map,select_spec,cache,k,f){
var select_spec__$1 = cljs.core.get_in.call(null,select_spec,new cljs.core.PersistentVector(null, 3, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"select","select",1147833503),new cljs.core.Keyword(null,"pred-id","pred-id",-942630484),f.p], null));
var full_select_spec = (cljs.core.truth_(fluree.db.query.fql.has_ns_lookups_QMARK_.call(null,select_spec__$1))?fluree.db.query.fql.full_select_spec.call(null,db,cache,select_spec__$1,fluree.db.query.fql.s.call(null,f)):select_spec__$1);
return cljs.core.assoc_in.call(null,cljs.core.assoc_in.call(null,cljs.core.assoc_in.call(null,recursion_map,new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [k,fluree.db.query.fql.s.call(null,f)], null),(0)),new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"pred-ids","pred-ids",-1902141555),k], null),f.p),new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"select-specs","select-specs",-681748023),f.p], null),full_select_spec);
});
fluree.db.query.fql.flake__GT_recur = (function fluree$db$query$fql$flake__GT_recur(db,f,pred_spec,recursion_map,flakes,acc,fuel,max_fuel,select_spec,cache){
var c__86675__auto__ = cljs.core.async.chan.call(null,(1));
cljs.core.async.impl.dispatch.run.call(null,((function (c__86675__auto__){
return (function (){
var f__86676__auto__ = (function (){var switch__86624__auto__ = ((function (c__86675__auto__){
return (function (state_97909){
var state_val_97910 = (state_97909[(1)]);
if((state_val_97910 === (7))){
var inst_97774 = (state_97909[(7)]);
var inst_97754 = (state_97909[(8)]);
var inst_97766 = (state_97909[(9)]);
var inst_97766__$1 = (state_97909[(2)]);
var inst_97767 = cljs.core.PersistentVector.EMPTY;
var inst_97768 = cljs.core.repeat.call(null,(0),inst_97766__$1);
var inst_97769 = cljs.core.into.call(null,inst_97767,inst_97768);
var inst_97770 = cljs.core.get_in.call(null,acc,inst_97769);
var inst_97771 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_97772 = [inst_97766__$1,inst_97754];
var inst_97773 = (new cljs.core.PersistentVector(null,2,(5),inst_97771,inst_97772,null));
var inst_97774__$1 = cljs.core.get_in.call(null,recursion_map,inst_97773);
var state_97909__$1 = (function (){var statearr_97911 = state_97909;
(statearr_97911[(10)] = inst_97770);

(statearr_97911[(7)] = inst_97774__$1);

(statearr_97911[(9)] = inst_97766__$1);

return statearr_97911;
})();
if(cljs.core.truth_(inst_97774__$1)){
var statearr_97912_98003 = state_97909__$1;
(statearr_97912_98003[(1)] = (11));

} else {
var statearr_97913_98004 = state_97909__$1;
(statearr_97913_98004[(1)] = (12));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97910 === (59))){
var inst_97891 = (state_97909[(11)]);
var state_97909__$1 = state_97909;
var statearr_97914_98005 = state_97909__$1;
(statearr_97914_98005[(2)] = inst_97891);

(statearr_97914_98005[(1)] = (60));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97910 === (20))){
var inst_97798 = (state_97909[(12)]);
var state_97909__$1 = state_97909;
var statearr_97915_98006 = state_97909__$1;
(statearr_97915_98006[(2)] = inst_97798);

(statearr_97915_98006[(1)] = (22));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97910 === (58))){
var inst_97891 = (state_97909[(11)]);
var inst_97893 = fluree.db.query.fql.fuel_flake_transducer.call(null,fuel,max_fuel);
var inst_97894 = cljs.core.sequence.call(null,inst_97893,inst_97891);
var state_97909__$1 = state_97909;
var statearr_97916_98007 = state_97909__$1;
(statearr_97916_98007[(2)] = inst_97894);

(statearr_97916_98007[(1)] = (60));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97910 === (60))){
var inst_97883 = (state_97909[(13)]);
var inst_97897 = (state_97909[(2)]);
var inst_97898 = cljs.core.concat.call(null,inst_97883,inst_97897);
var state_97909__$1 = state_97909;
var statearr_97917_98008 = state_97909__$1;
(statearr_97917_98008[(2)] = inst_97898);

(statearr_97917_98008[(1)] = (56));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97910 === (27))){
var state_97909__$1 = state_97909;
var statearr_97918_98009 = state_97909__$1;
(statearr_97918_98009[(2)] = null);

(statearr_97918_98009[(1)] = (28));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97910 === (1))){
var state_97909__$1 = state_97909;
var statearr_97919_98010 = state_97909__$1;
(statearr_97919_98010[(2)] = null);

(statearr_97919_98010[(1)] = (4));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97910 === (24))){
var inst_97810 = (state_97909[(14)]);
var inst_97793 = (state_97909[(15)]);
var inst_97805 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_97806 = f.p;
var inst_97807 = [new cljs.core.Keyword(null,"select-specs","select-specs",-681748023),inst_97806];
var inst_97808 = (new cljs.core.PersistentVector(null,2,(5),inst_97805,inst_97807,null));
var inst_97809 = cljs.core.get_in.call(null,inst_97793,inst_97808);
var inst_97810__$1 = fluree.db.query.fql.select_spec__GT_reverse_pred_specs.call(null,inst_97809);
var state_97909__$1 = (function (){var statearr_97920 = state_97909;
(statearr_97920[(14)] = inst_97810__$1);

return statearr_97920;
})();
if(cljs.core.truth_(inst_97810__$1)){
var statearr_97921_98011 = state_97909__$1;
(statearr_97921_98011[(1)] = (26));

} else {
var statearr_97922_98012 = state_97909__$1;
(statearr_97922_98012[(1)] = (27));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97910 === (55))){
var inst_97754 = (state_97909[(8)]);
var inst_97883 = cljs.core.rest.call(null,flakes);
var inst_97885 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_97886 = [inst_97754];
var inst_97887 = (new cljs.core.PersistentVector(null,1,(5),inst_97885,inst_97886,null));
var inst_97888 = fluree.db.query.range.index_range.call(null,db,new cljs.core.Keyword(null,"spot","spot",-1706962147),cljs.core._EQ_,inst_97887);
var state_97909__$1 = (function (){var statearr_97923 = state_97909;
(statearr_97923[(13)] = inst_97883);

return statearr_97923;
})();
return cljs.core.async.impl.ioc_helpers.take_BANG_.call(null,state_97909__$1,(57),inst_97888);
} else {
if((state_val_97910 === (39))){
var inst_97851 = (state_97909[(16)]);
var inst_97821 = (state_97909[(17)]);
var inst_97766 = (state_97909[(9)]);
var inst_97853 = cljs.core.get.call(null,inst_97851,inst_97766);
var inst_97854 = cljs.core.merge.call(null,inst_97853,inst_97821);
var inst_97855 = cljs.core.assoc.call(null,inst_97851,inst_97766,inst_97854);
var state_97909__$1 = state_97909;
var statearr_97924_98013 = state_97909__$1;
(statearr_97924_98013[(2)] = inst_97855);

(statearr_97924_98013[(1)] = (41));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97910 === (46))){
var state_97909__$1 = state_97909;
var statearr_97925_98014 = state_97909__$1;
(statearr_97925_98014[(1)] = (48));



return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97910 === (4))){
var inst_97756 = (state_97909[(18)]);
var _ = cljs.core.async.impl.ioc_helpers.add_exception_frame.call(null,state_97909,(3),Error,null,(2));
var inst_97754 = f.o;
var inst_97755 = new cljs.core.Keyword(null,"multi?","multi?",-749311069).cljs$core$IFn$_invoke$arity$1(pred_spec);
var inst_97756__$1 = new cljs.core.Keyword(null,"as","as",1148689641).cljs$core$IFn$_invoke$arity$1(pred_spec);
var state_97909__$1 = (function (){var statearr_97927 = state_97909;
(statearr_97927[(19)] = inst_97755);

(statearr_97927[(8)] = inst_97754);

(statearr_97927[(18)] = inst_97756__$1);

return statearr_97927;
})();
if(cljs.core.truth_(inst_97756__$1)){
var statearr_97928_98015 = state_97909__$1;
(statearr_97928_98015[(1)] = (5));

} else {
var statearr_97929_98016 = state_97909__$1;
(statearr_97929_98016[(1)] = (6));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97910 === (54))){
var inst_97881 = cljs.core.rest.call(null,flakes);
var state_97909__$1 = state_97909;
var statearr_97930_98017 = state_97909__$1;
(statearr_97930_98017[(2)] = inst_97881);

(statearr_97930_98017[(1)] = (56));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97910 === (15))){
var state_97909__$1 = state_97909;
var statearr_97931_98018 = state_97909__$1;
(statearr_97931_98018[(2)] = recursion_map);

(statearr_97931_98018[(1)] = (16));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97910 === (48))){
var inst_97858 = (state_97909[(20)]);
var inst_97766 = (state_97909[(9)]);
var inst_97865 = cljs.core.PersistentVector.EMPTY;
var inst_97866 = cljs.core.repeat.call(null,(0),inst_97766);
var inst_97867 = cljs.core.into.call(null,inst_97865,inst_97866);
var inst_97868 = cljs.core.assoc_in.call(null,acc,inst_97867,inst_97858);
var state_97909__$1 = state_97909;
var statearr_97932_98019 = state_97909__$1;
(statearr_97932_98019[(2)] = inst_97868);

(statearr_97932_98019[(1)] = (50));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97910 === (50))){
var inst_97871 = (state_97909[(2)]);
var state_97909__$1 = state_97909;
var statearr_97933_98020 = state_97909__$1;
(statearr_97933_98020[(2)] = inst_97871);

(statearr_97933_98020[(1)] = (47));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97910 === (21))){
var inst_97778 = (state_97909[(21)]);
var state_97909__$1 = state_97909;
var statearr_97934_98021 = state_97909__$1;
(statearr_97934_98021[(2)] = inst_97778);

(statearr_97934_98021[(1)] = (22));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97910 === (31))){
var inst_97755 = (state_97909[(19)]);
var state_97909__$1 = state_97909;
var statearr_97935_98022 = state_97909__$1;
(statearr_97935_98022[(2)] = inst_97755);

(statearr_97935_98022[(1)] = (32));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97910 === (32))){
var inst_97829 = (state_97909[(2)]);
var state_97909__$1 = state_97909;
if(cljs.core.truth_(inst_97829)){
var statearr_97936_98023 = state_97909__$1;
(statearr_97936_98023[(1)] = (33));

} else {
var statearr_97937_98024 = state_97909__$1;
(statearr_97937_98024[(1)] = (34));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97910 === (40))){
var inst_97851 = (state_97909[(16)]);
var state_97909__$1 = state_97909;
var statearr_97938_98025 = state_97909__$1;
(statearr_97938_98025[(2)] = inst_97851);

(statearr_97938_98025[(1)] = (41));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97910 === (56))){
var inst_97793 = (state_97909[(15)]);
var inst_97875 = (state_97909[(22)]);
var inst_97900 = (state_97909[(2)]);
var inst_97901 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_97902 = [inst_97875,inst_97900,inst_97793];
var inst_97903 = (new cljs.core.PersistentVector(null,3,(5),inst_97901,inst_97902,null));
var state_97909__$1 = state_97909;
var statearr_97939_98026 = state_97909__$1;
(statearr_97939_98026[(2)] = inst_97903);

(statearr_97939_98026[(1)] = (35));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97910 === (33))){
var inst_97793 = (state_97909[(15)]);
var inst_97831 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_97832 = cljs.core.rest.call(null,flakes);
var inst_97833 = [acc,inst_97832,inst_97793];
var inst_97834 = (new cljs.core.PersistentVector(null,3,(5),inst_97831,inst_97833,null));
var state_97909__$1 = state_97909;
var statearr_97940_98027 = state_97909__$1;
(statearr_97940_98027[(2)] = inst_97834);

(statearr_97940_98027[(1)] = (35));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97910 === (13))){
var inst_97778 = (state_97909[(21)]);
var inst_97778__$1 = (state_97909[(2)]);
var inst_97779 = cljs.core.not.call(null,inst_97778__$1);
var state_97909__$1 = (function (){var statearr_97941 = state_97909;
(statearr_97941[(21)] = inst_97778__$1);

return statearr_97941;
})();
if(inst_97779){
var statearr_97942_98028 = state_97909__$1;
(statearr_97942_98028[(1)] = (14));

} else {
var statearr_97943_98029 = state_97909__$1;
(statearr_97943_98029[(1)] = (15));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97910 === (22))){
var inst_97802 = (state_97909[(2)]);
var state_97909__$1 = state_97909;
if(cljs.core.truth_(inst_97802)){
var statearr_97944_98030 = state_97909__$1;
(statearr_97944_98030[(1)] = (23));

} else {
var statearr_97945_98031 = state_97909__$1;
(statearr_97945_98031[(1)] = (24));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97910 === (36))){
var inst_97770 = (state_97909[(10)]);
var inst_97754 = (state_97909[(8)]);
var inst_97766 = (state_97909[(9)]);
var inst_97837 = cljs.core.PersistentVector.EMPTY;
var inst_97838 = cljs.core.get.call(null,inst_97770,inst_97766);
var inst_97839 = [new cljs.core.Keyword(null,"_id","_id",-789960287)];
var inst_97840 = [inst_97754];
var inst_97841 = cljs.core.PersistentHashMap.fromArrays(inst_97839,inst_97840);
var inst_97842 = cljs.core.conj.call(null,inst_97838,inst_97841);
var inst_97843 = cljs.core.into.call(null,inst_97837,inst_97842);
var inst_97844 = cljs.core.assoc.call(null,inst_97770,inst_97766,inst_97843);
var state_97909__$1 = state_97909;
var statearr_97946_98032 = state_97909__$1;
(statearr_97946_98032[(2)] = inst_97844);

(statearr_97946_98032[(1)] = (38));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97910 === (41))){
var inst_97778 = (state_97909[(21)]);
var inst_97858 = (state_97909[(2)]);
var inst_97859 = cljs.core.not.call(null,inst_97778);
var state_97909__$1 = (function (){var statearr_97947 = state_97909;
(statearr_97947[(20)] = inst_97858);

return statearr_97947;
})();
if(inst_97859){
var statearr_97948_98033 = state_97909__$1;
(statearr_97948_98033[(1)] = (42));

} else {
var statearr_97949_98034 = state_97909__$1;
(statearr_97949_98034[(1)] = (43));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97910 === (43))){
var inst_97778 = (state_97909[(21)]);
var state_97909__$1 = state_97909;
if(cljs.core.truth_(inst_97778)){
var statearr_97950_98035 = state_97909__$1;
(statearr_97950_98035[(1)] = (45));

} else {
var statearr_97951_98036 = state_97909__$1;
(statearr_97951_98036[(1)] = (46));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97910 === (29))){
var inst_97815 = (state_97909[(2)]);
var inst_97816 = fluree.db.util.async.throw_err.call(null,inst_97815);
var state_97909__$1 = state_97909;
var statearr_97952_98037 = state_97909__$1;
(statearr_97952_98037[(2)] = inst_97816);

(statearr_97952_98037[(1)] = (28));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97910 === (44))){
var inst_97798 = (state_97909[(12)]);
var inst_97875 = (state_97909[(2)]);
var state_97909__$1 = (function (){var statearr_97953 = state_97909;
(statearr_97953[(22)] = inst_97875);

return statearr_97953;
})();
if(cljs.core.truth_(inst_97798)){
var statearr_97954_98038 = state_97909__$1;
(statearr_97954_98038[(1)] = (51));

} else {
var statearr_97955_98039 = state_97909__$1;
(statearr_97955_98039[(1)] = (52));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97910 === (6))){
var inst_97759 = (state_97909[(23)]);
var inst_97759__$1 = new cljs.core.Keyword(null,"name","name",1843675177).cljs$core$IFn$_invoke$arity$1(pred_spec);
var state_97909__$1 = (function (){var statearr_97956 = state_97909;
(statearr_97956[(23)] = inst_97759__$1);

return statearr_97956;
})();
if(cljs.core.truth_(inst_97759__$1)){
var statearr_97957_98040 = state_97909__$1;
(statearr_97957_98040[(1)] = (8));

} else {
var statearr_97958_98041 = state_97909__$1;
(statearr_97958_98041[(1)] = (9));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97910 === (28))){
var inst_97819 = (state_97909[(2)]);
var state_97909__$1 = state_97909;
var statearr_97959_98042 = state_97909__$1;
(statearr_97959_98042[(2)] = inst_97819);

(statearr_97959_98042[(1)] = (25));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97910 === (51))){
var inst_97798 = (state_97909[(12)]);
var state_97909__$1 = state_97909;
var statearr_97960_98043 = state_97909__$1;
(statearr_97960_98043[(2)] = inst_97798);

(statearr_97960_98043[(1)] = (53));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97910 === (25))){
var inst_97755 = (state_97909[(19)]);
var inst_97821 = (state_97909[(2)]);
var state_97909__$1 = (function (){var statearr_97961 = state_97909;
(statearr_97961[(17)] = inst_97821);

return statearr_97961;
})();
if(cljs.core.truth_(inst_97755)){
var statearr_97962_98044 = state_97909__$1;
(statearr_97962_98044[(1)] = (30));

} else {
var statearr_97963_98045 = state_97909__$1;
(statearr_97963_98045[(1)] = (31));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97910 === (34))){
var inst_97755 = (state_97909[(19)]);
var state_97909__$1 = state_97909;
if(cljs.core.truth_(inst_97755)){
var statearr_97964_98046 = state_97909__$1;
(statearr_97964_98046[(1)] = (36));

} else {
var statearr_97965_98047 = state_97909__$1;
(statearr_97965_98047[(1)] = (37));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97910 === (17))){
var inst_97784 = (state_97909[(24)]);
var state_97909__$1 = state_97909;
var statearr_97966_98048 = state_97909__$1;
(statearr_97966_98048[(2)] = inst_97784);

(statearr_97966_98048[(1)] = (19));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97910 === (3))){
var inst_97750 = (state_97909[(2)]);
var state_97909__$1 = state_97909;
var statearr_97967_98049 = state_97909__$1;
(statearr_97967_98049[(2)] = inst_97750);


cljs.core.async.impl.ioc_helpers.process_exception.call(null,state_97909__$1);

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97910 === (12))){
var state_97909__$1 = state_97909;
var statearr_97968_98050 = state_97909__$1;
(statearr_97968_98050[(2)] = false);

(statearr_97968_98050[(1)] = (13));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97910 === (2))){
var inst_97907 = (state_97909[(2)]);
var state_97909__$1 = state_97909;
return cljs.core.async.impl.ioc_helpers.return_chan.call(null,state_97909__$1,inst_97907);
} else {
if((state_val_97910 === (23))){
var state_97909__$1 = state_97909;
var statearr_97969_98051 = state_97909__$1;
(statearr_97969_98051[(2)] = null);

(statearr_97969_98051[(1)] = (25));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97910 === (47))){
var inst_97873 = (state_97909[(2)]);
var state_97909__$1 = state_97909;
var statearr_97970_98052 = state_97909__$1;
(statearr_97970_98052[(2)] = inst_97873);

(statearr_97970_98052[(1)] = (44));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97910 === (35))){
var inst_97905 = (state_97909[(2)]);
var state_97909__$1 = state_97909;
var statearr_97971_98053 = state_97909__$1;
(statearr_97971_98053[(2)] = inst_97905);


cljs.core.async.impl.ioc_helpers.process_exception.call(null,state_97909__$1);

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97910 === (19))){
var inst_97793 = (state_97909[(15)]);
var inst_97798 = (state_97909[(12)]);
var inst_97766 = (state_97909[(9)]);
var inst_97793__$1 = (state_97909[(2)]);
var inst_97794 = new cljs.core.Keyword(null,"recur","recur",-437573268).cljs$core$IFn$_invoke$arity$1(pred_spec);
var inst_97795 = cljs.core.get.call(null,inst_97793__$1,inst_97766);
var inst_97796 = cljs.core.vals.call(null,inst_97795);
var inst_97797 = cljs.core.apply.call(null,cljs.core.max,inst_97796);
var inst_97798__$1 = (inst_97794 < inst_97797);
var state_97909__$1 = (function (){var statearr_97972 = state_97909;
(statearr_97972[(15)] = inst_97793__$1);

(statearr_97972[(12)] = inst_97798__$1);

return statearr_97972;
})();
if(cljs.core.truth_(inst_97798__$1)){
var statearr_97973_98054 = state_97909__$1;
(statearr_97973_98054[(1)] = (20));

} else {
var statearr_97974_98055 = state_97909__$1;
(statearr_97974_98055[(1)] = (21));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97910 === (57))){
var inst_97890 = (state_97909[(2)]);
var inst_97891 = fluree.db.util.async.throw_err.call(null,inst_97890);
var state_97909__$1 = (function (){var statearr_97975 = state_97909;
(statearr_97975[(11)] = inst_97891);

return statearr_97975;
})();
if(cljs.core.truth_(fuel)){
var statearr_97976_98056 = state_97909__$1;
(statearr_97976_98056[(1)] = (58));

} else {
var statearr_97977_98057 = state_97909__$1;
(statearr_97977_98057[(1)] = (59));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97910 === (11))){
var inst_97774 = (state_97909[(7)]);
var state_97909__$1 = state_97909;
var statearr_97978_98058 = state_97909__$1;
(statearr_97978_98058[(2)] = inst_97774);

(statearr_97978_98058[(1)] = (13));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97910 === (9))){
var inst_97762 = new cljs.core.Keyword(null,"p","p",151049309).cljs$core$IFn$_invoke$arity$1(pred_spec);
var state_97909__$1 = state_97909;
var statearr_97979_98059 = state_97909__$1;
(statearr_97979_98059[(2)] = inst_97762);

(statearr_97979_98059[(1)] = (10));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97910 === (5))){
var inst_97756 = (state_97909[(18)]);
var state_97909__$1 = state_97909;
var statearr_97980_98060 = state_97909__$1;
(statearr_97980_98060[(2)] = inst_97756);

(statearr_97980_98060[(1)] = (7));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97910 === (14))){
var inst_97766 = (state_97909[(9)]);
var inst_97781 = fluree.db.query.fql.get_recursion_map.call(null,db,recursion_map,select_spec,cache,inst_97766,f);
var state_97909__$1 = state_97909;
var statearr_97981_98061 = state_97909__$1;
(statearr_97981_98061[(2)] = inst_97781);

(statearr_97981_98061[(1)] = (16));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97910 === (45))){
var state_97909__$1 = state_97909;
var statearr_97982_98062 = state_97909__$1;
(statearr_97982_98062[(2)] = acc);

(statearr_97982_98062[(1)] = (47));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97910 === (53))){
var inst_97879 = (state_97909[(2)]);
var state_97909__$1 = state_97909;
if(cljs.core.truth_(inst_97879)){
var statearr_97983_98063 = state_97909__$1;
(statearr_97983_98063[(1)] = (54));

} else {
var statearr_97984_98064 = state_97909__$1;
(statearr_97984_98064[(1)] = (55));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97910 === (26))){
var inst_97810 = (state_97909[(14)]);
var inst_97812 = f.o;
var inst_97813 = fluree.db.query.fql.resolve_reverse_refs.call(null,db,cache,fuel,max_fuel,inst_97812,inst_97810);
var state_97909__$1 = state_97909;
return cljs.core.async.impl.ioc_helpers.take_BANG_.call(null,state_97909__$1,(29),inst_97813);
} else {
if((state_val_97910 === (16))){
var inst_97778 = (state_97909[(21)]);
var inst_97784 = (state_97909[(2)]);
var state_97909__$1 = (function (){var statearr_97985 = state_97909;
(statearr_97985[(24)] = inst_97784);

return statearr_97985;
})();
if(cljs.core.truth_(inst_97778)){
var statearr_97986_98065 = state_97909__$1;
(statearr_97986_98065[(1)] = (17));

} else {
var statearr_97987_98066 = state_97909__$1;
(statearr_97987_98066[(1)] = (18));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97910 === (38))){
var inst_97821 = (state_97909[(17)]);
var inst_97851 = (state_97909[(2)]);
var state_97909__$1 = (function (){var statearr_97988 = state_97909;
(statearr_97988[(16)] = inst_97851);

return statearr_97988;
})();
if(cljs.core.truth_(inst_97821)){
var statearr_97989_98067 = state_97909__$1;
(statearr_97989_98067[(1)] = (39));

} else {
var statearr_97990_98068 = state_97909__$1;
(statearr_97990_98068[(1)] = (40));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97910 === (30))){
var inst_97770 = (state_97909[(10)]);
var inst_97766 = (state_97909[(9)]);
var inst_97823 = cljs.core.get.call(null,inst_97770,inst_97766);
var inst_97824 = cljs.core.count.call(null,inst_97823);
var inst_97825 = new cljs.core.Keyword(null,"limit","limit",-1355822363).cljs$core$IFn$_invoke$arity$1(pred_spec);
var inst_97826 = (inst_97824 > inst_97825);
var state_97909__$1 = state_97909;
var statearr_97991_98069 = state_97909__$1;
(statearr_97991_98069[(2)] = inst_97826);

(statearr_97991_98069[(1)] = (32));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97910 === (10))){
var inst_97764 = (state_97909[(2)]);
var state_97909__$1 = state_97909;
var statearr_97992_98070 = state_97909__$1;
(statearr_97992_98070[(2)] = inst_97764);

(statearr_97992_98070[(1)] = (7));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97910 === (18))){
var inst_97754 = (state_97909[(8)]);
var inst_97784 = (state_97909[(24)]);
var inst_97766 = (state_97909[(9)]);
var inst_97787 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_97788 = [inst_97766,inst_97754];
var inst_97789 = (new cljs.core.PersistentVector(null,2,(5),inst_97787,inst_97788,null));
var inst_97790 = ((0) + (1));
var inst_97791 = cljs.core.assoc_in.call(null,inst_97784,inst_97789,inst_97790);
var state_97909__$1 = state_97909;
var statearr_97993_98071 = state_97909__$1;
(statearr_97993_98071[(2)] = inst_97791);

(statearr_97993_98071[(1)] = (19));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97910 === (52))){
var inst_97778 = (state_97909[(21)]);
var state_97909__$1 = state_97909;
var statearr_97994_98072 = state_97909__$1;
(statearr_97994_98072[(2)] = inst_97778);

(statearr_97994_98072[(1)] = (53));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97910 === (42))){
var inst_97858 = (state_97909[(20)]);
var state_97909__$1 = state_97909;
var statearr_97995_98073 = state_97909__$1;
(statearr_97995_98073[(2)] = inst_97858);

(statearr_97995_98073[(1)] = (44));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97910 === (37))){
var inst_97770 = (state_97909[(10)]);
var inst_97754 = (state_97909[(8)]);
var inst_97766 = (state_97909[(9)]);
var inst_97846 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_97847 = [inst_97766,new cljs.core.Keyword(null,"_id","_id",-789960287)];
var inst_97848 = (new cljs.core.PersistentVector(null,2,(5),inst_97846,inst_97847,null));
var inst_97849 = cljs.core.assoc_in.call(null,inst_97770,inst_97848,inst_97754);
var state_97909__$1 = state_97909;
var statearr_97996_98074 = state_97909__$1;
(statearr_97996_98074[(2)] = inst_97849);

(statearr_97996_98074[(1)] = (38));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97910 === (8))){
var inst_97759 = (state_97909[(23)]);
var state_97909__$1 = state_97909;
var statearr_97997_98075 = state_97909__$1;
(statearr_97997_98075[(2)] = inst_97759);

(statearr_97997_98075[(1)] = (10));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_97910 === (49))){
var state_97909__$1 = state_97909;
var statearr_97998_98076 = state_97909__$1;
(statearr_97998_98076[(2)] = null);

(statearr_97998_98076[(1)] = (50));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
return null;
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
});})(c__86675__auto__))
;
return ((function (switch__86624__auto__,c__86675__auto__){
return (function() {
var fluree$db$query$fql$flake__GT_recur_$_state_machine__86625__auto__ = null;
var fluree$db$query$fql$flake__GT_recur_$_state_machine__86625__auto____0 = (function (){
var statearr_97999 = [null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null];
(statearr_97999[(0)] = fluree$db$query$fql$flake__GT_recur_$_state_machine__86625__auto__);

(statearr_97999[(1)] = (1));

return statearr_97999;
});
var fluree$db$query$fql$flake__GT_recur_$_state_machine__86625__auto____1 = (function (state_97909){
while(true){
var ret_value__86626__auto__ = (function (){try{while(true){
var result__86627__auto__ = switch__86624__auto__.call(null,state_97909);
if(cljs.core.keyword_identical_QMARK_.call(null,result__86627__auto__,new cljs.core.Keyword(null,"recur","recur",-437573268))){
continue;
} else {
return result__86627__auto__;
}
break;
}
}catch (e98000){if((e98000 instanceof Object)){
var ex__86628__auto__ = e98000;
var statearr_98001_98077 = state_97909;
(statearr_98001_98077[(5)] = ex__86628__auto__);


cljs.core.async.impl.ioc_helpers.process_exception.call(null,state_97909);

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
throw e98000;

}
}})();
if(cljs.core.keyword_identical_QMARK_.call(null,ret_value__86626__auto__,new cljs.core.Keyword(null,"recur","recur",-437573268))){
var G__98078 = state_97909;
state_97909 = G__98078;
continue;
} else {
return ret_value__86626__auto__;
}
break;
}
});
fluree$db$query$fql$flake__GT_recur_$_state_machine__86625__auto__ = function(state_97909){
switch(arguments.length){
case 0:
return fluree$db$query$fql$flake__GT_recur_$_state_machine__86625__auto____0.call(this);
case 1:
return fluree$db$query$fql$flake__GT_recur_$_state_machine__86625__auto____1.call(this,state_97909);
}
throw(new Error('Invalid arity: ' + arguments.length));
};
fluree$db$query$fql$flake__GT_recur_$_state_machine__86625__auto__.cljs$core$IFn$_invoke$arity$0 = fluree$db$query$fql$flake__GT_recur_$_state_machine__86625__auto____0;
fluree$db$query$fql$flake__GT_recur_$_state_machine__86625__auto__.cljs$core$IFn$_invoke$arity$1 = fluree$db$query$fql$flake__GT_recur_$_state_machine__86625__auto____1;
return fluree$db$query$fql$flake__GT_recur_$_state_machine__86625__auto__;
})()
;})(switch__86624__auto__,c__86675__auto__))
})();
var state__86677__auto__ = (function (){var statearr_98002 = f__86676__auto__.call(null);
(statearr_98002[(6)] = c__86675__auto__);

return statearr_98002;
})();
return cljs.core.async.impl.ioc_helpers.run_state_machine_wrapped.call(null,state__86677__auto__);
});})(c__86675__auto__))
);

return c__86675__auto__;
});
/**
 * Takes a sequence of flakes of the same subject and
 *   composes them into a map result based on the 'select' spec
 *   provided. Optionally, also follows components or recurs.
 */
fluree.db.query.fql.flakes__GT_res = (function fluree$db$query$fql$flakes__GT_res(db,cache,fuel,max_fuel,base_select_spec,flakes){
var c__86675__auto__ = cljs.core.async.chan.call(null,(1));
cljs.core.async.impl.dispatch.run.call(null,((function (c__86675__auto__){
return (function (){
var f__86676__auto__ = (function (){var switch__86624__auto__ = ((function (c__86675__auto__){
return (function (state_98262){
var state_val_98263 = (state_98262[(1)]);
if((state_val_98263 === (7))){
var inst_98258 = (state_98262[(2)]);
var state_98262__$1 = state_98262;
var statearr_98264_98344 = state_98262__$1;
(statearr_98264_98344[(2)] = inst_98258);


cljs.core.async.impl.ioc_helpers.process_exception.call(null,state_98262__$1);

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98263 === (20))){
var inst_98100 = (state_98262[(7)]);
var inst_98120 = cljs.core.first.call(null,flakes);
var inst_98121 = fluree.db.query.fql.s.call(null,inst_98120);
var inst_98122 = fluree.db.query.fql.select_spec__GT_reverse_pred_specs.call(null,inst_98100);
var inst_98123 = fluree.db.query.fql.resolve_reverse_refs.call(null,db,cache,fuel,max_fuel,inst_98121,inst_98122);
var state_98262__$1 = state_98262;
return cljs.core.async.impl.ioc_helpers.take_BANG_.call(null,state_98262__$1,(23),inst_98123);
} else {
if((state_val_98263 === (27))){
var inst_98100 = (state_98262[(7)]);
var inst_98144 = (state_98262[(8)]);
var inst_98151 = (state_98262[(9)]);
var inst_98149 = (state_98262[(10)]);
var inst_98133 = (state_98262[(11)]);
var inst_98144__$1 = cljs.core.first.call(null,inst_98133);
var inst_98145 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_98146 = inst_98144__$1.p;
var inst_98147 = [new cljs.core.Keyword(null,"select","select",1147833503),new cljs.core.Keyword(null,"pred-id","pred-id",-942630484),inst_98146];
var inst_98148 = (new cljs.core.PersistentVector(null,3,(5),inst_98145,inst_98147,null));
var inst_98149__$1 = cljs.core.get_in.call(null,inst_98100,inst_98148);
var inst_98150 = fluree.db.query.fql.component_follow_QMARK_.call(null,inst_98149__$1,inst_98100);
var inst_98151__$1 = new cljs.core.Keyword(null,"multi?","multi?",-749311069).cljs$core$IFn$_invoke$arity$1(inst_98149__$1);
var state_98262__$1 = (function (){var statearr_98265 = state_98262;
(statearr_98265[(12)] = inst_98150);

(statearr_98265[(8)] = inst_98144__$1);

(statearr_98265[(9)] = inst_98151__$1);

(statearr_98265[(10)] = inst_98149__$1);

return statearr_98265;
})();
if(cljs.core.truth_(inst_98151__$1)){
var statearr_98266_98345 = state_98262__$1;
(statearr_98266_98345[(1)] = (29));

} else {
var statearr_98267_98346 = state_98262__$1;
(statearr_98267_98346[(1)] = (30));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98263 === (1))){
var state_98262__$1 = state_98262;
var statearr_98268_98347 = state_98262__$1;
(statearr_98268_98347[(2)] = null);

(statearr_98268_98347[(1)] = (4));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98263 === (24))){
var inst_98133 = (state_98262[(11)]);
var inst_98138 = cljs.core.empty_QMARK_.call(null,inst_98133);
var state_98262__$1 = state_98262;
if(inst_98138){
var statearr_98269_98348 = state_98262__$1;
(statearr_98269_98348[(1)] = (26));

} else {
var statearr_98270_98349 = state_98262__$1;
(statearr_98270_98349[(1)] = (27));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98263 === (55))){
var state_98262__$1 = state_98262;
var statearr_98271_98350 = state_98262__$1;
(statearr_98271_98350[(2)] = null);

(statearr_98271_98350[(1)] = (56));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98263 === (39))){
var inst_98167 = (state_98262[(2)]);
var inst_98168 = fluree.db.util.async.throw_err.call(null,inst_98167);
var state_98262__$1 = state_98262;
var statearr_98272_98351 = state_98262__$1;
(statearr_98272_98351[(2)] = inst_98168);

(statearr_98272_98351[(1)] = (38));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98263 === (46))){
var inst_98225 = (state_98262[(2)]);
var state_98262__$1 = state_98262;
var statearr_98273_98352 = state_98262__$1;
(statearr_98273_98352[(2)] = inst_98225);

(statearr_98273_98352[(1)] = (42));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98263 === (4))){
var _ = cljs.core.async.impl.ioc_helpers.add_exception_frame.call(null,state_98262,(3),Error,null,(2));
var inst_98083 = cljs.core.not_empty.call(null,flakes);
var state_98262__$1 = state_98262;
if(cljs.core.truth_(inst_98083)){
var statearr_98274_98353 = state_98262__$1;
(statearr_98274_98353[(1)] = (5));

} else {
var statearr_98275_98354 = state_98262__$1;
(statearr_98275_98354[(1)] = (6));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98263 === (54))){
var inst_98135 = (state_98262[(13)]);
var inst_98136 = (state_98262[(14)]);
var inst_98134 = (state_98262[(15)]);
var inst_98133 = (state_98262[(11)]);
var inst_98215 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_98216 = cljs.core.rest.call(null,inst_98133);
var inst_98217 = [inst_98134,inst_98216,inst_98135,inst_98136];
var inst_98218 = (new cljs.core.PersistentVector(null,4,(5),inst_98215,inst_98217,null));
var state_98262__$1 = state_98262;
var statearr_98276_98355 = state_98262__$1;
(statearr_98276_98355[(2)] = inst_98218);

(statearr_98276_98355[(1)] = (56));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98263 === (15))){
var inst_98100 = (state_98262[(7)]);
var inst_98104 = new cljs.core.Keyword(null,"id?","id?",-1487101183).cljs$core$IFn$_invoke$arity$1(inst_98100);
var state_98262__$1 = state_98262;
var statearr_98277_98356 = state_98262__$1;
(statearr_98277_98356[(2)] = inst_98104);

(statearr_98277_98356[(1)] = (16));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98263 === (48))){
var inst_98100 = (state_98262[(7)]);
var inst_98200 = new cljs.core.Keyword(null,"id?","id?",-1487101183).cljs$core$IFn$_invoke$arity$1(inst_98100);
var state_98262__$1 = state_98262;
var statearr_98278_98357 = state_98262__$1;
(statearr_98278_98357[(2)] = inst_98200);

(statearr_98278_98357[(1)] = (50));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98263 === (50))){
var inst_98203 = (state_98262[(2)]);
var state_98262__$1 = state_98262;
if(cljs.core.truth_(inst_98203)){
var statearr_98279_98358 = state_98262__$1;
(statearr_98279_98358[(1)] = (51));

} else {
var statearr_98280_98359 = state_98262__$1;
(statearr_98280_98359[(1)] = (52));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98263 === (21))){
var inst_98114 = (state_98262[(16)]);
var state_98262__$1 = state_98262;
var statearr_98281_98360 = state_98262__$1;
(statearr_98281_98360[(2)] = inst_98114);

(statearr_98281_98360[(1)] = (22));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98263 === (31))){
var inst_98156 = (state_98262[(2)]);
var state_98262__$1 = state_98262;
if(cljs.core.truth_(inst_98156)){
var statearr_98282_98361 = state_98262__$1;
(statearr_98282_98361[(1)] = (32));

} else {
var statearr_98283_98362 = state_98262__$1;
(statearr_98283_98362[(1)] = (33));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98263 === (32))){
var inst_98135 = (state_98262[(13)]);
var inst_98100 = (state_98262[(7)]);
var inst_98134 = (state_98262[(15)]);
var inst_98144 = (state_98262[(8)]);
var inst_98149 = (state_98262[(10)]);
var inst_98133 = (state_98262[(11)]);
var inst_98158 = fluree.db.query.fql.flake__GT_recur_multi.call(null,db,inst_98144,inst_98149,inst_98135,inst_98133,inst_98134,fuel,max_fuel,inst_98100,cache,fluree.db.query.fql.component_follow_QMARK_);
var state_98262__$1 = state_98262;
return cljs.core.async.impl.ioc_helpers.take_BANG_.call(null,state_98262__$1,(35),inst_98158);
} else {
if((state_val_98263 === (40))){
var inst_98150 = (state_98262[(12)]);
var inst_98136 = (state_98262[(14)]);
var inst_98134 = (state_98262[(15)]);
var inst_98144 = (state_98262[(8)]);
var inst_98149 = (state_98262[(10)]);
var inst_98174 = fluree.db.query.fql.add_pred.call(null,db,cache,fuel,max_fuel,inst_98134,inst_98149,inst_98144,inst_98150,false,inst_98136);
var state_98262__$1 = state_98262;
return cljs.core.async.impl.ioc_helpers.take_BANG_.call(null,state_98262__$1,(43),inst_98174);
} else {
if((state_val_98263 === (56))){
var inst_98221 = (state_98262[(2)]);
var state_98262__$1 = state_98262;
var statearr_98284_98363 = state_98262__$1;
(statearr_98284_98363[(2)] = inst_98221);

(statearr_98284_98363[(1)] = (53));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98263 === (33))){
var inst_98149 = (state_98262[(10)]);
var inst_98163 = new cljs.core.Keyword(null,"recur","recur",-437573268).cljs$core$IFn$_invoke$arity$1(inst_98149);
var state_98262__$1 = state_98262;
if(cljs.core.truth_(inst_98163)){
var statearr_98285_98364 = state_98262__$1;
(statearr_98285_98364[(1)] = (36));

} else {
var statearr_98286_98365 = state_98262__$1;
(statearr_98286_98365[(1)] = (37));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98263 === (13))){
var inst_98101 = (state_98262[(17)]);
var inst_98100 = (state_98262[(7)]);
var inst_98100__$1 = (state_98262[(2)]);
var inst_98101__$1 = new cljs.core.Keyword(null,"wildcard?","wildcard?",-686044101).cljs$core$IFn$_invoke$arity$1(inst_98100__$1);
var state_98262__$1 = (function (){var statearr_98287 = state_98262;
(statearr_98287[(17)] = inst_98101__$1);

(statearr_98287[(7)] = inst_98100__$1);

return statearr_98287;
})();
if(cljs.core.truth_(inst_98101__$1)){
var statearr_98288_98366 = state_98262__$1;
(statearr_98288_98366[(1)] = (14));

} else {
var statearr_98289_98367 = state_98262__$1;
(statearr_98289_98367[(1)] = (15));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98263 === (22))){
var inst_98130 = (state_98262[(18)]);
var inst_98130__$1 = (state_98262[(2)]);
var inst_98131 = cljs.core.PersistentHashMap.EMPTY;
var inst_98132 = cljs.core.PersistentHashMap.EMPTY;
var inst_98133 = flakes;
var inst_98134 = inst_98130__$1;
var inst_98135 = inst_98131;
var inst_98136 = inst_98132;
var state_98262__$1 = (function (){var statearr_98290 = state_98262;
(statearr_98290[(13)] = inst_98135);

(statearr_98290[(14)] = inst_98136);

(statearr_98290[(18)] = inst_98130__$1);

(statearr_98290[(15)] = inst_98134);

(statearr_98290[(11)] = inst_98133);

return statearr_98290;
})();
var statearr_98291_98368 = state_98262__$1;
(statearr_98291_98368[(2)] = null);

(statearr_98291_98368[(1)] = (24));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98263 === (36))){
var inst_98135 = (state_98262[(13)]);
var inst_98100 = (state_98262[(7)]);
var inst_98134 = (state_98262[(15)]);
var inst_98144 = (state_98262[(8)]);
var inst_98149 = (state_98262[(10)]);
var inst_98133 = (state_98262[(11)]);
var inst_98165 = fluree.db.query.fql.flake__GT_recur.call(null,db,inst_98144,inst_98149,inst_98135,inst_98133,inst_98134,fuel,max_fuel,inst_98100,cache);
var state_98262__$1 = state_98262;
return cljs.core.async.impl.ioc_helpers.take_BANG_.call(null,state_98262__$1,(39),inst_98165);
} else {
if((state_val_98263 === (41))){
var inst_98100 = (state_98262[(7)]);
var inst_98185 = new cljs.core.Keyword(null,"wildcard?","wildcard?",-686044101).cljs$core$IFn$_invoke$arity$1(inst_98100);
var state_98262__$1 = state_98262;
if(cljs.core.truth_(inst_98185)){
var statearr_98292_98369 = state_98262__$1;
(statearr_98292_98369[(1)] = (44));

} else {
var statearr_98293_98370 = state_98262__$1;
(statearr_98293_98370[(1)] = (45));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98263 === (43))){
var inst_98135 = (state_98262[(13)]);
var inst_98133 = (state_98262[(11)]);
var inst_98176 = (state_98262[(2)]);
var inst_98177 = fluree.db.util.async.throw_err.call(null,inst_98176);
var inst_98178 = cljs.core.nth.call(null,inst_98177,(0),null);
var inst_98179 = cljs.core.nth.call(null,inst_98177,(1),null);
var inst_98180 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_98181 = cljs.core.rest.call(null,inst_98133);
var inst_98182 = [inst_98178,inst_98181,inst_98135,inst_98179];
var inst_98183 = (new cljs.core.PersistentVector(null,4,(5),inst_98180,inst_98182,null));
var state_98262__$1 = state_98262;
var statearr_98294_98371 = state_98262__$1;
(statearr_98294_98371[(2)] = inst_98183);

(statearr_98294_98371[(1)] = (42));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98263 === (29))){
var inst_98149 = (state_98262[(10)]);
var inst_98153 = new cljs.core.Keyword(null,"recur","recur",-437573268).cljs$core$IFn$_invoke$arity$1(inst_98149);
var state_98262__$1 = state_98262;
var statearr_98295_98372 = state_98262__$1;
(statearr_98295_98372[(2)] = inst_98153);

(statearr_98295_98372[(1)] = (31));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98263 === (44))){
var inst_98150 = (state_98262[(12)]);
var inst_98100 = (state_98262[(7)]);
var inst_98134 = (state_98262[(15)]);
var inst_98144 = (state_98262[(8)]);
var inst_98187 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_98188 = fluree.db.query.fql.add_pred.call(null,db,cache,fuel,max_fuel,inst_98134,inst_98100,inst_98144,inst_98150,false);
var state_98262__$1 = (function (){var statearr_98296 = state_98262;
(statearr_98296[(19)] = inst_98187);

return statearr_98296;
})();
return cljs.core.async.impl.ioc_helpers.take_BANG_.call(null,state_98262__$1,(47),inst_98188);
} else {
if((state_val_98263 === (6))){
var state_98262__$1 = state_98262;
var statearr_98297_98373 = state_98262__$1;
(statearr_98297_98373[(2)] = null);

(statearr_98297_98373[(1)] = (7));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98263 === (28))){
var inst_98240 = (state_98262[(2)]);
var state_98262__$1 = state_98262;
var statearr_98298_98374 = state_98262__$1;
(statearr_98298_98374[(2)] = inst_98240);

(statearr_98298_98374[(1)] = (25));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98263 === (51))){
var inst_98135 = (state_98262[(13)]);
var inst_98136 = (state_98262[(14)]);
var inst_98144 = (state_98262[(8)]);
var inst_98133 = (state_98262[(11)]);
var inst_98205 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_98206 = ["_id"];
var inst_98207 = inst_98144.s;
var inst_98208 = [inst_98207];
var inst_98209 = cljs.core.PersistentHashMap.fromArrays(inst_98206,inst_98208);
var inst_98210 = cljs.core.rest.call(null,inst_98133);
var inst_98211 = [inst_98209,inst_98210,inst_98135,inst_98136];
var inst_98212 = (new cljs.core.PersistentVector(null,4,(5),inst_98205,inst_98211,null));
var state_98262__$1 = state_98262;
var statearr_98299_98375 = state_98262__$1;
(statearr_98299_98375[(2)] = inst_98212);

(statearr_98299_98375[(1)] = (53));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98263 === (25))){
var inst_98100 = (state_98262[(7)]);
var inst_98130 = (state_98262[(18)]);
var inst_98094 = (state_98262[(20)]);
var inst_98114 = (state_98262[(16)]);
var inst_98242 = (state_98262[(2)]);
var inst_98243 = (function (){var top_level_subject = inst_98094;
var select_spec = inst_98100;
var base_acc = inst_98114;
var acc_PLUS_refs = inst_98130;
var result = inst_98242;
return ((function (top_level_subject,select_spec,base_acc,acc_PLUS_refs,result,inst_98100,inst_98130,inst_98094,inst_98114,inst_98242,state_val_98263,c__86675__auto__){
return (function (acc,spec){
if(cljs.core.truth_((function (){var or__4131__auto__ = (function (){var and__4120__auto__ = new cljs.core.Keyword(null,"multi?","multi?",-749311069).cljs$core$IFn$_invoke$arity$1(spec);
if(cljs.core.truth_(and__4120__auto__)){
return new cljs.core.Keyword(null,"orderBy","orderBy",-1329797793).cljs$core$IFn$_invoke$arity$1(spec);
} else {
return and__4120__auto__;
}
})();
if(cljs.core.truth_(or__4131__auto__)){
return or__4131__auto__;
} else {
var and__4120__auto__ = new cljs.core.Keyword(null,"reverse?","reverse?",-1672868474).cljs$core$IFn$_invoke$arity$1(spec);
if(cljs.core.truth_(and__4120__auto__)){
return new cljs.core.Keyword(null,"orderBy","orderBy",-1329797793).cljs$core$IFn$_invoke$arity$1(spec);
} else {
return and__4120__auto__;
}
}
})())){
return cljs.core.conj.call(null,acc,new cljs.core.PersistentVector(null, 4, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"as","as",1148689641).cljs$core$IFn$_invoke$arity$1(spec),new cljs.core.Keyword(null,"order","order",-1254677256).cljs$core$IFn$_invoke$arity$1(new cljs.core.Keyword(null,"orderBy","orderBy",-1329797793).cljs$core$IFn$_invoke$arity$1(spec)),new cljs.core.Keyword(null,"predicate","predicate",-1742501860).cljs$core$IFn$_invoke$arity$1(new cljs.core.Keyword(null,"orderBy","orderBy",-1329797793).cljs$core$IFn$_invoke$arity$1(spec)),new cljs.core.Keyword(null,"limit","limit",-1355822363).cljs$core$IFn$_invoke$arity$1(spec)], null));
} else {
return acc;
}
});
;})(top_level_subject,select_spec,base_acc,acc_PLUS_refs,result,inst_98100,inst_98130,inst_98094,inst_98114,inst_98242,state_val_98263,c__86675__auto__))
})();
var inst_98244 = cljs.core.PersistentVector.EMPTY;
var inst_98245 = new cljs.core.Keyword(null,"select","select",1147833503).cljs$core$IFn$_invoke$arity$1(inst_98100);
var inst_98246 = new cljs.core.Keyword(null,"pred-id","pred-id",-942630484).cljs$core$IFn$_invoke$arity$1(inst_98245);
var inst_98247 = cljs.core.vals.call(null,inst_98246);
var inst_98248 = new cljs.core.Keyword(null,"select","select",1147833503).cljs$core$IFn$_invoke$arity$1(inst_98100);
var inst_98249 = new cljs.core.Keyword(null,"reverse","reverse",-888455266).cljs$core$IFn$_invoke$arity$1(inst_98248);
var inst_98250 = cljs.core.vals.call(null,inst_98249);
var inst_98251 = cljs.core.concat.call(null,inst_98247,inst_98250);
var inst_98252 = cljs.core.reduce.call(null,inst_98243,inst_98244,inst_98251);
var inst_98254 = (function (){var top_level_subject = inst_98094;
var select_spec = inst_98100;
var base_acc = inst_98114;
var acc_PLUS_refs = inst_98130;
var result = inst_98242;
var sort_preds = inst_98252;
return ((function (top_level_subject,select_spec,base_acc,acc_PLUS_refs,result,sort_preds,inst_98100,inst_98130,inst_98094,inst_98114,inst_98242,inst_98243,inst_98244,inst_98245,inst_98246,inst_98247,inst_98248,inst_98249,inst_98250,inst_98251,inst_98252,state_val_98263,c__86675__auto__){
return (function (acc,p__98253){
var vec__98300 = p__98253;
var selectPred = cljs.core.nth.call(null,vec__98300,(0),null);
var sortOrder = cljs.core.nth.call(null,vec__98300,(1),null);
var sortPred = cljs.core.nth.call(null,vec__98300,(2),null);
var limit = cljs.core.nth.call(null,vec__98300,(3),null);
return cljs.core.assoc.call(null,acc,selectPred,fluree.db.query.fql.sort_offset_and_limit_res.call(null,sortPred,sortOrder,(0),limit,cljs.core.get.call(null,acc,selectPred)));
});
;})(top_level_subject,select_spec,base_acc,acc_PLUS_refs,result,sort_preds,inst_98100,inst_98130,inst_98094,inst_98114,inst_98242,inst_98243,inst_98244,inst_98245,inst_98246,inst_98247,inst_98248,inst_98249,inst_98250,inst_98251,inst_98252,state_val_98263,c__86675__auto__))
})();
var inst_98255 = cljs.core.reduce.call(null,inst_98254,inst_98242,inst_98252);
var state_98262__$1 = state_98262;
var statearr_98303_98376 = state_98262__$1;
(statearr_98303_98376[(2)] = inst_98255);

(statearr_98303_98376[(1)] = (7));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98263 === (34))){
var inst_98144 = (state_98262[(8)]);
var inst_98231 = (state_98262[(2)]);
var inst_98232 = cljs.core.nth.call(null,inst_98231,(0),null);
var inst_98233 = cljs.core.nth.call(null,inst_98231,(1),null);
var inst_98234 = cljs.core.nth.call(null,inst_98231,(2),null);
var inst_98235 = cljs.core.nth.call(null,inst_98231,(3),null);
var inst_98236 = inst_98144.s;
var inst_98237 = cljs.core.assoc.call(null,inst_98232,new cljs.core.Keyword(null,"_id","_id",-789960287),inst_98236);
var inst_98133 = inst_98233;
var inst_98134 = inst_98237;
var inst_98135 = inst_98234;
var inst_98136 = inst_98235;
var state_98262__$1 = (function (){var statearr_98304 = state_98262;
(statearr_98304[(13)] = inst_98135);

(statearr_98304[(14)] = inst_98136);

(statearr_98304[(15)] = inst_98134);

(statearr_98304[(11)] = inst_98133);

return statearr_98304;
})();
var statearr_98305_98377 = state_98262__$1;
(statearr_98305_98377[(2)] = null);

(statearr_98305_98377[(1)] = (24));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98263 === (17))){
var inst_98094 = (state_98262[(20)]);
var inst_98108 = ["_id"];
var inst_98109 = [inst_98094];
var inst_98110 = cljs.core.PersistentHashMap.fromArrays(inst_98108,inst_98109);
var state_98262__$1 = state_98262;
var statearr_98306_98378 = state_98262__$1;
(statearr_98306_98378[(2)] = inst_98110);

(statearr_98306_98378[(1)] = (19));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98263 === (3))){
var inst_98079 = (state_98262[(2)]);
var state_98262__$1 = state_98262;
var statearr_98307_98379 = state_98262__$1;
(statearr_98307_98379[(2)] = inst_98079);


cljs.core.async.impl.ioc_helpers.process_exception.call(null,state_98262__$1);

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98263 === (12))){
var state_98262__$1 = state_98262;
var statearr_98308_98380 = state_98262__$1;
(statearr_98308_98380[(2)] = base_select_spec);

(statearr_98308_98380[(1)] = (13));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98263 === (2))){
var inst_98260 = (state_98262[(2)]);
var state_98262__$1 = state_98262;
return cljs.core.async.impl.ioc_helpers.return_chan.call(null,state_98262__$1,inst_98260);
} else {
if((state_val_98263 === (23))){
var inst_98114 = (state_98262[(16)]);
var inst_98125 = (state_98262[(2)]);
var inst_98126 = fluree.db.util.async.throw_err.call(null,inst_98125);
var inst_98127 = cljs.core.merge.call(null,inst_98114,inst_98126);
var state_98262__$1 = state_98262;
var statearr_98309_98381 = state_98262__$1;
(statearr_98309_98381[(2)] = inst_98127);

(statearr_98309_98381[(1)] = (22));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98263 === (47))){
var inst_98135 = (state_98262[(13)]);
var inst_98136 = (state_98262[(14)]);
var inst_98187 = (state_98262[(19)]);
var inst_98133 = (state_98262[(11)]);
var inst_98190 = (state_98262[(2)]);
var inst_98191 = fluree.db.util.async.throw_err.call(null,inst_98190);
var inst_98192 = cljs.core.first.call(null,inst_98191);
var inst_98193 = cljs.core.rest.call(null,inst_98133);
var inst_98194 = [inst_98192,inst_98193,inst_98135,inst_98136];
var inst_98195 = (new cljs.core.PersistentVector(null,4,(5),inst_98187,inst_98194,null));
var state_98262__$1 = state_98262;
var statearr_98310_98382 = state_98262__$1;
(statearr_98310_98382[(2)] = inst_98195);

(statearr_98310_98382[(1)] = (46));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98263 === (35))){
var inst_98160 = (state_98262[(2)]);
var inst_98161 = fluree.db.util.async.throw_err.call(null,inst_98160);
var state_98262__$1 = state_98262;
var statearr_98311_98383 = state_98262__$1;
(statearr_98311_98383[(2)] = inst_98161);

(statearr_98311_98383[(1)] = (34));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98263 === (19))){
var inst_98100 = (state_98262[(7)]);
var inst_98114 = (state_98262[(2)]);
var inst_98115 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_98116 = [new cljs.core.Keyword(null,"select","select",1147833503),new cljs.core.Keyword(null,"reverse","reverse",-888455266)];
var inst_98117 = (new cljs.core.PersistentVector(null,2,(5),inst_98115,inst_98116,null));
var inst_98118 = cljs.core.get_in.call(null,inst_98100,inst_98117);
var state_98262__$1 = (function (){var statearr_98312 = state_98262;
(statearr_98312[(16)] = inst_98114);

return statearr_98312;
})();
if(cljs.core.truth_(inst_98118)){
var statearr_98313_98384 = state_98262__$1;
(statearr_98313_98384[(1)] = (20));

} else {
var statearr_98314_98385 = state_98262__$1;
(statearr_98314_98385[(1)] = (21));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98263 === (11))){
var inst_98094 = (state_98262[(20)]);
var inst_98097 = fluree.db.query.fql.full_select_spec.call(null,db,cache,base_select_spec,inst_98094);
var state_98262__$1 = state_98262;
var statearr_98315_98386 = state_98262__$1;
(statearr_98315_98386[(2)] = inst_98097);

(statearr_98315_98386[(1)] = (13));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98263 === (9))){
var inst_98085 = (state_98262[(2)]);
var inst_98086 = fluree.db.util.log.error.call(null,inst_98085);
var inst_98087 = (function(){throw inst_98085})();
var state_98262__$1 = (function (){var statearr_98316 = state_98262;
(statearr_98316[(21)] = inst_98086);

return statearr_98316;
})();
var statearr_98317_98387 = state_98262__$1;
(statearr_98317_98387[(2)] = inst_98087);


cljs.core.async.impl.ioc_helpers.process_exception.call(null,state_98262__$1);

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98263 === (5))){
var state_98262__$1 = state_98262;
var statearr_98318_98388 = state_98262__$1;
(statearr_98318_98388[(2)] = null);

(statearr_98318_98388[(1)] = (10));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98263 === (14))){
var inst_98101 = (state_98262[(17)]);
var state_98262__$1 = state_98262;
var statearr_98319_98389 = state_98262__$1;
(statearr_98319_98389[(2)] = inst_98101);

(statearr_98319_98389[(1)] = (16));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98263 === (45))){
var inst_98100 = (state_98262[(7)]);
var inst_98198 = (state_98262[(22)]);
var inst_98197 = new cljs.core.Keyword(null,"select","select",1147833503).cljs$core$IFn$_invoke$arity$1(inst_98100);
var inst_98198__$1 = cljs.core.empty_QMARK_.call(null,inst_98197);
var state_98262__$1 = (function (){var statearr_98320 = state_98262;
(statearr_98320[(22)] = inst_98198__$1);

return statearr_98320;
})();
if(inst_98198__$1){
var statearr_98321_98390 = state_98262__$1;
(statearr_98321_98390[(1)] = (48));

} else {
var statearr_98322_98391 = state_98262__$1;
(statearr_98322_98391[(1)] = (49));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98263 === (53))){
var inst_98223 = (state_98262[(2)]);
var state_98262__$1 = state_98262;
var statearr_98323_98392 = state_98262__$1;
(statearr_98323_98392[(2)] = inst_98223);

(statearr_98323_98392[(1)] = (46));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98263 === (26))){
var inst_98134 = (state_98262[(15)]);
var state_98262__$1 = state_98262;
var statearr_98324_98393 = state_98262__$1;
(statearr_98324_98393[(2)] = inst_98134);

(statearr_98324_98393[(1)] = (28));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98263 === (16))){
var inst_98106 = (state_98262[(2)]);
var state_98262__$1 = state_98262;
if(cljs.core.truth_(inst_98106)){
var statearr_98325_98394 = state_98262__$1;
(statearr_98325_98394[(1)] = (17));

} else {
var statearr_98326_98395 = state_98262__$1;
(statearr_98326_98395[(1)] = (18));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98263 === (38))){
var inst_98229 = (state_98262[(2)]);
var state_98262__$1 = state_98262;
var statearr_98327_98396 = state_98262__$1;
(statearr_98327_98396[(2)] = inst_98229);

(statearr_98327_98396[(1)] = (34));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98263 === (30))){
var inst_98151 = (state_98262[(9)]);
var state_98262__$1 = state_98262;
var statearr_98328_98397 = state_98262__$1;
(statearr_98328_98397[(2)] = inst_98151);

(statearr_98328_98397[(1)] = (31));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98263 === (10))){
var _ = cljs.core.async.impl.ioc_helpers.add_exception_frame.call(null,state_98262,(9),new cljs.core.Keyword(null,"default","default",-1987822328),null,(8));
var inst_98091 = cljs.core.first.call(null,flakes);
var inst_98092 = fluree.db.query.fql.s.call(null,inst_98091);
var state_98262__$1 = state_98262;
var statearr_98329_98398 = state_98262__$1;
(statearr_98329_98398[(2)] = inst_98092);


cljs.core.async.impl.ioc_helpers.process_exception.call(null,state_98262__$1);

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98263 === (18))){
var inst_98112 = cljs.core.PersistentHashMap.EMPTY;
var state_98262__$1 = state_98262;
var statearr_98330_98399 = state_98262__$1;
(statearr_98330_98399[(2)] = inst_98112);

(statearr_98330_98399[(1)] = (19));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98263 === (52))){
var state_98262__$1 = state_98262;
var statearr_98331_98400 = state_98262__$1;
(statearr_98331_98400[(1)] = (54));



return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98263 === (42))){
var inst_98227 = (state_98262[(2)]);
var state_98262__$1 = state_98262;
var statearr_98333_98401 = state_98262__$1;
(statearr_98333_98401[(2)] = inst_98227);

(statearr_98333_98401[(1)] = (38));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98263 === (37))){
var inst_98149 = (state_98262[(10)]);
var state_98262__$1 = state_98262;
if(cljs.core.truth_(inst_98149)){
var statearr_98334_98402 = state_98262__$1;
(statearr_98334_98402[(1)] = (40));

} else {
var statearr_98335_98403 = state_98262__$1;
(statearr_98335_98403[(1)] = (41));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98263 === (8))){
var inst_98094 = (state_98262[(2)]);
var inst_98095 = fluree.db.query.fql.has_ns_lookups_QMARK_.call(null,base_select_spec);
var state_98262__$1 = (function (){var statearr_98336 = state_98262;
(statearr_98336[(20)] = inst_98094);

return statearr_98336;
})();
if(cljs.core.truth_(inst_98095)){
var statearr_98337_98404 = state_98262__$1;
(statearr_98337_98404[(1)] = (11));

} else {
var statearr_98338_98405 = state_98262__$1;
(statearr_98338_98405[(1)] = (12));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98263 === (49))){
var inst_98198 = (state_98262[(22)]);
var state_98262__$1 = state_98262;
var statearr_98339_98406 = state_98262__$1;
(statearr_98339_98406[(2)] = inst_98198);

(statearr_98339_98406[(1)] = (50));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
return null;
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
});})(c__86675__auto__))
;
return ((function (switch__86624__auto__,c__86675__auto__){
return (function() {
var fluree$db$query$fql$flakes__GT_res_$_state_machine__86625__auto__ = null;
var fluree$db$query$fql$flakes__GT_res_$_state_machine__86625__auto____0 = (function (){
var statearr_98340 = [null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null];
(statearr_98340[(0)] = fluree$db$query$fql$flakes__GT_res_$_state_machine__86625__auto__);

(statearr_98340[(1)] = (1));

return statearr_98340;
});
var fluree$db$query$fql$flakes__GT_res_$_state_machine__86625__auto____1 = (function (state_98262){
while(true){
var ret_value__86626__auto__ = (function (){try{while(true){
var result__86627__auto__ = switch__86624__auto__.call(null,state_98262);
if(cljs.core.keyword_identical_QMARK_.call(null,result__86627__auto__,new cljs.core.Keyword(null,"recur","recur",-437573268))){
continue;
} else {
return result__86627__auto__;
}
break;
}
}catch (e98341){if((e98341 instanceof Object)){
var ex__86628__auto__ = e98341;
var statearr_98342_98407 = state_98262;
(statearr_98342_98407[(5)] = ex__86628__auto__);


cljs.core.async.impl.ioc_helpers.process_exception.call(null,state_98262);

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
throw e98341;

}
}})();
if(cljs.core.keyword_identical_QMARK_.call(null,ret_value__86626__auto__,new cljs.core.Keyword(null,"recur","recur",-437573268))){
var G__98408 = state_98262;
state_98262 = G__98408;
continue;
} else {
return ret_value__86626__auto__;
}
break;
}
});
fluree$db$query$fql$flakes__GT_res_$_state_machine__86625__auto__ = function(state_98262){
switch(arguments.length){
case 0:
return fluree$db$query$fql$flakes__GT_res_$_state_machine__86625__auto____0.call(this);
case 1:
return fluree$db$query$fql$flakes__GT_res_$_state_machine__86625__auto____1.call(this,state_98262);
}
throw(new Error('Invalid arity: ' + arguments.length));
};
fluree$db$query$fql$flakes__GT_res_$_state_machine__86625__auto__.cljs$core$IFn$_invoke$arity$0 = fluree$db$query$fql$flakes__GT_res_$_state_machine__86625__auto____0;
fluree$db$query$fql$flakes__GT_res_$_state_machine__86625__auto__.cljs$core$IFn$_invoke$arity$1 = fluree$db$query$fql$flakes__GT_res_$_state_machine__86625__auto____1;
return fluree$db$query$fql$flakes__GT_res_$_state_machine__86625__auto__;
})()
;})(switch__86624__auto__,c__86675__auto__))
})();
var state__86677__auto__ = (function (){var statearr_98343 = f__86676__auto__.call(null);
(statearr_98343[(6)] = c__86675__auto__);

return statearr_98343;
})();
return cljs.core.async.impl.ioc_helpers.run_state_machine_wrapped.call(null,state__86677__auto__);
});})(c__86675__auto__))
);

return c__86675__auto__;
});
/**
 * Runs a select statement based on a sequence of flakes.
 */
fluree.db.query.fql.flake_select = (function fluree$db$query$fql$flake_select(var_args){
var G__98411 = arguments.length;
switch (G__98411) {
case 6:
return fluree.db.query.fql.flake_select.cljs$core$IFn$_invoke$arity$6((arguments[(0)]),(arguments[(1)]),(arguments[(2)]),(arguments[(3)]),(arguments[(4)]),(arguments[(5)]));

break;
case 7:
return fluree.db.query.fql.flake_select.cljs$core$IFn$_invoke$arity$7((arguments[(0)]),(arguments[(1)]),(arguments[(2)]),(arguments[(3)]),(arguments[(4)]),(arguments[(5)]),(arguments[(6)]));

break;
case 8:
return fluree.db.query.fql.flake_select.cljs$core$IFn$_invoke$arity$8((arguments[(0)]),(arguments[(1)]),(arguments[(2)]),(arguments[(3)]),(arguments[(4)]),(arguments[(5)]),(arguments[(6)]),(arguments[(7)]));

break;
default:
throw (new Error(["Invalid arity: ",cljs.core.str.cljs$core$IFn$_invoke$arity$1(arguments.length)].join('')));

}
});

fluree.db.query.fql.flake_select.cljs$core$IFn$_invoke$arity$6 = (function (db,cache,fuel,max_fuel,select_spec,flakes){
return fluree.db.query.fql.flake_select.call(null,db,cache,fuel,max_fuel,select_spec,flakes,null,null);
});

fluree.db.query.fql.flake_select.cljs$core$IFn$_invoke$arity$7 = (function (db,cache,fuel,max_fuel,select_spec,flakes,limit){
return fluree.db.query.fql.flake_select.call(null,db,cache,fuel,max_fuel,select_spec,flakes,limit,null);
});

fluree.db.query.fql.flake_select.cljs$core$IFn$_invoke$arity$8 = (function (db,cache,fuel,max_fuel,select_spec,flakes,limit,offset){
var c__86675__auto__ = cljs.core.async.chan.call(null,(1));
cljs.core.async.impl.dispatch.run.call(null,((function (c__86675__auto__){
return (function (){
var f__86676__auto__ = (function (){var switch__86624__auto__ = ((function (c__86675__auto__){
return (function (state_98450){
var state_val_98451 = (state_98450[(1)]);
if((state_val_98451 === (7))){
var inst_98423 = (state_98450[(2)]);
var state_98450__$1 = (function (){var statearr_98452 = state_98450;
(statearr_98452[(7)] = inst_98423);

return statearr_98452;
})();
if(cljs.core.truth_(offset)){
var statearr_98453_98475 = state_98450__$1;
(statearr_98453_98475[(1)] = (8));

} else {
var statearr_98454_98476 = state_98450__$1;
(statearr_98454_98476[(1)] = (9));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98451 === (1))){
var state_98450__$1 = state_98450;
var statearr_98455_98477 = state_98450__$1;
(statearr_98455_98477[(2)] = null);

(statearr_98455_98477[(1)] = (4));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98451 === (4))){
var _ = cljs.core.async.impl.ioc_helpers.add_exception_frame.call(null,state_98450,(3),Error,null,(2));
var inst_98417 = cljs.core.partition_by.call(null,fluree.db.query.fql.s);
var state_98450__$1 = (function (){var statearr_98456 = state_98450;
(statearr_98456[(8)] = inst_98417);

return statearr_98456;
})();
if(cljs.core.truth_(fuel)){
var statearr_98457_98478 = state_98450__$1;
(statearr_98457_98478[(1)] = (5));

} else {
var statearr_98458_98479 = state_98450__$1;
(statearr_98458_98479[(1)] = (6));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98451 === (13))){
var inst_98435 = (state_98450[(2)]);
var inst_98436 = (function (){return ((function (inst_98435,state_val_98451,c__86675__auto__){
return (function (x){
var and__4120__auto__ = max_fuel;
if(cljs.core.truth_(and__4120__auto__)){
return (cljs.core.deref.call(null,fuel) >= max_fuel);
} else {
return and__4120__auto__;
}
});
;})(inst_98435,state_val_98451,c__86675__auto__))
})();
var inst_98437 = cljs.core.halt_when.call(null,inst_98436);
var inst_98438 = cljs.core.comp.call(null,inst_98435,inst_98437);
var inst_98439 = cljs.core.sequence.call(null,inst_98438,flakes);
var inst_98440 = cljs.core.PersistentVector.EMPTY;
var inst_98441 = (function (){var xf = inst_98438;
var flakes_by_sub = inst_98439;
return ((function (xf,flakes_by_sub,inst_98435,inst_98436,inst_98437,inst_98438,inst_98439,inst_98440,state_val_98451,c__86675__auto__){
return (function (p1__98409_SHARP_){
return fluree.db.query.fql.flakes__GT_res.call(null,db,cache,fuel,max_fuel,select_spec,p1__98409_SHARP_);
});
;})(xf,flakes_by_sub,inst_98435,inst_98436,inst_98437,inst_98438,inst_98439,inst_98440,state_val_98451,c__86675__auto__))
})();
var inst_98442 = cljs.core.map.call(null,inst_98441,inst_98439);
var inst_98443 = fluree.db.util.async.merge_into_QMARK_.call(null,inst_98440,inst_98442);
var state_98450__$1 = state_98450;
return cljs.core.async.impl.ioc_helpers.take_BANG_.call(null,state_98450__$1,(14),inst_98443);
} else {
if((state_val_98451 === (6))){
var inst_98417 = (state_98450[(8)]);
var state_98450__$1 = state_98450;
var statearr_98459_98480 = state_98450__$1;
(statearr_98459_98480[(2)] = inst_98417);

(statearr_98459_98480[(1)] = (7));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98451 === (3))){
var inst_98412 = (state_98450[(2)]);
var state_98450__$1 = state_98450;
var statearr_98460_98481 = state_98450__$1;
(statearr_98460_98481[(2)] = inst_98412);


cljs.core.async.impl.ioc_helpers.process_exception.call(null,state_98450__$1);

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98451 === (12))){
var inst_98429 = (state_98450[(9)]);
var state_98450__$1 = state_98450;
var statearr_98461_98482 = state_98450__$1;
(statearr_98461_98482[(2)] = inst_98429);

(statearr_98461_98482[(1)] = (13));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98451 === (2))){
var inst_98448 = (state_98450[(2)]);
var state_98450__$1 = state_98450;
return cljs.core.async.impl.ioc_helpers.return_chan.call(null,state_98450__$1,inst_98448);
} else {
if((state_val_98451 === (11))){
var inst_98429 = (state_98450[(9)]);
var inst_98431 = cljs.core.take.call(null,limit);
var inst_98432 = cljs.core.comp.call(null,inst_98429,inst_98431);
var state_98450__$1 = state_98450;
var statearr_98462_98483 = state_98450__$1;
(statearr_98462_98483[(2)] = inst_98432);

(statearr_98462_98483[(1)] = (13));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98451 === (9))){
var inst_98423 = (state_98450[(7)]);
var state_98450__$1 = state_98450;
var statearr_98463_98484 = state_98450__$1;
(statearr_98463_98484[(2)] = inst_98423);

(statearr_98463_98484[(1)] = (10));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98451 === (5))){
var inst_98417 = (state_98450[(8)]);
var inst_98419 = fluree.db.query.fql.fuel_flakes_transducer.call(null,fuel,max_fuel);
var inst_98420 = cljs.core.comp.call(null,inst_98417,inst_98419);
var state_98450__$1 = state_98450;
var statearr_98464_98485 = state_98450__$1;
(statearr_98464_98485[(2)] = inst_98420);

(statearr_98464_98485[(1)] = (7));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98451 === (14))){
var inst_98445 = (state_98450[(2)]);
var inst_98446 = fluree.db.util.async.throw_err.call(null,inst_98445);
var state_98450__$1 = state_98450;
var statearr_98465_98486 = state_98450__$1;
(statearr_98465_98486[(2)] = inst_98446);


cljs.core.async.impl.ioc_helpers.process_exception.call(null,state_98450__$1);

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98451 === (10))){
var inst_98429 = (state_98450[(2)]);
var state_98450__$1 = (function (){var statearr_98466 = state_98450;
(statearr_98466[(9)] = inst_98429);

return statearr_98466;
})();
if(cljs.core.truth_(limit)){
var statearr_98467_98487 = state_98450__$1;
(statearr_98467_98487[(1)] = (11));

} else {
var statearr_98468_98488 = state_98450__$1;
(statearr_98468_98488[(1)] = (12));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98451 === (8))){
var inst_98423 = (state_98450[(7)]);
var inst_98425 = cljs.core.drop.call(null,offset);
var inst_98426 = cljs.core.comp.call(null,inst_98423,inst_98425);
var state_98450__$1 = state_98450;
var statearr_98469_98489 = state_98450__$1;
(statearr_98469_98489[(2)] = inst_98426);

(statearr_98469_98489[(1)] = (10));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
return null;
}
}
}
}
}
}
}
}
}
}
}
}
}
}
});})(c__86675__auto__))
;
return ((function (switch__86624__auto__,c__86675__auto__){
return (function() {
var fluree$db$query$fql$state_machine__86625__auto__ = null;
var fluree$db$query$fql$state_machine__86625__auto____0 = (function (){
var statearr_98470 = [null,null,null,null,null,null,null,null,null,null];
(statearr_98470[(0)] = fluree$db$query$fql$state_machine__86625__auto__);

(statearr_98470[(1)] = (1));

return statearr_98470;
});
var fluree$db$query$fql$state_machine__86625__auto____1 = (function (state_98450){
while(true){
var ret_value__86626__auto__ = (function (){try{while(true){
var result__86627__auto__ = switch__86624__auto__.call(null,state_98450);
if(cljs.core.keyword_identical_QMARK_.call(null,result__86627__auto__,new cljs.core.Keyword(null,"recur","recur",-437573268))){
continue;
} else {
return result__86627__auto__;
}
break;
}
}catch (e98471){if((e98471 instanceof Object)){
var ex__86628__auto__ = e98471;
var statearr_98472_98490 = state_98450;
(statearr_98472_98490[(5)] = ex__86628__auto__);


cljs.core.async.impl.ioc_helpers.process_exception.call(null,state_98450);

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
throw e98471;

}
}})();
if(cljs.core.keyword_identical_QMARK_.call(null,ret_value__86626__auto__,new cljs.core.Keyword(null,"recur","recur",-437573268))){
var G__98491 = state_98450;
state_98450 = G__98491;
continue;
} else {
return ret_value__86626__auto__;
}
break;
}
});
fluree$db$query$fql$state_machine__86625__auto__ = function(state_98450){
switch(arguments.length){
case 0:
return fluree$db$query$fql$state_machine__86625__auto____0.call(this);
case 1:
return fluree$db$query$fql$state_machine__86625__auto____1.call(this,state_98450);
}
throw(new Error('Invalid arity: ' + arguments.length));
};
fluree$db$query$fql$state_machine__86625__auto__.cljs$core$IFn$_invoke$arity$0 = fluree$db$query$fql$state_machine__86625__auto____0;
fluree$db$query$fql$state_machine__86625__auto__.cljs$core$IFn$_invoke$arity$1 = fluree$db$query$fql$state_machine__86625__auto____1;
return fluree$db$query$fql$state_machine__86625__auto__;
})()
;})(switch__86624__auto__,c__86675__auto__))
})();
var state__86677__auto__ = (function (){var statearr_98473 = f__86676__auto__.call(null);
(statearr_98473[(6)] = c__86675__auto__);

return statearr_98473;
})();
return cljs.core.async.impl.ioc_helpers.run_state_machine_wrapped.call(null,state__86677__auto__);
});})(c__86675__auto__))
);

return c__86675__auto__;
});

fluree.db.query.fql.flake_select.cljs$lang$maxFixedArity = 8;

/**
 * Like flake select, but takes a collection of subject ids which we
 *   then find collections of flakes for.
 */
fluree.db.query.fql.subject_select = (function fluree$db$query$fql$subject_select(var_args){
var G__98493 = arguments.length;
switch (G__98493) {
case 6:
return fluree.db.query.fql.subject_select.cljs$core$IFn$_invoke$arity$6((arguments[(0)]),(arguments[(1)]),(arguments[(2)]),(arguments[(3)]),(arguments[(4)]),(arguments[(5)]));

break;
case 7:
return fluree.db.query.fql.subject_select.cljs$core$IFn$_invoke$arity$7((arguments[(0)]),(arguments[(1)]),(arguments[(2)]),(arguments[(3)]),(arguments[(4)]),(arguments[(5)]),(arguments[(6)]));

break;
case 8:
return fluree.db.query.fql.subject_select.cljs$core$IFn$_invoke$arity$8((arguments[(0)]),(arguments[(1)]),(arguments[(2)]),(arguments[(3)]),(arguments[(4)]),(arguments[(5)]),(arguments[(6)]),(arguments[(7)]));

break;
default:
throw (new Error(["Invalid arity: ",cljs.core.str.cljs$core$IFn$_invoke$arity$1(arguments.length)].join('')));

}
});

fluree.db.query.fql.subject_select.cljs$core$IFn$_invoke$arity$6 = (function (db,cache,fuel,max_fuel,select_spec,subjects){
return fluree.db.query.fql.subject_select.call(null,db,cache,fuel,max_fuel,select_spec,subjects,null,null);
});

fluree.db.query.fql.subject_select.cljs$core$IFn$_invoke$arity$7 = (function (db,cache,fuel,max_fuel,select_spec,subjects,limit){
return fluree.db.query.fql.subject_select.call(null,db,cache,fuel,max_fuel,select_spec,subjects,limit,null);
});

fluree.db.query.fql.subject_select.cljs$core$IFn$_invoke$arity$8 = (function (db,cache,fuel,max_fuel,select_spec,subjects,limit,offset){
var c__86675__auto__ = cljs.core.async.chan.call(null,(1));
cljs.core.async.impl.dispatch.run.call(null,((function (c__86675__auto__){
return (function (){
var f__86676__auto__ = (function (){var switch__86624__auto__ = ((function (c__86675__auto__){
return (function (state_98571){
var state_val_98572 = (state_98571[(1)]);
if((state_val_98572 === (7))){
var inst_98519 = (state_98571[(7)]);
var state_98571__$1 = state_98571;
var statearr_98573_98613 = state_98571__$1;
(statearr_98573_98613[(2)] = inst_98519);

(statearr_98573_98613[(1)] = (9));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98572 === (20))){
var state_98571__$1 = state_98571;
var statearr_98574_98614 = state_98571__$1;
(statearr_98574_98614[(1)] = (22));



return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98572 === (1))){
var state_98571__$1 = state_98571;
var statearr_98576_98615 = state_98571__$1;
(statearr_98576_98615[(2)] = null);

(statearr_98576_98615[(1)] = (4));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98572 === (24))){
var inst_98561 = (state_98571[(2)]);
var state_98571__$1 = state_98571;
var statearr_98577_98616 = state_98571__$1;
(statearr_98577_98616[(2)] = inst_98561);

(statearr_98577_98616[(1)] = (21));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98572 === (4))){
var _ = cljs.core.async.impl.ioc_helpers.add_exception_frame.call(null,state_98571,(3),Error,null,(2));
var inst_98505 = cljs.core.seq.call(null,subjects);
var inst_98506 = cljs.core.first.call(null,inst_98505);
var inst_98507 = cljs.core.next.call(null,inst_98505);
var inst_98508 = cljs.core.PersistentVector.EMPTY;
var inst_98509 = subjects;
var inst_98510 = (0);
var inst_98511 = inst_98508;
var state_98571__$1 = (function (){var statearr_98578 = state_98571;
(statearr_98578[(8)] = inst_98510);

(statearr_98578[(9)] = inst_98507);

(statearr_98578[(10)] = inst_98511);

(statearr_98578[(11)] = inst_98509);

(statearr_98578[(12)] = inst_98506);

return statearr_98578;
})();
var statearr_98579_98617 = state_98571__$1;
(statearr_98579_98617[(2)] = null);

(statearr_98579_98617[(1)] = (5));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98572 === (15))){
var inst_98565 = (state_98571[(2)]);
var state_98571__$1 = state_98571;
var statearr_98580_98618 = state_98571__$1;
(statearr_98580_98618[(2)] = inst_98565);

(statearr_98580_98618[(1)] = (6));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98572 === (21))){
var inst_98563 = (state_98571[(2)]);
var state_98571__$1 = state_98571;
var statearr_98581_98619 = state_98571__$1;
(statearr_98581_98619[(2)] = inst_98563);

(statearr_98581_98619[(1)] = (15));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98572 === (13))){
var inst_98511 = (state_98571[(10)]);
var state_98571__$1 = state_98571;
var statearr_98582_98620 = state_98571__$1;
(statearr_98582_98620[(2)] = inst_98511);

(statearr_98582_98620[(1)] = (15));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98572 === (22))){
var inst_98510 = (state_98571[(8)]);
var inst_98507 = (state_98571[(9)]);
var inst_98518 = (state_98571[(13)]);
var inst_98511 = (state_98571[(10)]);
var inst_98517 = (state_98571[(14)]);
var inst_98509 = (state_98571[(11)]);
var inst_98506 = (state_98571[(12)]);
var inst_98541 = (inst_98510 + (1));
var inst_98542 = (function (){var first__98515 = inst_98517;
var seq__98514 = inst_98518;
var r = inst_98518;
var seq__98503 = inst_98507;
var vec__98513 = inst_98509;
var acc = inst_98511;
var n = inst_98510;
var G__98501 = inst_98509;
var s = inst_98517;
var vec__98502 = subjects;
var first__98504 = inst_98506;
return ((function (first__98515,seq__98514,r,seq__98503,vec__98513,acc,n,G__98501,s,vec__98502,first__98504,inst_98510,inst_98507,inst_98518,inst_98511,inst_98517,inst_98509,inst_98506,inst_98541,state_val_98572,c__86675__auto__){
return (function (n__$1){
return fluree.db.query.fql.flakes__GT_res.call(null,db,cache,fuel,max_fuel,select_spec,n__$1);
});
;})(first__98515,seq__98514,r,seq__98503,vec__98513,acc,n,G__98501,s,vec__98502,first__98504,inst_98510,inst_98507,inst_98518,inst_98511,inst_98517,inst_98509,inst_98506,inst_98541,state_val_98572,c__86675__auto__))
})();
var inst_98543 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_98544 = [inst_98517];
var inst_98545 = (new cljs.core.PersistentVector(null,1,(5),inst_98543,inst_98544,null));
var inst_98546 = [new cljs.core.Keyword(null,"limit","limit",-1355822363)];
var inst_98547 = [limit];
var inst_98548 = cljs.core.PersistentHashMap.fromArrays(inst_98546,inst_98547);
var inst_98549 = fluree.db.query.range.index_range.call(null,db,new cljs.core.Keyword(null,"spot","spot",-1706962147),cljs.core._EQ_,inst_98545,inst_98548);
var state_98571__$1 = (function (){var statearr_98583 = state_98571;
(statearr_98583[(15)] = inst_98542);

(statearr_98583[(16)] = inst_98541);

return statearr_98583;
})();
return cljs.core.async.impl.ioc_helpers.take_BANG_.call(null,state_98571__$1,(26),inst_98549);
} else {
if((state_val_98572 === (6))){
var inst_98567 = (state_98571[(2)]);
var state_98571__$1 = state_98571;
var statearr_98584_98621 = state_98571__$1;
(statearr_98584_98621[(2)] = inst_98567);


cljs.core.async.impl.ioc_helpers.process_exception.call(null,state_98571__$1);

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98572 === (25))){
var inst_98541 = (state_98571[(16)]);
var inst_98518 = (state_98571[(13)]);
var inst_98511 = (state_98571[(10)]);
var inst_98555 = (state_98571[(2)]);
var inst_98556 = fluree.db.util.async.throw_err.call(null,inst_98555);
var inst_98557 = cljs.core.conj.call(null,inst_98511,inst_98556);
var inst_98509 = inst_98518;
var inst_98510 = inst_98541;
var inst_98511__$1 = inst_98557;
var state_98571__$1 = (function (){var statearr_98585 = state_98571;
(statearr_98585[(8)] = inst_98510);

(statearr_98585[(10)] = inst_98511__$1);

(statearr_98585[(11)] = inst_98509);

return statearr_98585;
})();
var statearr_98586_98622 = state_98571__$1;
(statearr_98586_98622[(2)] = null);

(statearr_98586_98622[(1)] = (5));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98572 === (17))){
var state_98571__$1 = state_98571;
var statearr_98587_98623 = state_98571__$1;
(statearr_98587_98623[(2)] = offset);

(statearr_98587_98623[(1)] = (18));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98572 === (3))){
var inst_98494 = (state_98571[(2)]);
var state_98571__$1 = state_98571;
var statearr_98588_98624 = state_98571__$1;
(statearr_98588_98624[(2)] = inst_98494);


cljs.core.async.impl.ioc_helpers.process_exception.call(null,state_98571__$1);

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98572 === (12))){
var inst_98526 = (state_98571[(2)]);
var state_98571__$1 = state_98571;
var statearr_98589_98625 = state_98571__$1;
(statearr_98589_98625[(2)] = inst_98526);

(statearr_98589_98625[(1)] = (9));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98572 === (2))){
var inst_98569 = (state_98571[(2)]);
var state_98571__$1 = state_98571;
return cljs.core.async.impl.ioc_helpers.return_chan.call(null,state_98571__$1,inst_98569);
} else {
if((state_val_98572 === (23))){
var state_98571__$1 = state_98571;
var statearr_98591_98626 = state_98571__$1;
(statearr_98591_98626[(2)] = null);

(statearr_98591_98626[(1)] = (24));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98572 === (19))){
var inst_98510 = (state_98571[(8)]);
var inst_98518 = (state_98571[(13)]);
var inst_98511 = (state_98571[(10)]);
var inst_98537 = (inst_98510 + (1));
var tmp98590 = inst_98511;
var inst_98509 = inst_98518;
var inst_98510__$1 = inst_98537;
var inst_98511__$1 = tmp98590;
var state_98571__$1 = (function (){var statearr_98592 = state_98571;
(statearr_98592[(8)] = inst_98510__$1);

(statearr_98592[(10)] = inst_98511__$1);

(statearr_98592[(11)] = inst_98509);

return statearr_98592;
})();
var statearr_98593_98627 = state_98571__$1;
(statearr_98593_98627[(2)] = null);

(statearr_98593_98627[(1)] = (5));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98572 === (11))){
var state_98571__$1 = state_98571;
var statearr_98594_98628 = state_98571__$1;
(statearr_98594_98628[(2)] = limit);

(statearr_98594_98628[(1)] = (12));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98572 === (9))){
var inst_98528 = (state_98571[(2)]);
var state_98571__$1 = state_98571;
if(cljs.core.truth_(inst_98528)){
var statearr_98595_98629 = state_98571__$1;
(statearr_98595_98629[(1)] = (13));

} else {
var statearr_98596_98630 = state_98571__$1;
(statearr_98596_98630[(1)] = (14));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98572 === (5))){
var inst_98519 = (state_98571[(7)]);
var inst_98517 = (state_98571[(14)]);
var inst_98509 = (state_98571[(11)]);
var inst_98516 = cljs.core.seq.call(null,inst_98509);
var inst_98517__$1 = cljs.core.first.call(null,inst_98516);
var inst_98518 = cljs.core.next.call(null,inst_98516);
var inst_98519__$1 = (inst_98517__$1 == null);
var state_98571__$1 = (function (){var statearr_98597 = state_98571;
(statearr_98597[(7)] = inst_98519__$1);

(statearr_98597[(13)] = inst_98518);

(statearr_98597[(14)] = inst_98517__$1);

return statearr_98597;
})();
if(cljs.core.truth_(inst_98519__$1)){
var statearr_98598_98631 = state_98571__$1;
(statearr_98598_98631[(1)] = (7));

} else {
var statearr_98599_98632 = state_98571__$1;
(statearr_98599_98632[(1)] = (8));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98572 === (14))){
var state_98571__$1 = state_98571;
if(cljs.core.truth_(offset)){
var statearr_98600_98633 = state_98571__$1;
(statearr_98600_98633[(1)] = (16));

} else {
var statearr_98601_98634 = state_98571__$1;
(statearr_98601_98634[(1)] = (17));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98572 === (26))){
var inst_98542 = (state_98571[(15)]);
var inst_98551 = (state_98571[(2)]);
var inst_98552 = fluree.db.util.async.throw_err.call(null,inst_98551);
var inst_98553 = inst_98542.call(null,inst_98552);
var state_98571__$1 = state_98571;
return cljs.core.async.impl.ioc_helpers.take_BANG_.call(null,state_98571__$1,(25),inst_98553);
} else {
if((state_val_98572 === (16))){
var inst_98510 = (state_98571[(8)]);
var inst_98532 = (inst_98510 < offset);
var state_98571__$1 = state_98571;
var statearr_98602_98635 = state_98571__$1;
(statearr_98602_98635[(2)] = inst_98532);

(statearr_98602_98635[(1)] = (18));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98572 === (10))){
var inst_98510 = (state_98571[(8)]);
var inst_98523 = (inst_98510 > limit);
var state_98571__$1 = state_98571;
var statearr_98603_98636 = state_98571__$1;
(statearr_98603_98636[(2)] = inst_98523);

(statearr_98603_98636[(1)] = (12));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98572 === (18))){
var inst_98535 = (state_98571[(2)]);
var state_98571__$1 = state_98571;
if(cljs.core.truth_(inst_98535)){
var statearr_98604_98637 = state_98571__$1;
(statearr_98604_98637[(1)] = (19));

} else {
var statearr_98605_98638 = state_98571__$1;
(statearr_98605_98638[(1)] = (20));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98572 === (8))){
var state_98571__$1 = state_98571;
if(cljs.core.truth_(limit)){
var statearr_98606_98639 = state_98571__$1;
(statearr_98606_98639[(1)] = (10));

} else {
var statearr_98607_98640 = state_98571__$1;
(statearr_98607_98640[(1)] = (11));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
return null;
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
});})(c__86675__auto__))
;
return ((function (switch__86624__auto__,c__86675__auto__){
return (function() {
var fluree$db$query$fql$state_machine__86625__auto__ = null;
var fluree$db$query$fql$state_machine__86625__auto____0 = (function (){
var statearr_98608 = [null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null];
(statearr_98608[(0)] = fluree$db$query$fql$state_machine__86625__auto__);

(statearr_98608[(1)] = (1));

return statearr_98608;
});
var fluree$db$query$fql$state_machine__86625__auto____1 = (function (state_98571){
while(true){
var ret_value__86626__auto__ = (function (){try{while(true){
var result__86627__auto__ = switch__86624__auto__.call(null,state_98571);
if(cljs.core.keyword_identical_QMARK_.call(null,result__86627__auto__,new cljs.core.Keyword(null,"recur","recur",-437573268))){
continue;
} else {
return result__86627__auto__;
}
break;
}
}catch (e98609){if((e98609 instanceof Object)){
var ex__86628__auto__ = e98609;
var statearr_98610_98641 = state_98571;
(statearr_98610_98641[(5)] = ex__86628__auto__);


cljs.core.async.impl.ioc_helpers.process_exception.call(null,state_98571);

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
throw e98609;

}
}})();
if(cljs.core.keyword_identical_QMARK_.call(null,ret_value__86626__auto__,new cljs.core.Keyword(null,"recur","recur",-437573268))){
var G__98642 = state_98571;
state_98571 = G__98642;
continue;
} else {
return ret_value__86626__auto__;
}
break;
}
});
fluree$db$query$fql$state_machine__86625__auto__ = function(state_98571){
switch(arguments.length){
case 0:
return fluree$db$query$fql$state_machine__86625__auto____0.call(this);
case 1:
return fluree$db$query$fql$state_machine__86625__auto____1.call(this,state_98571);
}
throw(new Error('Invalid arity: ' + arguments.length));
};
fluree$db$query$fql$state_machine__86625__auto__.cljs$core$IFn$_invoke$arity$0 = fluree$db$query$fql$state_machine__86625__auto____0;
fluree$db$query$fql$state_machine__86625__auto__.cljs$core$IFn$_invoke$arity$1 = fluree$db$query$fql$state_machine__86625__auto____1;
return fluree$db$query$fql$state_machine__86625__auto__;
})()
;})(switch__86624__auto__,c__86675__auto__))
})();
var state__86677__auto__ = (function (){var statearr_98611 = f__86676__auto__.call(null);
(statearr_98611[(6)] = c__86675__auto__);

return statearr_98611;
})();
return cljs.core.async.impl.ioc_helpers.run_state_machine_wrapped.call(null,state__86677__auto__);
});})(c__86675__auto__))
);

return c__86675__auto__;
});

fluree.db.query.fql.subject_select.cljs$lang$maxFixedArity = 8;

fluree.db.query.fql.valid_where_predicate_QMARK_ = (function fluree$db$query$fql$valid_where_predicate_QMARK_(db,p){
var or__4131__auto__ = fluree.db.dbproto._p_prop.call(null,db,new cljs.core.Keyword(null,"idx?","idx?",-564590377),p);
if(cljs.core.truth_(or__4131__auto__)){
return or__4131__auto__;
} else {
var or__4131__auto____$1 = fluree.db.dbproto._p_prop.call(null,db,new cljs.core.Keyword(null,"ref?","ref?",1932693720),p);
if(cljs.core.truth_(or__4131__auto____$1)){
return or__4131__auto____$1;
} else {
return cljs.core._EQ_.call(null,new cljs.core.Keyword(null,"tag","tag",-1290361223),fluree.db.dbproto._p_prop.call(null,db,new cljs.core.Keyword(null,"type","type",1174270348),p));
}
}
});
/**
 * Takes a where clause and returns subjects that match.
 */
fluree.db.query.fql.where_filter = (function fluree$db$query$fql$where_filter(var_args){
var G__98644 = arguments.length;
switch (G__98644) {
case 2:
return fluree.db.query.fql.where_filter.cljs$core$IFn$_invoke$arity$2((arguments[(0)]),(arguments[(1)]));

break;
case 3:
return fluree.db.query.fql.where_filter.cljs$core$IFn$_invoke$arity$3((arguments[(0)]),(arguments[(1)]),(arguments[(2)]));

break;
default:
throw (new Error(["Invalid arity: ",cljs.core.str.cljs$core$IFn$_invoke$arity$1(arguments.length)].join('')));

}
});

fluree.db.query.fql.where_filter.cljs$core$IFn$_invoke$arity$2 = (function (db,where_clause){
return fluree.db.query.fql.where_filter.call(null,db,where_clause,null);
});

fluree.db.query.fql.where_filter.cljs$core$IFn$_invoke$arity$3 = (function (db,where_clause,default_collection){
var c__86675__auto__ = cljs.core.async.chan.call(null,(1));
cljs.core.async.impl.dispatch.run.call(null,((function (c__86675__auto__){
return (function (){
var f__86676__auto__ = (function (){var switch__86624__auto__ = ((function (c__86675__auto__){
return (function (state_98828){
var state_val_98829 = (state_98828[(1)]);
if((state_val_98829 === (7))){
var inst_98824 = (state_98828[(2)]);
var state_98828__$1 = state_98828;
var statearr_98830_98894 = state_98828__$1;
(statearr_98830_98894[(2)] = inst_98824);


cljs.core.async.impl.ioc_helpers.process_exception.call(null,state_98828__$1);

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98829 === (20))){
var inst_98713 = (state_98828[(7)]);
var inst_98722 = (state_98828[(2)]);
var inst_98723 = fluree.db.util.async.throw_err.call(null,inst_98722);
var inst_98724 = cljs.core.concat.call(null,inst_98713,inst_98723);
var state_98828__$1 = state_98828;
var statearr_98831_98895 = state_98828__$1;
(statearr_98831_98895[(2)] = inst_98724);

(statearr_98831_98895[(1)] = (18));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98829 === (27))){
var inst_98796 = (state_98828[(2)]);
var state_98828__$1 = state_98828;
var statearr_98832_98896 = state_98828__$1;
(statearr_98832_98896[(2)] = inst_98796);

(statearr_98832_98896[(1)] = (23));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98829 === (1))){
var state_98828__$1 = state_98828;
var statearr_98833_98897 = state_98828__$1;
(statearr_98833_98897[(2)] = null);

(statearr_98833_98897[(1)] = (4));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98829 === (24))){
var inst_98733 = (state_98828[(2)]);
var inst_98734 = fluree.db.util.async.throw_err.call(null,inst_98733);
var state_98828__$1 = state_98828;
var statearr_98834_98898 = state_98828__$1;
(statearr_98834_98898[(2)] = inst_98734);

(statearr_98834_98898[(1)] = (23));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98829 === (39))){
var inst_98790 = (state_98828[(2)]);
var state_98828__$1 = state_98828;
var statearr_98835_98899 = state_98828__$1;
(statearr_98835_98899[(2)] = inst_98790);

(statearr_98835_98899[(1)] = (35));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98829 === (46))){
var inst_98817 = (state_98828[(2)]);
var state_98828__$1 = state_98828;
var statearr_98836_98900 = state_98828__$1;
(statearr_98836_98900[(2)] = inst_98817);

(statearr_98836_98900[(1)] = (12));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98829 === (4))){
var inst_98654 = (state_98828[(8)]);
var _ = cljs.core.async.impl.ioc_helpers.add_exception_frame.call(null,state_98828,(3),Error,null,(2));
var inst_98652 = fluree.db.query.fql_parser.parse_where.call(null,db,where_clause,default_collection);
var inst_98653 = cljs.core.nth.call(null,inst_98652,(0),null);
var inst_98654__$1 = cljs.core.nth.call(null,inst_98652,(1),null);
var inst_98655 = cljs.core.not_empty.call(null,inst_98654__$1);
var state_98828__$1 = (function (){var statearr_98837 = state_98828;
(statearr_98837[(8)] = inst_98654__$1);

(statearr_98837[(9)] = inst_98653);

return statearr_98837;
})();
if(cljs.core.truth_(inst_98655)){
var statearr_98838_98901 = state_98828__$1;
(statearr_98838_98901[(1)] = (5));

} else {
var statearr_98839_98902 = state_98828__$1;
(statearr_98839_98902[(1)] = (6));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98829 === (15))){
var inst_98684 = (state_98828[(10)]);
var inst_98698 = (state_98828[(2)]);
var inst_98702 = (cljs.core.not_EQ_ === inst_98684);
var state_98828__$1 = (function (){var statearr_98840 = state_98828;
(statearr_98840[(11)] = inst_98698);

return statearr_98840;
})();
if(inst_98702){
var statearr_98841_98903 = state_98828__$1;
(statearr_98841_98903[(1)] = (16));

} else {
var statearr_98842_98904 = state_98828__$1;
(statearr_98842_98904[(1)] = (17));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98829 === (21))){
var inst_98685 = (state_98828[(12)]);
var inst_98683 = (state_98828[(13)]);
var inst_98728 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_98729 = [inst_98683,inst_98685];
var inst_98730 = (new cljs.core.PersistentVector(null,2,(5),inst_98728,inst_98729,null));
var inst_98731 = fluree.db.query.range.index_range.call(null,db,new cljs.core.Keyword(null,"post","post",269697687),cljs.core._EQ_,inst_98730);
var state_98828__$1 = state_98828;
return cljs.core.async.impl.ioc_helpers.take_BANG_.call(null,state_98828__$1,(24),inst_98731);
} else {
if((state_val_98829 === (31))){
var inst_98794 = (state_98828[(2)]);
var state_98828__$1 = state_98828;
var statearr_98843_98905 = state_98828__$1;
(statearr_98843_98905[(2)] = inst_98794);

(statearr_98843_98905[(1)] = (27));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98829 === (32))){
var inst_98759 = (state_98828[(2)]);
var inst_98760 = fluree.db.util.async.throw_err.call(null,inst_98759);
var state_98828__$1 = state_98828;
var statearr_98844_98906 = state_98828__$1;
(statearr_98844_98906[(2)] = inst_98760);

(statearr_98844_98906[(1)] = (31));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98829 === (40))){
var inst_98785 = (state_98828[(2)]);
var inst_98786 = fluree.db.util.async.throw_err.call(null,inst_98785);
var state_98828__$1 = state_98828;
var statearr_98845_98907 = state_98828__$1;
(statearr_98845_98907[(2)] = inst_98786);

(statearr_98845_98907[(1)] = (39));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98829 === (33))){
var inst_98685 = (state_98828[(12)]);
var inst_98683 = (state_98828[(13)]);
var inst_98764 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_98765 = [inst_98683];
var inst_98766 = (new cljs.core.PersistentVector(null,1,(5),inst_98764,inst_98765,null));
var inst_98767 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_98768 = [inst_98683,inst_98685];
var inst_98769 = (new cljs.core.PersistentVector(null,2,(5),inst_98767,inst_98768,null));
var inst_98770 = fluree.db.query.range.index_range.call(null,db,new cljs.core.Keyword(null,"post","post",269697687),cljs.core._GT__EQ_,inst_98766,cljs.core._LT_,inst_98769);
var state_98828__$1 = state_98828;
return cljs.core.async.impl.ioc_helpers.take_BANG_.call(null,state_98828__$1,(36),inst_98770);
} else {
if((state_val_98829 === (13))){
var inst_98683 = (state_98828[(13)]);
var inst_98689 = fluree.db.dbproto._p_prop.call(null,db,new cljs.core.Keyword(null,"name","name",1843675177),inst_98683);
var inst_98690 = ["Non-indexed predicates are not valid in where clause statements. Provided: ",cljs.core.str.cljs$core$IFn$_invoke$arity$1(inst_98689)].join('');
var inst_98691 = [new cljs.core.Keyword(null,"status","status",-1997798413),new cljs.core.Keyword(null,"error","error",-978969032)];
var inst_98692 = [(400),new cljs.core.Keyword("db","invalid-query","db/invalid-query",-1009699917)];
var inst_98693 = cljs.core.PersistentHashMap.fromArrays(inst_98691,inst_98692);
var inst_98694 = cljs.core.ex_info.call(null,inst_98690,inst_98693);
var inst_98695 = (function(){throw inst_98694})();
var state_98828__$1 = state_98828;
var statearr_98846_98908 = state_98828__$1;
(statearr_98846_98908[(2)] = inst_98695);

(statearr_98846_98908[(1)] = (15));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98829 === (22))){
var inst_98684 = (state_98828[(10)]);
var inst_98736 = (cljs.core._GT_ === inst_98684);
var state_98828__$1 = state_98828;
if(inst_98736){
var statearr_98847_98909 = state_98828__$1;
(statearr_98847_98909[(1)] = (25));

} else {
var statearr_98848_98910 = state_98828__$1;
(statearr_98848_98910[(1)] = (26));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98829 === (36))){
var inst_98772 = (state_98828[(2)]);
var inst_98773 = fluree.db.util.async.throw_err.call(null,inst_98772);
var state_98828__$1 = state_98828;
var statearr_98849_98911 = state_98828__$1;
(statearr_98849_98911[(2)] = inst_98773);

(statearr_98849_98911[(1)] = (35));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98829 === (41))){
var inst_98653 = (state_98828[(9)]);
var inst_98809 = (state_98828[(14)]);
var inst_98809__$1 = (state_98828[(2)]);
var inst_98810 = cljs.core._EQ_.call(null,new cljs.core.Keyword(null,"and","and",-971899817),inst_98653);
var inst_98811 = cljs.core.empty_QMARK_.call(null,inst_98809__$1);
var inst_98812 = ((inst_98810) && (inst_98811));
var state_98828__$1 = (function (){var statearr_98850 = state_98828;
(statearr_98850[(14)] = inst_98809__$1);

return statearr_98850;
})();
if(cljs.core.truth_(inst_98812)){
var statearr_98851_98912 = state_98828__$1;
(statearr_98851_98912[(1)] = (44));

} else {
var statearr_98852_98913 = state_98828__$1;
(statearr_98852_98913[(1)] = (45));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98829 === (43))){
var inst_98669 = (state_98828[(15)]);
var inst_98801 = (state_98828[(16)]);
var inst_98804 = cljs.core.PersistentHashSet.EMPTY;
var inst_98805 = cljs.core.into.call(null,inst_98804,inst_98801);
var inst_98806 = clojure.set.intersection.call(null,inst_98669,inst_98805);
var state_98828__$1 = state_98828;
var statearr_98853_98914 = state_98828__$1;
(statearr_98853_98914[(2)] = inst_98806);

(statearr_98853_98914[(1)] = (41));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98829 === (29))){
var inst_98685 = (state_98828[(12)]);
var inst_98683 = (state_98828[(13)]);
var inst_98751 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_98752 = [inst_98683,inst_98685];
var inst_98753 = (new cljs.core.PersistentVector(null,2,(5),inst_98751,inst_98752,null));
var inst_98754 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_98755 = [inst_98683];
var inst_98756 = (new cljs.core.PersistentVector(null,1,(5),inst_98754,inst_98755,null));
var inst_98757 = fluree.db.query.range.index_range.call(null,db,new cljs.core.Keyword(null,"post","post",269697687),cljs.core._GT__EQ_,inst_98753,cljs.core._LT__EQ_,inst_98756);
var state_98828__$1 = state_98828;
return cljs.core.async.impl.ioc_helpers.take_BANG_.call(null,state_98828__$1,(32),inst_98757);
} else {
if((state_val_98829 === (44))){
var inst_98809 = (state_98828[(14)]);
var state_98828__$1 = state_98828;
var statearr_98854_98915 = state_98828__$1;
(statearr_98854_98915[(2)] = inst_98809);

(statearr_98854_98915[(1)] = (46));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98829 === (6))){
var state_98828__$1 = state_98828;
var statearr_98855_98916 = state_98828__$1;
(statearr_98855_98916[(2)] = null);

(statearr_98855_98916[(1)] = (7));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98829 === (28))){
var inst_98746 = (state_98828[(2)]);
var inst_98747 = fluree.db.util.async.throw_err.call(null,inst_98746);
var state_98828__$1 = state_98828;
var statearr_98856_98917 = state_98828__$1;
(statearr_98856_98917[(2)] = inst_98747);

(statearr_98856_98917[(1)] = (27));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98829 === (25))){
var inst_98685 = (state_98828[(12)]);
var inst_98683 = (state_98828[(13)]);
var inst_98738 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_98739 = [inst_98683,inst_98685];
var inst_98740 = (new cljs.core.PersistentVector(null,2,(5),inst_98738,inst_98739,null));
var inst_98741 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_98742 = [inst_98683];
var inst_98743 = (new cljs.core.PersistentVector(null,1,(5),inst_98741,inst_98742,null));
var inst_98744 = fluree.db.query.range.index_range.call(null,db,new cljs.core.Keyword(null,"post","post",269697687),cljs.core._GT_,inst_98740,cljs.core._LT__EQ_,inst_98743);
var state_98828__$1 = state_98828;
return cljs.core.async.impl.ioc_helpers.take_BANG_.call(null,state_98828__$1,(28),inst_98744);
} else {
if((state_val_98829 === (34))){
var inst_98684 = (state_98828[(10)]);
var inst_98775 = (cljs.core._LT__EQ_ === inst_98684);
var state_98828__$1 = state_98828;
if(inst_98775){
var statearr_98857_98918 = state_98828__$1;
(statearr_98857_98918[(1)] = (37));

} else {
var statearr_98858_98919 = state_98828__$1;
(statearr_98858_98919[(1)] = (38));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98829 === (17))){
var inst_98684 = (state_98828[(10)]);
var inst_98726 = (cljs.core._EQ_ === inst_98684);
var state_98828__$1 = state_98828;
if(inst_98726){
var statearr_98859_98920 = state_98828__$1;
(statearr_98859_98920[(1)] = (21));

} else {
var statearr_98860_98921 = state_98828__$1;
(statearr_98860_98921[(1)] = (22));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98829 === (3))){
var inst_98645 = (state_98828[(2)]);
var state_98828__$1 = state_98828;
var statearr_98861_98922 = state_98828__$1;
(statearr_98861_98922[(2)] = inst_98645);


cljs.core.async.impl.ioc_helpers.process_exception.call(null,state_98828__$1);

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98829 === (12))){
var inst_98819 = (state_98828[(2)]);
var state_98828__$1 = state_98828;
var statearr_98862_98923 = state_98828__$1;
(statearr_98862_98923[(2)] = inst_98819);

(statearr_98862_98923[(1)] = (9));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98829 === (2))){
var inst_98826 = (state_98828[(2)]);
var state_98828__$1 = state_98828;
return cljs.core.async.impl.ioc_helpers.return_chan.call(null,state_98828__$1,inst_98826);
} else {
if((state_val_98829 === (23))){
var inst_98798 = (state_98828[(2)]);
var state_98828__$1 = state_98828;
var statearr_98863_98924 = state_98828__$1;
(statearr_98863_98924[(2)] = inst_98798);

(statearr_98863_98924[(1)] = (18));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98829 === (35))){
var inst_98792 = (state_98828[(2)]);
var state_98828__$1 = state_98828;
var statearr_98864_98925 = state_98828__$1;
(statearr_98864_98925[(2)] = inst_98792);

(statearr_98864_98925[(1)] = (31));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98829 === (19))){
var inst_98685 = (state_98828[(12)]);
var inst_98683 = (state_98828[(13)]);
var inst_98712 = (state_98828[(2)]);
var inst_98713 = fluree.db.util.async.throw_err.call(null,inst_98712);
var inst_98714 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_98715 = [inst_98683];
var inst_98716 = (new cljs.core.PersistentVector(null,1,(5),inst_98714,inst_98715,null));
var inst_98717 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_98718 = [inst_98683,inst_98685];
var inst_98719 = (new cljs.core.PersistentVector(null,2,(5),inst_98717,inst_98718,null));
var inst_98720 = fluree.db.query.range.index_range.call(null,db,new cljs.core.Keyword(null,"post","post",269697687),cljs.core._GT__EQ_,inst_98716,cljs.core._LT_,inst_98719);
var state_98828__$1 = (function (){var statearr_98865 = state_98828;
(statearr_98865[(7)] = inst_98713);

return statearr_98865;
})();
return cljs.core.async.impl.ioc_helpers.take_BANG_.call(null,state_98828__$1,(20),inst_98720);
} else {
if((state_val_98829 === (11))){
var inst_98675 = (state_98828[(17)]);
var inst_98683 = (state_98828[(13)]);
var inst_98683__$1 = cljs.core.nth.call(null,inst_98675,(0),null);
var inst_98684 = cljs.core.nth.call(null,inst_98675,(1),null);
var inst_98685 = cljs.core.nth.call(null,inst_98675,(2),null);
var inst_98686 = fluree.db.query.fql.valid_where_predicate_QMARK_.call(null,db,inst_98683__$1);
var inst_98687 = cljs.core.not.call(null,inst_98686);
var state_98828__$1 = (function (){var statearr_98866 = state_98828;
(statearr_98866[(10)] = inst_98684);

(statearr_98866[(12)] = inst_98685);

(statearr_98866[(13)] = inst_98683__$1);

return statearr_98866;
})();
if(inst_98687){
var statearr_98867_98926 = state_98828__$1;
(statearr_98867_98926[(1)] = (13));

} else {
var statearr_98868_98927 = state_98828__$1;
(statearr_98868_98927[(1)] = (14));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98829 === (9))){
var inst_98821 = (state_98828[(2)]);
var state_98828__$1 = state_98828;
var statearr_98869_98928 = state_98828__$1;
(statearr_98869_98928[(2)] = inst_98821);

(statearr_98869_98928[(1)] = (7));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98829 === (5))){
var inst_98654 = (state_98828[(8)]);
var inst_98664 = cljs.core.seq.call(null,inst_98654);
var inst_98665 = cljs.core.first.call(null,inst_98664);
var inst_98666 = cljs.core.next.call(null,inst_98664);
var inst_98667 = cljs.core.PersistentHashSet.EMPTY;
var inst_98668 = inst_98654;
var inst_98669 = inst_98667;
var state_98828__$1 = (function (){var statearr_98870 = state_98828;
(statearr_98870[(18)] = inst_98668);

(statearr_98870[(19)] = inst_98665);

(statearr_98870[(20)] = inst_98666);

(statearr_98870[(15)] = inst_98669);

return statearr_98870;
})();
var statearr_98871_98929 = state_98828__$1;
(statearr_98871_98929[(2)] = null);

(statearr_98871_98929[(1)] = (8));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98829 === (14))){
var state_98828__$1 = state_98828;
var statearr_98872_98930 = state_98828__$1;
(statearr_98872_98930[(2)] = null);

(statearr_98872_98930[(1)] = (15));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98829 === (45))){
var inst_98676 = (state_98828[(21)]);
var inst_98809 = (state_98828[(14)]);
var inst_98668 = inst_98676;
var inst_98669 = inst_98809;
var state_98828__$1 = (function (){var statearr_98873 = state_98828;
(statearr_98873[(18)] = inst_98668);

(statearr_98873[(15)] = inst_98669);

return statearr_98873;
})();
var statearr_98874_98931 = state_98828__$1;
(statearr_98874_98931[(2)] = null);

(statearr_98874_98931[(1)] = (8));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98829 === (26))){
var inst_98684 = (state_98828[(10)]);
var inst_98749 = (cljs.core._GT__EQ_ === inst_98684);
var state_98828__$1 = state_98828;
if(inst_98749){
var statearr_98875_98932 = state_98828__$1;
(statearr_98875_98932[(1)] = (29));

} else {
var statearr_98876_98933 = state_98828__$1;
(statearr_98876_98933[(1)] = (30));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98829 === (16))){
var inst_98685 = (state_98828[(12)]);
var inst_98683 = (state_98828[(13)]);
var inst_98704 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_98705 = [inst_98683,inst_98685];
var inst_98706 = (new cljs.core.PersistentVector(null,2,(5),inst_98704,inst_98705,null));
var inst_98707 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_98708 = [inst_98683];
var inst_98709 = (new cljs.core.PersistentVector(null,1,(5),inst_98707,inst_98708,null));
var inst_98710 = fluree.db.query.range.index_range.call(null,db,new cljs.core.Keyword(null,"post","post",269697687),cljs.core._GT_,inst_98706,cljs.core._LT__EQ_,inst_98709);
var state_98828__$1 = state_98828;
return cljs.core.async.impl.ioc_helpers.take_BANG_.call(null,state_98828__$1,(19),inst_98710);
} else {
if((state_val_98829 === (38))){
var inst_98788 = null;
var state_98828__$1 = state_98828;
var statearr_98877_98934 = state_98828__$1;
(statearr_98877_98934[(2)] = inst_98788);

(statearr_98877_98934[(1)] = (39));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98829 === (30))){
var inst_98684 = (state_98828[(10)]);
var inst_98762 = (cljs.core._LT_ === inst_98684);
var state_98828__$1 = state_98828;
if(inst_98762){
var statearr_98878_98935 = state_98828__$1;
(statearr_98878_98935[(1)] = (33));

} else {
var statearr_98879_98936 = state_98828__$1;
(statearr_98879_98936[(1)] = (34));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98829 === (10))){
var inst_98669 = (state_98828[(15)]);
var state_98828__$1 = state_98828;
var statearr_98880_98937 = state_98828__$1;
(statearr_98880_98937[(2)] = inst_98669);

(statearr_98880_98937[(1)] = (12));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98829 === (18))){
var inst_98653 = (state_98828[(9)]);
var inst_98800 = (state_98828[(2)]);
var inst_98801 = cljs.core.map.call(null,fluree.db.query.fql.s,inst_98800);
var state_98828__$1 = (function (){var statearr_98881 = state_98828;
(statearr_98881[(16)] = inst_98801);

return statearr_98881;
})();
var G__98882_98938 = inst_98653;
var G__98882_98939__$1 = (((G__98882_98938 instanceof cljs.core.Keyword))?G__98882_98938.fqn:null);
switch (G__98882_98939__$1) {
case "or":
var statearr_98883_98941 = state_98828__$1;
(statearr_98883_98941[(1)] = (42));


break;
case "and":
var statearr_98884_98942 = state_98828__$1;
(statearr_98884_98942[(1)] = (43));


break;
default:
throw (new Error(["No matching clause: ",cljs.core.str.cljs$core$IFn$_invoke$arity$1(G__98882_98939__$1)].join('')));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98829 === (42))){
var inst_98669 = (state_98828[(15)]);
var inst_98801 = (state_98828[(16)]);
var inst_98802 = cljs.core.into.call(null,inst_98669,inst_98801);
var state_98828__$1 = state_98828;
var statearr_98885_98943 = state_98828__$1;
(statearr_98885_98943[(2)] = inst_98802);

(statearr_98885_98943[(1)] = (41));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_98829 === (37))){
var inst_98685 = (state_98828[(12)]);
var inst_98683 = (state_98828[(13)]);
var inst_98777 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_98778 = [inst_98683];
var inst_98779 = (new cljs.core.PersistentVector(null,1,(5),inst_98777,inst_98778,null));
var inst_98780 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_98781 = [inst_98683,inst_98685];
var inst_98782 = (new cljs.core.PersistentVector(null,2,(5),inst_98780,inst_98781,null));
var inst_98783 = fluree.db.query.range.index_range.call(null,db,new cljs.core.Keyword(null,"post","post",269697687),cljs.core._GT__EQ_,inst_98779,cljs.core._LT__EQ_,inst_98782);
var state_98828__$1 = state_98828;
return cljs.core.async.impl.ioc_helpers.take_BANG_.call(null,state_98828__$1,(40),inst_98783);
} else {
if((state_val_98829 === (8))){
var inst_98668 = (state_98828[(18)]);
var inst_98675 = (state_98828[(17)]);
var inst_98674 = cljs.core.seq.call(null,inst_98668);
var inst_98675__$1 = cljs.core.first.call(null,inst_98674);
var inst_98676 = cljs.core.next.call(null,inst_98674);
var inst_98677 = cljs.core.not.call(null,inst_98675__$1);
var state_98828__$1 = (function (){var statearr_98886 = state_98828;
(statearr_98886[(17)] = inst_98675__$1);

(statearr_98886[(21)] = inst_98676);

return statearr_98886;
})();
if(inst_98677){
var statearr_98887_98944 = state_98828__$1;
(statearr_98887_98944[(1)] = (10));

} else {
var statearr_98888_98945 = state_98828__$1;
(statearr_98888_98945[(1)] = (11));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
return null;
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
});})(c__86675__auto__))
;
return ((function (switch__86624__auto__,c__86675__auto__){
return (function() {
var fluree$db$query$fql$state_machine__86625__auto__ = null;
var fluree$db$query$fql$state_machine__86625__auto____0 = (function (){
var statearr_98889 = [null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null];
(statearr_98889[(0)] = fluree$db$query$fql$state_machine__86625__auto__);

(statearr_98889[(1)] = (1));

return statearr_98889;
});
var fluree$db$query$fql$state_machine__86625__auto____1 = (function (state_98828){
while(true){
var ret_value__86626__auto__ = (function (){try{while(true){
var result__86627__auto__ = switch__86624__auto__.call(null,state_98828);
if(cljs.core.keyword_identical_QMARK_.call(null,result__86627__auto__,new cljs.core.Keyword(null,"recur","recur",-437573268))){
continue;
} else {
return result__86627__auto__;
}
break;
}
}catch (e98890){if((e98890 instanceof Object)){
var ex__86628__auto__ = e98890;
var statearr_98891_98946 = state_98828;
(statearr_98891_98946[(5)] = ex__86628__auto__);


cljs.core.async.impl.ioc_helpers.process_exception.call(null,state_98828);

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
throw e98890;

}
}})();
if(cljs.core.keyword_identical_QMARK_.call(null,ret_value__86626__auto__,new cljs.core.Keyword(null,"recur","recur",-437573268))){
var G__98947 = state_98828;
state_98828 = G__98947;
continue;
} else {
return ret_value__86626__auto__;
}
break;
}
});
fluree$db$query$fql$state_machine__86625__auto__ = function(state_98828){
switch(arguments.length){
case 0:
return fluree$db$query$fql$state_machine__86625__auto____0.call(this);
case 1:
return fluree$db$query$fql$state_machine__86625__auto____1.call(this,state_98828);
}
throw(new Error('Invalid arity: ' + arguments.length));
};
fluree$db$query$fql$state_machine__86625__auto__.cljs$core$IFn$_invoke$arity$0 = fluree$db$query$fql$state_machine__86625__auto____0;
fluree$db$query$fql$state_machine__86625__auto__.cljs$core$IFn$_invoke$arity$1 = fluree$db$query$fql$state_machine__86625__auto____1;
return fluree$db$query$fql$state_machine__86625__auto__;
})()
;})(switch__86624__auto__,c__86675__auto__))
})();
var state__86677__auto__ = (function (){var statearr_98892 = f__86676__auto__.call(null);
(statearr_98892[(6)] = c__86675__auto__);

return statearr_98892;
})();
return cljs.core.async.impl.ioc_helpers.run_state_machine_wrapped.call(null,state__86677__auto__);
});})(c__86675__auto__))
);

return c__86675__auto__;
});

fluree.db.query.fql.where_filter.cljs$lang$maxFixedArity = 3;

/**
 * Order By can be:
 *  - Single variable, ?favNums
 *  - Two-tuple,  [ASC, ?favNums]
 */
fluree.db.query.fql.order_offset_and_limit_results = (function fluree$db$query$fql$order_offset_and_limit_results(orderBy,p__98949,offset,limit){
var map__98950 = p__98949;
var map__98950__$1 = (((((!((map__98950 == null))))?(((((map__98950.cljs$lang$protocol_mask$partition0$ & (64))) || ((cljs.core.PROTOCOL_SENTINEL === map__98950.cljs$core$ISeq$))))?true:false):false))?cljs.core.apply.call(null,cljs.core.hash_map,map__98950):map__98950);
var res = map__98950__$1;
var headers = cljs.core.get.call(null,map__98950__$1,new cljs.core.Keyword(null,"headers","headers",-835030129));
var tuples = cljs.core.get.call(null,map__98950__$1,new cljs.core.Keyword(null,"tuples","tuples",-676032639));
var vec__98952 = orderBy;
var order = cljs.core.nth.call(null,vec__98952,(0),null);
var var$ = cljs.core.nth.call(null,vec__98952,(1),null);
var indexOfFind = (function (){var or__4131__auto__ = fluree.db.util.core.index_of.call(null,headers,cljs.core.symbol.call(null,var$));
if(cljs.core.truth_(or__4131__auto__)){
return or__4131__auto__;
} else {
return (-1);
}
})();
var tuples__$1 = ((((0) <= indexOfFind))?(function (){var G__98955 = cljs.core.sort_by.call(null,((function (vec__98952,order,var$,indexOfFind,map__98950,map__98950__$1,res,headers,tuples){
return (function (p1__98948_SHARP_){
return cljs.core.nth.call(null,p1__98948_SHARP_,indexOfFind);
});})(vec__98952,order,var$,indexOfFind,map__98950,map__98950__$1,res,headers,tuples))
,fluree.db.query.fql.compare_fn,tuples);
var G__98955__$1 = ((cljs.core._EQ_.call(null,"DESC",order))?cljs.core.reverse.call(null,G__98955):G__98955);
var G__98955__$2 = (cljs.core.truth_(offset)?cljs.core.drop.call(null,offset,G__98955__$1):G__98955__$1);
if(cljs.core.truth_(limit)){
return cljs.core.take.call(null,limit,G__98955__$2);
} else {
return G__98955__$2;
}
})():tuples);
return new cljs.core.PersistentArrayMap(null, 2, [new cljs.core.Keyword(null,"headers","headers",-835030129),headers,new cljs.core.Keyword(null,"tuples","tuples",-676032639),tuples__$1], null);
});
fluree.db.query.fql.parse_map = (function fluree$db$query$fql$parse_map(x,valid_var){
var _ = ((cljs.core._EQ_.call(null,(1),cljs.core.count.call(null,cljs.core.keys.call(null,x))))?null:(function(){throw cljs.core.ex_info.call(null,["Invalid aggregate selection, provided: ",cljs.core.str.cljs$core$IFn$_invoke$arity$1(x)].join(''),new cljs.core.PersistentArrayMap(null, 2, [new cljs.core.Keyword(null,"status","status",-1997798413),(400),new cljs.core.Keyword(null,"error","error",-978969032),new cljs.core.Keyword("db","invalid-query","db/invalid-query",-1009699917)], null))})());
var var_as_symbol = cljs.core.symbol.call(null,cljs.core.first.call(null,cljs.core.keys.call(null,x)));
var ___$1 = (cljs.core.truth_(valid_var.call(null,var_as_symbol))?null:(function(){throw cljs.core.ex_info.call(null,["Invalid select variable in aggregate select, provided: ",cljs.core.str.cljs$core$IFn$_invoke$arity$1(x)].join(''),new cljs.core.PersistentArrayMap(null, 2, [new cljs.core.Keyword(null,"status","status",-1997798413),(400),new cljs.core.Keyword(null,"error","error",-978969032),new cljs.core.Keyword("db","invalid-query","db/invalid-query",-1009699917)], null))})());
return new cljs.core.PersistentArrayMap(null, 2, [new cljs.core.Keyword(null,"variable","variable",-281346492),var_as_symbol,new cljs.core.Keyword(null,"selection","selection",975998651),cljs.core.first.call(null,cljs.core.vals.call(null,x))], null);
});
fluree.db.query.fql.parse_select = (function fluree$db$query$fql$parse_select(vars,interim_vars,select_smt){
var _ = (function (){var or__4131__auto__ = cljs.core.every_QMARK_.call(null,(function (p1__98956_SHARP_){
return ((typeof p1__98956_SHARP_ === 'string') || (cljs.core.map_QMARK_.call(null,p1__98956_SHARP_)));
}),select_smt);
if(or__4131__auto__){
return or__4131__auto__;
} else {
throw cljs.core.ex_info.call(null,["Invalid select statement. Every selection must be a string or map. Provided: ",cljs.core.str.cljs$core$IFn$_invoke$arity$1(select_smt)].join(''),new cljs.core.PersistentArrayMap(null, 2, [new cljs.core.Keyword(null,"status","status",-1997798413),(400),new cljs.core.Keyword(null,"error","error",-978969032),new cljs.core.Keyword("db","invalid-query","db/invalid-query",-1009699917)], null));
}
})();
var vars__$1 = cljs.core.set.call(null,vars);
var all_vars = cljs.core.set.call(null,cljs.core.concat.call(null,vars__$1,cljs.core.keys.call(null,interim_vars)));
return cljs.core.map.call(null,((function (_,vars__$1,all_vars){
return (function (select){
var var_symbol = ((cljs.core.map_QMARK_.call(null,select))?null:cljs.core.symbol.call(null,select));
if(cljs.core.truth_(vars__$1.call(null,var_symbol))){
return new cljs.core.PersistentArrayMap(null, 1, [new cljs.core.Keyword(null,"variable","variable",-281346492),var_symbol], null);
} else {
if(cljs.core.truth_(fluree.db.query.analytical.aggregate_QMARK_.call(null,select))){
return fluree.db.query.analytical.parse_aggregate.call(null,select,vars__$1);
} else {
if(cljs.core.map_QMARK_.call(null,select)){
return fluree.db.query.fql.parse_map.call(null,select,all_vars);
} else {
if(cljs.core.truth_(cljs.core.get.call(null,interim_vars,var_symbol))){
return new cljs.core.PersistentArrayMap(null, 1, [new cljs.core.Keyword(null,"value","value",305978217),cljs.core.get.call(null,interim_vars,var_symbol)], null);
} else {
throw cljs.core.ex_info.call(null,["Invalid select in statement, provided: ",cljs.core.str.cljs$core$IFn$_invoke$arity$1(select)].join(''),new cljs.core.PersistentArrayMap(null, 2, [new cljs.core.Keyword(null,"status","status",-1997798413),(400),new cljs.core.Keyword(null,"error","error",-978969032),new cljs.core.Keyword("db","invalid-query","db/invalid-query",-1009699917)], null));

}
}
}
}
});})(_,vars__$1,all_vars))
,select_smt);
});
fluree.db.query.fql.get_pretty_print_keys = (function fluree$db$query$fql$get_pretty_print_keys(select){
var vars = cljs.core.map.call(null,(function (select__$1){
if(cljs.core.truth_(new cljs.core.Keyword(null,"as","as",1148689641).cljs$core$IFn$_invoke$arity$1(select__$1))){
return cljs.core.subs.call(null,cljs.core.str.cljs$core$IFn$_invoke$arity$1(new cljs.core.Keyword(null,"as","as",1148689641).cljs$core$IFn$_invoke$arity$1(select__$1)),(1));
} else {
if(cljs.core.truth_(new cljs.core.Keyword(null,"code","code",1586293142).cljs$core$IFn$_invoke$arity$1(select__$1))){
return cljs.core.str.cljs$core$IFn$_invoke$arity$1(new cljs.core.Keyword(null,"code","code",1586293142).cljs$core$IFn$_invoke$arity$1(select__$1));
} else {
if(cljs.core.truth_(new cljs.core.Keyword(null,"variable","variable",-281346492).cljs$core$IFn$_invoke$arity$1(select__$1))){
return cljs.core.subs.call(null,cljs.core.str.cljs$core$IFn$_invoke$arity$1(new cljs.core.Keyword(null,"variable","variable",-281346492).cljs$core$IFn$_invoke$arity$1(select__$1)),(1));
} else {
return null;
}
}
}
}),select);
var freqs = cljs.core.frequencies.call(null,vars);
if(cljs.core.every_QMARK_.call(null,((function (vars,freqs){
return (function (p1__98957_SHARP_){
return cljs.core._EQ_.call(null,(1),p1__98957_SHARP_);
});})(vars,freqs))
,cljs.core.vals.call(null,freqs))){
return vars;
} else {
var G__98961 = vars;
var vec__98962 = G__98961;
var seq__98963 = cljs.core.seq.call(null,vec__98962);
var first__98964 = cljs.core.first.call(null,seq__98963);
var seq__98963__$1 = cljs.core.next.call(null,seq__98963);
var var$ = first__98964;
var r = seq__98963__$1;
var all_vars = cljs.core.PersistentVector.EMPTY;
var G__98961__$1 = G__98961;
var all_vars__$1 = all_vars;
while(true){
var vec__98968 = G__98961__$1;
var seq__98969 = cljs.core.seq.call(null,vec__98968);
var first__98970 = cljs.core.first.call(null,seq__98969);
var seq__98969__$1 = cljs.core.next.call(null,seq__98969);
var var$__$1 = first__98970;
var r__$1 = seq__98969__$1;
var all_vars__$2 = all_vars__$1;
if(cljs.core.not.call(null,var$__$1)){
return all_vars__$2;
} else {
if(cljs.core.truth_(cljs.core.set.call(null,all_vars__$2).call(null,var$__$1))){
var G__98971 = r__$1;
var G__98972 = cljs.core.conj.call(null,all_vars__$2,[cljs.core.str.cljs$core$IFn$_invoke$arity$1(var$__$1),"$",cljs.core.str.cljs$core$IFn$_invoke$arity$1(cljs.core.count.call(null,all_vars__$2))].join(''));
G__98961__$1 = G__98971;
all_vars__$1 = G__98972;
continue;
} else {
var G__98973 = r__$1;
var G__98974 = cljs.core.conj.call(null,all_vars__$2,var$__$1);
G__98961__$1 = G__98973;
all_vars__$1 = G__98974;
continue;

}
}
break;
}
}
});
fluree.db.query.fql.format_tuple = (function fluree$db$query$fql$format_tuple(functionArray,tuple){
var c__86675__auto__ = cljs.core.async.chan.call(null,(1));
cljs.core.async.impl.dispatch.run.call(null,((function (c__86675__auto__){
return (function (){
var f__86676__auto__ = (function (){var switch__86624__auto__ = ((function (c__86675__auto__){
return (function (state_99008){
var state_val_99009 = (state_99008[(1)]);
if((state_val_99009 === (1))){
var inst_98982 = cljs.core.seq.call(null,functionArray);
var inst_98983 = cljs.core.first.call(null,inst_98982);
var inst_98984 = cljs.core.next.call(null,inst_98982);
var inst_98985 = cljs.core.PersistentVector.EMPTY;
var inst_98986 = functionArray;
var inst_98987 = inst_98985;
var state_99008__$1 = (function (){var statearr_99010 = state_99008;
(statearr_99010[(7)] = inst_98983);

(statearr_99010[(8)] = inst_98984);

(statearr_99010[(9)] = inst_98986);

(statearr_99010[(10)] = inst_98987);

return statearr_99010;
})();
var statearr_99011_99023 = state_99008__$1;
(statearr_99011_99023[(2)] = null);

(statearr_99011_99023[(1)] = (2));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99009 === (2))){
var inst_98986 = (state_99008[(9)]);
var inst_98993 = (state_99008[(11)]);
var inst_98992 = cljs.core.seq.call(null,inst_98986);
var inst_98993__$1 = cljs.core.first.call(null,inst_98992);
var inst_98994 = cljs.core.next.call(null,inst_98992);
var state_99008__$1 = (function (){var statearr_99012 = state_99008;
(statearr_99012[(12)] = inst_98994);

(statearr_99012[(11)] = inst_98993__$1);

return statearr_99012;
})();
if(cljs.core.truth_(inst_98993__$1)){
var statearr_99013_99024 = state_99008__$1;
(statearr_99013_99024[(1)] = (4));

} else {
var statearr_99014_99025 = state_99008__$1;
(statearr_99014_99025[(1)] = (5));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99009 === (3))){
var inst_99006 = (state_99008[(2)]);
var state_99008__$1 = state_99008;
return cljs.core.async.impl.ioc_helpers.return_chan.call(null,state_99008__$1,inst_99006);
} else {
if((state_val_99009 === (4))){
var inst_98993 = (state_99008[(11)]);
var inst_98996 = inst_98993.call(null,tuple);
var state_99008__$1 = state_99008;
return cljs.core.async.impl.ioc_helpers.take_BANG_.call(null,state_99008__$1,(7),inst_98996);
} else {
if((state_val_99009 === (5))){
var inst_98987 = (state_99008[(10)]);
var state_99008__$1 = state_99008;
var statearr_99015_99026 = state_99008__$1;
(statearr_99015_99026[(2)] = inst_98987);

(statearr_99015_99026[(1)] = (6));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99009 === (6))){
var inst_99004 = (state_99008[(2)]);
var state_99008__$1 = state_99008;
var statearr_99016_99027 = state_99008__$1;
(statearr_99016_99027[(2)] = inst_99004);

(statearr_99016_99027[(1)] = (3));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99009 === (7))){
var inst_98994 = (state_99008[(12)]);
var inst_98987 = (state_99008[(10)]);
var inst_98998 = (state_99008[(2)]);
var inst_98999 = fluree.db.util.async.throw_err.call(null,inst_98998);
var inst_99000 = cljs.core.conj.call(null,inst_98987,inst_98999);
var inst_98986 = inst_98994;
var inst_98987__$1 = inst_99000;
var state_99008__$1 = (function (){var statearr_99017 = state_99008;
(statearr_99017[(9)] = inst_98986);

(statearr_99017[(10)] = inst_98987__$1);

return statearr_99017;
})();
var statearr_99018_99028 = state_99008__$1;
(statearr_99018_99028[(2)] = null);

(statearr_99018_99028[(1)] = (2));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
return null;
}
}
}
}
}
}
}
});})(c__86675__auto__))
;
return ((function (switch__86624__auto__,c__86675__auto__){
return (function() {
var fluree$db$query$fql$format_tuple_$_state_machine__86625__auto__ = null;
var fluree$db$query$fql$format_tuple_$_state_machine__86625__auto____0 = (function (){
var statearr_99019 = [null,null,null,null,null,null,null,null,null,null,null,null,null];
(statearr_99019[(0)] = fluree$db$query$fql$format_tuple_$_state_machine__86625__auto__);

(statearr_99019[(1)] = (1));

return statearr_99019;
});
var fluree$db$query$fql$format_tuple_$_state_machine__86625__auto____1 = (function (state_99008){
while(true){
var ret_value__86626__auto__ = (function (){try{while(true){
var result__86627__auto__ = switch__86624__auto__.call(null,state_99008);
if(cljs.core.keyword_identical_QMARK_.call(null,result__86627__auto__,new cljs.core.Keyword(null,"recur","recur",-437573268))){
continue;
} else {
return result__86627__auto__;
}
break;
}
}catch (e99020){if((e99020 instanceof Object)){
var ex__86628__auto__ = e99020;
var statearr_99021_99029 = state_99008;
(statearr_99021_99029[(5)] = ex__86628__auto__);


cljs.core.async.impl.ioc_helpers.process_exception.call(null,state_99008);

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
throw e99020;

}
}})();
if(cljs.core.keyword_identical_QMARK_.call(null,ret_value__86626__auto__,new cljs.core.Keyword(null,"recur","recur",-437573268))){
var G__99030 = state_99008;
state_99008 = G__99030;
continue;
} else {
return ret_value__86626__auto__;
}
break;
}
});
fluree$db$query$fql$format_tuple_$_state_machine__86625__auto__ = function(state_99008){
switch(arguments.length){
case 0:
return fluree$db$query$fql$format_tuple_$_state_machine__86625__auto____0.call(this);
case 1:
return fluree$db$query$fql$format_tuple_$_state_machine__86625__auto____1.call(this,state_99008);
}
throw(new Error('Invalid arity: ' + arguments.length));
};
fluree$db$query$fql$format_tuple_$_state_machine__86625__auto__.cljs$core$IFn$_invoke$arity$0 = fluree$db$query$fql$format_tuple_$_state_machine__86625__auto____0;
fluree$db$query$fql$format_tuple_$_state_machine__86625__auto__.cljs$core$IFn$_invoke$arity$1 = fluree$db$query$fql$format_tuple_$_state_machine__86625__auto____1;
return fluree$db$query$fql$format_tuple_$_state_machine__86625__auto__;
})()
;})(switch__86624__auto__,c__86675__auto__))
})();
var state__86677__auto__ = (function (){var statearr_99022 = f__86676__auto__.call(null);
(statearr_99022[(6)] = c__86675__auto__);

return statearr_99022;
})();
return cljs.core.async.impl.ioc_helpers.run_state_machine_wrapped.call(null,state__86677__auto__);
});})(c__86675__auto__))
);

return c__86675__auto__;
});
fluree.db.query.fql.get_header_idx = (function fluree$db$query$fql$get_header_idx(headers,select){
if(cljs.core.truth_(new cljs.core.Keyword(null,"as","as",1148689641).cljs$core$IFn$_invoke$arity$1(select))){
return fluree.db.util.core.index_of.call(null,headers,new cljs.core.Keyword(null,"as","as",1148689641).cljs$core$IFn$_invoke$arity$1(select));
} else {
if(cljs.core.truth_(new cljs.core.Keyword(null,"code","code",1586293142).cljs$core$IFn$_invoke$arity$1(select))){
return fluree.db.util.core.index_of.call(null,cljs.core.map.call(null,cljs.core.str,headers),cljs.core.str.cljs$core$IFn$_invoke$arity$1(new cljs.core.Keyword(null,"code","code",1586293142).cljs$core$IFn$_invoke$arity$1(select)));
} else {
if(cljs.core.truth_(new cljs.core.Keyword(null,"variable","variable",-281346492).cljs$core$IFn$_invoke$arity$1(select))){
return fluree.db.util.core.index_of.call(null,headers,new cljs.core.Keyword(null,"variable","variable",-281346492).cljs$core$IFn$_invoke$arity$1(select));
} else {
return null;
}
}
}
});
fluree.db.query.fql.format_filter_tuples = (function fluree$db$query$fql$format_filter_tuples(db,tuples,p__99032,headers,vars,opts){
var map__99033 = p__99032;
var map__99033__$1 = (((((!((map__99033 == null))))?(((((map__99033.cljs$lang$protocol_mask$partition0$ & (64))) || ((cljs.core.PROTOCOL_SENTINEL === map__99033.cljs$core$ISeq$))))?true:false):false))?cljs.core.apply.call(null,cljs.core.hash_map,map__99033):map__99033);
var select_spec = map__99033__$1;
var prettyPrint = cljs.core.get.call(null,map__99033__$1,new cljs.core.Keyword(null,"prettyPrint","prettyPrint",215590803));
var select = cljs.core.get.call(null,map__99033__$1,new cljs.core.Keyword(null,"select","select",1147833503));
var inVector_QMARK_ = cljs.core.get.call(null,map__99033__$1,new cljs.core.Keyword(null,"inVector?","inVector?",1948069375));
var expandMaps_QMARK_ = cljs.core.get.call(null,map__99033__$1,new cljs.core.Keyword(null,"expandMaps?","expandMaps?",-1946388444));
var c__86675__auto__ = cljs.core.async.chan.call(null,(1));
cljs.core.async.impl.dispatch.run.call(null,((function (c__86675__auto__,map__99033,map__99033__$1,select_spec,prettyPrint,select,inVector_QMARK_,expandMaps_QMARK_){
return (function (){
var f__86676__auto__ = (function (){var switch__86624__auto__ = ((function (c__86675__auto__,map__99033,map__99033__$1,select_spec,prettyPrint,select,inVector_QMARK_,expandMaps_QMARK_){
return (function (state_99116){
var state_val_99117 = (state_99116[(1)]);
if((state_val_99117 === (7))){
var inst_99043 = (state_99116[(2)]);
var state_99116__$1 = (function (){var statearr_99118 = state_99116;
(statearr_99118[(7)] = inst_99043);

return statearr_99118;
})();
if(cljs.core.truth_(expandMaps_QMARK_)){
var statearr_99119_99230 = state_99116__$1;
(statearr_99119_99230[(1)] = (8));

} else {
var statearr_99120_99231 = state_99116__$1;
(statearr_99120_99231[(1)] = (9));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99117 === (1))){
var state_99116__$1 = state_99116;
var statearr_99121_99232 = state_99116__$1;
(statearr_99121_99232[(2)] = null);

(statearr_99121_99232[(1)] = (4));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99117 === (4))){
var _ = cljs.core.async.impl.ioc_helpers.add_exception_frame.call(null,state_99116,(3),Error,null,(2));
var state_99116__$1 = state_99116;
if(cljs.core.truth_(prettyPrint)){
var statearr_99122_99233 = state_99116__$1;
(statearr_99122_99233[(1)] = (5));

} else {
var statearr_99123_99234 = state_99116__$1;
(statearr_99123_99234[(1)] = (6));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99117 === (13))){
var inst_99112 = (state_99116[(2)]);
var state_99116__$1 = state_99116;
var statearr_99124_99235 = state_99116__$1;
(statearr_99124_99235[(2)] = inst_99112);


cljs.core.async.impl.ioc_helpers.process_exception.call(null,state_99116__$1);

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99117 === (6))){
var state_99116__$1 = state_99116;
var statearr_99125_99236 = state_99116__$1;
(statearr_99125_99236[(2)] = null);

(statearr_99125_99236[(1)] = (7));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99117 === (3))){
var inst_99035 = (state_99116[(2)]);
var state_99116__$1 = state_99116;
var statearr_99126_99237 = state_99116__$1;
(statearr_99126_99237[(2)] = inst_99035);


cljs.core.async.impl.ioc_helpers.process_exception.call(null,state_99116__$1);

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99117 === (12))){
var inst_99043 = (state_99116[(7)]);
var inst_99051 = (state_99116[(8)]);
var inst_99109 = (function (){var pp = inst_99043;
var functionArray = inst_99051;
return ((function (pp,functionArray,inst_99043,inst_99051,state_val_99117,c__86675__auto__,map__99033,map__99033__$1,select_spec,prettyPrint,select,inVector_QMARK_,expandMaps_QMARK_){
return (function (tuple){
var tuple_res = cljs.core.map.call(null,((function (pp,functionArray,inst_99043,inst_99051,state_val_99117,c__86675__auto__,map__99033,map__99033__$1,select_spec,prettyPrint,select,inVector_QMARK_,expandMaps_QMARK_){
return (function (p1__99031_SHARP_){
return p1__99031_SHARP_.call(null,tuple);
});})(pp,functionArray,inst_99043,inst_99051,state_val_99117,c__86675__auto__,map__99033,map__99033__$1,select_spec,prettyPrint,select,inVector_QMARK_,expandMaps_QMARK_))
,functionArray);
if(cljs.core.truth_(pp)){
return cljs.core.zipmap.call(null,pp,tuple_res);
} else {
if(cljs.core.truth_(inVector_QMARK_)){
return tuple_res;
} else {
return cljs.core.first.call(null,tuple_res);

}
}
});
;})(pp,functionArray,inst_99043,inst_99051,state_val_99117,c__86675__auto__,map__99033,map__99033__$1,select_spec,prettyPrint,select,inVector_QMARK_,expandMaps_QMARK_))
})();
var inst_99110 = cljs.core.map.call(null,inst_99109,tuples);
var state_99116__$1 = state_99116;
var statearr_99127_99238 = state_99116__$1;
(statearr_99127_99238[(2)] = inst_99110);

(statearr_99127_99238[(1)] = (13));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99117 === (2))){
var inst_99114 = (state_99116[(2)]);
var state_99116__$1 = state_99116;
return cljs.core.async.impl.ioc_helpers.return_chan.call(null,state_99116__$1,inst_99114);
} else {
if((state_val_99117 === (11))){
var inst_99043 = (state_99116[(7)]);
var inst_99051 = (state_99116[(8)]);
var inst_99102 = cljs.core.async.chan.call(null,(1));
var inst_99103 = (function (){var pp = inst_99043;
var functionArray = inst_99051;
var c__86675__auto____$1 = inst_99102;
return ((function (pp,functionArray,c__86675__auto____$1,inst_99043,inst_99051,inst_99102,state_val_99117,c__86675__auto__,map__99033,map__99033__$1,select_spec,prettyPrint,select,inVector_QMARK_,expandMaps_QMARK_){
return (function (){
var f__86676__auto__ = (function (){var switch__86624__auto__ = ((function (pp,functionArray,c__86675__auto____$1,inst_99043,inst_99051,inst_99102,state_val_99117,c__86675__auto__,map__99033,map__99033__$1,select_spec,prettyPrint,select,inVector_QMARK_,expandMaps_QMARK_){
return (function (state_99100){
var state_val_99101 = (state_99100[(1)]);
if((state_val_99101 === (7))){
var inst_99076 = (state_99100[(2)]);
var inst_99077 = fluree.db.util.async.throw_err.call(null,inst_99076);
var state_99100__$1 = (function (){var statearr_99128 = state_99100;
(statearr_99128[(7)] = inst_99077);

return statearr_99128;
})();
if(cljs.core.truth_(pp)){
var statearr_99129_99239 = state_99100__$1;
(statearr_99129_99239[(1)] = (8));

} else {
var statearr_99130_99240 = state_99100__$1;
(statearr_99130_99240[(1)] = (9));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99101 === (1))){
var inst_99060 = cljs.core.seq.call(null,tuples);
var inst_99061 = cljs.core.first.call(null,inst_99060);
var inst_99062 = cljs.core.next.call(null,inst_99060);
var inst_99063 = cljs.core.PersistentVector.EMPTY;
var inst_99064 = tuples;
var inst_99065 = inst_99063;
var state_99100__$1 = (function (){var statearr_99131 = state_99100;
(statearr_99131[(8)] = inst_99065);

(statearr_99131[(9)] = inst_99061);

(statearr_99131[(10)] = inst_99062);

(statearr_99131[(11)] = inst_99064);

return statearr_99131;
})();
var statearr_99132_99241 = state_99100__$1;
(statearr_99132_99241[(2)] = null);

(statearr_99132_99241[(1)] = (2));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99101 === (4))){
var inst_99071 = (state_99100[(12)]);
var inst_99074 = fluree.db.query.fql.format_tuple.call(null,functionArray,inst_99071);
var state_99100__$1 = state_99100;
return cljs.core.async.impl.ioc_helpers.take_BANG_.call(null,state_99100__$1,(7),inst_99074);
} else {
if((state_val_99101 === (15))){
var state_99100__$1 = state_99100;
var statearr_99133_99242 = state_99100__$1;
(statearr_99133_99242[(2)] = null);

(statearr_99133_99242[(1)] = (16));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99101 === (13))){
var inst_99089 = (state_99100[(2)]);
var state_99100__$1 = state_99100;
var statearr_99134_99243 = state_99100__$1;
(statearr_99134_99243[(2)] = inst_99089);

(statearr_99134_99243[(1)] = (10));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99101 === (6))){
var inst_99096 = (state_99100[(2)]);
var state_99100__$1 = state_99100;
var statearr_99135_99244 = state_99100__$1;
(statearr_99135_99244[(2)] = inst_99096);

(statearr_99135_99244[(1)] = (3));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99101 === (3))){
var inst_99098 = (state_99100[(2)]);
var state_99100__$1 = state_99100;
return cljs.core.async.impl.ioc_helpers.return_chan.call(null,state_99100__$1,inst_99098);
} else {
if((state_val_99101 === (12))){
var state_99100__$1 = state_99100;
var statearr_99136_99245 = state_99100__$1;
(statearr_99136_99245[(1)] = (14));



return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99101 === (2))){
var inst_99071 = (state_99100[(12)]);
var inst_99064 = (state_99100[(11)]);
var inst_99070 = cljs.core.seq.call(null,inst_99064);
var inst_99071__$1 = cljs.core.first.call(null,inst_99070);
var inst_99072 = cljs.core.next.call(null,inst_99070);
var state_99100__$1 = (function (){var statearr_99138 = state_99100;
(statearr_99138[(13)] = inst_99072);

(statearr_99138[(12)] = inst_99071__$1);

return statearr_99138;
})();
if(cljs.core.truth_(inst_99071__$1)){
var statearr_99139_99246 = state_99100__$1;
(statearr_99139_99246[(1)] = (4));

} else {
var statearr_99140_99247 = state_99100__$1;
(statearr_99140_99247[(1)] = (5));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99101 === (11))){
var inst_99077 = (state_99100[(7)]);
var state_99100__$1 = state_99100;
var statearr_99141_99248 = state_99100__$1;
(statearr_99141_99248[(2)] = inst_99077);

(statearr_99141_99248[(1)] = (13));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99101 === (9))){
var state_99100__$1 = state_99100;
if(cljs.core.truth_(inVector_QMARK_)){
var statearr_99142_99249 = state_99100__$1;
(statearr_99142_99249[(1)] = (11));

} else {
var statearr_99143_99250 = state_99100__$1;
(statearr_99143_99250[(1)] = (12));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99101 === (5))){
var inst_99065 = (state_99100[(8)]);
var state_99100__$1 = state_99100;
var statearr_99144_99251 = state_99100__$1;
(statearr_99144_99251[(2)] = inst_99065);

(statearr_99144_99251[(1)] = (6));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99101 === (14))){
var inst_99077 = (state_99100[(7)]);
var inst_99084 = cljs.core.first.call(null,inst_99077);
var state_99100__$1 = state_99100;
var statearr_99145_99252 = state_99100__$1;
(statearr_99145_99252[(2)] = inst_99084);

(statearr_99145_99252[(1)] = (16));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99101 === (16))){
var inst_99087 = (state_99100[(2)]);
var state_99100__$1 = state_99100;
var statearr_99146_99253 = state_99100__$1;
(statearr_99146_99253[(2)] = inst_99087);

(statearr_99146_99253[(1)] = (13));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99101 === (10))){
var inst_99072 = (state_99100[(13)]);
var inst_99065 = (state_99100[(8)]);
var inst_99091 = (state_99100[(2)]);
var inst_99092 = cljs.core.conj.call(null,inst_99065,inst_99091);
var inst_99064 = inst_99072;
var inst_99065__$1 = inst_99092;
var state_99100__$1 = (function (){var statearr_99147 = state_99100;
(statearr_99147[(8)] = inst_99065__$1);

(statearr_99147[(11)] = inst_99064);

return statearr_99147;
})();
var statearr_99148_99254 = state_99100__$1;
(statearr_99148_99254[(2)] = null);

(statearr_99148_99254[(1)] = (2));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99101 === (8))){
var inst_99077 = (state_99100[(7)]);
var inst_99079 = cljs.core.zipmap.call(null,pp,inst_99077);
var state_99100__$1 = state_99100;
var statearr_99149_99255 = state_99100__$1;
(statearr_99149_99255[(2)] = inst_99079);

(statearr_99149_99255[(1)] = (10));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
return null;
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
});})(pp,functionArray,c__86675__auto____$1,inst_99043,inst_99051,inst_99102,state_val_99117,c__86675__auto__,map__99033,map__99033__$1,select_spec,prettyPrint,select,inVector_QMARK_,expandMaps_QMARK_))
;
return ((function (switch__86624__auto__,pp,functionArray,c__86675__auto____$1,inst_99043,inst_99051,inst_99102,state_val_99117,c__86675__auto__,map__99033,map__99033__$1,select_spec,prettyPrint,select,inVector_QMARK_,expandMaps_QMARK_){
return (function() {
var fluree$db$query$fql$format_filter_tuples_$_state_machine__86625__auto__ = null;
var fluree$db$query$fql$format_filter_tuples_$_state_machine__86625__auto____0 = (function (){
var statearr_99150 = [null,null,null,null,null,null,null,null,null,null,null,null,null,null];
(statearr_99150[(0)] = fluree$db$query$fql$format_filter_tuples_$_state_machine__86625__auto__);

(statearr_99150[(1)] = (1));

return statearr_99150;
});
var fluree$db$query$fql$format_filter_tuples_$_state_machine__86625__auto____1 = (function (state_99100){
while(true){
var ret_value__86626__auto__ = (function (){try{while(true){
var result__86627__auto__ = switch__86624__auto__.call(null,state_99100);
if(cljs.core.keyword_identical_QMARK_.call(null,result__86627__auto__,new cljs.core.Keyword(null,"recur","recur",-437573268))){
continue;
} else {
return result__86627__auto__;
}
break;
}
}catch (e99151){if((e99151 instanceof Object)){
var ex__86628__auto__ = e99151;
var statearr_99152_99256 = state_99100;
(statearr_99152_99256[(5)] = ex__86628__auto__);


cljs.core.async.impl.ioc_helpers.process_exception.call(null,state_99100);

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
throw e99151;

}
}})();
if(cljs.core.keyword_identical_QMARK_.call(null,ret_value__86626__auto__,new cljs.core.Keyword(null,"recur","recur",-437573268))){
var G__99257 = state_99100;
state_99100 = G__99257;
continue;
} else {
return ret_value__86626__auto__;
}
break;
}
});
fluree$db$query$fql$format_filter_tuples_$_state_machine__86625__auto__ = function(state_99100){
switch(arguments.length){
case 0:
return fluree$db$query$fql$format_filter_tuples_$_state_machine__86625__auto____0.call(this);
case 1:
return fluree$db$query$fql$format_filter_tuples_$_state_machine__86625__auto____1.call(this,state_99100);
}
throw(new Error('Invalid arity: ' + arguments.length));
};
fluree$db$query$fql$format_filter_tuples_$_state_machine__86625__auto__.cljs$core$IFn$_invoke$arity$0 = fluree$db$query$fql$format_filter_tuples_$_state_machine__86625__auto____0;
fluree$db$query$fql$format_filter_tuples_$_state_machine__86625__auto__.cljs$core$IFn$_invoke$arity$1 = fluree$db$query$fql$format_filter_tuples_$_state_machine__86625__auto____1;
return fluree$db$query$fql$format_filter_tuples_$_state_machine__86625__auto__;
})()
;})(switch__86624__auto__,pp,functionArray,c__86675__auto____$1,inst_99043,inst_99051,inst_99102,state_val_99117,c__86675__auto__,map__99033,map__99033__$1,select_spec,prettyPrint,select,inVector_QMARK_,expandMaps_QMARK_))
})();
var state__86677__auto__ = (function (){var statearr_99153 = f__86676__auto__.call(null);
(statearr_99153[(6)] = c__86675__auto____$1);

return statearr_99153;
})();
return cljs.core.async.impl.ioc_helpers.run_state_machine_wrapped.call(null,state__86677__auto__);
});
;})(pp,functionArray,c__86675__auto____$1,inst_99043,inst_99051,inst_99102,state_val_99117,c__86675__auto__,map__99033,map__99033__$1,select_spec,prettyPrint,select,inVector_QMARK_,expandMaps_QMARK_))
})();
var inst_99104 = cljs.core.async.impl.dispatch.run.call(null,inst_99103);
var state_99116__$1 = (function (){var statearr_99154 = state_99116;
(statearr_99154[(9)] = inst_99104);

return statearr_99154;
})();
return cljs.core.async.impl.ioc_helpers.take_BANG_.call(null,state_99116__$1,(14),inst_99102);
} else {
if((state_val_99117 === (9))){
var inst_99043 = (state_99116[(7)]);
var inst_99048 = (function (){var pp = inst_99043;
return ((function (pp,inst_99043,state_val_99117,c__86675__auto__,map__99033,map__99033__$1,select_spec,prettyPrint,select,inVector_QMARK_,expandMaps_QMARK_){
return (function (select__$1){
var temp__5733__auto__ = new cljs.core.Keyword(null,"value","value",305978217).cljs$core$IFn$_invoke$arity$1(select__$1);
if(cljs.core.truth_(temp__5733__auto__)){
var val = temp__5733__auto__;
return ((function (val,temp__5733__auto__,pp,inst_99043,state_val_99117,c__86675__auto__,map__99033,map__99033__$1,select_spec,prettyPrint,select,inVector_QMARK_,expandMaps_QMARK_){
return (function (x){
return val;
});
;})(val,temp__5733__auto__,pp,inst_99043,state_val_99117,c__86675__auto__,map__99033,map__99033__$1,select_spec,prettyPrint,select,inVector_QMARK_,expandMaps_QMARK_))
} else {
var idx = fluree.db.query.fql.get_header_idx.call(null,headers,select__$1);
return ((function (idx,temp__5733__auto__,pp,inst_99043,state_val_99117,c__86675__auto__,map__99033,map__99033__$1,select_spec,prettyPrint,select,inVector_QMARK_,expandMaps_QMARK_){
return (function (tuple){
return cljs.core.nth.call(null,tuple,idx);
});
;})(idx,temp__5733__auto__,pp,inst_99043,state_val_99117,c__86675__auto__,map__99033,map__99033__$1,select_spec,prettyPrint,select,inVector_QMARK_,expandMaps_QMARK_))
}
});
;})(pp,inst_99043,state_val_99117,c__86675__auto__,map__99033,map__99033__$1,select_spec,prettyPrint,select,inVector_QMARK_,expandMaps_QMARK_))
})();
var inst_99049 = cljs.core.map.call(null,inst_99048,select);
var state_99116__$1 = state_99116;
var statearr_99155_99258 = state_99116__$1;
(statearr_99155_99258[(2)] = inst_99049);

(statearr_99155_99258[(1)] = (10));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99117 === (5))){
var inst_99040 = fluree.db.query.fql.get_pretty_print_keys.call(null,select);
var state_99116__$1 = state_99116;
var statearr_99156_99259 = state_99116__$1;
(statearr_99156_99259[(2)] = inst_99040);

(statearr_99156_99259[(1)] = (7));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99117 === (14))){
var inst_99106 = (state_99116[(2)]);
var inst_99107 = fluree.db.util.async.throw_err.call(null,inst_99106);
var state_99116__$1 = state_99116;
var statearr_99157_99260 = state_99116__$1;
(statearr_99157_99260[(2)] = inst_99107);

(statearr_99157_99260[(1)] = (13));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99117 === (10))){
var inst_99051 = (state_99116[(2)]);
var state_99116__$1 = (function (){var statearr_99158 = state_99116;
(statearr_99158[(8)] = inst_99051);

return statearr_99158;
})();
if(cljs.core.truth_(expandMaps_QMARK_)){
var statearr_99159_99261 = state_99116__$1;
(statearr_99159_99261[(1)] = (11));

} else {
var statearr_99160_99262 = state_99116__$1;
(statearr_99160_99262[(1)] = (12));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99117 === (8))){
var inst_99043 = (state_99116[(7)]);
var inst_99045 = (function (){var pp = inst_99043;
return ((function (pp,inst_99043,state_val_99117,c__86675__auto__,map__99033,map__99033__$1,select_spec,prettyPrint,select,inVector_QMARK_,expandMaps_QMARK_){
return (function (select__$1){
var select_val = (function (){var or__4131__auto__ = new cljs.core.Keyword(null,"as","as",1148689641).cljs$core$IFn$_invoke$arity$1(select__$1);
if(cljs.core.truth_(or__4131__auto__)){
return or__4131__auto__;
} else {
return new cljs.core.Keyword(null,"variable","variable",-281346492).cljs$core$IFn$_invoke$arity$1(select__$1);
}
})();
var idx = (cljs.core.truth_(select_val)?fluree.db.util.core.index_of.call(null,headers,select_val):null);
var select_fn = (cljs.core.truth_(idx)?((function (select_val,idx,pp,inst_99043,state_val_99117,c__86675__auto__,map__99033,map__99033__$1,select_spec,prettyPrint,select,inVector_QMARK_,expandMaps_QMARK_){
return (function (tuple){
return cljs.core.nth.call(null,tuple,idx);
});})(select_val,idx,pp,inst_99043,state_val_99117,c__86675__auto__,map__99033,map__99033__$1,select_spec,prettyPrint,select,inVector_QMARK_,expandMaps_QMARK_))
:(cljs.core.truth_(new cljs.core.Keyword(null,"value","value",305978217).cljs$core$IFn$_invoke$arity$1(select__$1))?((function (select_val,idx,pp,inst_99043,state_val_99117,c__86675__auto__,map__99033,map__99033__$1,select_spec,prettyPrint,select,inVector_QMARK_,expandMaps_QMARK_){
return (function (tuple){
return new cljs.core.Keyword(null,"value","value",305978217).cljs$core$IFn$_invoke$arity$1(select__$1);
});})(select_val,idx,pp,inst_99043,state_val_99117,c__86675__auto__,map__99033,map__99033__$1,select_spec,prettyPrint,select,inVector_QMARK_,expandMaps_QMARK_))
:(cljs.core.truth_(cljs.core.get.call(null,vars,select_val))?((function (select_val,idx,pp,inst_99043,state_val_99117,c__86675__auto__,map__99033,map__99033__$1,select_spec,prettyPrint,select,inVector_QMARK_,expandMaps_QMARK_){
return (function (tuple){
return cljs.core.get.call(null,vars,select_val);
});})(select_val,idx,pp,inst_99043,state_val_99117,c__86675__auto__,map__99033,map__99033__$1,select_spec,prettyPrint,select,inVector_QMARK_,expandMaps_QMARK_))
:null)));
if(cljs.core.truth_(new cljs.core.Keyword(null,"selection","selection",975998651).cljs$core$IFn$_invoke$arity$1(select__$1))){
return ((function (select_val,idx,select_fn,pp,inst_99043,state_val_99117,c__86675__auto__,map__99033,map__99033__$1,select_spec,prettyPrint,select,inVector_QMARK_,expandMaps_QMARK_){
return (function (tuple){
var c__86675__auto____$1 = cljs.core.async.chan.call(null,(1));
cljs.core.async.impl.dispatch.run.call(null,((function (c__86675__auto____$1,select_val,idx,select_fn,pp,inst_99043,state_val_99117,c__86675__auto__,map__99033,map__99033__$1,select_spec,prettyPrint,select,inVector_QMARK_,expandMaps_QMARK_){
return (function (){
var f__86676__auto__ = (function (){var switch__86624__auto__ = ((function (c__86675__auto____$1,select_val,idx,select_fn,pp,inst_99043,state_val_99117,c__86675__auto__,map__99033,map__99033__$1,select_spec,prettyPrint,select,inVector_QMARK_,expandMaps_QMARK_){
return (function (state_99190){
var state_val_99191 = (state_99190[(1)]);
if((state_val_99191 === (7))){
var inst_99186 = (state_99190[(2)]);
var state_99190__$1 = state_99190;
var statearr_99192_99263 = state_99190__$1;
(statearr_99192_99263[(2)] = inst_99186);


cljs.core.async.impl.ioc_helpers.process_exception.call(null,state_99190__$1);

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99191 === (1))){
var state_99190__$1 = state_99190;
var statearr_99193_99264 = state_99190__$1;
(statearr_99193_99264[(2)] = null);

(statearr_99193_99264[(1)] = (4));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99191 === (4))){
var _ = cljs.core.async.impl.ioc_helpers.add_exception_frame.call(null,state_99190,(3),Error,null,(2));
var inst_99165 = select_fn.call(null,tuple);
var state_99190__$1 = state_99190;
if(cljs.core.truth_(inst_99165)){
var statearr_99194_99265 = state_99190__$1;
(statearr_99194_99265[(1)] = (5));

} else {
var statearr_99195_99266 = state_99190__$1;
(statearr_99195_99266[(1)] = (6));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99191 === (6))){
var state_99190__$1 = state_99190;
var statearr_99196_99267 = state_99190__$1;
(statearr_99196_99267[(2)] = null);

(statearr_99196_99267[(1)] = (7));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99191 === (3))){
var inst_99161 = (state_99190[(2)]);
var state_99190__$1 = state_99190;
var statearr_99197_99268 = state_99190__$1;
(statearr_99197_99268[(2)] = inst_99161);


cljs.core.async.impl.ioc_helpers.process_exception.call(null,state_99190__$1);

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99191 === (2))){
var inst_99188 = (state_99190[(2)]);
var state_99190__$1 = state_99190;
return cljs.core.async.impl.ioc_helpers.return_chan.call(null,state_99190__$1,inst_99188);
} else {
if((state_val_99191 === (11))){
var inst_99183 = (state_99190[(2)]);
var state_99190__$1 = state_99190;
var statearr_99198_99269 = state_99190__$1;
(statearr_99198_99269[(2)] = inst_99183);

(statearr_99198_99269[(1)] = (7));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99191 === (9))){
var inst_99175 = (state_99190[(7)]);
var state_99190__$1 = state_99190;
var statearr_99199_99270 = state_99190__$1;
(statearr_99199_99270[(2)] = inst_99175);

(statearr_99199_99270[(1)] = (11));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99191 === (5))){
var inst_99167 = [new cljs.core.Keyword(null,"selectOne","selectOne",1588429876),new cljs.core.Keyword(null,"from","from",1815293044)];
var inst_99168 = new cljs.core.Keyword(null,"selection","selection",975998651).cljs$core$IFn$_invoke$arity$1(select__$1);
var inst_99169 = select_fn.call(null,tuple);
var inst_99170 = [inst_99168,inst_99169];
var inst_99171 = cljs.core.PersistentHashMap.fromArrays(inst_99167,inst_99170);
var inst_99172 = fluree.db.query.fql.query.call(null,db,inst_99171,opts);
var state_99190__$1 = state_99190;
return cljs.core.async.impl.ioc_helpers.take_BANG_.call(null,state_99190__$1,(8),inst_99172);
} else {
if((state_val_99191 === (10))){
var inst_99178 = [new cljs.core.Keyword(null,"_id","_id",-789960287)];
var inst_99179 = select_fn.call(null,tuple);
var inst_99180 = [inst_99179];
var inst_99181 = cljs.core.PersistentHashMap.fromArrays(inst_99178,inst_99180);
var state_99190__$1 = state_99190;
var statearr_99200_99271 = state_99190__$1;
(statearr_99200_99271[(2)] = inst_99181);

(statearr_99200_99271[(1)] = (11));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99191 === (8))){
var inst_99175 = (state_99190[(7)]);
var inst_99174 = (state_99190[(2)]);
var inst_99175__$1 = fluree.db.util.async.throw_err.call(null,inst_99174);
var state_99190__$1 = (function (){var statearr_99201 = state_99190;
(statearr_99201[(7)] = inst_99175__$1);

return statearr_99201;
})();
if(cljs.core.truth_(inst_99175__$1)){
var statearr_99202_99272 = state_99190__$1;
(statearr_99202_99272[(1)] = (9));

} else {
var statearr_99203_99273 = state_99190__$1;
(statearr_99203_99273[(1)] = (10));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
return null;
}
}
}
}
}
}
}
}
}
}
}
});})(c__86675__auto____$1,select_val,idx,select_fn,pp,inst_99043,state_val_99117,c__86675__auto__,map__99033,map__99033__$1,select_spec,prettyPrint,select,inVector_QMARK_,expandMaps_QMARK_))
;
return ((function (switch__86624__auto__,c__86675__auto____$1,select_val,idx,select_fn,pp,inst_99043,state_val_99117,c__86675__auto__,map__99033,map__99033__$1,select_spec,prettyPrint,select,inVector_QMARK_,expandMaps_QMARK_){
return (function() {
var fluree$db$query$fql$format_filter_tuples_$_state_machine__86625__auto__ = null;
var fluree$db$query$fql$format_filter_tuples_$_state_machine__86625__auto____0 = (function (){
var statearr_99204 = [null,null,null,null,null,null,null,null];
(statearr_99204[(0)] = fluree$db$query$fql$format_filter_tuples_$_state_machine__86625__auto__);

(statearr_99204[(1)] = (1));

return statearr_99204;
});
var fluree$db$query$fql$format_filter_tuples_$_state_machine__86625__auto____1 = (function (state_99190){
while(true){
var ret_value__86626__auto__ = (function (){try{while(true){
var result__86627__auto__ = switch__86624__auto__.call(null,state_99190);
if(cljs.core.keyword_identical_QMARK_.call(null,result__86627__auto__,new cljs.core.Keyword(null,"recur","recur",-437573268))){
continue;
} else {
return result__86627__auto__;
}
break;
}
}catch (e99205){if((e99205 instanceof Object)){
var ex__86628__auto__ = e99205;
var statearr_99206_99274 = state_99190;
(statearr_99206_99274[(5)] = ex__86628__auto__);


cljs.core.async.impl.ioc_helpers.process_exception.call(null,state_99190);

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
throw e99205;

}
}})();
if(cljs.core.keyword_identical_QMARK_.call(null,ret_value__86626__auto__,new cljs.core.Keyword(null,"recur","recur",-437573268))){
var G__99275 = state_99190;
state_99190 = G__99275;
continue;
} else {
return ret_value__86626__auto__;
}
break;
}
});
fluree$db$query$fql$format_filter_tuples_$_state_machine__86625__auto__ = function(state_99190){
switch(arguments.length){
case 0:
return fluree$db$query$fql$format_filter_tuples_$_state_machine__86625__auto____0.call(this);
case 1:
return fluree$db$query$fql$format_filter_tuples_$_state_machine__86625__auto____1.call(this,state_99190);
}
throw(new Error('Invalid arity: ' + arguments.length));
};
fluree$db$query$fql$format_filter_tuples_$_state_machine__86625__auto__.cljs$core$IFn$_invoke$arity$0 = fluree$db$query$fql$format_filter_tuples_$_state_machine__86625__auto____0;
fluree$db$query$fql$format_filter_tuples_$_state_machine__86625__auto__.cljs$core$IFn$_invoke$arity$1 = fluree$db$query$fql$format_filter_tuples_$_state_machine__86625__auto____1;
return fluree$db$query$fql$format_filter_tuples_$_state_machine__86625__auto__;
})()
;})(switch__86624__auto__,c__86675__auto____$1,select_val,idx,select_fn,pp,inst_99043,state_val_99117,c__86675__auto__,map__99033,map__99033__$1,select_spec,prettyPrint,select,inVector_QMARK_,expandMaps_QMARK_))
})();
var state__86677__auto__ = (function (){var statearr_99207 = f__86676__auto__.call(null);
(statearr_99207[(6)] = c__86675__auto____$1);

return statearr_99207;
})();
return cljs.core.async.impl.ioc_helpers.run_state_machine_wrapped.call(null,state__86677__auto__);
});})(c__86675__auto____$1,select_val,idx,select_fn,pp,inst_99043,state_val_99117,c__86675__auto__,map__99033,map__99033__$1,select_spec,prettyPrint,select,inVector_QMARK_,expandMaps_QMARK_))
);

return c__86675__auto____$1;
});
;})(select_val,idx,select_fn,pp,inst_99043,state_val_99117,c__86675__auto__,map__99033,map__99033__$1,select_spec,prettyPrint,select,inVector_QMARK_,expandMaps_QMARK_))
} else {
return ((function (select_val,idx,select_fn,pp,inst_99043,state_val_99117,c__86675__auto__,map__99033,map__99033__$1,select_spec,prettyPrint,select,inVector_QMARK_,expandMaps_QMARK_){
return (function (tuple){
var c__86675__auto____$1 = cljs.core.async.chan.call(null,(1));
cljs.core.async.impl.dispatch.run.call(null,((function (c__86675__auto____$1,select_val,idx,select_fn,pp,inst_99043,state_val_99117,c__86675__auto__,map__99033,map__99033__$1,select_spec,prettyPrint,select,inVector_QMARK_,expandMaps_QMARK_){
return (function (){
var f__86676__auto__ = (function (){var switch__86624__auto__ = ((function (c__86675__auto____$1,select_val,idx,select_fn,pp,inst_99043,state_val_99117,c__86675__auto__,map__99033,map__99033__$1,select_spec,prettyPrint,select,inVector_QMARK_,expandMaps_QMARK_){
return (function (state_99216){
var state_val_99217 = (state_99216[(1)]);
if((state_val_99217 === (1))){
var state_99216__$1 = state_99216;
var statearr_99218_99276 = state_99216__$1;
(statearr_99218_99276[(2)] = null);

(statearr_99218_99276[(1)] = (4));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99217 === (2))){
var inst_99214 = (state_99216[(2)]);
var state_99216__$1 = state_99216;
return cljs.core.async.impl.ioc_helpers.return_chan.call(null,state_99216__$1,inst_99214);
} else {
if((state_val_99217 === (3))){
var inst_99208 = (state_99216[(2)]);
var state_99216__$1 = state_99216;
var statearr_99219_99277 = state_99216__$1;
(statearr_99219_99277[(2)] = inst_99208);


cljs.core.async.impl.ioc_helpers.process_exception.call(null,state_99216__$1);

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99217 === (4))){
var _ = cljs.core.async.impl.ioc_helpers.add_exception_frame.call(null,state_99216,(3),Error,null,(2));
var inst_99212 = select_fn.call(null,tuple);
var state_99216__$1 = state_99216;
var statearr_99220_99278 = state_99216__$1;
(statearr_99220_99278[(2)] = inst_99212);


cljs.core.async.impl.ioc_helpers.process_exception.call(null,state_99216__$1);

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
return null;
}
}
}
}
});})(c__86675__auto____$1,select_val,idx,select_fn,pp,inst_99043,state_val_99117,c__86675__auto__,map__99033,map__99033__$1,select_spec,prettyPrint,select,inVector_QMARK_,expandMaps_QMARK_))
;
return ((function (switch__86624__auto__,c__86675__auto____$1,select_val,idx,select_fn,pp,inst_99043,state_val_99117,c__86675__auto__,map__99033,map__99033__$1,select_spec,prettyPrint,select,inVector_QMARK_,expandMaps_QMARK_){
return (function() {
var fluree$db$query$fql$format_filter_tuples_$_state_machine__86625__auto__ = null;
var fluree$db$query$fql$format_filter_tuples_$_state_machine__86625__auto____0 = (function (){
var statearr_99221 = [null,null,null,null,null,null,null];
(statearr_99221[(0)] = fluree$db$query$fql$format_filter_tuples_$_state_machine__86625__auto__);

(statearr_99221[(1)] = (1));

return statearr_99221;
});
var fluree$db$query$fql$format_filter_tuples_$_state_machine__86625__auto____1 = (function (state_99216){
while(true){
var ret_value__86626__auto__ = (function (){try{while(true){
var result__86627__auto__ = switch__86624__auto__.call(null,state_99216);
if(cljs.core.keyword_identical_QMARK_.call(null,result__86627__auto__,new cljs.core.Keyword(null,"recur","recur",-437573268))){
continue;
} else {
return result__86627__auto__;
}
break;
}
}catch (e99222){if((e99222 instanceof Object)){
var ex__86628__auto__ = e99222;
var statearr_99223_99279 = state_99216;
(statearr_99223_99279[(5)] = ex__86628__auto__);


cljs.core.async.impl.ioc_helpers.process_exception.call(null,state_99216);

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
throw e99222;

}
}})();
if(cljs.core.keyword_identical_QMARK_.call(null,ret_value__86626__auto__,new cljs.core.Keyword(null,"recur","recur",-437573268))){
var G__99280 = state_99216;
state_99216 = G__99280;
continue;
} else {
return ret_value__86626__auto__;
}
break;
}
});
fluree$db$query$fql$format_filter_tuples_$_state_machine__86625__auto__ = function(state_99216){
switch(arguments.length){
case 0:
return fluree$db$query$fql$format_filter_tuples_$_state_machine__86625__auto____0.call(this);
case 1:
return fluree$db$query$fql$format_filter_tuples_$_state_machine__86625__auto____1.call(this,state_99216);
}
throw(new Error('Invalid arity: ' + arguments.length));
};
fluree$db$query$fql$format_filter_tuples_$_state_machine__86625__auto__.cljs$core$IFn$_invoke$arity$0 = fluree$db$query$fql$format_filter_tuples_$_state_machine__86625__auto____0;
fluree$db$query$fql$format_filter_tuples_$_state_machine__86625__auto__.cljs$core$IFn$_invoke$arity$1 = fluree$db$query$fql$format_filter_tuples_$_state_machine__86625__auto____1;
return fluree$db$query$fql$format_filter_tuples_$_state_machine__86625__auto__;
})()
;})(switch__86624__auto__,c__86675__auto____$1,select_val,idx,select_fn,pp,inst_99043,state_val_99117,c__86675__auto__,map__99033,map__99033__$1,select_spec,prettyPrint,select,inVector_QMARK_,expandMaps_QMARK_))
})();
var state__86677__auto__ = (function (){var statearr_99224 = f__86676__auto__.call(null);
(statearr_99224[(6)] = c__86675__auto____$1);

return statearr_99224;
})();
return cljs.core.async.impl.ioc_helpers.run_state_machine_wrapped.call(null,state__86677__auto__);
});})(c__86675__auto____$1,select_val,idx,select_fn,pp,inst_99043,state_val_99117,c__86675__auto__,map__99033,map__99033__$1,select_spec,prettyPrint,select,inVector_QMARK_,expandMaps_QMARK_))
);

return c__86675__auto____$1;
});
;})(select_val,idx,select_fn,pp,inst_99043,state_val_99117,c__86675__auto__,map__99033,map__99033__$1,select_spec,prettyPrint,select,inVector_QMARK_,expandMaps_QMARK_))
}
});
;})(pp,inst_99043,state_val_99117,c__86675__auto__,map__99033,map__99033__$1,select_spec,prettyPrint,select,inVector_QMARK_,expandMaps_QMARK_))
})();
var inst_99046 = cljs.core.map.call(null,inst_99045,select);
var state_99116__$1 = state_99116;
var statearr_99225_99281 = state_99116__$1;
(statearr_99225_99281[(2)] = inst_99046);

(statearr_99225_99281[(1)] = (10));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
return null;
}
}
}
}
}
}
}
}
}
}
}
}
}
}
});})(c__86675__auto__,map__99033,map__99033__$1,select_spec,prettyPrint,select,inVector_QMARK_,expandMaps_QMARK_))
;
return ((function (switch__86624__auto__,c__86675__auto__,map__99033,map__99033__$1,select_spec,prettyPrint,select,inVector_QMARK_,expandMaps_QMARK_){
return (function() {
var fluree$db$query$fql$format_filter_tuples_$_state_machine__86625__auto__ = null;
var fluree$db$query$fql$format_filter_tuples_$_state_machine__86625__auto____0 = (function (){
var statearr_99226 = [null,null,null,null,null,null,null,null,null,null];
(statearr_99226[(0)] = fluree$db$query$fql$format_filter_tuples_$_state_machine__86625__auto__);

(statearr_99226[(1)] = (1));

return statearr_99226;
});
var fluree$db$query$fql$format_filter_tuples_$_state_machine__86625__auto____1 = (function (state_99116){
while(true){
var ret_value__86626__auto__ = (function (){try{while(true){
var result__86627__auto__ = switch__86624__auto__.call(null,state_99116);
if(cljs.core.keyword_identical_QMARK_.call(null,result__86627__auto__,new cljs.core.Keyword(null,"recur","recur",-437573268))){
continue;
} else {
return result__86627__auto__;
}
break;
}
}catch (e99227){if((e99227 instanceof Object)){
var ex__86628__auto__ = e99227;
var statearr_99228_99282 = state_99116;
(statearr_99228_99282[(5)] = ex__86628__auto__);


cljs.core.async.impl.ioc_helpers.process_exception.call(null,state_99116);

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
throw e99227;

}
}})();
if(cljs.core.keyword_identical_QMARK_.call(null,ret_value__86626__auto__,new cljs.core.Keyword(null,"recur","recur",-437573268))){
var G__99283 = state_99116;
state_99116 = G__99283;
continue;
} else {
return ret_value__86626__auto__;
}
break;
}
});
fluree$db$query$fql$format_filter_tuples_$_state_machine__86625__auto__ = function(state_99116){
switch(arguments.length){
case 0:
return fluree$db$query$fql$format_filter_tuples_$_state_machine__86625__auto____0.call(this);
case 1:
return fluree$db$query$fql$format_filter_tuples_$_state_machine__86625__auto____1.call(this,state_99116);
}
throw(new Error('Invalid arity: ' + arguments.length));
};
fluree$db$query$fql$format_filter_tuples_$_state_machine__86625__auto__.cljs$core$IFn$_invoke$arity$0 = fluree$db$query$fql$format_filter_tuples_$_state_machine__86625__auto____0;
fluree$db$query$fql$format_filter_tuples_$_state_machine__86625__auto__.cljs$core$IFn$_invoke$arity$1 = fluree$db$query$fql$format_filter_tuples_$_state_machine__86625__auto____1;
return fluree$db$query$fql$format_filter_tuples_$_state_machine__86625__auto__;
})()
;})(switch__86624__auto__,c__86675__auto__,map__99033,map__99033__$1,select_spec,prettyPrint,select,inVector_QMARK_,expandMaps_QMARK_))
})();
var state__86677__auto__ = (function (){var statearr_99229 = f__86676__auto__.call(null);
(statearr_99229[(6)] = c__86675__auto__);

return statearr_99229;
})();
return cljs.core.async.impl.ioc_helpers.run_state_machine_wrapped.call(null,state__86677__auto__);
});})(c__86675__auto__,map__99033,map__99033__$1,select_spec,prettyPrint,select,inVector_QMARK_,expandMaps_QMARK_))
);

return c__86675__auto__;
});
fluree.db.query.fql.process_ad_hoc_group = (function fluree$db$query$fql$process_ad_hoc_group(var_args){
var G__99285 = arguments.length;
switch (G__99285) {
case 4:
return fluree.db.query.fql.process_ad_hoc_group.cljs$core$IFn$_invoke$arity$4((arguments[(0)]),(arguments[(1)]),(arguments[(2)]),(arguments[(3)]));

break;
case 5:
return fluree.db.query.fql.process_ad_hoc_group.cljs$core$IFn$_invoke$arity$5((arguments[(0)]),(arguments[(1)]),(arguments[(2)]),(arguments[(3)]),(arguments[(4)]));

break;
default:
throw (new Error(["Invalid arity: ",cljs.core.str.cljs$core$IFn$_invoke$arity$1(arguments.length)].join('')));

}
});

fluree.db.query.fql.process_ad_hoc_group.cljs$core$IFn$_invoke$arity$4 = (function (db,res,select_spec,opts){
return fluree.db.query.fql.process_ad_hoc_group.call(null,db,res,select_spec,null,opts);
});

fluree.db.query.fql.process_ad_hoc_group.cljs$core$IFn$_invoke$arity$5 = (function (db,p__99286,p__99287,group_limit,opts){
var map__99288 = p__99286;
var map__99288__$1 = (((((!((map__99288 == null))))?(((((map__99288.cljs$lang$protocol_mask$partition0$ & (64))) || ((cljs.core.PROTOCOL_SENTINEL === map__99288.cljs$core$ISeq$))))?true:false):false))?cljs.core.apply.call(null,cljs.core.hash_map,map__99288):map__99288);
var res = map__99288__$1;
var vars = cljs.core.get.call(null,map__99288__$1,new cljs.core.Keyword(null,"vars","vars",-2046957217));
var map__99289 = p__99287;
var map__99289__$1 = (((((!((map__99289 == null))))?(((((map__99289.cljs$lang$protocol_mask$partition0$ & (64))) || ((cljs.core.PROTOCOL_SENTINEL === map__99289.cljs$core$ISeq$))))?true:false):false))?cljs.core.apply.call(null,cljs.core.hash_map,map__99289):map__99289);
var select_spec = map__99289__$1;
var inVector_QMARK_ = cljs.core.get.call(null,map__99289__$1,new cljs.core.Keyword(null,"inVector?","inVector?",1948069375));
var select = cljs.core.get.call(null,map__99289__$1,new cljs.core.Keyword(null,"select","select",1147833503));
var orderBy = cljs.core.get.call(null,map__99289__$1,new cljs.core.Keyword(null,"orderBy","orderBy",-1329797793));
var limit = cljs.core.get.call(null,map__99289__$1,new cljs.core.Keyword(null,"limit","limit",-1355822363));
var offset = cljs.core.get.call(null,map__99289__$1,new cljs.core.Keyword(null,"offset","offset",296498311));
var aggregates = cljs.core.get.call(null,map__99289__$1,new cljs.core.Keyword(null,"aggregates","aggregates",-1684250289));
var prettyPrint = cljs.core.get.call(null,map__99289__$1,new cljs.core.Keyword(null,"prettyPrint","prettyPrint",215590803));
var selectDistinct_QMARK_ = cljs.core.get.call(null,map__99289__$1,new cljs.core.Keyword(null,"selectDistinct?","selectDistinct?",-1672346731));
var groupBy = cljs.core.get.call(null,map__99289__$1,new cljs.core.Keyword(null,"groupBy","groupBy",-1581230667));
var c__86675__auto__ = cljs.core.async.chan.call(null,(1));
cljs.core.async.impl.dispatch.run.call(null,((function (c__86675__auto__,map__99288,map__99288__$1,res,vars,map__99289,map__99289__$1,select_spec,inVector_QMARK_,select,orderBy,limit,offset,aggregates,prettyPrint,selectDistinct_QMARK_,groupBy){
return (function (){
var f__86676__auto__ = (function (){var switch__86624__auto__ = ((function (c__86675__auto__,map__99288,map__99288__$1,res,vars,map__99289,map__99289__$1,select_spec,inVector_QMARK_,select,orderBy,limit,offset,aggregates,prettyPrint,selectDistinct_QMARK_,groupBy){
return (function (state_99395){
var state_val_99396 = (state_99395[(1)]);
if((state_val_99396 === (7))){
var inst_99301 = (state_99395[(2)]);
var state_99395__$1 = state_99395;
if(cljs.core.truth_(inst_99301)){
var statearr_99397_99468 = state_99395__$1;
(statearr_99397_99468[(1)] = (8));

} else {
var statearr_99398_99469 = state_99395__$1;
(statearr_99398_99469[(1)] = (9));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99396 === (20))){
var state_99395__$1 = state_99395;
var statearr_99399_99470 = state_99395__$1;
(statearr_99399_99470[(2)] = (0));

(statearr_99399_99470[(1)] = (22));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99396 === (27))){
var state_99395__$1 = state_99395;
var statearr_99400_99471 = state_99395__$1;
(statearr_99400_99471[(2)] = false);

(statearr_99400_99471[(1)] = (28));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99396 === (1))){
var state_99395__$1 = state_99395;
var statearr_99401_99472 = state_99395__$1;
(statearr_99401_99472[(2)] = null);

(statearr_99401_99472[(1)] = (4));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99396 === (24))){
var inst_99330 = (state_99395[(7)]);
var state_99395__$1 = state_99395;
var statearr_99402_99473 = state_99395__$1;
(statearr_99402_99473[(2)] = inst_99330);

(statearr_99402_99473[(1)] = (25));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99396 === (39))){
var inst_99334 = (state_99395[(8)]);
var state_99395__$1 = state_99395;
var statearr_99403_99474 = state_99395__$1;
(statearr_99403_99474[(2)] = inst_99334);

(statearr_99403_99474[(1)] = (40));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99396 === (46))){
var inst_99381 = (state_99395[(9)]);
var state_99395__$1 = state_99395;
var statearr_99404_99475 = state_99395__$1;
(statearr_99404_99475[(2)] = inst_99381);

(statearr_99404_99475[(1)] = (47));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99396 === (4))){
var _ = cljs.core.async.impl.ioc_helpers.add_exception_frame.call(null,state_99395,(3),Error,null,(2));
var state_99395__$1 = state_99395;
if(cljs.core.truth_(aggregates)){
var statearr_99405_99476 = state_99395__$1;
(statearr_99405_99476[(1)] = (5));

} else {
var statearr_99406_99477 = state_99395__$1;
(statearr_99406_99477[(1)] = (6));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99396 === (15))){
var inst_99316 = (state_99395[(10)]);
var state_99395__$1 = state_99395;
var statearr_99407_99478 = state_99395__$1;
(statearr_99407_99478[(2)] = inst_99316);

(statearr_99407_99478[(1)] = (16));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99396 === (21))){
var state_99395__$1 = state_99395;
var statearr_99408_99479 = state_99395__$1;
(statearr_99408_99479[(2)] = offset);

(statearr_99408_99479[(1)] = (22));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99396 === (31))){
var inst_99352 = (state_99395[(2)]);
var state_99395__$1 = state_99395;
var statearr_99409_99480 = state_99395__$1;
(statearr_99409_99480[(2)] = inst_99352);

(statearr_99409_99480[(1)] = (28));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99396 === (32))){
var inst_99339 = (state_99395[(11)]);
var inst_99357 = cljs.core.apply.call(null,cljs.core.hash_map,inst_99339);
var state_99395__$1 = state_99395;
var statearr_99410_99481 = state_99395__$1;
(statearr_99410_99481[(2)] = inst_99357);

(statearr_99410_99481[(1)] = (34));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99396 === (40))){
var inst_99368 = (state_99395[(2)]);
var state_99395__$1 = state_99395;
var statearr_99411_99482 = state_99395__$1;
(statearr_99411_99482[(2)] = inst_99368);

(statearr_99411_99482[(1)] = (37));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99396 === (33))){
var inst_99339 = (state_99395[(11)]);
var state_99395__$1 = state_99395;
var statearr_99412_99483 = state_99395__$1;
(statearr_99412_99483[(2)] = inst_99339);

(statearr_99412_99483[(1)] = (34));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99396 === (13))){
var inst_99316 = (state_99395[(2)]);
var state_99395__$1 = (function (){var statearr_99413 = state_99395;
(statearr_99413[(10)] = inst_99316);

return statearr_99413;
})();
if(cljs.core.truth_(inVector_QMARK_)){
var statearr_99414_99484 = state_99395__$1;
(statearr_99414_99484[(1)] = (14));

} else {
var statearr_99415_99485 = state_99395__$1;
(statearr_99415_99485[(1)] = (15));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99396 === (22))){
var inst_99334 = (state_99395[(2)]);
var state_99395__$1 = (function (){var statearr_99416 = state_99395;
(statearr_99416[(8)] = inst_99334);

return statearr_99416;
})();
if(cljs.core.truth_(orderBy)){
var statearr_99417_99486 = state_99395__$1;
(statearr_99417_99486[(1)] = (23));

} else {
var statearr_99418_99487 = state_99395__$1;
(statearr_99418_99487[(1)] = (24));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99396 === (36))){
var inst_99363 = (state_99395[(12)]);
var state_99395__$1 = state_99395;
var statearr_99419_99488 = state_99395__$1;
(statearr_99419_99488[(2)] = inst_99363);

(statearr_99419_99488[(1)] = (37));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99396 === (41))){
var inst_99334 = (state_99395[(8)]);
var inst_99362 = (state_99395[(13)]);
var inst_99373 = cljs.core.drop.call(null,inst_99334,inst_99362);
var inst_99374 = cljs.core.take.call(null,limit,inst_99373);
var state_99395__$1 = state_99395;
var statearr_99420_99489 = state_99395__$1;
(statearr_99420_99489[(2)] = inst_99374);

(statearr_99420_99489[(1)] = (43));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99396 === (43))){
var inst_99361 = (state_99395[(14)]);
var inst_99377 = (state_99395[(2)]);
var inst_99378 = fluree.db.query.fql.format_filter_tuples.call(null,db,inst_99377,select_spec,inst_99361,vars,opts);
var state_99395__$1 = state_99395;
return cljs.core.async.impl.ioc_helpers.take_BANG_.call(null,state_99395__$1,(44),inst_99378);
} else {
if((state_val_99396 === (29))){
var state_99395__$1 = state_99395;
var statearr_99421_99490 = state_99395__$1;
(statearr_99421_99490[(2)] = true);

(statearr_99421_99490[(1)] = (31));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99396 === (44))){
var inst_99380 = (state_99395[(2)]);
var inst_99381 = fluree.db.util.async.throw_err.call(null,inst_99380);
var state_99395__$1 = (function (){var statearr_99422 = state_99395;
(statearr_99422[(9)] = inst_99381);

return statearr_99422;
})();
if(cljs.core.truth_(selectDistinct_QMARK_)){
var statearr_99423_99491 = state_99395__$1;
(statearr_99423_99491[(1)] = (45));

} else {
var statearr_99424_99492 = state_99395__$1;
(statearr_99424_99492[(1)] = (46));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99396 === (6))){
var state_99395__$1 = state_99395;
var statearr_99425_99493 = state_99395__$1;
(statearr_99425_99493[(2)] = aggregates);

(statearr_99425_99493[(1)] = (7));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99396 === (28))){
var inst_99355 = (state_99395[(2)]);
var state_99395__$1 = state_99395;
if(cljs.core.truth_(inst_99355)){
var statearr_99426_99494 = state_99395__$1;
(statearr_99426_99494[(1)] = (32));

} else {
var statearr_99427_99495 = state_99395__$1;
(statearr_99427_99495[(1)] = (33));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99396 === (25))){
var inst_99339 = (state_99395[(11)]);
var inst_99339__$1 = (state_99395[(2)]);
var inst_99341 = (inst_99339__$1 == null);
var inst_99342 = cljs.core.not.call(null,inst_99341);
var state_99395__$1 = (function (){var statearr_99428 = state_99395;
(statearr_99428[(11)] = inst_99339__$1);

return statearr_99428;
})();
if(inst_99342){
var statearr_99429_99496 = state_99395__$1;
(statearr_99429_99496[(1)] = (26));

} else {
var statearr_99430_99497 = state_99395__$1;
(statearr_99430_99497[(1)] = (27));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99396 === (34))){
var inst_99363 = (state_99395[(12)]);
var inst_99360 = (state_99395[(2)]);
var inst_99361 = cljs.core.get.call(null,inst_99360,new cljs.core.Keyword(null,"headers","headers",-835030129));
var inst_99362 = cljs.core.get.call(null,inst_99360,new cljs.core.Keyword(null,"tuples","tuples",-676032639));
var inst_99363__$1 = cljs.core.not.call(null,orderBy);
var state_99395__$1 = (function (){var statearr_99431 = state_99395;
(statearr_99431[(12)] = inst_99363__$1);

(statearr_99431[(14)] = inst_99361);

(statearr_99431[(13)] = inst_99362);

return statearr_99431;
})();
if(inst_99363__$1){
var statearr_99432_99498 = state_99395__$1;
(statearr_99432_99498[(1)] = (35));

} else {
var statearr_99433_99499 = state_99395__$1;
(statearr_99433_99499[(1)] = (36));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99396 === (17))){
var inst_99327 = fluree.db.query.analytical.add_aggregate_cols.call(null,res,aggregates);
var state_99395__$1 = state_99395;
var statearr_99434_99500 = state_99395__$1;
(statearr_99434_99500[(2)] = inst_99327);

(statearr_99434_99500[(1)] = (19));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99396 === (3))){
var inst_99292 = (state_99395[(2)]);
var state_99395__$1 = state_99395;
var statearr_99435_99501 = state_99395__$1;
(statearr_99435_99501[(2)] = inst_99292);


cljs.core.async.impl.ioc_helpers.process_exception.call(null,state_99395__$1);

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99396 === (12))){
var inst_99305 = (state_99395[(15)]);
var state_99395__$1 = state_99395;
var statearr_99436_99502 = state_99395__$1;
(statearr_99436_99502[(2)] = inst_99305);

(statearr_99436_99502[(1)] = (13));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99396 === (2))){
var inst_99393 = (state_99395[(2)]);
var state_99395__$1 = state_99395;
return cljs.core.async.impl.ioc_helpers.return_chan.call(null,state_99395__$1,inst_99393);
} else {
if((state_val_99396 === (23))){
var inst_99330 = (state_99395[(7)]);
var inst_99334 = (state_99395[(8)]);
var inst_99336 = fluree.db.query.fql.order_offset_and_limit_results.call(null,orderBy,inst_99330,inst_99334,group_limit);
var state_99395__$1 = state_99395;
var statearr_99437_99503 = state_99395__$1;
(statearr_99437_99503[(2)] = inst_99336);

(statearr_99437_99503[(1)] = (25));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99396 === (47))){
var inst_99389 = (state_99395[(2)]);
var state_99395__$1 = state_99395;
var statearr_99438_99504 = state_99395__$1;
(statearr_99438_99504[(2)] = inst_99389);

(statearr_99438_99504[(1)] = (10));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99396 === (35))){
var state_99395__$1 = state_99395;
if(cljs.core.truth_(limit)){
var statearr_99439_99505 = state_99395__$1;
(statearr_99439_99505[(1)] = (38));

} else {
var statearr_99440_99506 = state_99395__$1;
(statearr_99440_99506[(1)] = (39));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99396 === (19))){
var inst_99330 = (state_99395[(2)]);
var state_99395__$1 = (function (){var statearr_99441 = state_99395;
(statearr_99441[(7)] = inst_99330);

return statearr_99441;
})();
if(cljs.core.truth_(groupBy)){
var statearr_99442_99507 = state_99395__$1;
(statearr_99442_99507[(1)] = (20));

} else {
var statearr_99443_99508 = state_99395__$1;
(statearr_99443_99508[(1)] = (21));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99396 === (11))){
var inst_99305 = (state_99395[(15)]);
var inst_99307 = cljs.core.first.call(null,select);
var inst_99308 = new cljs.core.Keyword(null,"as","as",1148689641).cljs$core$IFn$_invoke$arity$1(inst_99307);
var inst_99309 = cljs.core.str.cljs$core$IFn$_invoke$arity$1(inst_99308);
var inst_99310 = cljs.core.subs.call(null,inst_99309,(1));
var inst_99311 = [inst_99310];
var inst_99312 = [inst_99305];
var inst_99313 = cljs.core.PersistentHashMap.fromArrays(inst_99311,inst_99312);
var state_99395__$1 = state_99395;
var statearr_99444_99509 = state_99395__$1;
(statearr_99444_99509[(2)] = inst_99313);

(statearr_99444_99509[(1)] = (13));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99396 === (9))){
var state_99395__$1 = state_99395;
if(cljs.core.truth_(aggregates)){
var statearr_99445_99510 = state_99395__$1;
(statearr_99445_99510[(1)] = (17));

} else {
var statearr_99446_99511 = state_99395__$1;
(statearr_99446_99511[(1)] = (18));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99396 === (5))){
var inst_99297 = cljs.core.count.call(null,select);
var inst_99298 = cljs.core._EQ_.call(null,(1),inst_99297);
var state_99395__$1 = state_99395;
var statearr_99447_99512 = state_99395__$1;
(statearr_99447_99512[(2)] = inst_99298);

(statearr_99447_99512[(1)] = (7));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99396 === (14))){
var inst_99316 = (state_99395[(10)]);
var inst_99318 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_99319 = [inst_99316];
var inst_99320 = (new cljs.core.PersistentVector(null,1,(5),inst_99318,inst_99319,null));
var state_99395__$1 = state_99395;
var statearr_99448_99513 = state_99395__$1;
(statearr_99448_99513[(2)] = inst_99320);

(statearr_99448_99513[(1)] = (16));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99396 === (45))){
var inst_99381 = (state_99395[(9)]);
var inst_99383 = cljs.core.PersistentVector.EMPTY;
var inst_99384 = cljs.core.PersistentHashSet.EMPTY;
var inst_99385 = cljs.core.into.call(null,inst_99384,inst_99381);
var inst_99386 = cljs.core.into.call(null,inst_99383,inst_99385);
var state_99395__$1 = state_99395;
var statearr_99449_99514 = state_99395__$1;
(statearr_99449_99514[(2)] = inst_99386);

(statearr_99449_99514[(1)] = (47));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99396 === (26))){
var inst_99339 = (state_99395[(11)]);
var inst_99344 = inst_99339.cljs$lang$protocol_mask$partition0$;
var inst_99345 = (inst_99344 & (64));
var inst_99346 = inst_99339.cljs$core$ISeq$;
var inst_99347 = (cljs.core.PROTOCOL_SENTINEL === inst_99346);
var inst_99348 = ((inst_99345) || (inst_99347));
var state_99395__$1 = state_99395;
if(cljs.core.truth_(inst_99348)){
var statearr_99450_99515 = state_99395__$1;
(statearr_99450_99515[(1)] = (29));

} else {
var statearr_99451_99516 = state_99395__$1;
(statearr_99451_99516[(1)] = (30));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99396 === (16))){
var inst_99323 = (state_99395[(2)]);
var state_99395__$1 = state_99395;
var statearr_99452_99517 = state_99395__$1;
(statearr_99452_99517[(2)] = inst_99323);

(statearr_99452_99517[(1)] = (10));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99396 === (38))){
var state_99395__$1 = state_99395;
var statearr_99453_99518 = state_99395__$1;
(statearr_99453_99518[(2)] = limit);

(statearr_99453_99518[(1)] = (40));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99396 === (30))){
var state_99395__$1 = state_99395;
var statearr_99454_99519 = state_99395__$1;
(statearr_99454_99519[(2)] = false);

(statearr_99454_99519[(1)] = (31));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99396 === (10))){
var inst_99391 = (state_99395[(2)]);
var state_99395__$1 = state_99395;
var statearr_99455_99520 = state_99395__$1;
(statearr_99455_99520[(2)] = inst_99391);


cljs.core.async.impl.ioc_helpers.process_exception.call(null,state_99395__$1);

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99396 === (18))){
var state_99395__$1 = state_99395;
var statearr_99456_99521 = state_99395__$1;
(statearr_99456_99521[(2)] = res);

(statearr_99456_99521[(1)] = (19));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99396 === (42))){
var inst_99362 = (state_99395[(13)]);
var state_99395__$1 = state_99395;
var statearr_99457_99522 = state_99395__$1;
(statearr_99457_99522[(2)] = inst_99362);

(statearr_99457_99522[(1)] = (43));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99396 === (37))){
var inst_99371 = (state_99395[(2)]);
var state_99395__$1 = state_99395;
if(cljs.core.truth_(inst_99371)){
var statearr_99458_99523 = state_99395__$1;
(statearr_99458_99523[(1)] = (41));

} else {
var statearr_99459_99524 = state_99395__$1;
(statearr_99459_99524[(1)] = (42));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99396 === (8))){
var inst_99303 = cljs.core.first.call(null,aggregates);
var inst_99304 = fluree.db.query.analytical.calculate_aggregate.call(null,res,inst_99303);
var inst_99305 = cljs.core.second.call(null,inst_99304);
var state_99395__$1 = (function (){var statearr_99460 = state_99395;
(statearr_99460[(15)] = inst_99305);

return statearr_99460;
})();
if(cljs.core.truth_(prettyPrint)){
var statearr_99461_99525 = state_99395__$1;
(statearr_99461_99525[(1)] = (11));

} else {
var statearr_99462_99526 = state_99395__$1;
(statearr_99462_99526[(1)] = (12));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
return null;
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
});})(c__86675__auto__,map__99288,map__99288__$1,res,vars,map__99289,map__99289__$1,select_spec,inVector_QMARK_,select,orderBy,limit,offset,aggregates,prettyPrint,selectDistinct_QMARK_,groupBy))
;
return ((function (switch__86624__auto__,c__86675__auto__,map__99288,map__99288__$1,res,vars,map__99289,map__99289__$1,select_spec,inVector_QMARK_,select,orderBy,limit,offset,aggregates,prettyPrint,selectDistinct_QMARK_,groupBy){
return (function() {
var fluree$db$query$fql$state_machine__86625__auto__ = null;
var fluree$db$query$fql$state_machine__86625__auto____0 = (function (){
var statearr_99463 = [null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null];
(statearr_99463[(0)] = fluree$db$query$fql$state_machine__86625__auto__);

(statearr_99463[(1)] = (1));

return statearr_99463;
});
var fluree$db$query$fql$state_machine__86625__auto____1 = (function (state_99395){
while(true){
var ret_value__86626__auto__ = (function (){try{while(true){
var result__86627__auto__ = switch__86624__auto__.call(null,state_99395);
if(cljs.core.keyword_identical_QMARK_.call(null,result__86627__auto__,new cljs.core.Keyword(null,"recur","recur",-437573268))){
continue;
} else {
return result__86627__auto__;
}
break;
}
}catch (e99464){if((e99464 instanceof Object)){
var ex__86628__auto__ = e99464;
var statearr_99465_99527 = state_99395;
(statearr_99465_99527[(5)] = ex__86628__auto__);


cljs.core.async.impl.ioc_helpers.process_exception.call(null,state_99395);

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
throw e99464;

}
}})();
if(cljs.core.keyword_identical_QMARK_.call(null,ret_value__86626__auto__,new cljs.core.Keyword(null,"recur","recur",-437573268))){
var G__99528 = state_99395;
state_99395 = G__99528;
continue;
} else {
return ret_value__86626__auto__;
}
break;
}
});
fluree$db$query$fql$state_machine__86625__auto__ = function(state_99395){
switch(arguments.length){
case 0:
return fluree$db$query$fql$state_machine__86625__auto____0.call(this);
case 1:
return fluree$db$query$fql$state_machine__86625__auto____1.call(this,state_99395);
}
throw(new Error('Invalid arity: ' + arguments.length));
};
fluree$db$query$fql$state_machine__86625__auto__.cljs$core$IFn$_invoke$arity$0 = fluree$db$query$fql$state_machine__86625__auto____0;
fluree$db$query$fql$state_machine__86625__auto__.cljs$core$IFn$_invoke$arity$1 = fluree$db$query$fql$state_machine__86625__auto____1;
return fluree$db$query$fql$state_machine__86625__auto__;
})()
;})(switch__86624__auto__,c__86675__auto__,map__99288,map__99288__$1,res,vars,map__99289,map__99289__$1,select_spec,inVector_QMARK_,select,orderBy,limit,offset,aggregates,prettyPrint,selectDistinct_QMARK_,groupBy))
})();
var state__86677__auto__ = (function (){var statearr_99466 = f__86676__auto__.call(null);
(statearr_99466[(6)] = c__86675__auto__);

return statearr_99466;
})();
return cljs.core.async.impl.ioc_helpers.run_state_machine_wrapped.call(null,state__86677__auto__);
});})(c__86675__auto__,map__99288,map__99288__$1,res,vars,map__99289,map__99289__$1,select_spec,inVector_QMARK_,select,orderBy,limit,offset,aggregates,prettyPrint,selectDistinct_QMARK_,groupBy))
);

return c__86675__auto__;
});

fluree.db.query.fql.process_ad_hoc_group.cljs$lang$maxFixedArity = 5;

fluree.db.query.fql.ad_hoc_group_by = (function fluree$db$query$fql$ad_hoc_group_by(p__99531,groupBy){
var map__99532 = p__99531;
var map__99532__$1 = (((((!((map__99532 == null))))?(((((map__99532.cljs$lang$protocol_mask$partition0$ & (64))) || ((cljs.core.PROTOCOL_SENTINEL === map__99532.cljs$core$ISeq$))))?true:false):false))?cljs.core.apply.call(null,cljs.core.hash_map,map__99532):map__99532);
var res = map__99532__$1;
var headers = cljs.core.get.call(null,map__99532__$1,new cljs.core.Keyword(null,"headers","headers",-835030129));
var tuples = cljs.core.get.call(null,map__99532__$1,new cljs.core.Keyword(null,"tuples","tuples",-676032639));
var vec__99534 = ((cljs.core.vector_QMARK_.call(null,groupBy))?new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [true,cljs.core.map.call(null,cljs.core.symbol,groupBy)], null):((typeof groupBy === 'string')?new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [false,new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [cljs.core.symbol.call(null,groupBy)], null)], null):(function(){throw cljs.core.ex_info.call(null,["Invalid groupBy clause, must be a string or vector. Provided: ",cljs.core.str.cljs$core$IFn$_invoke$arity$1(groupBy)].join(''),new cljs.core.PersistentArrayMap(null, 2, [new cljs.core.Keyword(null,"status","status",-1997798413),(400),new cljs.core.Keyword(null,"error","error",-978969032),new cljs.core.Keyword("db","invalid-query","db/invalid-query",-1009699917)], null))})()
));
var inVector_QMARK_ = cljs.core.nth.call(null,vec__99534,(0),null);
var groupBy__$1 = cljs.core.nth.call(null,vec__99534,(1),null);
var group_idxs = cljs.core.map.call(null,((function (vec__99534,inVector_QMARK_,groupBy__$1,map__99532,map__99532__$1,res,headers,tuples){
return (function (p1__99529_SHARP_){
return fluree.db.util.core.index_of.call(null,headers,p1__99529_SHARP_);
});})(vec__99534,inVector_QMARK_,groupBy__$1,map__99532,map__99532__$1,res,headers,tuples))
,groupBy__$1);
var _ = (cljs.core.truth_(cljs.core.some.call(null,cljs.core.nil_QMARK_,group_idxs))?(function(){throw cljs.core.ex_info.call(null,["Invalid groupBy clause - are all groupBy vars declared in the where clause. Provided: ",cljs.core.str.cljs$core$IFn$_invoke$arity$1(groupBy__$1)].join(''),new cljs.core.PersistentArrayMap(null, 2, [new cljs.core.Keyword(null,"status","status",-1997798413),(400),new cljs.core.Keyword(null,"error","error",-978969032),new cljs.core.Keyword("db","invalid-query","db/invalid-query",-1009699917)], null))})():null);
return cljs.core.reduce.call(null,((function (vec__99534,inVector_QMARK_,groupBy__$1,group_idxs,_,map__99532,map__99532__$1,res,headers,tuples){
return (function (res__$1,tuple){
var k = cljs.core.map.call(null,((function (vec__99534,inVector_QMARK_,groupBy__$1,group_idxs,_,map__99532,map__99532__$1,res,headers,tuples){
return (function (p1__99530_SHARP_){
return cljs.core.nth.call(null,tuple,p1__99530_SHARP_);
});})(vec__99534,inVector_QMARK_,groupBy__$1,group_idxs,_,map__99532,map__99532__$1,res,headers,tuples))
,group_idxs);
var k_SINGLEQUOTE_ = (cljs.core.truth_(inVector_QMARK_)?cljs.core.into.call(null,cljs.core.PersistentVector.EMPTY,k):cljs.core.first.call(null,k));
var v = tuple;
return cljs.core.assoc.call(null,res__$1,k_SINGLEQUOTE_,cljs.core.conj.call(null,cljs.core.get.call(null,res__$1,k_SINGLEQUOTE_,cljs.core.PersistentVector.EMPTY),v));
});})(vec__99534,inVector_QMARK_,groupBy__$1,group_idxs,_,map__99532,map__99532__$1,res,headers,tuples))
,cljs.core.PersistentArrayMap.EMPTY,tuples);
});
fluree.db.query.fql.process_ad_hoc_res = (function fluree$db$query$fql$process_ad_hoc_res(db,p__99537,p__99538,opts){
var map__99539 = p__99537;
var map__99539__$1 = (((((!((map__99539 == null))))?(((((map__99539.cljs$lang$protocol_mask$partition0$ & (64))) || ((cljs.core.PROTOCOL_SENTINEL === map__99539.cljs$core$ISeq$))))?true:false):false))?cljs.core.apply.call(null,cljs.core.hash_map,map__99539):map__99539);
var res = map__99539__$1;
var headers = cljs.core.get.call(null,map__99539__$1,new cljs.core.Keyword(null,"headers","headers",-835030129));
var vars = cljs.core.get.call(null,map__99539__$1,new cljs.core.Keyword(null,"vars","vars",-2046957217));
var map__99540 = p__99538;
var map__99540__$1 = (((((!((map__99540 == null))))?(((((map__99540.cljs$lang$protocol_mask$partition0$ & (64))) || ((cljs.core.PROTOCOL_SENTINEL === map__99540.cljs$core$ISeq$))))?true:false):false))?cljs.core.apply.call(null,cljs.core.hash_map,map__99540):map__99540);
var select_spec = map__99540__$1;
var groupBy = cljs.core.get.call(null,map__99540__$1,new cljs.core.Keyword(null,"groupBy","groupBy",-1581230667));
var orderBy = cljs.core.get.call(null,map__99540__$1,new cljs.core.Keyword(null,"orderBy","orderBy",-1329797793));
var limit = cljs.core.get.call(null,map__99540__$1,new cljs.core.Keyword(null,"limit","limit",-1355822363));
var selectOne_QMARK_ = cljs.core.get.call(null,map__99540__$1,new cljs.core.Keyword(null,"selectOne?","selectOne?",-1041343472));
var selectDistinct_QMARK_ = cljs.core.get.call(null,map__99540__$1,new cljs.core.Keyword(null,"selectDistinct?","selectDistinct?",-1672346731));
var inVector_QMARK_ = cljs.core.get.call(null,map__99540__$1,new cljs.core.Keyword(null,"inVector?","inVector?",1948069375));
var offset = cljs.core.get.call(null,map__99540__$1,new cljs.core.Keyword(null,"offset","offset",296498311));
var c__86675__auto__ = cljs.core.async.chan.call(null,(1));
cljs.core.async.impl.dispatch.run.call(null,((function (c__86675__auto__,map__99539,map__99539__$1,res,headers,vars,map__99540,map__99540__$1,select_spec,groupBy,orderBy,limit,selectOne_QMARK_,selectDistinct_QMARK_,inVector_QMARK_,offset){
return (function (){
var f__86676__auto__ = (function (){var switch__86624__auto__ = ((function (c__86675__auto__,map__99539,map__99539__$1,res,headers,vars,map__99540,map__99540__$1,select_spec,groupBy,orderBy,limit,selectOne_QMARK_,selectDistinct_QMARK_,inVector_QMARK_,offset){
return (function (state_99759){
var state_val_99760 = (state_99759[(1)]);
if((state_val_99760 === (65))){
var inst_99726 = (state_99759[(7)]);
var inst_99725 = (state_99759[(2)]);
var inst_99726__$1 = fluree.db.util.async.throw_err.call(null,inst_99725);
var inst_99727 = cljs.core.coll_QMARK_.call(null,inst_99726__$1);
var inst_99728 = (!(inst_99727));
var state_99759__$1 = (function (){var statearr_99761 = state_99759;
(statearr_99761[(7)] = inst_99726__$1);

return statearr_99761;
})();
if(inst_99728){
var statearr_99762_99876 = state_99759__$1;
(statearr_99762_99876[(1)] = (66));

} else {
var statearr_99763_99877 = state_99759__$1;
(statearr_99763_99877[(1)] = (67));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99760 === (70))){
var inst_99726 = (state_99759[(7)]);
var state_99759__$1 = state_99759;
var statearr_99764_99878 = state_99759__$1;
(statearr_99764_99878[(2)] = inst_99726);

(statearr_99764_99878[(1)] = (71));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99760 === (62))){
var state_99759__$1 = state_99759;
var statearr_99765_99879 = state_99759__$1;
(statearr_99765_99879[(2)] = (1));

(statearr_99765_99879[(1)] = (64));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99760 === (74))){
var inst_99751 = (state_99759[(2)]);
var state_99759__$1 = state_99759;
var statearr_99766_99880 = state_99759__$1;
(statearr_99766_99880[(2)] = inst_99751);

(statearr_99766_99880[(1)] = (68));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99760 === (7))){
var inst_99755 = (state_99759[(2)]);
var state_99759__$1 = state_99759;
var statearr_99767_99881 = state_99759__$1;
(statearr_99767_99881[(2)] = inst_99755);


cljs.core.async.impl.ioc_helpers.process_exception.call(null,state_99759__$1);

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99760 === (59))){
var inst_99595 = (state_99759[(8)]);
var inst_99709 = (state_99759[(9)]);
var inst_99711 = cljs.core.sorted_map_by.call(null,inst_99595);
var inst_99712 = cljs.core.into.call(null,inst_99711,inst_99709);
var state_99759__$1 = state_99759;
var statearr_99768_99882 = state_99759__$1;
(statearr_99768_99882[(2)] = inst_99712);

(statearr_99768_99882[(1)] = (61));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99760 === (20))){
var inst_99568 = cljs.core.set.call(null,groupBy);
var inst_99569 = cljs.core.second.call(null,orderBy);
var inst_99570 = inst_99568.call(null,inst_99569);
var state_99759__$1 = state_99759;
var statearr_99769_99883 = state_99759__$1;
(statearr_99769_99883[(2)] = inst_99570);

(statearr_99769_99883[(1)] = (22));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99760 === (72))){
var inst_99726 = (state_99759[(7)]);
var inst_99739 = cljs.core.first.call(null,inst_99726);
var state_99759__$1 = state_99759;
var statearr_99770_99884 = state_99759__$1;
(statearr_99770_99884[(2)] = inst_99739);

(statearr_99770_99884[(1)] = (74));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99760 === (58))){
var inst_99639 = (state_99759[(10)]);
var inst_99648 = (state_99759[(11)]);
var inst_99691 = (state_99759[(2)]);
var inst_99692 = fluree.db.util.async.throw_err.call(null,inst_99691);
var inst_99693 = cljs.core.assoc.call(null,inst_99639,inst_99648,inst_99692);
var state_99759__$1 = state_99759;
var statearr_99771_99885 = state_99759__$1;
(statearr_99771_99885[(2)] = inst_99693);

(statearr_99771_99885[(1)] = (57));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99760 === (60))){
var inst_99709 = (state_99759[(9)]);
var state_99759__$1 = state_99759;
var statearr_99772_99886 = state_99759__$1;
(statearr_99772_99886[(2)] = inst_99709);

(statearr_99772_99886[(1)] = (61));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99760 === (27))){
var inst_99576 = (state_99759[(12)]);
var inst_99548 = (state_99759[(13)]);
var inst_99577 = (state_99759[(14)]);
var inst_99582 = (function (){var group_map = inst_99548;
var orderByIdx = inst_99576;
var orderDirection = inst_99577;
return ((function (group_map,orderByIdx,orderDirection,inst_99576,inst_99548,inst_99577,state_val_99760,c__86675__auto__,map__99539,map__99539__$1,res,headers,vars,map__99540,map__99540__$1,select_spec,groupBy,orderBy,limit,selectOne_QMARK_,selectDistinct_QMARK_,inVector_QMARK_,offset){
return (function (x,y){
return fluree.db.query.fql.compare_fn.call(null,cljs.core.nth.call(null,x,orderByIdx),cljs.core.nth.call(null,y,orderByIdx));
});
;})(group_map,orderByIdx,orderDirection,inst_99576,inst_99548,inst_99577,state_val_99760,c__86675__auto__,map__99539,map__99539__$1,res,headers,vars,map__99540,map__99540__$1,select_spec,groupBy,orderBy,limit,selectOne_QMARK_,selectDistinct_QMARK_,inVector_QMARK_,offset))
})();
var state_99759__$1 = state_99759;
var statearr_99773_99887 = state_99759__$1;
(statearr_99773_99887[(2)] = inst_99582);

(statearr_99773_99887[(1)] = (28));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99760 === (1))){
var state_99759__$1 = state_99759;
var statearr_99774_99888 = state_99759__$1;
(statearr_99774_99888[(2)] = null);

(statearr_99774_99888[(1)] = (4));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99760 === (69))){
var inst_99726 = (state_99759[(7)]);
var inst_99731 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_99732 = [inst_99726];
var inst_99733 = (new cljs.core.PersistentVector(null,1,(5),inst_99731,inst_99732,null));
var state_99759__$1 = state_99759;
var statearr_99775_99889 = state_99759__$1;
(statearr_99775_99889[(2)] = inst_99733);

(statearr_99775_99889[(1)] = (71));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99760 === (24))){
var state_99759__$1 = state_99759;
var statearr_99776_99890 = state_99759__$1;
(statearr_99776_99890[(1)] = (29));



return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99760 === (55))){
var inst_99663 = (state_99759[(15)]);
var inst_99651 = (state_99759[(16)]);
var inst_99666 = (state_99759[(17)]);
var inst_99686 = cljs.core.count.call(null,inst_99651);
var inst_99687 = (inst_99663 - limit);
var inst_99688 = (inst_99686 - inst_99687);
var inst_99689 = fluree.db.query.fql.process_ad_hoc_group.call(null,db,inst_99666,select_spec,inst_99688,opts);
var state_99759__$1 = state_99759;
return cljs.core.async.impl.ioc_helpers.take_BANG_.call(null,state_99759__$1,(58),inst_99689);
} else {
if((state_val_99760 === (39))){
var inst_99638 = (state_99759[(18)]);
var inst_99656 = (inst_99638 > (0));
var state_99759__$1 = state_99759;
if(cljs.core.truth_(inst_99656)){
var statearr_99778_99891 = state_99759__$1;
(statearr_99778_99891[(1)] = (41));

} else {
var statearr_99779_99892 = state_99759__$1;
(statearr_99779_99892[(1)] = (42));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99760 === (46))){
var inst_99703 = (state_99759[(2)]);
var state_99759__$1 = state_99759;
var statearr_99780_99893 = state_99759__$1;
(statearr_99780_99893[(2)] = inst_99703);

(statearr_99780_99893[(1)] = (43));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99760 === (4))){
var _ = cljs.core.async.impl.ioc_helpers.add_exception_frame.call(null,state_99759,(3),Error,null,(2));
var state_99759__$1 = state_99759;
if(cljs.core.truth_(groupBy)){
var statearr_99781_99894 = state_99759__$1;
(statearr_99781_99894[(1)] = (5));

} else {
var statearr_99782_99895 = state_99759__$1;
(statearr_99782_99895[(1)] = (6));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99760 === (77))){
var inst_99749 = (state_99759[(2)]);
var state_99759__$1 = state_99759;
var statearr_99783_99896 = state_99759__$1;
(statearr_99783_99896[(2)] = inst_99749);

(statearr_99783_99896[(1)] = (74));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99760 === (54))){
var inst_99639 = (state_99759[(10)]);
var inst_99648 = (state_99759[(11)]);
var inst_99680 = (state_99759[(2)]);
var inst_99681 = fluree.db.util.async.throw_err.call(null,inst_99680);
var inst_99682 = cljs.core.assoc.call(null,inst_99639,inst_99648,inst_99681);
var state_99759__$1 = state_99759;
var statearr_99784_99897 = state_99759__$1;
(statearr_99784_99897[(2)] = inst_99682);

(statearr_99784_99897[(1)] = (53));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99760 === (15))){
var state_99759__$1 = state_99759;
var statearr_99786_99898 = state_99759__$1;
(statearr_99786_99898[(2)] = fluree.db.query.fql.compare_fn);

(statearr_99786_99898[(1)] = (16));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99760 === (48))){
var inst_99663 = (state_99759[(15)]);
var inst_99676 = cljs.core._EQ_.call(null,limit,inst_99663);
var state_99759__$1 = state_99759;
if(inst_99676){
var statearr_99787_99899 = state_99759__$1;
(statearr_99787_99899[(1)] = (51));

} else {
var statearr_99788_99900 = state_99759__$1;
(statearr_99788_99900[(1)] = (52));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99760 === (50))){
var inst_99639 = (state_99759[(10)]);
var inst_99638 = (state_99759[(18)]);
var inst_99649 = (state_99759[(19)]);
var inst_99663 = (state_99759[(15)]);
var inst_99652 = (state_99759[(20)]);
var inst_99648 = (state_99759[(11)]);
var inst_99671 = (state_99759[(2)]);
var inst_99672 = fluree.db.util.async.throw_err.call(null,inst_99671);
var inst_99673 = cljs.core.assoc.call(null,inst_99639,inst_99648,inst_99672);
var tmp99785 = inst_99638;
var inst_99635 = inst_99649;
var inst_99636 = inst_99652;
var inst_99637 = inst_99663;
var inst_99638__$1 = tmp99785;
var inst_99639__$1 = inst_99673;
var state_99759__$1 = (function (){var statearr_99789 = state_99759;
(statearr_99789[(21)] = inst_99635);

(statearr_99789[(10)] = inst_99639__$1);

(statearr_99789[(18)] = inst_99638__$1);

(statearr_99789[(22)] = inst_99636);

(statearr_99789[(23)] = inst_99637);

return statearr_99789;
})();
var statearr_99790_99901 = state_99759__$1;
(statearr_99790_99901[(2)] = null);

(statearr_99790_99901[(1)] = (36));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99760 === (75))){
var inst_99726 = (state_99759[(7)]);
var inst_99742 = cljs.core.distinct.call(null,inst_99726);
var state_99759__$1 = state_99759;
var statearr_99791_99902 = state_99759__$1;
(statearr_99791_99902[(2)] = inst_99742);

(statearr_99791_99902[(1)] = (77));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99760 === (21))){
var state_99759__$1 = state_99759;
var statearr_99792_99903 = state_99759__$1;
(statearr_99792_99903[(2)] = orderBy);

(statearr_99792_99903[(1)] = (22));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99760 === (31))){
var inst_99589 = (state_99759[(2)]);
var state_99759__$1 = state_99759;
var statearr_99793_99904 = state_99759__$1;
(statearr_99793_99904[(2)] = inst_99589);

(statearr_99793_99904[(1)] = (25));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99760 === (32))){
var inst_99548 = (state_99759[(13)]);
var inst_99597 = cljs.core.keys.call(null,inst_99548);
var inst_99598 = cljs.core.first.call(null,inst_99597);
var inst_99599 = [new cljs.core.Keyword(null,"headers","headers",-835030129),new cljs.core.Keyword(null,"vars","vars",-2046957217),new cljs.core.Keyword(null,"tuples","tuples",-676032639)];
var inst_99600 = cljs.core.vals.call(null,inst_99548);
var inst_99601 = cljs.core.first.call(null,inst_99600);
var inst_99602 = [headers,vars,inst_99601];
var inst_99603 = cljs.core.PersistentHashMap.fromArrays(inst_99599,inst_99602);
var inst_99604 = fluree.db.query.fql.process_ad_hoc_group.call(null,db,inst_99603,select_spec,limit,opts);
var state_99759__$1 = (function (){var statearr_99794 = state_99759;
(statearr_99794[(24)] = inst_99598);

return statearr_99794;
})();
return cljs.core.async.impl.ioc_helpers.take_BANG_.call(null,state_99759__$1,(35),inst_99604);
} else {
if((state_val_99760 === (40))){
var inst_99707 = (state_99759[(2)]);
var state_99759__$1 = state_99759;
var statearr_99795_99905 = state_99759__$1;
(statearr_99795_99905[(2)] = inst_99707);

(statearr_99795_99905[(1)] = (37));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99760 === (56))){
var state_99759__$1 = state_99759;
var statearr_99796_99906 = state_99759__$1;
(statearr_99796_99906[(2)] = null);

(statearr_99796_99906[(1)] = (57));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99760 === (33))){
var inst_99548 = (state_99759[(13)]);
var inst_99626 = cljs.core.keys.call(null,inst_99548);
var inst_99627 = cljs.core.seq.call(null,inst_99626);
var inst_99628 = cljs.core.first.call(null,inst_99627);
var inst_99629 = cljs.core.next.call(null,inst_99627);
var inst_99630 = cljs.core.vals.call(null,inst_99548);
var inst_99631 = cljs.core.seq.call(null,inst_99630);
var inst_99632 = cljs.core.first.call(null,inst_99631);
var inst_99633 = cljs.core.next.call(null,inst_99631);
var inst_99634 = cljs.core.PersistentHashMap.EMPTY;
var inst_99635 = inst_99626;
var inst_99636 = inst_99630;
var inst_99637 = (0);
var inst_99638 = offset;
var inst_99639 = inst_99634;
var state_99759__$1 = (function (){var statearr_99797 = state_99759;
(statearr_99797[(25)] = inst_99633);

(statearr_99797[(21)] = inst_99635);

(statearr_99797[(10)] = inst_99639);

(statearr_99797[(18)] = inst_99638);

(statearr_99797[(26)] = inst_99629);

(statearr_99797[(27)] = inst_99628);

(statearr_99797[(28)] = inst_99632);

(statearr_99797[(22)] = inst_99636);

(statearr_99797[(23)] = inst_99637);

return statearr_99797;
})();
var statearr_99798_99907 = state_99759__$1;
(statearr_99798_99907[(2)] = null);

(statearr_99798_99907[(1)] = (36));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99760 === (13))){
var inst_99595 = (state_99759[(2)]);
var state_99759__$1 = (function (){var statearr_99799 = state_99759;
(statearr_99799[(8)] = inst_99595);

return statearr_99799;
})();
if(cljs.core.truth_(selectOne_QMARK_)){
var statearr_99800_99908 = state_99759__$1;
(statearr_99800_99908[(1)] = (32));

} else {
var statearr_99801_99909 = state_99759__$1;
(statearr_99801_99909[(1)] = (33));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99760 === (22))){
var inst_99573 = (state_99759[(2)]);
var state_99759__$1 = state_99759;
if(cljs.core.truth_(inst_99573)){
var statearr_99804_99910 = state_99759__$1;
(statearr_99804_99910[(1)] = (23));

} else {
var statearr_99805_99911 = state_99759__$1;
(statearr_99805_99911[(1)] = (24));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99760 === (36))){
var inst_99635 = (state_99759[(21)]);
var inst_99651 = (state_99759[(16)]);
var inst_99636 = (state_99759[(22)]);
var inst_99647 = cljs.core.seq.call(null,inst_99635);
var inst_99648 = cljs.core.first.call(null,inst_99647);
var inst_99649 = cljs.core.next.call(null,inst_99647);
var inst_99650 = cljs.core.seq.call(null,inst_99636);
var inst_99651__$1 = cljs.core.first.call(null,inst_99650);
var inst_99652 = cljs.core.next.call(null,inst_99650);
var inst_99653 = (inst_99651__$1 == null);
var state_99759__$1 = (function (){var statearr_99806 = state_99759;
(statearr_99806[(19)] = inst_99649);

(statearr_99806[(16)] = inst_99651__$1);

(statearr_99806[(20)] = inst_99652);

(statearr_99806[(11)] = inst_99648);

return statearr_99806;
})();
if(cljs.core.truth_(inst_99653)){
var statearr_99807_99912 = state_99759__$1;
(statearr_99807_99912[(1)] = (38));

} else {
var statearr_99808_99913 = state_99759__$1;
(statearr_99808_99913[(1)] = (39));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99760 === (41))){
var inst_99639 = (state_99759[(10)]);
var inst_99638 = (state_99759[(18)]);
var inst_99649 = (state_99759[(19)]);
var inst_99652 = (state_99759[(20)]);
var inst_99637 = (state_99759[(23)]);
var inst_99658 = (inst_99638 - (1));
var tmp99802 = inst_99639;
var tmp99803 = inst_99637;
var inst_99635 = inst_99649;
var inst_99636 = inst_99652;
var inst_99637__$1 = tmp99803;
var inst_99638__$1 = inst_99658;
var inst_99639__$1 = tmp99802;
var state_99759__$1 = (function (){var statearr_99809 = state_99759;
(statearr_99809[(21)] = inst_99635);

(statearr_99809[(10)] = inst_99639__$1);

(statearr_99809[(18)] = inst_99638__$1);

(statearr_99809[(22)] = inst_99636);

(statearr_99809[(23)] = inst_99637__$1);

return statearr_99809;
})();
var statearr_99810_99914 = state_99759__$1;
(statearr_99810_99914[(2)] = null);

(statearr_99810_99914[(1)] = (36));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99760 === (43))){
var inst_99705 = (state_99759[(2)]);
var state_99759__$1 = state_99759;
var statearr_99811_99915 = state_99759__$1;
(statearr_99811_99915[(2)] = inst_99705);

(statearr_99811_99915[(1)] = (40));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99760 === (61))){
var inst_99715 = (state_99759[(2)]);
var state_99759__$1 = state_99759;
var statearr_99812_99916 = state_99759__$1;
(statearr_99812_99916[(2)] = inst_99715);

(statearr_99812_99916[(1)] = (34));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99760 === (29))){
var state_99759__$1 = state_99759;
var statearr_99813_99917 = state_99759__$1;
(statearr_99813_99917[(2)] = null);

(statearr_99813_99917[(1)] = (31));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99760 === (44))){
var inst_99663 = (state_99759[(15)]);
var inst_99651 = (state_99759[(16)]);
var inst_99637 = (state_99759[(23)]);
var inst_99662 = cljs.core.count.call(null,inst_99651);
var inst_99663__$1 = (inst_99637 + inst_99662);
var inst_99664 = [new cljs.core.Keyword(null,"headers","headers",-835030129),new cljs.core.Keyword(null,"vars","vars",-2046957217),new cljs.core.Keyword(null,"tuples","tuples",-676032639)];
var inst_99665 = [headers,vars,inst_99651];
var inst_99666 = cljs.core.PersistentHashMap.fromArrays(inst_99664,inst_99665);
var inst_99667 = (limit > inst_99663__$1);
var state_99759__$1 = (function (){var statearr_99814 = state_99759;
(statearr_99814[(15)] = inst_99663__$1);

(statearr_99814[(17)] = inst_99666);

return statearr_99814;
})();
if(cljs.core.truth_(inst_99667)){
var statearr_99815_99918 = state_99759__$1;
(statearr_99815_99918[(1)] = (47));

} else {
var statearr_99816_99919 = state_99759__$1;
(statearr_99816_99919[(1)] = (48));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99760 === (6))){
var state_99759__$1 = state_99759;
if(cljs.core.truth_(selectOne_QMARK_)){
var statearr_99817_99920 = state_99759__$1;
(statearr_99817_99920[(1)] = (62));

} else {
var statearr_99818_99921 = state_99759__$1;
(statearr_99818_99921[(1)] = (63));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99760 === (28))){
var inst_99584 = (state_99759[(2)]);
var state_99759__$1 = state_99759;
var statearr_99819_99922 = state_99759__$1;
(statearr_99819_99922[(2)] = inst_99584);

(statearr_99819_99922[(1)] = (25));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99760 === (64))){
var inst_99722 = (state_99759[(2)]);
var inst_99723 = fluree.db.query.fql.process_ad_hoc_group.call(null,db,res,select_spec,inst_99722,opts);
var state_99759__$1 = state_99759;
return cljs.core.async.impl.ioc_helpers.take_BANG_.call(null,state_99759__$1,(65),inst_99723);
} else {
if((state_val_99760 === (51))){
var inst_99666 = (state_99759[(17)]);
var inst_99678 = fluree.db.query.fql.process_ad_hoc_group.call(null,db,inst_99666,select_spec,opts);
var state_99759__$1 = state_99759;
return cljs.core.async.impl.ioc_helpers.take_BANG_.call(null,state_99759__$1,(54),inst_99678);
} else {
if((state_val_99760 === (25))){
var inst_99591 = (state_99759[(2)]);
var state_99759__$1 = state_99759;
var statearr_99820_99923 = state_99759__$1;
(statearr_99820_99923[(2)] = inst_99591);

(statearr_99820_99923[(1)] = (19));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99760 === (34))){
var inst_99717 = (state_99759[(2)]);
var state_99759__$1 = state_99759;
var statearr_99821_99924 = state_99759__$1;
(statearr_99821_99924[(2)] = inst_99717);

(statearr_99821_99924[(1)] = (7));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99760 === (17))){
var state_99759__$1 = state_99759;
var statearr_99822_99925 = state_99759__$1;
(statearr_99822_99925[(2)] = null);

(statearr_99822_99925[(1)] = (19));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99760 === (3))){
var inst_99543 = (state_99759[(2)]);
var state_99759__$1 = state_99759;
var statearr_99823_99926 = state_99759__$1;
(statearr_99823_99926[(2)] = inst_99543);


cljs.core.async.impl.ioc_helpers.process_exception.call(null,state_99759__$1);

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99760 === (12))){
var inst_99564 = cljs.core.not.call(null,orderBy);
var state_99759__$1 = state_99759;
if(inst_99564){
var statearr_99824_99927 = state_99759__$1;
(statearr_99824_99927[(1)] = (17));

} else {
var statearr_99825_99928 = state_99759__$1;
(statearr_99825_99928[(1)] = (18));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99760 === (2))){
var inst_99757 = (state_99759[(2)]);
var state_99759__$1 = state_99759;
return cljs.core.async.impl.ioc_helpers.return_chan.call(null,state_99759__$1,inst_99757);
} else {
if((state_val_99760 === (66))){
var state_99759__$1 = state_99759;
if(cljs.core.truth_(inVector_QMARK_)){
var statearr_99826_99929 = state_99759__$1;
(statearr_99826_99929[(1)] = (69));

} else {
var statearr_99827_99930 = state_99759__$1;
(statearr_99827_99930[(1)] = (70));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99760 === (23))){
var inst_99577 = (state_99759[(14)]);
var inst_99575 = cljs.core.second.call(null,orderBy);
var inst_99576 = fluree.db.util.core.index_of.call(null,groupBy,inst_99575);
var inst_99577__$1 = cljs.core.first.call(null,orderBy);
var inst_99578 = cljs.core._EQ_.call(null,"DESC",inst_99577__$1);
var state_99759__$1 = (function (){var statearr_99828 = state_99759;
(statearr_99828[(12)] = inst_99576);

(statearr_99828[(14)] = inst_99577__$1);

return statearr_99828;
})();
if(inst_99578){
var statearr_99829_99931 = state_99759__$1;
(statearr_99829_99931[(1)] = (26));

} else {
var statearr_99830_99932 = state_99759__$1;
(statearr_99830_99932[(1)] = (27));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99760 === (47))){
var inst_99666 = (state_99759[(17)]);
var inst_99669 = fluree.db.query.fql.process_ad_hoc_group.call(null,db,inst_99666,select_spec,opts);
var state_99759__$1 = state_99759;
return cljs.core.async.impl.ioc_helpers.take_BANG_.call(null,state_99759__$1,(50),inst_99669);
} else {
if((state_val_99760 === (35))){
var inst_99598 = (state_99759[(24)]);
var inst_99606 = (state_99759[(2)]);
var inst_99607 = fluree.db.util.async.throw_err.call(null,inst_99606);
var inst_99608 = [inst_99598];
var inst_99609 = [inst_99607];
var inst_99610 = cljs.core.PersistentHashMap.fromArrays(inst_99608,inst_99609);
var state_99759__$1 = state_99759;
var statearr_99831_99933 = state_99759__$1;
(statearr_99831_99933[(2)] = inst_99610);

(statearr_99831_99933[(1)] = (34));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99760 === (76))){
var state_99759__$1 = state_99759;
var statearr_99832_99934 = state_99759__$1;
(statearr_99832_99934[(1)] = (78));



return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99760 === (19))){
var inst_99593 = (state_99759[(2)]);
var state_99759__$1 = state_99759;
var statearr_99834_99935 = state_99759__$1;
(statearr_99834_99935[(2)] = inst_99593);

(statearr_99834_99935[(1)] = (13));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99760 === (57))){
var inst_99696 = (state_99759[(2)]);
var state_99759__$1 = state_99759;
var statearr_99835_99936 = state_99759__$1;
(statearr_99835_99936[(2)] = inst_99696);

(statearr_99835_99936[(1)] = (53));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99760 === (68))){
var inst_99753 = (state_99759[(2)]);
var state_99759__$1 = state_99759;
var statearr_99836_99937 = state_99759__$1;
(statearr_99836_99937[(2)] = inst_99753);

(statearr_99836_99937[(1)] = (7));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99760 === (11))){
var inst_99556 = cljs.core.first.call(null,orderBy);
var inst_99557 = cljs.core._EQ_.call(null,inst_99556,"DESC");
var state_99759__$1 = state_99759;
if(inst_99557){
var statearr_99837_99938 = state_99759__$1;
(statearr_99837_99938[(1)] = (14));

} else {
var statearr_99838_99939 = state_99759__$1;
(statearr_99838_99939[(1)] = (15));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99760 === (9))){
var state_99759__$1 = state_99759;
var statearr_99839_99940 = state_99759__$1;
(statearr_99839_99940[(2)] = orderBy);

(statearr_99839_99940[(1)] = (10));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99760 === (5))){
var inst_99548 = fluree.db.query.fql.ad_hoc_group_by.call(null,res,groupBy);
var state_99759__$1 = (function (){var statearr_99840 = state_99759;
(statearr_99840[(13)] = inst_99548);

return statearr_99840;
})();
if(cljs.core.truth_(orderBy)){
var statearr_99841_99941 = state_99759__$1;
(statearr_99841_99941[(1)] = (8));

} else {
var statearr_99842_99942 = state_99759__$1;
(statearr_99842_99942[(1)] = (9));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99760 === (14))){
var inst_99548 = (state_99759[(13)]);
var inst_99559 = (function (){var group_map = inst_99548;
return ((function (group_map,inst_99548,state_val_99760,c__86675__auto__,map__99539,map__99539__$1,res,headers,vars,map__99540,map__99540__$1,select_spec,groupBy,orderBy,limit,selectOne_QMARK_,selectDistinct_QMARK_,inVector_QMARK_,offset){
return (function (x,y){
return ((-1) * fluree.db.query.fql.compare_fn.call(null,x,y));
});
;})(group_map,inst_99548,state_val_99760,c__86675__auto__,map__99539,map__99539__$1,res,headers,vars,map__99540,map__99540__$1,select_spec,groupBy,orderBy,limit,selectOne_QMARK_,selectDistinct_QMARK_,inVector_QMARK_,offset))
})();
var state_99759__$1 = state_99759;
var statearr_99843_99943 = state_99759__$1;
(statearr_99843_99943[(2)] = inst_99559);

(statearr_99843_99943[(1)] = (16));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99760 === (45))){
var state_99759__$1 = state_99759;
var statearr_99844_99944 = state_99759__$1;
(statearr_99844_99944[(2)] = null);

(statearr_99844_99944[(1)] = (46));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99760 === (53))){
var inst_99698 = (state_99759[(2)]);
var state_99759__$1 = state_99759;
var statearr_99845_99945 = state_99759__$1;
(statearr_99845_99945[(2)] = inst_99698);

(statearr_99845_99945[(1)] = (49));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99760 === (78))){
var inst_99726 = (state_99759[(7)]);
var state_99759__$1 = state_99759;
var statearr_99846_99946 = state_99759__$1;
(statearr_99846_99946[(2)] = inst_99726);

(statearr_99846_99946[(1)] = (80));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99760 === (26))){
var inst_99576 = (state_99759[(12)]);
var inst_99548 = (state_99759[(13)]);
var inst_99577 = (state_99759[(14)]);
var inst_99580 = (function (){var group_map = inst_99548;
var orderByIdx = inst_99576;
var orderDirection = inst_99577;
return ((function (group_map,orderByIdx,orderDirection,inst_99576,inst_99548,inst_99577,state_val_99760,c__86675__auto__,map__99539,map__99539__$1,res,headers,vars,map__99540,map__99540__$1,select_spec,groupBy,orderBy,limit,selectOne_QMARK_,selectDistinct_QMARK_,inVector_QMARK_,offset){
return (function (x,y){
return ((-1) * fluree.db.query.fql.compare_fn.call(null,cljs.core.nth.call(null,x,orderByIdx),cljs.core.nth.call(null,y,orderByIdx)));
});
;})(group_map,orderByIdx,orderDirection,inst_99576,inst_99548,inst_99577,state_val_99760,c__86675__auto__,map__99539,map__99539__$1,res,headers,vars,map__99540,map__99540__$1,select_spec,groupBy,orderBy,limit,selectOne_QMARK_,selectDistinct_QMARK_,inVector_QMARK_,offset))
})();
var state_99759__$1 = state_99759;
var statearr_99847_99947 = state_99759__$1;
(statearr_99847_99947[(2)] = inst_99580);

(statearr_99847_99947[(1)] = (28));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99760 === (16))){
var inst_99562 = (state_99759[(2)]);
var state_99759__$1 = state_99759;
var statearr_99848_99948 = state_99759__$1;
(statearr_99848_99948[(2)] = inst_99562);

(statearr_99848_99948[(1)] = (13));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99760 === (79))){
var state_99759__$1 = state_99759;
var statearr_99849_99949 = state_99759__$1;
(statearr_99849_99949[(2)] = null);

(statearr_99849_99949[(1)] = (80));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99760 === (38))){
var inst_99639 = (state_99759[(10)]);
var state_99759__$1 = state_99759;
var statearr_99850_99950 = state_99759__$1;
(statearr_99850_99950[(2)] = inst_99639);

(statearr_99850_99950[(1)] = (40));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99760 === (30))){
var state_99759__$1 = state_99759;
var statearr_99851_99951 = state_99759__$1;
(statearr_99851_99951[(2)] = null);

(statearr_99851_99951[(1)] = (31));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99760 === (73))){
var state_99759__$1 = state_99759;
if(cljs.core.truth_(selectDistinct_QMARK_)){
var statearr_99852_99952 = state_99759__$1;
(statearr_99852_99952[(1)] = (75));

} else {
var statearr_99853_99953 = state_99759__$1;
(statearr_99853_99953[(1)] = (76));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99760 === (10))){
var inst_99554 = (state_99759[(2)]);
var state_99759__$1 = state_99759;
if(cljs.core.truth_(inst_99554)){
var statearr_99854_99954 = state_99759__$1;
(statearr_99854_99954[(1)] = (11));

} else {
var statearr_99855_99955 = state_99759__$1;
(statearr_99855_99955[(1)] = (12));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99760 === (18))){
var state_99759__$1 = state_99759;
if(cljs.core.truth_(orderBy)){
var statearr_99856_99956 = state_99759__$1;
(statearr_99856_99956[(1)] = (20));

} else {
var statearr_99857_99957 = state_99759__$1;
(statearr_99857_99957[(1)] = (21));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99760 === (52))){
var inst_99663 = (state_99759[(15)]);
var inst_99684 = (limit < inst_99663);
var state_99759__$1 = state_99759;
if(cljs.core.truth_(inst_99684)){
var statearr_99858_99958 = state_99759__$1;
(statearr_99858_99958[(1)] = (55));

} else {
var statearr_99859_99959 = state_99759__$1;
(statearr_99859_99959[(1)] = (56));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99760 === (67))){
var state_99759__$1 = state_99759;
if(cljs.core.truth_(selectOne_QMARK_)){
var statearr_99860_99960 = state_99759__$1;
(statearr_99860_99960[(1)] = (72));

} else {
var statearr_99861_99961 = state_99759__$1;
(statearr_99861_99961[(1)] = (73));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99760 === (71))){
var inst_99736 = (state_99759[(2)]);
var state_99759__$1 = state_99759;
var statearr_99862_99962 = state_99759__$1;
(statearr_99862_99962[(2)] = inst_99736);

(statearr_99862_99962[(1)] = (68));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99760 === (42))){
var state_99759__$1 = state_99759;
var statearr_99863_99963 = state_99759__$1;
(statearr_99863_99963[(1)] = (44));



return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99760 === (80))){
var inst_99747 = (state_99759[(2)]);
var state_99759__$1 = state_99759;
var statearr_99865_99964 = state_99759__$1;
(statearr_99865_99964[(2)] = inst_99747);

(statearr_99865_99964[(1)] = (77));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99760 === (37))){
var inst_99595 = (state_99759[(8)]);
var inst_99709 = (state_99759[(2)]);
var state_99759__$1 = (function (){var statearr_99866 = state_99759;
(statearr_99866[(9)] = inst_99709);

return statearr_99866;
})();
if(cljs.core.truth_(inst_99595)){
var statearr_99867_99965 = state_99759__$1;
(statearr_99867_99965[(1)] = (59));

} else {
var statearr_99868_99966 = state_99759__$1;
(statearr_99868_99966[(1)] = (60));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99760 === (63))){
var state_99759__$1 = state_99759;
var statearr_99869_99967 = state_99759__$1;
(statearr_99869_99967[(2)] = limit);

(statearr_99869_99967[(1)] = (64));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99760 === (8))){
var inst_99550 = cljs.core.second.call(null,orderBy);
var inst_99551 = cljs.core._EQ_.call(null,inst_99550,groupBy);
var state_99759__$1 = state_99759;
var statearr_99870_99968 = state_99759__$1;
(statearr_99870_99968[(2)] = inst_99551);

(statearr_99870_99968[(1)] = (10));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_99760 === (49))){
var inst_99700 = (state_99759[(2)]);
var state_99759__$1 = state_99759;
var statearr_99871_99969 = state_99759__$1;
(statearr_99871_99969[(2)] = inst_99700);

(statearr_99871_99969[(1)] = (46));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
return null;
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
});})(c__86675__auto__,map__99539,map__99539__$1,res,headers,vars,map__99540,map__99540__$1,select_spec,groupBy,orderBy,limit,selectOne_QMARK_,selectDistinct_QMARK_,inVector_QMARK_,offset))
;
return ((function (switch__86624__auto__,c__86675__auto__,map__99539,map__99539__$1,res,headers,vars,map__99540,map__99540__$1,select_spec,groupBy,orderBy,limit,selectOne_QMARK_,selectDistinct_QMARK_,inVector_QMARK_,offset){
return (function() {
var fluree$db$query$fql$process_ad_hoc_res_$_state_machine__86625__auto__ = null;
var fluree$db$query$fql$process_ad_hoc_res_$_state_machine__86625__auto____0 = (function (){
var statearr_99872 = [null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null];
(statearr_99872[(0)] = fluree$db$query$fql$process_ad_hoc_res_$_state_machine__86625__auto__);

(statearr_99872[(1)] = (1));

return statearr_99872;
});
var fluree$db$query$fql$process_ad_hoc_res_$_state_machine__86625__auto____1 = (function (state_99759){
while(true){
var ret_value__86626__auto__ = (function (){try{while(true){
var result__86627__auto__ = switch__86624__auto__.call(null,state_99759);
if(cljs.core.keyword_identical_QMARK_.call(null,result__86627__auto__,new cljs.core.Keyword(null,"recur","recur",-437573268))){
continue;
} else {
return result__86627__auto__;
}
break;
}
}catch (e99873){if((e99873 instanceof Object)){
var ex__86628__auto__ = e99873;
var statearr_99874_99970 = state_99759;
(statearr_99874_99970[(5)] = ex__86628__auto__);


cljs.core.async.impl.ioc_helpers.process_exception.call(null,state_99759);

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
throw e99873;

}
}})();
if(cljs.core.keyword_identical_QMARK_.call(null,ret_value__86626__auto__,new cljs.core.Keyword(null,"recur","recur",-437573268))){
var G__99971 = state_99759;
state_99759 = G__99971;
continue;
} else {
return ret_value__86626__auto__;
}
break;
}
});
fluree$db$query$fql$process_ad_hoc_res_$_state_machine__86625__auto__ = function(state_99759){
switch(arguments.length){
case 0:
return fluree$db$query$fql$process_ad_hoc_res_$_state_machine__86625__auto____0.call(this);
case 1:
return fluree$db$query$fql$process_ad_hoc_res_$_state_machine__86625__auto____1.call(this,state_99759);
}
throw(new Error('Invalid arity: ' + arguments.length));
};
fluree$db$query$fql$process_ad_hoc_res_$_state_machine__86625__auto__.cljs$core$IFn$_invoke$arity$0 = fluree$db$query$fql$process_ad_hoc_res_$_state_machine__86625__auto____0;
fluree$db$query$fql$process_ad_hoc_res_$_state_machine__86625__auto__.cljs$core$IFn$_invoke$arity$1 = fluree$db$query$fql$process_ad_hoc_res_$_state_machine__86625__auto____1;
return fluree$db$query$fql$process_ad_hoc_res_$_state_machine__86625__auto__;
})()
;})(switch__86624__auto__,c__86675__auto__,map__99539,map__99539__$1,res,headers,vars,map__99540,map__99540__$1,select_spec,groupBy,orderBy,limit,selectOne_QMARK_,selectDistinct_QMARK_,inVector_QMARK_,offset))
})();
var state__86677__auto__ = (function (){var statearr_99875 = f__86676__auto__.call(null);
(statearr_99875[(6)] = c__86675__auto__);

return statearr_99875;
})();
return cljs.core.async.impl.ioc_helpers.run_state_machine_wrapped.call(null,state__86677__auto__);
});})(c__86675__auto__,map__99539,map__99539__$1,res,headers,vars,map__99540,map__99540__$1,select_spec,groupBy,orderBy,limit,selectOne_QMARK_,selectDistinct_QMARK_,inVector_QMARK_,offset))
);

return c__86675__auto__;
});
fluree.db.query.fql.get_ad_hoc_select_spec = (function fluree$db$query$fql$get_ad_hoc_select_spec(headers,vars,p__99974,opts){
var map__99975 = p__99974;
var map__99975__$1 = (((((!((map__99975 == null))))?(((((map__99975.cljs$lang$protocol_mask$partition0$ & (64))) || ((cljs.core.PROTOCOL_SENTINEL === map__99975.cljs$core$ISeq$))))?true:false):false))?cljs.core.apply.call(null,cljs.core.hash_map,map__99975):map__99975);
var query_map = map__99975__$1;
var select = cljs.core.get.call(null,map__99975__$1,new cljs.core.Keyword(null,"select","select",1147833503));
var orderBy = cljs.core.get.call(null,map__99975__$1,new cljs.core.Keyword(null,"orderBy","orderBy",-1329797793));
var limit = cljs.core.get.call(null,map__99975__$1,new cljs.core.Keyword(null,"limit","limit",-1355822363));
var offset = cljs.core.get.call(null,map__99975__$1,new cljs.core.Keyword(null,"offset","offset",296498311));
var selectDistinct = cljs.core.get.call(null,map__99975__$1,new cljs.core.Keyword(null,"selectDistinct","selectDistinct",-1896277872));
var prettyPrint = cljs.core.get.call(null,map__99975__$1,new cljs.core.Keyword(null,"prettyPrint","prettyPrint",215590803));
var selectOne = cljs.core.get.call(null,map__99975__$1,new cljs.core.Keyword(null,"selectOne","selectOne",1588429876));
var groupBy = cljs.core.get.call(null,map__99975__$1,new cljs.core.Keyword(null,"groupBy","groupBy",-1581230667));
var selectReduced = cljs.core.get.call(null,map__99975__$1,new cljs.core.Keyword(null,"selectReduced","selectReduced",212266935));
var _ = (cljs.core.truth_((function (){var or__4131__auto__ = orderBy;
if(cljs.core.truth_(or__4131__auto__)){
return or__4131__auto__;
} else {
var or__4131__auto____$1 = groupBy;
if(cljs.core.truth_(or__4131__auto____$1)){
return or__4131__auto____$1;
} else {
var or__4131__auto____$2 = limit;
if(cljs.core.truth_(or__4131__auto____$2)){
return or__4131__auto____$2;
} else {
var or__4131__auto____$3 = offset;
if(cljs.core.truth_(or__4131__auto____$3)){
return or__4131__auto____$3;
} else {
return prettyPrint;
}
}
}
}
})())?fluree.db.util.log.warn.call(null,["The query options: limit, offset, groupBy, prettyPrint, and orderBy should be included in the opts map. Top-level options are being deprecated. Provided: ",cljs.core.pr_str.call(null,query_map)].join('')):null);
var select_smt = (function (){var or__4131__auto__ = selectOne;
if(cljs.core.truth_(or__4131__auto__)){
return or__4131__auto__;
} else {
var or__4131__auto____$1 = select;
if(cljs.core.truth_(or__4131__auto____$1)){
return or__4131__auto____$1;
} else {
var or__4131__auto____$2 = selectDistinct;
if(cljs.core.truth_(or__4131__auto____$2)){
return or__4131__auto____$2;
} else {
return selectReduced;
}
}
}
})();
var inVector_QMARK_ = cljs.core.vector_QMARK_.call(null,select_smt);
var select_smt__$1 = ((inVector_QMARK_)?select_smt:new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [select_smt], null));
var parsed_select = fluree.db.query.fql.parse_select.call(null,headers,vars,select_smt__$1);
var aggregates = cljs.core.filter.call(null,((function (_,select_smt,inVector_QMARK_,select_smt__$1,parsed_select,map__99975,map__99975__$1,query_map,select,orderBy,limit,offset,selectDistinct,prettyPrint,selectOne,groupBy,selectReduced){
return (function (p1__99972_SHARP_){
return cljs.core.contains_QMARK_.call(null,p1__99972_SHARP_,new cljs.core.Keyword(null,"code","code",1586293142));
});})(_,select_smt,inVector_QMARK_,select_smt__$1,parsed_select,map__99975,map__99975__$1,query_map,select,orderBy,limit,offset,selectDistinct,prettyPrint,selectOne,groupBy,selectReduced))
,parsed_select);
var expandMap_QMARK_ = cljs.core.some.call(null,((function (_,select_smt,inVector_QMARK_,select_smt__$1,parsed_select,aggregates,map__99975,map__99975__$1,query_map,select,orderBy,limit,offset,selectDistinct,prettyPrint,selectOne,groupBy,selectReduced){
return (function (p1__99973_SHARP_){
return cljs.core.contains_QMARK_.call(null,p1__99973_SHARP_,new cljs.core.Keyword(null,"selection","selection",975998651));
});})(_,select_smt,inVector_QMARK_,select_smt__$1,parsed_select,aggregates,map__99975,map__99975__$1,query_map,select,orderBy,limit,offset,selectDistinct,prettyPrint,selectOne,groupBy,selectReduced))
,parsed_select);
var aggregates__$1 = ((cljs.core.empty_QMARK_.call(null,aggregates))?null:aggregates);
var orderBy__$1 = (function (){var temp__5735__auto__ = new cljs.core.Keyword(null,"orderBy","orderBy",-1329797793).cljs$core$IFn$_invoke$arity$1(opts);
if(cljs.core.truth_(temp__5735__auto__)){
var orderBy__$1 = temp__5735__auto__;
if(cljs.core.truth_((function (){var or__4131__auto__ = typeof orderBy__$1 === 'string';
if(or__4131__auto__){
return or__4131__auto__;
} else {
var and__4120__auto__ = cljs.core.vector_QMARK_.call(null,orderBy__$1);
if(and__4120__auto__){
return new cljs.core.PersistentHashSet(null, new cljs.core.PersistentArrayMap(null, 2, ["DESC",null,"ASC",null], null), null).call(null,cljs.core.first.call(null,orderBy__$1));
} else {
return and__4120__auto__;
}
}
})())){
if(cljs.core.vector_QMARK_.call(null,orderBy__$1)){
return orderBy__$1;
} else {
return new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, ["ASC",orderBy__$1], null);
}
} else {
throw cljs.core.ex_info.call(null,["Invalid orderBy clause, must by variable or two-tuple formatted ['ASC' or 'DESC', var]. Provided: ",cljs.core.str.cljs$core$IFn$_invoke$arity$1(orderBy__$1)].join(''),new cljs.core.PersistentArrayMap(null, 2, [new cljs.core.Keyword(null,"status","status",-1997798413),(400),new cljs.core.Keyword(null,"error","error",-978969032),new cljs.core.Keyword("db","invalid-query","db/invalid-query",-1009699917)], null));
}
} else {
return null;
}
})();
return cljs.core.PersistentHashMap.fromArrays([new cljs.core.Keyword(null,"expandMaps?","expandMaps?",-1946388444),new cljs.core.Keyword(null,"limit","limit",-1355822363),new cljs.core.Keyword(null,"offset","offset",296498311),new cljs.core.Keyword(null,"aggregates","aggregates",-1684250289),new cljs.core.Keyword(null,"selectOne?","selectOne?",-1041343472),new cljs.core.Keyword(null,"prettyPrint","prettyPrint",215590803),new cljs.core.Keyword(null,"groupBy","groupBy",-1581230667),new cljs.core.Keyword(null,"selectDistinct?","selectDistinct?",-1672346731),new cljs.core.Keyword(null,"select","select",1147833503),new cljs.core.Keyword(null,"orderBy","orderBy",-1329797793),new cljs.core.Keyword(null,"inVector?","inVector?",1948069375)],[expandMap_QMARK_,(function (){var or__4131__auto__ = new cljs.core.Keyword(null,"limit","limit",-1355822363).cljs$core$IFn$_invoke$arity$1(opts);
if(cljs.core.truth_(or__4131__auto__)){
return or__4131__auto__;
} else {
return (100);
}
})(),(function (){var or__4131__auto__ = new cljs.core.Keyword(null,"offset","offset",296498311).cljs$core$IFn$_invoke$arity$1(opts);
if(cljs.core.truth_(or__4131__auto__)){
return or__4131__auto__;
} else {
return (0);
}
})(),aggregates__$1,cljs.core.boolean$.call(null,selectOne),(function (){var or__4131__auto__ = new cljs.core.Keyword(null,"prettyPrint","prettyPrint",215590803).cljs$core$IFn$_invoke$arity$1(opts);
if(cljs.core.truth_(or__4131__auto__)){
return or__4131__auto__;
} else {
return false;
}
})(),new cljs.core.Keyword(null,"groupBy","groupBy",-1581230667).cljs$core$IFn$_invoke$arity$1(opts),cljs.core.boolean$.call(null,(function (){var or__4131__auto__ = selectDistinct;
if(cljs.core.truth_(or__4131__auto__)){
return or__4131__auto__;
} else {
return selectReduced;
}
})()),parsed_select,orderBy__$1,inVector_QMARK_]);
});
fluree.db.query.fql.construct_triples = (function fluree$db$query$fql$construct_triples(p__99977,p__99978){
var map__99979 = p__99977;
var map__99979__$1 = (((((!((map__99979 == null))))?(((((map__99979.cljs$lang$protocol_mask$partition0$ & (64))) || ((cljs.core.PROTOCOL_SENTINEL === map__99979.cljs$core$ISeq$))))?true:false):false))?cljs.core.apply.call(null,cljs.core.hash_map,map__99979):map__99979);
var query_map = map__99979__$1;
var construct = cljs.core.get.call(null,map__99979__$1,new cljs.core.Keyword(null,"construct","construct",692547932));
var map__99980 = p__99978;
var map__99980__$1 = (((((!((map__99980 == null))))?(((((map__99980.cljs$lang$protocol_mask$partition0$ & (64))) || ((cljs.core.PROTOCOL_SENTINEL === map__99980.cljs$core$ISeq$))))?true:false):false))?cljs.core.apply.call(null,cljs.core.hash_map,map__99980):map__99980);
var where_result = map__99980__$1;
var headers = cljs.core.get.call(null,map__99980__$1,new cljs.core.Keyword(null,"headers","headers",-835030129));
var tuples = cljs.core.get.call(null,map__99980__$1,new cljs.core.Keyword(null,"tuples","tuples",-676032639));
var vec__99983 = cljs.core.map.call(null,((function (map__99979,map__99979__$1,query_map,construct,map__99980,map__99980__$1,where_result,headers,tuples){
return (function (construct_item){
var temp__5733__auto__ = fluree.db.util.core.index_of.call(null,headers,cljs.core.symbol.call(null,construct_item));
if(cljs.core.truth_(temp__5733__auto__)){
var index_of = temp__5733__auto__;
return ((function (index_of,temp__5733__auto__,map__99979,map__99979__$1,query_map,construct,map__99980,map__99980__$1,where_result,headers,tuples){
return (function (row){
return cljs.core.nth.call(null,row,index_of);
});
;})(index_of,temp__5733__auto__,map__99979,map__99979__$1,query_map,construct,map__99980,map__99980__$1,where_result,headers,tuples))
} else {
return ((function (temp__5733__auto__,map__99979,map__99979__$1,query_map,construct,map__99980,map__99980__$1,where_result,headers,tuples){
return (function (row){
return construct_item;
});
;})(temp__5733__auto__,map__99979,map__99979__$1,query_map,construct,map__99980,map__99980__$1,where_result,headers,tuples))
}
});})(map__99979,map__99979__$1,query_map,construct,map__99980,map__99980__$1,where_result,headers,tuples))
,construct);
var fn1 = cljs.core.nth.call(null,vec__99983,(0),null);
var fn2 = cljs.core.nth.call(null,vec__99983,(1),null);
var fn3 = cljs.core.nth.call(null,vec__99983,(2),null);
return cljs.core.map.call(null,((function (vec__99983,fn1,fn2,fn3,map__99979,map__99979__$1,query_map,construct,map__99980,map__99980__$1,where_result,headers,tuples){
return (function (res){
return new cljs.core.PersistentVector(null, 3, 5, cljs.core.PersistentVector.EMPTY_NODE, [fn1.call(null,res),fn2.call(null,res),fn3.call(null,res)], null);
});})(vec__99983,fn1,fn2,fn3,map__99979,map__99979__$1,query_map,construct,map__99980,map__99980__$1,where_result,headers,tuples))
,tuples);
});
fluree.db.query.fql.ad_hoc_query = (function fluree$db$query$fql$ad_hoc_query(db,fuel,max_fuel,query_map,opts){
var c__86675__auto__ = cljs.core.async.chan.call(null,(1));
cljs.core.async.impl.dispatch.run.call(null,((function (c__86675__auto__){
return (function (){
var f__86676__auto__ = (function (){var switch__86624__auto__ = ((function (c__86675__auto__){
return (function (state_100013){
var state_val_100014 = (state_100013[(1)]);
if((state_val_100014 === (7))){
var state_100013__$1 = state_100013;
var statearr_100015_100031 = state_100013__$1;
(statearr_100015_100031[(1)] = (9));



return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100014 === (1))){
var state_100013__$1 = state_100013;
var statearr_100017_100032 = state_100013__$1;
(statearr_100017_100032[(2)] = null);

(statearr_100017_100032[(1)] = (4));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100014 === (4))){
var _ = cljs.core.async.impl.ioc_helpers.add_exception_frame.call(null,state_100013,(3),Error,null,(2));
var inst_99990 = fluree.db.query.analytical.q.call(null,query_map,fuel,max_fuel,db,opts);
var state_100013__$1 = state_100013;
return cljs.core.async.impl.ioc_helpers.take_BANG_.call(null,state_100013__$1,(5),inst_99990);
} else {
if((state_val_100014 === (6))){
var inst_99993 = (state_100013[(7)]);
var state_100013__$1 = state_100013;
var statearr_100018_100033 = state_100013__$1;
(statearr_100018_100033[(2)] = inst_99993);

(statearr_100018_100033[(1)] = (8));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100014 === (3))){
var inst_99986 = (state_100013[(2)]);
var state_100013__$1 = state_100013;
var statearr_100019_100034 = state_100013__$1;
(statearr_100019_100034[(2)] = inst_99986);


cljs.core.async.impl.ioc_helpers.process_exception.call(null,state_100013__$1);

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100014 === (12))){
var inst_100003 = (state_100013[(2)]);
var inst_100004 = fluree.db.util.async.throw_err.call(null,inst_100003);
var state_100013__$1 = state_100013;
var statearr_100020_100035 = state_100013__$1;
(statearr_100020_100035[(2)] = inst_100004);

(statearr_100020_100035[(1)] = (11));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100014 === (2))){
var inst_100011 = (state_100013[(2)]);
var state_100013__$1 = state_100013;
return cljs.core.async.impl.ioc_helpers.return_chan.call(null,state_100013__$1,inst_100011);
} else {
if((state_val_100014 === (11))){
var inst_100007 = (state_100013[(2)]);
var state_100013__$1 = state_100013;
var statearr_100021_100036 = state_100013__$1;
(statearr_100021_100036[(2)] = inst_100007);

(statearr_100021_100036[(1)] = (8));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100014 === (9))){
var inst_99993 = (state_100013[(7)]);
var inst_99998 = new cljs.core.Keyword(null,"headers","headers",-835030129).cljs$core$IFn$_invoke$arity$1(inst_99993);
var inst_99999 = new cljs.core.Keyword(null,"vars","vars",-2046957217).cljs$core$IFn$_invoke$arity$1(inst_99993);
var inst_100000 = fluree.db.query.fql.get_ad_hoc_select_spec.call(null,inst_99998,inst_99999,query_map,opts);
var inst_100001 = fluree.db.query.fql.process_ad_hoc_res.call(null,db,inst_99993,inst_100000,opts);
var state_100013__$1 = state_100013;
return cljs.core.async.impl.ioc_helpers.take_BANG_.call(null,state_100013__$1,(12),inst_100001);
} else {
if((state_val_100014 === (5))){
var inst_99993 = (state_100013[(7)]);
var inst_99992 = (state_100013[(2)]);
var inst_99993__$1 = fluree.db.util.async.throw_err.call(null,inst_99992);
var inst_99994 = fluree.db.util.core.exception_QMARK_.call(null,inst_99993__$1);
var state_100013__$1 = (function (){var statearr_100022 = state_100013;
(statearr_100022[(7)] = inst_99993__$1);

return statearr_100022;
})();
if(inst_99994){
var statearr_100023_100037 = state_100013__$1;
(statearr_100023_100037[(1)] = (6));

} else {
var statearr_100024_100038 = state_100013__$1;
(statearr_100024_100038[(1)] = (7));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100014 === (10))){
var state_100013__$1 = state_100013;
var statearr_100025_100039 = state_100013__$1;
(statearr_100025_100039[(2)] = null);

(statearr_100025_100039[(1)] = (11));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100014 === (8))){
var inst_100009 = (state_100013[(2)]);
var state_100013__$1 = state_100013;
var statearr_100026_100040 = state_100013__$1;
(statearr_100026_100040[(2)] = inst_100009);


cljs.core.async.impl.ioc_helpers.process_exception.call(null,state_100013__$1);

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
return null;
}
}
}
}
}
}
}
}
}
}
}
}
});})(c__86675__auto__))
;
return ((function (switch__86624__auto__,c__86675__auto__){
return (function() {
var fluree$db$query$fql$ad_hoc_query_$_state_machine__86625__auto__ = null;
var fluree$db$query$fql$ad_hoc_query_$_state_machine__86625__auto____0 = (function (){
var statearr_100027 = [null,null,null,null,null,null,null,null];
(statearr_100027[(0)] = fluree$db$query$fql$ad_hoc_query_$_state_machine__86625__auto__);

(statearr_100027[(1)] = (1));

return statearr_100027;
});
var fluree$db$query$fql$ad_hoc_query_$_state_machine__86625__auto____1 = (function (state_100013){
while(true){
var ret_value__86626__auto__ = (function (){try{while(true){
var result__86627__auto__ = switch__86624__auto__.call(null,state_100013);
if(cljs.core.keyword_identical_QMARK_.call(null,result__86627__auto__,new cljs.core.Keyword(null,"recur","recur",-437573268))){
continue;
} else {
return result__86627__auto__;
}
break;
}
}catch (e100028){if((e100028 instanceof Object)){
var ex__86628__auto__ = e100028;
var statearr_100029_100041 = state_100013;
(statearr_100029_100041[(5)] = ex__86628__auto__);


cljs.core.async.impl.ioc_helpers.process_exception.call(null,state_100013);

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
throw e100028;

}
}})();
if(cljs.core.keyword_identical_QMARK_.call(null,ret_value__86626__auto__,new cljs.core.Keyword(null,"recur","recur",-437573268))){
var G__100042 = state_100013;
state_100013 = G__100042;
continue;
} else {
return ret_value__86626__auto__;
}
break;
}
});
fluree$db$query$fql$ad_hoc_query_$_state_machine__86625__auto__ = function(state_100013){
switch(arguments.length){
case 0:
return fluree$db$query$fql$ad_hoc_query_$_state_machine__86625__auto____0.call(this);
case 1:
return fluree$db$query$fql$ad_hoc_query_$_state_machine__86625__auto____1.call(this,state_100013);
}
throw(new Error('Invalid arity: ' + arguments.length));
};
fluree$db$query$fql$ad_hoc_query_$_state_machine__86625__auto__.cljs$core$IFn$_invoke$arity$0 = fluree$db$query$fql$ad_hoc_query_$_state_machine__86625__auto____0;
fluree$db$query$fql$ad_hoc_query_$_state_machine__86625__auto__.cljs$core$IFn$_invoke$arity$1 = fluree$db$query$fql$ad_hoc_query_$_state_machine__86625__auto____1;
return fluree$db$query$fql$ad_hoc_query_$_state_machine__86625__auto__;
})()
;})(switch__86624__auto__,c__86675__auto__))
})();
var state__86677__auto__ = (function (){var statearr_100030 = f__86676__auto__.call(null);
(statearr_100030[(6)] = c__86675__auto__);

return statearr_100030;
})();
return cljs.core.async.impl.ioc_helpers.run_state_machine_wrapped.call(null,state__86677__auto__);
});})(c__86675__auto__))
);

return c__86675__auto__;
});
/**
 * Returns core async channel with results
 */
fluree.db.query.fql.query = (function fluree$db$query$fql$query(var_args){
var G__100044 = arguments.length;
switch (G__100044) {
case 2:
return fluree.db.query.fql.query.cljs$core$IFn$_invoke$arity$2((arguments[(0)]),(arguments[(1)]));

break;
case 3:
return fluree.db.query.fql.query.cljs$core$IFn$_invoke$arity$3((arguments[(0)]),(arguments[(1)]),(arguments[(2)]));

break;
default:
throw (new Error(["Invalid arity: ",cljs.core.str.cljs$core$IFn$_invoke$arity$1(arguments.length)].join('')));

}
});

fluree.db.query.fql.query.cljs$core$IFn$_invoke$arity$2 = (function (db,query_map){
return fluree.db.query.fql.query.call(null,db,query_map,null);
});

fluree.db.query.fql.query.cljs$core$IFn$_invoke$arity$3 = (function (db,query_map,opts){
var map__100045 = query_map;
var map__100045__$1 = (((((!((map__100045 == null))))?(((((map__100045.cljs$lang$protocol_mask$partition0$ & (64))) || ((cljs.core.PROTOCOL_SENTINEL === map__100045.cljs$core$ISeq$))))?true:false):false))?cljs.core.apply.call(null,cljs.core.hash_map,map__100045):map__100045);
var select = cljs.core.get.call(null,map__100045__$1,new cljs.core.Keyword(null,"select","select",1147833503));
var orderBy = cljs.core.get.call(null,map__100045__$1,new cljs.core.Keyword(null,"orderBy","orderBy",-1329797793));
var where = cljs.core.get.call(null,map__100045__$1,new cljs.core.Keyword(null,"where","where",-2044795965));
var limit = cljs.core.get.call(null,map__100045__$1,new cljs.core.Keyword(null,"limit","limit",-1355822363));
var offset = cljs.core.get.call(null,map__100045__$1,new cljs.core.Keyword(null,"offset","offset",296498311));
var component = cljs.core.get.call(null,map__100045__$1,new cljs.core.Keyword(null,"component","component",1555936782));
var selectDistinct = cljs.core.get.call(null,map__100045__$1,new cljs.core.Keyword(null,"selectDistinct","selectDistinct",-1896277872));
var prettyPrint = cljs.core.get.call(null,map__100045__$1,new cljs.core.Keyword(null,"prettyPrint","prettyPrint",215590803));
var selectOne = cljs.core.get.call(null,map__100045__$1,new cljs.core.Keyword(null,"selectOne","selectOne",1588429876));
var from = cljs.core.get.call(null,map__100045__$1,new cljs.core.Keyword(null,"from","from",1815293044));
var groupBy = cljs.core.get.call(null,map__100045__$1,new cljs.core.Keyword(null,"groupBy","groupBy",-1581230667));
var opts_SINGLEQUOTE_ = cljs.core.merge.call(null,new cljs.core.PersistentArrayMap(null, 6, [new cljs.core.Keyword(null,"limit","limit",-1355822363),limit,new cljs.core.Keyword(null,"offset","offset",296498311),(function (){var or__4131__auto__ = offset;
if(cljs.core.truth_(or__4131__auto__)){
return or__4131__auto__;
} else {
return (0);
}
})(),new cljs.core.Keyword(null,"component","component",1555936782),component,new cljs.core.Keyword(null,"orderBy","orderBy",-1329797793),orderBy,new cljs.core.Keyword(null,"groupBy","groupBy",-1581230667),groupBy,new cljs.core.Keyword(null,"prettyPrint","prettyPrint",215590803),prettyPrint], null),opts,new cljs.core.Keyword(null,"opts","opts",155075701).cljs$core$IFn$_invoke$arity$1(query_map));
var opts_SINGLEQUOTE__SINGLEQUOTE_ = (cljs.core.truth_(selectOne)?cljs.core.assoc.call(null,opts_SINGLEQUOTE_,new cljs.core.Keyword(null,"limit","limit",-1355822363),(1)):opts_SINGLEQUOTE_);
var opts_STAR_ = cljs.core.dissoc.call(null,opts_SINGLEQUOTE__SINGLEQUOTE_,new cljs.core.Keyword(null,"cache","cache",-1237023054));
if(cljs.core.truth_(new cljs.core.Keyword(null,"cache","cache",-1237023054).cljs$core$IFn$_invoke$arity$1(opts_STAR_))){
var oc = cljs.core.get_in.call(null,db,new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"conn","conn",278309663),new cljs.core.Keyword(null,"object-cache","object-cache",-2130324287)], null));
return oc.call(null,new cljs.core.PersistentVector(null, 5, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"query","query",-1288509510),new cljs.core.Keyword(null,"block","block",664686210).cljs$core$IFn$_invoke$arity$1(db),query_map,cljs.core.dissoc.call(null,opts,new cljs.core.Keyword(null,"fuel","fuel",10405485)),new cljs.core.Keyword(null,"auth","auth",1389754926).cljs$core$IFn$_invoke$arity$1(db)], null),((function (oc,map__100045,map__100045__$1,select,orderBy,where,limit,offset,component,selectDistinct,prettyPrint,selectOne,from,groupBy,opts_SINGLEQUOTE_,opts_SINGLEQUOTE__SINGLEQUOTE_,opts_STAR_){
return (function (_){
var pc = cljs.core.async.promise_chan.call(null);
fluree.db.query.fql.future.call(null,(function (){var res = cljs.core.async._LT__BANG__BANG_.call(null,fluree.db.query.fql.query.call(null,db,query_map,cljs.core.assoc.call(null,opts,new cljs.core.Keyword(null,"cache","cache",-1237023054),false)));
return cljs.core.async.put_BANG_.call(null,pc,res);
})());

return pc;
});})(oc,map__100045,map__100045__$1,select,orderBy,where,limit,offset,component,selectDistinct,prettyPrint,selectOne,from,groupBy,opts_SINGLEQUOTE_,opts_SINGLEQUOTE__SINGLEQUOTE_,opts_STAR_))
);
} else {
var max_fuel = new cljs.core.Keyword(null,"max-fuel","max-fuel",994681012).cljs$core$IFn$_invoke$arity$1(opts_STAR_);
var fuel = (function (){var or__4131__auto__ = new cljs.core.Keyword(null,"fuel","fuel",10405485).cljs$core$IFn$_invoke$arity$1(opts);
if(cljs.core.truth_(or__4131__auto__)){
return or__4131__auto__;
} else {
if(cljs.core.truth_((function (){var or__4131__auto____$1 = max_fuel;
if(cljs.core.truth_(or__4131__auto____$1)){
return or__4131__auto____$1;
} else {
return new cljs.core.Keyword(null,"meta","meta",1499536964).cljs$core$IFn$_invoke$arity$1(opts);
}
})())){
return cljs.core.volatile_BANG_.call(null,(0));
} else {
return null;
}
}
})();
if(cljs.core.sequential_QMARK_.call(null,where)){
return fluree.db.query.fql.ad_hoc_query.call(null,db,fuel,max_fuel,query_map,opts_STAR_);
} else {
var c__86675__auto__ = cljs.core.async.chan.call(null,(1));
cljs.core.async.impl.dispatch.run.call(null,((function (c__86675__auto__,max_fuel,fuel,map__100045,map__100045__$1,select,orderBy,where,limit,offset,component,selectDistinct,prettyPrint,selectOne,from,groupBy,opts_SINGLEQUOTE_,opts_SINGLEQUOTE__SINGLEQUOTE_,opts_STAR_){
return (function (){
var f__86676__auto__ = (function (){var switch__86624__auto__ = ((function (c__86675__auto__,max_fuel,fuel,map__100045,map__100045__$1,select,orderBy,where,limit,offset,component,selectDistinct,prettyPrint,selectOne,from,groupBy,opts_SINGLEQUOTE_,opts_SINGLEQUOTE__SINGLEQUOTE_,opts_STAR_){
return (function (state_100381){
var state_val_100382 = (state_100381[(1)]);
if((state_val_100382 === (121))){
var inst_100364 = (state_100381[(7)]);
var inst_100366 = cljs.core.coll_QMARK_.call(null,inst_100364);
var inst_100367 = fluree.db.util.core.exception_QMARK_.call(null,inst_100364);
var inst_100368 = (!(inst_100367));
var inst_100369 = ((inst_100366) && (inst_100368));
var state_100381__$1 = state_100381;
var statearr_100383_100557 = state_100381__$1;
(statearr_100383_100557[(2)] = inst_100369);

(statearr_100383_100557[(1)] = (123));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100382 === (65))){
var inst_100209 = (state_100381[(2)]);
var state_100381__$1 = state_100381;
if(cljs.core.truth_(inst_100209)){
var statearr_100384_100558 = state_100381__$1;
(statearr_100384_100558[(1)] = (66));

} else {
var statearr_100385_100559 = state_100381__$1;
(statearr_100385_100559[(1)] = (67));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100382 === (70))){
var inst_100094 = (state_100381[(8)]);
var inst_100096 = (state_100381[(9)]);
var inst_100214 = [new cljs.core.Keyword(null,"limit","limit",-1355822363),new cljs.core.Keyword(null,"offset","offset",296498311)];
var inst_100215 = [inst_100094,inst_100096];
var inst_100216 = cljs.core.PersistentHashMap.fromArrays(inst_100214,inst_100215);
var state_100381__$1 = state_100381;
var statearr_100386_100560 = state_100381__$1;
(statearr_100386_100560[(2)] = inst_100216);

(statearr_100386_100560[(1)] = (71));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100382 === (62))){
var inst_100198 = (state_100381[(2)]);
var inst_100199 = fluree.db.util.async.throw_err.call(null,inst_100198);
var state_100381__$1 = state_100381;
var statearr_100387_100561 = state_100381__$1;
(statearr_100387_100561[(2)] = inst_100199);

(statearr_100387_100561[(1)] = (51));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100382 === (74))){
var inst_100093 = (state_100381[(10)]);
var state_100381__$1 = state_100381;
if(cljs.core.truth_(inst_100093)){
var statearr_100388_100562 = state_100381__$1;
(statearr_100388_100562[(1)] = (77));

} else {
var statearr_100389_100563 = state_100381__$1;
(statearr_100389_100563[(1)] = (78));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100382 === (110))){
var inst_100297 = (state_100381[(11)]);
var inst_100321 = (state_100381[(2)]);
var inst_100289 = inst_100297;
var inst_100290 = inst_100321;
var state_100381__$1 = (function (){var statearr_100390 = state_100381;
(statearr_100390[(12)] = inst_100290);

(statearr_100390[(13)] = inst_100289);

return statearr_100390;
})();
var statearr_100391_100564 = state_100381__$1;
(statearr_100391_100564[(2)] = null);

(statearr_100391_100564[(1)] = (96));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100382 === (7))){
var inst_100071 = (state_100381[(2)]);
var inst_100073 = (opts_STAR_ == null);
var inst_100074 = cljs.core.not.call(null,inst_100073);
var state_100381__$1 = (function (){var statearr_100392 = state_100381;
(statearr_100392[(14)] = inst_100071);

return statearr_100392;
})();
if(inst_100074){
var statearr_100393_100565 = state_100381__$1;
(statearr_100393_100565[(1)] = (14));

} else {
var statearr_100394_100566 = state_100381__$1;
(statearr_100394_100566[(1)] = (15));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100382 === (59))){
var inst_100094 = (state_100381[(8)]);
var inst_100096 = (state_100381[(9)]);
var inst_100183 = [new cljs.core.Keyword(null,"limit","limit",-1355822363),new cljs.core.Keyword(null,"offset","offset",296498311)];
var inst_100184 = [inst_100094,inst_100096];
var inst_100185 = cljs.core.PersistentHashMap.fromArrays(inst_100183,inst_100184);
var state_100381__$1 = state_100381;
var statearr_100395_100567 = state_100381__$1;
(statearr_100395_100567[(2)] = inst_100185);

(statearr_100395_100567[(1)] = (60));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100382 === (86))){
var state_100381__$1 = state_100381;
var statearr_100396_100568 = state_100381__$1;
(statearr_100396_100568[(2)] = null);

(statearr_100396_100568[(1)] = (88));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100382 === (20))){
var inst_100089 = cljs.core.apply.call(null,cljs.core.hash_map,opts_STAR_);
var state_100381__$1 = state_100381;
var statearr_100397_100569 = state_100381__$1;
(statearr_100397_100569[(2)] = inst_100089);

(statearr_100397_100569[(1)] = (22));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100382 === (72))){
var inst_100104 = (state_100381[(15)]);
var inst_100106 = (state_100381[(16)]);
var inst_100221 = (state_100381[(2)]);
var inst_100222 = fluree.db.util.async.throw_err.call(null,inst_100221);
var inst_100223 = fluree.db.query.fql.flake_select.call(null,db,inst_100106,fuel,max_fuel,inst_100104,inst_100222);
var state_100381__$1 = state_100381;
return cljs.core.async.impl.ioc_helpers.take_BANG_.call(null,state_100381__$1,(73),inst_100223);
} else {
if((state_val_100382 === (58))){
var inst_100181 = cljs.core.PersistentHashMap.EMPTY;
var state_100381__$1 = state_100381;
var statearr_100398_100570 = state_100381__$1;
(statearr_100398_100570[(2)] = inst_100181);

(statearr_100398_100570[(1)] = (60));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100382 === (60))){
var inst_100187 = (state_100381[(2)]);
var inst_100188 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_100189 = [from];
var inst_100190 = (new cljs.core.PersistentVector(null,1,(5),inst_100188,inst_100189,null));
var inst_100191 = fluree.db.query.range.index_range.call(null,db,new cljs.core.Keyword(null,"psot","psot",2111653059),cljs.core._EQ_,inst_100190,inst_100187);
var state_100381__$1 = state_100381;
return cljs.core.async.impl.ioc_helpers.take_BANG_.call(null,state_100381__$1,(61),inst_100191);
} else {
if((state_val_100382 === (27))){
var inst_100134 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_100135 = [null,null];
var inst_100136 = (new cljs.core.PersistentVector(null,2,(5),inst_100134,inst_100135,null));
var state_100381__$1 = state_100381;
var statearr_100399_100571 = state_100381__$1;
(statearr_100399_100571[(2)] = inst_100136);

(statearr_100399_100571[(1)] = (28));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100382 === (1))){
var state_100381__$1 = state_100381;
var statearr_100400_100572 = state_100381__$1;
(statearr_100400_100572[(2)] = null);

(statearr_100400_100572[(1)] = (4));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100382 === (69))){
var inst_100212 = cljs.core.PersistentHashMap.EMPTY;
var state_100381__$1 = state_100381;
var statearr_100401_100573 = state_100381__$1;
(statearr_100401_100573[(2)] = inst_100212);

(statearr_100401_100573[(1)] = (71));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100382 === (101))){
var inst_100296 = (state_100381[(17)]);
var state_100381__$1 = state_100381;
var statearr_100402_100574 = state_100381__$1;
(statearr_100402_100574[(2)] = inst_100296);

(statearr_100402_100574[(1)] = (103));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100382 === (24))){
var inst_100097 = (state_100381[(18)]);
var state_100381__$1 = state_100381;
var statearr_100403_100575 = state_100381__$1;
(statearr_100403_100575[(2)] = inst_100097);

(statearr_100403_100575[(1)] = (25));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100382 === (102))){
var state_100381__$1 = state_100381;
if(cljs.core.truth_(fuel)){
var statearr_100404_100576 = state_100381__$1;
(statearr_100404_100576[(1)] = (104));

} else {
var statearr_100405_100577 = state_100381__$1;
(statearr_100405_100577[(1)] = (105));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100382 === (55))){
var inst_100173 = (state_100381[(19)]);
var inst_100175 = cljs.core.distinct.call(null);
var inst_100176 = cljs.core.comp.call(null,inst_100173,inst_100175);
var state_100381__$1 = state_100381;
var statearr_100406_100578 = state_100381__$1;
(statearr_100406_100578[(2)] = inst_100176);

(statearr_100406_100578[(1)] = (57));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100382 === (85))){
var inst_100253 = (state_100381[(20)]);
var inst_100252 = (state_100381[(2)]);
var inst_100253__$1 = fluree.db.util.async.throw_err.call(null,inst_100252);
var inst_100254 = (inst_100253__$1 == null);
var state_100381__$1 = (function (){var statearr_100407 = state_100381;
(statearr_100407[(20)] = inst_100253__$1);

return statearr_100407;
})();
if(cljs.core.truth_(inst_100254)){
var statearr_100408_100579 = state_100381__$1;
(statearr_100408_100579[(1)] = (86));

} else {
var statearr_100409_100580 = state_100381__$1;
(statearr_100409_100580[(1)] = (87));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100382 === (39))){
var inst_100161 = typeof from === 'string';
var inst_100162 = cljs.core.str.cljs$core$IFn$_invoke$arity$1(from);
var inst_100163 = clojure.string.includes_QMARK_.call(null,inst_100162,"/");
var inst_100164 = ((inst_100161) && (inst_100163));
var state_100381__$1 = state_100381;
if(cljs.core.truth_(inst_100164)){
var statearr_100410_100581 = state_100381__$1;
(statearr_100410_100581[(1)] = (49));

} else {
var statearr_100411_100582 = state_100381__$1;
(statearr_100411_100582[(1)] = (50));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100382 === (88))){
var inst_100104 = (state_100381[(15)]);
var inst_100106 = (state_100381[(16)]);
var inst_100094 = (state_100381[(8)]);
var inst_100096 = (state_100381[(9)]);
var inst_100261 = (state_100381[(2)]);
var inst_100262 = fluree.db.query.fql.subject_select.call(null,db,inst_100106,fuel,max_fuel,inst_100104,inst_100261,inst_100094,inst_100096);
var state_100381__$1 = state_100381;
return cljs.core.async.impl.ioc_helpers.take_BANG_.call(null,state_100381__$1,(89),inst_100262);
} else {
if((state_val_100382 === (46))){
var state_100381__$1 = state_100381;
var statearr_100412_100583 = state_100381__$1;
(statearr_100412_100583[(2)] = null);

(statearr_100412_100583[(1)] = (48));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100382 === (4))){
var _ = cljs.core.async.impl.ioc_helpers.add_exception_frame.call(null,state_100381,(3),Error,null,(2));
var state_100381__$1 = state_100381;
if(cljs.core.truth_(select)){
var statearr_100413_100584 = state_100381__$1;
(statearr_100413_100584[(1)] = (5));

} else {
var statearr_100414_100585 = state_100381__$1;
(statearr_100414_100585[(1)] = (6));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100382 === (77))){
var inst_100231 = cljs.core.PersistentHashMap.EMPTY;
var state_100381__$1 = state_100381;
var statearr_100415_100586 = state_100381__$1;
(statearr_100415_100586[(2)] = inst_100231);

(statearr_100415_100586[(1)] = (79));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100382 === (106))){
var inst_100296 = (state_100381[(17)]);
var inst_100310 = (state_100381[(2)]);
var inst_100311 = fluree.db.dbproto._subid.call(null,db,inst_100296,false);
var state_100381__$1 = (function (){var statearr_100416 = state_100381;
(statearr_100416[(21)] = inst_100310);

return statearr_100416;
})();
return cljs.core.async.impl.ioc_helpers.take_BANG_.call(null,state_100381__$1,(107),inst_100311);
} else {
if((state_val_100382 === (119))){
var inst_100359 = (state_100381[(22)]);
var state_100381__$1 = state_100381;
var statearr_100417_100587 = state_100381__$1;
(statearr_100417_100587[(2)] = inst_100359);

(statearr_100417_100587[(1)] = (120));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100382 === (95))){
var inst_100349 = (state_100381[(2)]);
var state_100381__$1 = state_100381;
var statearr_100418_100588 = state_100381__$1;
(statearr_100418_100588[(2)] = inst_100349);

(statearr_100418_100588[(1)] = (84));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100382 === (54))){
var inst_100173 = (state_100381[(2)]);
var state_100381__$1 = (function (){var statearr_100419 = state_100381;
(statearr_100419[(19)] = inst_100173);

return statearr_100419;
})();
var statearr_100420_100589 = state_100381__$1;
(statearr_100420_100589[(1)] = (55));



return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100382 === (92))){
var inst_100265 = (state_100381[(23)]);
var inst_100272 = (state_100381[(2)]);
var state_100381__$1 = (function (){var statearr_100422 = state_100381;
(statearr_100422[(24)] = inst_100272);

return statearr_100422;
})();
var statearr_100423_100590 = state_100381__$1;
(statearr_100423_100590[(2)] = inst_100265);

(statearr_100423_100590[(1)] = (84));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100382 === (104))){
var inst_100305 = cljs.core._deref.call(null,fuel);
var inst_100306 = (inst_100305 + (1));
var inst_100307 = cljs.core._vreset_BANG_.call(null,fuel,inst_100306);
var state_100381__$1 = state_100381;
var statearr_100424_100591 = state_100381__$1;
(statearr_100424_100591[(2)] = inst_100307);

(statearr_100424_100591[(1)] = (106));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100382 === (15))){
var state_100381__$1 = state_100381;
var statearr_100425_100592 = state_100381__$1;
(statearr_100425_100592[(2)] = false);

(statearr_100425_100592[(1)] = (16));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100382 === (48))){
var inst_100104 = (state_100381[(15)]);
var inst_100106 = (state_100381[(16)]);
var inst_100096 = (state_100381[(9)]);
var inst_100151 = (state_100381[(25)]);
var inst_100155 = (state_100381[(2)]);
var inst_100156 = fluree.db.query.fql.subject_select.call(null,db,inst_100106,fuel,max_fuel,inst_100104,inst_100151,inst_100155,inst_100096);
var state_100381__$1 = state_100381;
return cljs.core.async.impl.ioc_helpers.take_BANG_.call(null,state_100381__$1,(45),inst_100156);
} else {
if((state_val_100382 === (50))){
var inst_100201 = (state_100381[(26)]);
var inst_100201__$1 = typeof from === 'string';
var state_100381__$1 = (function (){var statearr_100426 = state_100381;
(statearr_100426[(26)] = inst_100201__$1);

return statearr_100426;
})();
if(cljs.core.truth_(inst_100201__$1)){
var statearr_100427_100593 = state_100381__$1;
(statearr_100427_100593[(1)] = (63));

} else {
var statearr_100428_100594 = state_100381__$1;
(statearr_100428_100594[(1)] = (64));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100382 === (116))){
var state_100381__$1 = state_100381;
var statearr_100429_100595 = state_100381__$1;
(statearr_100429_100595[(2)] = null);

(statearr_100429_100595[(1)] = (117));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100382 === (75))){
var inst_100247 = fluree.db.util.core.subj_ident_QMARK_.call(null,from);
var state_100381__$1 = state_100381;
if(inst_100247){
var statearr_100430_100596 = state_100381__$1;
(statearr_100430_100596[(1)] = (82));

} else {
var statearr_100431_100597 = state_100381__$1;
(statearr_100431_100597[(1)] = (83));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100382 === (99))){
var inst_100296 = (state_100381[(17)]);
var inst_100301 = cljs.core.int_QMARK_.call(null,inst_100296);
var state_100381__$1 = state_100381;
if(inst_100301){
var statearr_100432_100598 = state_100381__$1;
(statearr_100432_100598[(1)] = (101));

} else {
var statearr_100433_100599 = state_100381__$1;
(statearr_100433_100599[(1)] = (102));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100382 === (21))){
var state_100381__$1 = state_100381;
var statearr_100434_100600 = state_100381__$1;
(statearr_100434_100600[(2)] = opts_STAR_);

(statearr_100434_100600[(1)] = (22));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100382 === (31))){
var inst_100132 = (state_100381[(2)]);
var state_100381__$1 = state_100381;
var statearr_100435_100601 = state_100381__$1;
(statearr_100435_100601[(2)] = inst_100132);

(statearr_100435_100601[(1)] = (28));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100382 === (113))){
var inst_100094 = (state_100381[(8)]);
var state_100381__$1 = state_100381;
var statearr_100436_100602 = state_100381__$1;
(statearr_100436_100602[(2)] = inst_100094);

(statearr_100436_100602[(1)] = (114));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100382 === (32))){
var inst_100093 = (state_100381[(10)]);
var inst_100118 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_100119 = [inst_100093,"ASC"];
var inst_100120 = (new cljs.core.PersistentVector(null,2,(5),inst_100118,inst_100119,null));
var state_100381__$1 = state_100381;
var statearr_100437_100603 = state_100381__$1;
(statearr_100437_100603[(2)] = inst_100120);

(statearr_100437_100603[(1)] = (34));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100382 === (40))){
var inst_100139 = (state_100381[(27)]);
var inst_100359 = (state_100381[(2)]);
var state_100381__$1 = (function (){var statearr_100438 = state_100381;
(statearr_100438[(22)] = inst_100359);

return statearr_100438;
})();
if(cljs.core.truth_(inst_100139)){
var statearr_100439_100604 = state_100381__$1;
(statearr_100439_100604[(1)] = (118));

} else {
var statearr_100440_100605 = state_100381__$1;
(statearr_100440_100605[(1)] = (119));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100382 === (91))){
var state_100381__$1 = state_100381;
var statearr_100441_100606 = state_100381__$1;
(statearr_100441_100606[(2)] = null);

(statearr_100441_100606[(1)] = (92));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100382 === (117))){
var inst_100347 = (state_100381[(2)]);
var state_100381__$1 = state_100381;
var statearr_100442_100607 = state_100381__$1;
(statearr_100442_100607[(2)] = inst_100347);

(statearr_100442_100607[(1)] = (95));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100382 === (108))){
var inst_100290 = (state_100381[(12)]);
var inst_100316 = (state_100381[(28)]);
var inst_100318 = cljs.core.conj.call(null,inst_100290,inst_100316);
var state_100381__$1 = state_100381;
var statearr_100443_100608 = state_100381__$1;
(statearr_100443_100608[(2)] = inst_100318);

(statearr_100443_100608[(1)] = (110));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100382 === (56))){
var inst_100173 = (state_100381[(19)]);
var state_100381__$1 = state_100381;
var statearr_100444_100609 = state_100381__$1;
(statearr_100444_100609[(2)] = inst_100173);

(statearr_100444_100609[(1)] = (57));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100382 === (33))){
var state_100381__$1 = state_100381;
var statearr_100445_100610 = state_100381__$1;
(statearr_100445_100610[(1)] = (35));



return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100382 === (13))){
var inst_100067 = (state_100381[(2)]);
var state_100381__$1 = state_100381;
var statearr_100447_100611 = state_100381__$1;
(statearr_100447_100611[(2)] = inst_100067);

(statearr_100447_100611[(1)] = (10));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100382 === (22))){
var inst_100071 = (state_100381[(14)]);
var inst_100095 = (state_100381[(29)]);
var inst_100092 = (state_100381[(2)]);
var inst_100093 = cljs.core.get.call(null,inst_100092,new cljs.core.Keyword(null,"orderBy","orderBy",-1329797793));
var inst_100094 = cljs.core.get.call(null,inst_100092,new cljs.core.Keyword(null,"limit","limit",-1355822363));
var inst_100095__$1 = cljs.core.get.call(null,inst_100092,new cljs.core.Keyword(null,"component","component",1555936782));
var inst_100096 = cljs.core.get.call(null,inst_100092,new cljs.core.Keyword(null,"offset","offset",296498311));
var inst_100097 = fluree.db.query.fql_parser.parse_db.call(null,db,inst_100071,opts_STAR_);
var inst_100098 = (inst_100095__$1 == null);
var inst_100099 = cljs.core.not.call(null,inst_100098);
var state_100381__$1 = (function (){var statearr_100448 = state_100381;
(statearr_100448[(18)] = inst_100097);

(statearr_100448[(10)] = inst_100093);

(statearr_100448[(8)] = inst_100094);

(statearr_100448[(9)] = inst_100096);

(statearr_100448[(29)] = inst_100095__$1);

return statearr_100448;
})();
if(inst_100099){
var statearr_100449_100612 = state_100381__$1;
(statearr_100449_100612[(1)] = (23));

} else {
var statearr_100450_100613 = state_100381__$1;
(statearr_100450_100613[(1)] = (24));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100382 === (90))){
var inst_100267 = cljs.core._deref.call(null,fuel);
var inst_100268 = (inst_100267 + (1));
var inst_100269 = cljs.core._vreset_BANG_.call(null,fuel,inst_100268);
var state_100381__$1 = state_100381;
var statearr_100451_100614 = state_100381__$1;
(statearr_100451_100614[(2)] = inst_100269);

(statearr_100451_100614[(1)] = (92));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100382 === (109))){
var inst_100290 = (state_100381[(12)]);
var state_100381__$1 = state_100381;
var statearr_100452_100615 = state_100381__$1;
(statearr_100452_100615[(2)] = inst_100290);

(statearr_100452_100615[(1)] = (110));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100382 === (36))){
var state_100381__$1 = state_100381;
var statearr_100453_100616 = state_100381__$1;
(statearr_100453_100616[(2)] = null);

(statearr_100453_100616[(1)] = (37));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100382 === (41))){
var state_100381__$1 = state_100381;
var statearr_100454_100617 = state_100381__$1;
(statearr_100454_100617[(2)] = from);

(statearr_100454_100617[(1)] = (43));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100382 === (118))){
var inst_100359 = (state_100381[(22)]);
var inst_100094 = (state_100381[(8)]);
var inst_100140 = (state_100381[(30)]);
var inst_100139 = (state_100381[(27)]);
var inst_100096 = (state_100381[(9)]);
var inst_100361 = fluree.db.query.fql.sort_offset_and_limit_res.call(null,inst_100139,inst_100140,inst_100096,inst_100094,inst_100359);
var state_100381__$1 = state_100381;
var statearr_100455_100618 = state_100381__$1;
(statearr_100455_100618[(2)] = inst_100361);

(statearr_100455_100618[(1)] = (120));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100382 === (89))){
var inst_100264 = (state_100381[(2)]);
var inst_100265 = fluree.db.util.async.throw_err.call(null,inst_100264);
var state_100381__$1 = (function (){var statearr_100456 = state_100381;
(statearr_100456[(23)] = inst_100265);

return statearr_100456;
})();
if(cljs.core.truth_(fuel)){
var statearr_100457_100619 = state_100381__$1;
(statearr_100457_100619[(1)] = (90));

} else {
var statearr_100458_100620 = state_100381__$1;
(statearr_100458_100620[(1)] = (91));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100382 === (100))){
var inst_100324 = (state_100381[(2)]);
var state_100381__$1 = state_100381;
var statearr_100459_100621 = state_100381__$1;
(statearr_100459_100621[(2)] = inst_100324);

(statearr_100459_100621[(1)] = (97));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100382 === (122))){
var state_100381__$1 = state_100381;
var statearr_100460_100622 = state_100381__$1;
(statearr_100460_100622[(2)] = selectOne);

(statearr_100460_100622[(1)] = (123));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100382 === (43))){
var inst_100147 = (state_100381[(2)]);
var inst_100148 = fluree.db.query.fql.where_filter.call(null,db,where,inst_100147);
var state_100381__$1 = state_100381;
return cljs.core.async.impl.ioc_helpers.take_BANG_.call(null,state_100381__$1,(44),inst_100148);
} else {
if((state_val_100382 === (61))){
var inst_100179 = (state_100381[(31)]);
var inst_100104 = (state_100381[(15)]);
var inst_100106 = (state_100381[(16)]);
var inst_100094 = (state_100381[(8)]);
var inst_100193 = (state_100381[(2)]);
var inst_100194 = fluree.db.util.async.throw_err.call(null,inst_100193);
var inst_100195 = cljs.core.sequence.call(null,inst_100179,inst_100194);
var inst_100196 = fluree.db.query.fql.subject_select.call(null,db,inst_100106,fuel,max_fuel,inst_100104,inst_100195,inst_100094);
var state_100381__$1 = state_100381;
return cljs.core.async.impl.ioc_helpers.take_BANG_.call(null,state_100381__$1,(62),inst_100196);
} else {
if((state_val_100382 === (29))){
var inst_100093 = (state_100381[(10)]);
var inst_100110 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_100111 = cljs.core.second.call(null,inst_100093);
var inst_100112 = cljs.core.first.call(null,inst_100093);
var inst_100113 = [inst_100111,inst_100112];
var inst_100114 = (new cljs.core.PersistentVector(null,2,(5),inst_100110,inst_100113,null));
var state_100381__$1 = state_100381;
var statearr_100461_100623 = state_100381__$1;
(statearr_100461_100623[(2)] = inst_100114);

(statearr_100461_100623[(1)] = (31));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100382 === (44))){
var inst_100093 = (state_100381[(10)]);
var inst_100150 = (state_100381[(2)]);
var inst_100151 = fluree.db.util.async.throw_err.call(null,inst_100150);
var state_100381__$1 = (function (){var statearr_100462 = state_100381;
(statearr_100462[(25)] = inst_100151);

return statearr_100462;
})();
if(cljs.core.truth_(inst_100093)){
var statearr_100463_100624 = state_100381__$1;
(statearr_100463_100624[(1)] = (46));

} else {
var statearr_100464_100625 = state_100381__$1;
(statearr_100464_100625[(1)] = (47));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100382 === (93))){
var inst_100285 = cljs.core.seq.call(null,from);
var inst_100286 = cljs.core.first.call(null,inst_100285);
var inst_100287 = cljs.core.next.call(null,inst_100285);
var inst_100288 = cljs.core.PersistentVector.EMPTY;
var inst_100289 = from;
var inst_100290 = inst_100288;
var state_100381__$1 = (function (){var statearr_100465 = state_100381;
(statearr_100465[(32)] = inst_100287);

(statearr_100465[(33)] = inst_100286);

(statearr_100465[(12)] = inst_100290);

(statearr_100465[(13)] = inst_100289);

return statearr_100465;
})();
var statearr_100466_100626 = state_100381__$1;
(statearr_100466_100626[(2)] = null);

(statearr_100466_100626[(1)] = (96));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100382 === (6))){
var state_100381__$1 = state_100381;
if(cljs.core.truth_(selectOne)){
var statearr_100467_100627 = state_100381__$1;
(statearr_100467_100627[(1)] = (8));

} else {
var statearr_100468_100628 = state_100381__$1;
(statearr_100468_100628[(1)] = (9));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100382 === (111))){
var inst_100335 = (state_100381[(2)]);
var inst_100336 = fluree.db.util.async.throw_err.call(null,inst_100335);
var state_100381__$1 = state_100381;
var statearr_100469_100629 = state_100381__$1;
(statearr_100469_100629[(2)] = inst_100336);

(statearr_100469_100629[(1)] = (95));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100382 === (28))){
var inst_100138 = (state_100381[(2)]);
var inst_100139 = cljs.core.nth.call(null,inst_100138,(0),null);
var inst_100140 = cljs.core.nth.call(null,inst_100138,(1),null);
var inst_100141 = typeof where === 'string';
var state_100381__$1 = (function (){var statearr_100470 = state_100381;
(statearr_100470[(30)] = inst_100140);

(statearr_100470[(27)] = inst_100139);

return statearr_100470;
})();
if(cljs.core.truth_(inst_100141)){
var statearr_100471_100630 = state_100381__$1;
(statearr_100471_100630[(1)] = (38));

} else {
var statearr_100472_100631 = state_100381__$1;
(statearr_100472_100631[(1)] = (39));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100382 === (64))){
var inst_100201 = (state_100381[(26)]);
var state_100381__$1 = state_100381;
var statearr_100473_100632 = state_100381__$1;
(statearr_100473_100632[(2)] = inst_100201);

(statearr_100473_100632[(1)] = (65));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100382 === (103))){
var inst_100316 = (state_100381[(28)]);
var inst_100316__$1 = (state_100381[(2)]);
var state_100381__$1 = (function (){var statearr_100474 = state_100381;
(statearr_100474[(28)] = inst_100316__$1);

return statearr_100474;
})();
if(cljs.core.truth_(inst_100316__$1)){
var statearr_100475_100633 = state_100381__$1;
(statearr_100475_100633[(1)] = (108));

} else {
var statearr_100476_100634 = state_100381__$1;
(statearr_100476_100634[(1)] = (109));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100382 === (51))){
var inst_100357 = (state_100381[(2)]);
var state_100381__$1 = state_100381;
var statearr_100477_100635 = state_100381__$1;
(statearr_100477_100635[(2)] = inst_100357);

(statearr_100477_100635[(1)] = (40));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100382 === (25))){
var inst_100093 = (state_100381[(10)]);
var inst_100104 = (state_100381[(2)]);
var inst_100105 = cljs.core.PersistentHashMap.EMPTY;
var inst_100106 = cljs.core.volatile_BANG_.call(null,inst_100105);
var state_100381__$1 = (function (){var statearr_100478 = state_100381;
(statearr_100478[(15)] = inst_100104);

(statearr_100478[(16)] = inst_100106);

return statearr_100478;
})();
if(cljs.core.truth_(inst_100093)){
var statearr_100479_100636 = state_100381__$1;
(statearr_100479_100636[(1)] = (26));

} else {
var statearr_100480_100637 = state_100381__$1;
(statearr_100480_100637[(1)] = (27));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100382 === (34))){
var inst_100130 = (state_100381[(2)]);
var state_100381__$1 = state_100381;
var statearr_100481_100638 = state_100381__$1;
(statearr_100481_100638[(2)] = inst_100130);

(statearr_100481_100638[(1)] = (31));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100382 === (125))){
var inst_100364 = (state_100381[(7)]);
var state_100381__$1 = state_100381;
var statearr_100482_100639 = state_100381__$1;
(statearr_100482_100639[(2)] = inst_100364);

(statearr_100482_100639[(1)] = (126));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100382 === (17))){
var state_100381__$1 = state_100381;
var statearr_100483_100640 = state_100381__$1;
(statearr_100483_100640[(2)] = true);

(statearr_100483_100640[(1)] = (19));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100382 === (3))){
var inst_100047 = (state_100381[(2)]);
var state_100381__$1 = state_100381;
var statearr_100484_100641 = state_100381__$1;
(statearr_100484_100641[(2)] = inst_100047);


cljs.core.async.impl.ioc_helpers.process_exception.call(null,state_100381__$1);

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100382 === (12))){
var inst_100061 = [new cljs.core.Keyword(null,"status","status",-1997798413),new cljs.core.Keyword(null,"error","error",-978969032)];
var inst_100062 = [(400),new cljs.core.Keyword("db","invalid-query","db/invalid-query",-1009699917)];
var inst_100063 = cljs.core.PersistentHashMap.fromArrays(inst_100061,inst_100062);
var inst_100064 = cljs.core.ex_info.call(null,"Query missing :select or :selectOne.",inst_100063);
var inst_100065 = (function(){throw inst_100064})();
var state_100381__$1 = state_100381;
var statearr_100485_100642 = state_100381__$1;
(statearr_100485_100642[(2)] = inst_100065);

(statearr_100485_100642[(1)] = (13));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100382 === (2))){
var inst_100379 = (state_100381[(2)]);
var state_100381__$1 = state_100381;
return cljs.core.async.impl.ioc_helpers.return_chan.call(null,state_100381__$1,inst_100379);
} else {
if((state_val_100382 === (66))){
var inst_100093 = (state_100381[(10)]);
var state_100381__$1 = state_100381;
if(cljs.core.truth_(inst_100093)){
var statearr_100486_100643 = state_100381__$1;
(statearr_100486_100643[(1)] = (69));

} else {
var statearr_100487_100644 = state_100381__$1;
(statearr_100487_100644[(1)] = (70));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100382 === (107))){
var inst_100313 = (state_100381[(2)]);
var inst_100314 = fluree.db.util.async.throw_err.call(null,inst_100313);
var state_100381__$1 = state_100381;
var statearr_100488_100645 = state_100381__$1;
(statearr_100488_100645[(2)] = inst_100314);

(statearr_100488_100645[(1)] = (103));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100382 === (23))){
var inst_100097 = (state_100381[(18)]);
var inst_100095 = (state_100381[(29)]);
var inst_100101 = cljs.core.assoc.call(null,inst_100097,new cljs.core.Keyword(null,"componentFollow?","componentFollow?",-1486906651),inst_100095);
var state_100381__$1 = state_100381;
var statearr_100489_100646 = state_100381__$1;
(statearr_100489_100646[(2)] = inst_100101);

(statearr_100489_100646[(1)] = (25));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100382 === (47))){
var inst_100094 = (state_100381[(8)]);
var state_100381__$1 = state_100381;
var statearr_100490_100647 = state_100381__$1;
(statearr_100490_100647[(2)] = inst_100094);

(statearr_100490_100647[(1)] = (48));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100382 === (35))){
var inst_100123 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_100124 = [null,null];
var inst_100125 = (new cljs.core.PersistentVector(null,2,(5),inst_100123,inst_100124,null));
var state_100381__$1 = state_100381;
var statearr_100491_100648 = state_100381__$1;
(statearr_100491_100648[(2)] = inst_100125);

(statearr_100491_100648[(1)] = (37));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100382 === (82))){
var inst_100250 = fluree.db.dbproto._subid.call(null,db,from,false);
var state_100381__$1 = state_100381;
return cljs.core.async.impl.ioc_helpers.take_BANG_.call(null,state_100381__$1,(85),inst_100250);
} else {
if((state_val_100382 === (76))){
var inst_100353 = (state_100381[(2)]);
var state_100381__$1 = state_100381;
var statearr_100492_100649 = state_100381__$1;
(statearr_100492_100649[(2)] = inst_100353);

(statearr_100492_100649[(1)] = (68));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100382 === (97))){
var inst_100093 = (state_100381[(10)]);
var inst_100326 = (state_100381[(2)]);
var inst_100327 = cljs.core.PersistentVector.EMPTY;
var inst_100328 = cljs.core.into.call(null,inst_100327,inst_100326);
var state_100381__$1 = (function (){var statearr_100493 = state_100381;
(statearr_100493[(34)] = inst_100328);

return statearr_100493;
})();
if(cljs.core.truth_(inst_100093)){
var statearr_100494_100650 = state_100381__$1;
(statearr_100494_100650[(1)] = (112));

} else {
var statearr_100495_100651 = state_100381__$1;
(statearr_100495_100651[(1)] = (113));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100382 === (19))){
var inst_100084 = (state_100381[(2)]);
var state_100381__$1 = state_100381;
var statearr_100496_100652 = state_100381__$1;
(statearr_100496_100652[(2)] = inst_100084);

(statearr_100496_100652[(1)] = (16));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100382 === (57))){
var inst_100093 = (state_100381[(10)]);
var inst_100179 = (state_100381[(2)]);
var state_100381__$1 = (function (){var statearr_100497 = state_100381;
(statearr_100497[(31)] = inst_100179);

return statearr_100497;
})();
if(cljs.core.truth_(inst_100093)){
var statearr_100498_100653 = state_100381__$1;
(statearr_100498_100653[(1)] = (58));

} else {
var statearr_100499_100654 = state_100381__$1;
(statearr_100499_100654[(1)] = (59));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100382 === (68))){
var inst_100355 = (state_100381[(2)]);
var state_100381__$1 = state_100381;
var statearr_100500_100655 = state_100381__$1;
(statearr_100500_100655[(2)] = inst_100355);

(statearr_100500_100655[(1)] = (51));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100382 === (11))){
var state_100381__$1 = state_100381;
var statearr_100501_100656 = state_100381__$1;
(statearr_100501_100656[(2)] = selectDistinct);

(statearr_100501_100656[(1)] = (13));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100382 === (115))){
var inst_100339 = cljs.core.pr_str.call(null,query_map);
var inst_100340 = ["Invalid 'from' in query:",inst_100339].join('');
var inst_100341 = [new cljs.core.Keyword(null,"status","status",-1997798413),new cljs.core.Keyword(null,"error","error",-978969032)];
var inst_100342 = [(400),new cljs.core.Keyword("db","invalid-query","db/invalid-query",-1009699917)];
var inst_100343 = cljs.core.PersistentHashMap.fromArrays(inst_100341,inst_100342);
var inst_100344 = cljs.core.ex_info.call(null,inst_100340,inst_100343);
var state_100381__$1 = state_100381;
var statearr_100502_100657 = state_100381__$1;
(statearr_100502_100657[(2)] = inst_100344);

(statearr_100502_100657[(1)] = (117));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100382 === (9))){
var state_100381__$1 = state_100381;
if(cljs.core.truth_(selectDistinct)){
var statearr_100503_100658 = state_100381__$1;
(statearr_100503_100658[(1)] = (11));

} else {
var statearr_100504_100659 = state_100381__$1;
(statearr_100504_100659[(1)] = (12));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100382 === (5))){
var state_100381__$1 = state_100381;
var statearr_100505_100660 = state_100381__$1;
(statearr_100505_100660[(2)] = select);

(statearr_100505_100660[(1)] = (7));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100382 === (112))){
var state_100381__$1 = state_100381;
var statearr_100506_100661 = state_100381__$1;
(statearr_100506_100661[(2)] = null);

(statearr_100506_100661[(1)] = (114));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100382 === (83))){
var inst_100274 = cljs.core.sequential_QMARK_.call(null,from);
var inst_100275 = cljs.core.every_QMARK_.call(null,fluree.db.util.core.subj_ident_QMARK_,from);
var inst_100276 = ((inst_100274) && (inst_100275));
var state_100381__$1 = state_100381;
if(cljs.core.truth_(inst_100276)){
var statearr_100507_100662 = state_100381__$1;
(statearr_100507_100662[(1)] = (93));

} else {
var statearr_100508_100663 = state_100381__$1;
(statearr_100508_100663[(1)] = (94));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100382 === (14))){
var inst_100076 = opts_STAR_.cljs$lang$protocol_mask$partition0$;
var inst_100077 = (inst_100076 & (64));
var inst_100078 = opts_STAR_.cljs$core$ISeq$;
var inst_100079 = (cljs.core.PROTOCOL_SENTINEL === inst_100078);
var inst_100080 = ((inst_100077) || (inst_100079));
var state_100381__$1 = state_100381;
if(cljs.core.truth_(inst_100080)){
var statearr_100509_100664 = state_100381__$1;
(statearr_100509_100664[(1)] = (17));

} else {
var statearr_100510_100665 = state_100381__$1;
(statearr_100510_100665[(1)] = (18));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100382 === (45))){
var inst_100158 = (state_100381[(2)]);
var inst_100159 = fluree.db.util.async.throw_err.call(null,inst_100158);
var state_100381__$1 = state_100381;
var statearr_100511_100666 = state_100381__$1;
(statearr_100511_100666[(2)] = inst_100159);

(statearr_100511_100666[(1)] = (40));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100382 === (53))){
var inst_100167 = (state_100381[(35)]);
var state_100381__$1 = state_100381;
var statearr_100512_100667 = state_100381__$1;
(statearr_100512_100667[(2)] = inst_100167);

(statearr_100512_100667[(1)] = (54));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100382 === (78))){
var inst_100094 = (state_100381[(8)]);
var inst_100096 = (state_100381[(9)]);
var inst_100233 = [new cljs.core.Keyword(null,"limit","limit",-1355822363),new cljs.core.Keyword(null,"offset","offset",296498311)];
var inst_100234 = [inst_100094,inst_100096];
var inst_100235 = cljs.core.PersistentHashMap.fromArrays(inst_100233,inst_100234);
var state_100381__$1 = state_100381;
var statearr_100513_100668 = state_100381__$1;
(statearr_100513_100668[(2)] = inst_100235);

(statearr_100513_100668[(1)] = (79));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100382 === (26))){
var inst_100093 = (state_100381[(10)]);
var inst_100108 = cljs.core.vector_QMARK_.call(null,inst_100093);
var state_100381__$1 = state_100381;
if(inst_100108){
var statearr_100514_100669 = state_100381__$1;
(statearr_100514_100669[(1)] = (29));

} else {
var statearr_100515_100670 = state_100381__$1;
(statearr_100515_100670[(1)] = (30));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100382 === (123))){
var inst_100372 = (state_100381[(2)]);
var state_100381__$1 = state_100381;
if(cljs.core.truth_(inst_100372)){
var statearr_100516_100671 = state_100381__$1;
(statearr_100516_100671[(1)] = (124));

} else {
var statearr_100517_100672 = state_100381__$1;
(statearr_100517_100672[(1)] = (125));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100382 === (16))){
var inst_100087 = (state_100381[(2)]);
var state_100381__$1 = state_100381;
if(cljs.core.truth_(inst_100087)){
var statearr_100518_100673 = state_100381__$1;
(statearr_100518_100673[(1)] = (20));

} else {
var statearr_100519_100674 = state_100381__$1;
(statearr_100519_100674[(1)] = (21));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100382 === (81))){
var inst_100244 = (state_100381[(2)]);
var inst_100245 = fluree.db.util.async.throw_err.call(null,inst_100244);
var state_100381__$1 = state_100381;
var statearr_100520_100675 = state_100381__$1;
(statearr_100520_100675[(2)] = inst_100245);

(statearr_100520_100675[(1)] = (76));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100382 === (120))){
var inst_100364 = (state_100381[(2)]);
var state_100381__$1 = (function (){var statearr_100521 = state_100381;
(statearr_100521[(7)] = inst_100364);

return statearr_100521;
})();
if(cljs.core.truth_(selectOne)){
var statearr_100522_100676 = state_100381__$1;
(statearr_100522_100676[(1)] = (121));

} else {
var statearr_100523_100677 = state_100381__$1;
(statearr_100523_100677[(1)] = (122));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100382 === (79))){
var inst_100237 = (state_100381[(2)]);
var inst_100238 = fluree.db.query.range.collection.call(null,db,from,inst_100237);
var state_100381__$1 = state_100381;
return cljs.core.async.impl.ioc_helpers.take_BANG_.call(null,state_100381__$1,(80),inst_100238);
} else {
if((state_val_100382 === (38))){
var inst_100143 = typeof from === 'string';
var state_100381__$1 = state_100381;
if(cljs.core.truth_(inst_100143)){
var statearr_100524_100678 = state_100381__$1;
(statearr_100524_100678[(1)] = (41));

} else {
var statearr_100525_100679 = state_100381__$1;
(statearr_100525_100679[(1)] = (42));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100382 === (126))){
var inst_100377 = (state_100381[(2)]);
var state_100381__$1 = state_100381;
var statearr_100526_100680 = state_100381__$1;
(statearr_100526_100680[(2)] = inst_100377);


cljs.core.async.impl.ioc_helpers.process_exception.call(null,state_100381__$1);

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100382 === (98))){
var inst_100290 = (state_100381[(12)]);
var state_100381__$1 = state_100381;
var statearr_100527_100681 = state_100381__$1;
(statearr_100527_100681[(2)] = inst_100290);

(statearr_100527_100681[(1)] = (100));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100382 === (124))){
var inst_100364 = (state_100381[(7)]);
var inst_100374 = cljs.core.first.call(null,inst_100364);
var state_100381__$1 = state_100381;
var statearr_100528_100682 = state_100381__$1;
(statearr_100528_100682[(2)] = inst_100374);

(statearr_100528_100682[(1)] = (126));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100382 === (87))){
var inst_100253 = (state_100381[(20)]);
var inst_100257 = cljs.core.PersistentVector.EMPTY_NODE;
var inst_100258 = [inst_100253];
var inst_100259 = (new cljs.core.PersistentVector(null,1,(5),inst_100257,inst_100258,null));
var state_100381__$1 = state_100381;
var statearr_100529_100683 = state_100381__$1;
(statearr_100529_100683[(2)] = inst_100259);

(statearr_100529_100683[(1)] = (88));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100382 === (30))){
var inst_100093 = (state_100381[(10)]);
var inst_100116 = typeof inst_100093 === 'string';
var state_100381__$1 = state_100381;
if(cljs.core.truth_(inst_100116)){
var statearr_100530_100684 = state_100381__$1;
(statearr_100530_100684[(1)] = (32));

} else {
var statearr_100531_100685 = state_100381__$1;
(statearr_100531_100685[(1)] = (33));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100382 === (73))){
var inst_100225 = (state_100381[(2)]);
var inst_100226 = fluree.db.util.async.throw_err.call(null,inst_100225);
var state_100381__$1 = state_100381;
var statearr_100532_100686 = state_100381__$1;
(statearr_100532_100686[(2)] = inst_100226);

(statearr_100532_100686[(1)] = (68));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100382 === (96))){
var inst_100289 = (state_100381[(13)]);
var inst_100296 = (state_100381[(17)]);
var inst_100295 = cljs.core.seq.call(null,inst_100289);
var inst_100296__$1 = cljs.core.first.call(null,inst_100295);
var inst_100297 = cljs.core.next.call(null,inst_100295);
var inst_100298 = cljs.core.not.call(null,inst_100296__$1);
var state_100381__$1 = (function (){var statearr_100533 = state_100381;
(statearr_100533[(17)] = inst_100296__$1);

(statearr_100533[(11)] = inst_100297);

return statearr_100533;
})();
if(inst_100298){
var statearr_100534_100687 = state_100381__$1;
(statearr_100534_100687[(1)] = (98));

} else {
var statearr_100535_100688 = state_100381__$1;
(statearr_100535_100688[(1)] = (99));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100382 === (10))){
var inst_100069 = (state_100381[(2)]);
var state_100381__$1 = state_100381;
var statearr_100536_100689 = state_100381__$1;
(statearr_100536_100689[(2)] = inst_100069);

(statearr_100536_100689[(1)] = (7));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100382 === (18))){
var state_100381__$1 = state_100381;
var statearr_100537_100690 = state_100381__$1;
(statearr_100537_100690[(2)] = false);

(statearr_100537_100690[(1)] = (19));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100382 === (105))){
var state_100381__$1 = state_100381;
var statearr_100538_100691 = state_100381__$1;
(statearr_100538_100691[(2)] = null);

(statearr_100538_100691[(1)] = (106));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100382 === (52))){
var inst_100167 = (state_100381[(35)]);
var inst_100169 = fluree.db.query.fql.fuel_flake_transducer.call(null,fuel,max_fuel);
var inst_100170 = cljs.core.comp.call(null,inst_100167,inst_100169);
var state_100381__$1 = state_100381;
var statearr_100539_100692 = state_100381__$1;
(statearr_100539_100692[(2)] = inst_100170);

(statearr_100539_100692[(1)] = (54));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100382 === (114))){
var inst_100328 = (state_100381[(34)]);
var inst_100104 = (state_100381[(15)]);
var inst_100106 = (state_100381[(16)]);
var inst_100096 = (state_100381[(9)]);
var inst_100332 = (state_100381[(2)]);
var inst_100333 = fluree.db.query.fql.subject_select.call(null,db,inst_100106,fuel,max_fuel,inst_100104,inst_100328,inst_100332,inst_100096);
var state_100381__$1 = state_100381;
return cljs.core.async.impl.ioc_helpers.take_BANG_.call(null,state_100381__$1,(111),inst_100333);
} else {
if((state_val_100382 === (67))){
var inst_100228 = typeof from === 'string';
var state_100381__$1 = state_100381;
if(cljs.core.truth_(inst_100228)){
var statearr_100540_100693 = state_100381__$1;
(statearr_100540_100693[(1)] = (74));

} else {
var statearr_100541_100694 = state_100381__$1;
(statearr_100541_100694[(1)] = (75));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100382 === (71))){
var inst_100218 = (state_100381[(2)]);
var inst_100219 = fluree.db.query.range._block_or_tx_collection.call(null,db,inst_100218);
var state_100381__$1 = state_100381;
return cljs.core.async.impl.ioc_helpers.take_BANG_.call(null,state_100381__$1,(72),inst_100219);
} else {
if((state_val_100382 === (42))){
var state_100381__$1 = state_100381;
var statearr_100542_100695 = state_100381__$1;
(statearr_100542_100695[(2)] = null);

(statearr_100542_100695[(1)] = (43));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100382 === (80))){
var inst_100104 = (state_100381[(15)]);
var inst_100106 = (state_100381[(16)]);
var inst_100240 = (state_100381[(2)]);
var inst_100241 = fluree.db.util.async.throw_err.call(null,inst_100240);
var inst_100242 = fluree.db.query.fql.flake_select.call(null,db,inst_100106,fuel,max_fuel,inst_100104,inst_100241);
var state_100381__$1 = state_100381;
return cljs.core.async.impl.ioc_helpers.take_BANG_.call(null,state_100381__$1,(81),inst_100242);
} else {
if((state_val_100382 === (37))){
var inst_100128 = (state_100381[(2)]);
var state_100381__$1 = state_100381;
var statearr_100543_100696 = state_100381__$1;
(statearr_100543_100696[(2)] = inst_100128);

(statearr_100543_100696[(1)] = (34));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100382 === (63))){
var inst_100203 = ["_tx",null,"_block",null];
var inst_100204 = (new cljs.core.PersistentArrayMap(null,2,inst_100203,null));
var inst_100205 = (new cljs.core.PersistentHashSet(null,inst_100204,null));
var inst_100206 = inst_100205.call(null,from);
var state_100381__$1 = state_100381;
var statearr_100544_100697 = state_100381__$1;
(statearr_100544_100697[(2)] = inst_100206);

(statearr_100544_100697[(1)] = (65));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100382 === (94))){
var state_100381__$1 = state_100381;
var statearr_100545_100698 = state_100381__$1;
(statearr_100545_100698[(1)] = (115));



return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100382 === (8))){
var state_100381__$1 = state_100381;
var statearr_100547_100699 = state_100381__$1;
(statearr_100547_100699[(2)] = selectOne);

(statearr_100547_100699[(1)] = (10));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100382 === (49))){
var inst_100167 = cljs.core.map.call(null,fluree.db.query.fql.s);
var state_100381__$1 = (function (){var statearr_100548 = state_100381;
(statearr_100548[(35)] = inst_100167);

return statearr_100548;
})();
if(cljs.core.truth_(fuel)){
var statearr_100549_100700 = state_100381__$1;
(statearr_100549_100700[(1)] = (52));

} else {
var statearr_100550_100701 = state_100381__$1;
(statearr_100550_100701[(1)] = (53));

}

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
if((state_val_100382 === (84))){
var inst_100351 = (state_100381[(2)]);
var state_100381__$1 = state_100381;
var statearr_100551_100702 = state_100381__$1;
(statearr_100551_100702[(2)] = inst_100351);

(statearr_100551_100702[(1)] = (76));


return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
return null;
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
}
});})(c__86675__auto__,max_fuel,fuel,map__100045,map__100045__$1,select,orderBy,where,limit,offset,component,selectDistinct,prettyPrint,selectOne,from,groupBy,opts_SINGLEQUOTE_,opts_SINGLEQUOTE__SINGLEQUOTE_,opts_STAR_))
;
return ((function (switch__86624__auto__,c__86675__auto__,max_fuel,fuel,map__100045,map__100045__$1,select,orderBy,where,limit,offset,component,selectDistinct,prettyPrint,selectOne,from,groupBy,opts_SINGLEQUOTE_,opts_SINGLEQUOTE__SINGLEQUOTE_,opts_STAR_){
return (function() {
var fluree$db$query$fql$state_machine__86625__auto__ = null;
var fluree$db$query$fql$state_machine__86625__auto____0 = (function (){
var statearr_100552 = [null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null];
(statearr_100552[(0)] = fluree$db$query$fql$state_machine__86625__auto__);

(statearr_100552[(1)] = (1));

return statearr_100552;
});
var fluree$db$query$fql$state_machine__86625__auto____1 = (function (state_100381){
while(true){
var ret_value__86626__auto__ = (function (){try{while(true){
var result__86627__auto__ = switch__86624__auto__.call(null,state_100381);
if(cljs.core.keyword_identical_QMARK_.call(null,result__86627__auto__,new cljs.core.Keyword(null,"recur","recur",-437573268))){
continue;
} else {
return result__86627__auto__;
}
break;
}
}catch (e100553){if((e100553 instanceof Object)){
var ex__86628__auto__ = e100553;
var statearr_100554_100703 = state_100381;
(statearr_100554_100703[(5)] = ex__86628__auto__);


cljs.core.async.impl.ioc_helpers.process_exception.call(null,state_100381);

return new cljs.core.Keyword(null,"recur","recur",-437573268);
} else {
throw e100553;

}
}})();
if(cljs.core.keyword_identical_QMARK_.call(null,ret_value__86626__auto__,new cljs.core.Keyword(null,"recur","recur",-437573268))){
var G__100704 = state_100381;
state_100381 = G__100704;
continue;
} else {
return ret_value__86626__auto__;
}
break;
}
});
fluree$db$query$fql$state_machine__86625__auto__ = function(state_100381){
switch(arguments.length){
case 0:
return fluree$db$query$fql$state_machine__86625__auto____0.call(this);
case 1:
return fluree$db$query$fql$state_machine__86625__auto____1.call(this,state_100381);
}
throw(new Error('Invalid arity: ' + arguments.length));
};
fluree$db$query$fql$state_machine__86625__auto__.cljs$core$IFn$_invoke$arity$0 = fluree$db$query$fql$state_machine__86625__auto____0;
fluree$db$query$fql$state_machine__86625__auto__.cljs$core$IFn$_invoke$arity$1 = fluree$db$query$fql$state_machine__86625__auto____1;
return fluree$db$query$fql$state_machine__86625__auto__;
})()
;})(switch__86624__auto__,c__86675__auto__,max_fuel,fuel,map__100045,map__100045__$1,select,orderBy,where,limit,offset,component,selectDistinct,prettyPrint,selectOne,from,groupBy,opts_SINGLEQUOTE_,opts_SINGLEQUOTE__SINGLEQUOTE_,opts_STAR_))
})();
var state__86677__auto__ = (function (){var statearr_100555 = f__86676__auto__.call(null);
(statearr_100555[(6)] = c__86675__auto__);

return statearr_100555;
})();
return cljs.core.async.impl.ioc_helpers.run_state_machine_wrapped.call(null,state__86677__auto__);
});})(c__86675__auto__,max_fuel,fuel,map__100045,map__100045__$1,select,orderBy,where,limit,offset,component,selectDistinct,prettyPrint,selectOne,from,groupBy,opts_SINGLEQUOTE_,opts_SINGLEQUOTE__SINGLEQUOTE_,opts_STAR_))
);

return c__86675__auto__;
}
}
});

fluree.db.query.fql.query.cljs$lang$maxFixedArity = 3;

